///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/blog/minigui-licensing-policy/>.
 */
/*
** fixedsys_8x15.c: Fixed system 8x15 VBF font data.
*/

#include <stdio.h>
#include <stdlib.h>

#include "common.h"
#include "minigui.h"
#include "gdi.h"
#include "devfont.h"

#ifdef _MGFONT_RBF
#ifdef _MGINCORERBF_LATIN1_FIXEDSYS

#include "rawbitmap.h"

/* Fixedsys 8x15 Font */

static const unsigned char font_data [] = {

/* Character   (0x00):
   ht=15, width=8
   +--------+
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   +--------+ */
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,

/* 0x01 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x02 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x03 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x04 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x05 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x06 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x07 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x08 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x09 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x0a */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x0b */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x0c */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x0d */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x0e */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x0f */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x10 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x11 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x12 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x13 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x14 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x15 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x16 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x17 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x18 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x19 */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x1a */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x1b */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x1c */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x1d */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x1e */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,
/* 0x1f */
0x00, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x7e, 0x00,

/* Character   (0x20):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ! (0x21):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |  ****  |
   |  ****  |
   |  ****  |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x3c,
0x3c,
0x3c,
0x18,
0x18,
0x00,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character " (0x22):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character # (0x23):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ** ** |
   |  ** ** |
   | *******|
   |  ** ** |
   |  ** ** |
   |  ** ** |
   | *******|
   |  ** ** |
   |  ** ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x36,
0x36,
0x7f,
0x36,
0x36,
0x36,
0x7f,
0x36,
0x36,
0x00,
0x00,
0x00,

/* Character $ (0x24):
   ht=15, width=8
   +--------+
   |        |
   |   **   |
   |   **   |
   |  ****  |
   | **  ** |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   | **  ** |
   |  ****  |
   |   **   |
   |   **   |
   |        |
   +--------+ */
0x00,
0x18,
0x18,
0x3c,
0x66,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x66,
0x3c,
0x18,
0x18,
0x00,

/* Character % (0x25):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | ***    |
   |** **   |
   |** ** * |
   | *** ** |
   |    **  |
   |   **   |
   |  **    |
   | ** *** |
   | * ** **|
   |   ** **|
   |    *** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x70,
0xd8,
0xda,
0x76,
0x0c,
0x18,
0x30,
0x6e,
0x5b,
0x1b,
0x0e,
0x00,
0x00,

/* Character & (0x26):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ***   |
   | ** **  |
   | ** **  |
   |  ***   |
   | **     |
   | ** ****|
   | **  ** |
   | **  ** |
   |  *** **|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x38,
0x6c,
0x6c,
0x38,
0x60,
0x6f,
0x66,
0x66,
0x3b,
0x00,
0x00,
0x00,

/* Character ' (0x27):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ( (0x28):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |    **  |
   |   **   |
   |   **   |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |   **   |
   |   **   |
   |    **  |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x0c,
0x18,
0x18,
0x30,
0x30,
0x30,
0x30,
0x30,
0x18,
0x18,
0x0c,
0x00,

/* Character ) (0x29):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  **    |
   |   **   |
   |   **   |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |   **   |
   |   **   |
   |  **    |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x30,
0x18,
0x18,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x18,
0x18,
0x30,
0x00,

/* Character * (0x2a):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ** ** |
   |   ***  |
   | *******|
   |   ***  |
   |  ** ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x36,
0x1c,
0x7f,
0x1c,
0x36,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character + (0x2b):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x7e,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character , (0x2c):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |    **  |
   |   **   |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x0c,
0x18,
0x00,

/* Character - (0x2d):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character . (0x2e):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x00,
0x00,
0x00,

/* Character / (0x2f):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |     ** |
   |     ** |
   |    **  |
   |    **  |
   |   **   |
   |   **   |
   |  **    |
   |  **    |
   | **     |
   | **     |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x06,
0x06,
0x0c,
0x0c,
0x18,
0x18,
0x30,
0x30,
0x60,
0x60,
0x00,
0x00,

/* Character 0 (0x30):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **** |
   |  **  **|
   |  ** ***|
   |  ** ***|
   |  **  **|
   |  *** **|
   |  *** **|
   |  **  **|
   |   **** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x1e,
0x33,
0x37,
0x37,
0x33,
0x3b,
0x3b,
0x33,
0x1e,
0x00,
0x00,
0x00,

/* Character 1 (0x31):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |    **  |
   |   ***  |
   | *****  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x0c,
0x1c,
0x7c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x00,
0x00,
0x00,

/* Character 2 (0x32):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character 3 (0x33):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   |     ** |
   |   ***  |
   |     ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x06,
0x1c,
0x06,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character 4 (0x34):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  **    |
   |  **    |
   |  ** ** |
   |  ** ** |
   |  ** ** |
   | **  ** |
   | *******|
   |     ** |
   |     ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x30,
0x30,
0x36,
0x36,
0x36,
0x66,
0x7f,
0x06,
0x06,
0x00,
0x00,
0x00,

/* Character 5 (0x35):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | **     |
   | **     |
   | **     |
   | *****  |
   |     ** |
   |     ** |
   |    **  |
   | ****   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x60,
0x60,
0x60,
0x7c,
0x06,
0x06,
0x0c,
0x78,
0x00,
0x00,
0x00,

/* Character 6 (0x36):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   ***  |
   |   **   |
   |  **    |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x1c,
0x18,
0x30,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character 7 (0x37):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   |     ** |
   |    **  |
   |    **  |
   |   **   |
   |   **   |
   |  **    |
   |  **    |
   |  **    |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x06,
0x0c,
0x0c,
0x18,
0x18,
0x30,
0x30,
0x30,
0x00,
0x00,
0x00,

/* Character 8 (0x38):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | *** ** |
   |  ****  |
   | ** *** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x76,
0x3c,
0x6e,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character 9 (0x39):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |    **  |
   |   **   |
   |  ***   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x0c,
0x18,
0x38,
0x00,
0x00,
0x00,

/* Character : (0x3a):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x00,
0x00,
0x00,

/* Character ; (0x3b):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |    **  |
   |   **   |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x0c,
0x18,
0x00,

/* Character < (0x3c):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x00,
0x00,
0x00,

/* Character = (0x3d):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character > (0x3e):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x00,
0x00,
0x00,

/* Character ? (0x3f):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   |    **  |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x0c,
0x18,
0x18,
0x00,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character @ (0x40):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   |**    **|
   |**    **|
   |**  ****|
   |** ** **|
   |** ** **|
   |**  ****|
   |**      |
   | *******|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0xc3,
0xc3,
0xcf,
0xdb,
0xdb,
0xcf,
0xc0,
0x7f,
0x00,
0x00,
0x00,

/* Character A (0x41):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | ****** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x3c,
0x66,
0x66,
0x66,
0x7e,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character B (0x42):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x7c,
0x66,
0x66,
0x66,
0x7c,
0x00,
0x00,
0x00,

/* Character C (0x43):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **     |
   | **     |
   | **     |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x60,
0x60,
0x60,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character D (0x44):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****   |
   | ** **  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | ** **  |
   | ****   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x78,
0x6c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x6c,
0x78,
0x00,
0x00,
0x00,

/* Character E (0x45):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **     |
   | **     |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x60,
0x60,
0x60,
0x7c,
0x60,
0x60,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character F (0x46):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **     |
   | **     |
   | **     |
   | **     |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x60,
0x60,
0x60,
0x7c,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character G (0x47):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **     |
   | **     |
   | ** *** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x60,
0x60,
0x6e,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character H (0x48):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | ****** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x7e,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character I (0x49):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,

/* Character J (0x4a):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |     ** |
   |     ** |
   |     ** |
   |     ** |
   |     ** |
   |     ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x06,
0x06,
0x06,
0x06,
0x06,
0x06,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character K (0x4b):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | ** **  |
   | ** **  |
   | ****   |
   | ** **  |
   | ** **  |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x6c,
0x6c,
0x78,
0x6c,
0x6c,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character L (0x4c):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character M (0x4d):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **   **|
   | **   **|
   | *** ***|
   | ** * **|
   | ** * **|
   | ** * **|
   | **   **|
   | **   **|
   | **   **|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x63,
0x63,
0x77,
0x6b,
0x6b,
0x6b,
0x63,
0x63,
0x63,
0x00,
0x00,
0x00,

/* Character N (0x4e):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **   **|
   | **   **|
   | ***  **|
   | **** **|
   | ** ****|
   | **  ***|
   | **   **|
   | **   **|
   | **   **|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x63,
0x63,
0x73,
0x7b,
0x6f,
0x67,
0x63,
0x63,
0x63,
0x00,
0x00,
0x00,

/* Character O (0x4f):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character P (0x50):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   | **     |
   | **     |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character Q (0x51):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |    **  |
   |     ** |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x0c,
0x06,
0x00,

/* Character R (0x52):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | ** **  |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x7c,
0x6c,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character S (0x53):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character T (0x54):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character U (0x55):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character V (0x56):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x18,
0x00,
0x00,
0x00,

/* Character W (0x57):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **   **|
   | **   **|
   | **   **|
   | ** * **|
   | ** * **|
   | ** * **|
   |  ** ** |
   |  ** ** |
   |  ** ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x63,
0x63,
0x63,
0x6b,
0x6b,
0x6b,
0x36,
0x36,
0x36,
0x00,
0x00,
0x00,

/* Character X (0x58):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   |  ** *  |
   |   **   |
   |   **   |
   |  * **  |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x34,
0x18,
0x18,
0x2c,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character Y (0x59):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character Z (0x5a):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   |     ** |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x06,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character [ (0x5b):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  ****  |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x3c,

/* Character \ (0x5c):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   |  **    |
   |  **    |
   |   **   |
   |   **   |
   |    **  |
   |    **  |
   |     ** |
   |     ** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x30,
0x30,
0x18,
0x18,
0x0c,
0x0c,
0x06,
0x06,
0x00,
0x00,

/* Character ] (0x5d):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |  ****  |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x3c,

/* Character ^ (0x5e):
   ht=15, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x66,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character _ (0x5f):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |********|
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,

/* Character ` (0x60):
   ht=15, width=8
   +--------+
   |        |
   |  ***   |
   |   **   |
   |    **  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x38,
0x18,
0x0c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character a (0x61):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character b (0x62):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x00,
0x00,
0x00,

/* Character c (0x63):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **     |
   | **     |
   | **     |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x60,
0x60,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character d (0x64):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character e (0x65):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x7e,
0x60,
0x60,
0x3c,
0x00,
0x00,
0x00,

/* Character f (0x66):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **** |
   |  **    |
   |  **    |
   |  **    |
   | ****** |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x1e,
0x30,
0x30,
0x30,
0x7e,
0x30,
0x30,
0x30,
0x30,
0x00,
0x00,
0x00,

/* Character g (0x67):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |     ** |
   |     ** |
   | *****  |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3e,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x06,
0x06,
0x7c,

/* Character h (0x68):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character i (0x69):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |   **   |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x18,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,
0x00,

/* Character j (0x6a):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |    **  |
   |    **  |
   |        |
   |  ****  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   | ****   |
   +--------+ */
0x00,
0x00,
0x0c,
0x0c,
0x00,
0x3c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x78,

/* Character k (0x6b):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | **  ** |
   | **  ** |
   | ** **  |
   | ****   |
   | ** **  |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x66,
0x66,
0x6c,
0x78,
0x6c,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character l (0x6c):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,
0x00,

/* Character m (0x6d):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   | ** * **|
   | ** * **|
   | ** * **|
   | ** * **|
   | ** * **|
   | **   **|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x6b,
0x6b,
0x6b,
0x6b,
0x6b,
0x63,
0x00,
0x00,
0x00,

/* Character n (0x6e):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character o (0x6f):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character p (0x70):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   | **     |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0x60,

/* Character q (0x71):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |     ** |
   |     ** |
   |     ** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3e,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x06,
0x06,
0x06,

/* Character r (0x72):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | ** *** |
   | ***    |
   | **     |
   | **     |
   | **     |
   | **     |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x6e,
0x70,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character s (0x73):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***** |
   | **     |
   | **     |
   |  ****  |
   |     ** |
   |     ** |
   | *****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3e,
0x60,
0x60,
0x3c,
0x06,
0x06,
0x7c,
0x00,
0x00,
0x00,

/* Character t (0x74):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  **    |
   |  **    |
   | ****** |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |   **** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x30,
0x30,
0x7e,
0x30,
0x30,
0x30,
0x30,
0x30,
0x1e,
0x00,
0x00,
0x00,

/* Character u (0x75):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character v (0x76):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x18,
0x00,
0x00,
0x00,

/* Character w (0x77):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **   **|
   | ** * **|
   | ** * **|
   | ** * **|
   | ** * **|
   |  ** ** |
   |  ** ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x63,
0x6b,
0x6b,
0x6b,
0x6b,
0x36,
0x36,
0x00,
0x00,
0x00,

/* Character x (0x78):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x3c,
0x18,
0x3c,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character y (0x79):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |    **  |
   |   **   |
   |****    |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x0c,
0x18,
0xf0,

/* Character z (0x7a):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character { (0x7b):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |    **  |
   |   **   |
   |   **   |
   |   **   |
   |  **    |
   | **     |
   |  **    |
   |   **   |
   |   **   |
   |   **   |
   |    **  |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x0c,
0x18,
0x18,
0x18,
0x30,
0x60,
0x30,
0x18,
0x18,
0x18,
0x0c,
0x00,

/* Character | (0x7c):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character } (0x7d):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  **    |
   |   **   |
   |   **   |
   |   **   |
   |    **  |
   |     ** |
   |    **  |
   |   **   |
   |   **   |
   |   **   |
   |  **    |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x30,
0x18,
0x18,
0x18,
0x0c,
0x06,
0x0c,
0x18,
0x18,
0x18,
0x30,
0x00,

/* Character ~ (0x7e):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ***   *|
   |** ** **|
   |*   *** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x71,
0xdb,
0x8e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character  (0x7f):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ? (0x80):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x81):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x82):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x83):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x84):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x85):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x86):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x87):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x88):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x89):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x8a):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x8b):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x8c):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x8d):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x8e):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x8f):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x90):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x91):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |    **  |
   |   **   |
   |   ***  |
   |   ***  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x0c,
0x18,
0x1c,
0x1c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0x92):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |    **  |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x0c,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0x93):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x94):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x95):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x96):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x97):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x98):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x99):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x9a):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x9b):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x9c):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x9d):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x9e):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0x9f):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xa0):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa1):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |  ****  |
   |  ****  |
   |  ****  |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x00,
0x18,
0x18,
0x3c,
0x3c,
0x3c,
0x18,

/* Character ?(0xa2):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |  ****  |
   | **  ** |
   | **     |
   | **     |
   | **  ** |
   |  ****  |
   |   **   |
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x18,
0x3c,
0x66,
0x60,
0x60,
0x66,
0x3c,
0x18,
0x18,
0x00,
0x00,

/* Character ?(0xa3):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **     |
   | **     |
   |******  |
   | **     |
   | **     |
   |**      |
   |******* |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x60,
0xfc,
0x60,
0x60,
0xc0,
0xfe,
0x00,
0x00,
0x00,

/* Character ?(0xa4):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   |  ****  |
   | **  ** |
   | **  ** |
   |  ****  |
   | **  ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x66,
0x3c,
0x66,
0x66,
0x3c,
0x66,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa5):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   | ****** |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x3c,
0x7e,
0x18,
0x7e,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character ?(0xa6):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xa7):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **     |
   |  ***   |
   |  ****  |
   | **  ** |
   | **  ** |
   |  ****  |
   |   ***  |
   |     ** |
   | **  ** |
   |  ****  |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x38,
0x3c,
0x66,
0x66,
0x3c,
0x1c,
0x06,
0x66,
0x3c,

/* Character ?(0xa8):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x66,
0x66,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa9):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   |**    **|
   |*  **  *|
   |* *  * *|
   |* *    *|
   |* *  * *|
   |*  **  *|
   |**    **|
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0xc3,
0x99,
0xa5,
0xa1,
0xa5,
0x99,
0xc3,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xaa):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   |     ** |
   |  ***** |
   | **  ** |
   |  ***** |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x06,
0x3e,
0x66,
0x3e,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xab):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  **  **|
   | **  ** |
   |**  **  |
   | **  ** |
   |  **  **|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x33,
0x66,
0xcc,
0x66,
0x33,
0x00,
0x00,
0x00,

/* Character ?(0xac):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |     ** |
   |     ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x06,
0x06,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xad):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xae):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   |**    **|
   |* ***  *|
   |* *  * *|
   |* *  * *|
   |* ***  *|
   |* *  * *|
   |**    **|
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0xc3,
0xb9,
0xa5,
0xa5,
0xb9,
0xa5,
0xc3,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xaf):
   ht=15, width=8
   +--------+
   |********|
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0xff,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb0):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb1):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x7e,
0x18,
0x18,
0x00,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xb2):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ***   |
   |    **  |
   |   **   |
   |  **    |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x38,
0x0c,
0x18,
0x30,
0x3c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb3):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ***   |
   |    **  |
   |   **   |
   |    **  |
   |  ***   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x38,
0x0c,
0x18,
0x0c,
0x38,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb4):
   ht=15, width=8
   +--------+
   |        |
   |   ***  |
   |   **   |
   |  **    |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x1c,
0x18,
0x30,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb5):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **** **|
   | **     |
   | **     |
   |**      |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x7b,
0x60,
0x60,
0xc0,

/* Character ?(0xb6):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   *****|
   |  ***** |
   | ****** |
   | ****** |
   | ****** |
   |  ***** |
   |   **** |
   |     ** |
   |     ** |
   |     ** |
   |     ** |
   |     ** |
   +--------+ */
0x00,
0x00,
0x00,
0x1f,
0x3e,
0x7e,
0x7e,
0x7e,
0x3e,
0x1e,
0x06,
0x06,
0x06,
0x06,
0x06,

/* Character ?(0xb7):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb8):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |    **  |
   |  ***   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x0c,
0x38,

/* Character ?(0xb9):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |  ***   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x38,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xba):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbb):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |**  **  |
   | **  ** |
   |  **  **|
   | **  ** |
   |**  **  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xcc,
0x66,
0x33,
0x66,
0xcc,
0x00,
0x00,
0x00,

/* Character ?(0xbc):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **     |
   |***     |
   | **   **|
   | **  ** |
   | ** **  |
   |   **   |
   |  ** ***|
   | ** ****|
   |** ** **|
   |   *****|
   |      **|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x60,
0xe0,
0x63,
0x66,
0x6c,
0x18,
0x37,
0x6f,
0xdb,
0x1f,
0x03,
0x00,
0x00,

/* Character ?(0xbd):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **     |
   |***     |
   | **   **|
   | **  ** |
   | ** **  |
   |   **   |
   |  ***** |
   | **   **|
   |**   ** |
   |    **  |
   |    ****|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x60,
0xe0,
0x63,
0x66,
0x6c,
0x18,
0x3e,
0x63,
0xc6,
0x0c,
0x0f,
0x00,
0x00,

/* Character ?(0xbe):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |***     |
   |  **    |
   | **   **|
   |  ** ** |
   |*** **  |
   |   **   |
   |  ** ***|
   | ** ****|
   |** ** **|
   |   *****|
   |      **|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xe0,
0x30,
0x63,
0x36,
0xec,
0x18,
0x37,
0x6f,
0xdb,
0x1f,
0x03,
0x00,
0x00,

/* Character ?(0xbf):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |  **    |
   | **  ** |
   | **  ** |
   |  ****  |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x00,
0x18,
0x18,
0x30,
0x66,
0x66,
0x3c,

/* Character ?(0xc0):
   ht=15, width=8
   +--------+
   |  **    |
   |   **   |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | ****** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x30,
0x18,
0x00,
0x18,
0x3c,
0x66,
0x66,
0x66,
0x7e,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character ?(0xc1):
   ht=15, width=8
   +--------+
   |    **  |
   |   **   |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | ****** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x00,
0x18,
0x3c,
0x66,
0x66,
0x66,
0x7e,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character ?(0xc2):
   ht=15, width=8
   +--------+
   |  ****  |
   | **  ** |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | ****** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x3c,
0x66,
0x00,
0x18,
0x3c,
0x66,
0x66,
0x66,
0x7e,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character ?(0xc3):
   ht=15, width=8
   +--------+
   |  *** **|
   | ** *** |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | ****** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x3b,
0x6e,
0x00,
0x18,
0x3c,
0x66,
0x66,
0x66,
0x7e,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character ?(0xc4):
   ht=15, width=8
   +--------+
   | **  ** |
   | **  ** |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | ****** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x00,
0x18,
0x3c,
0x66,
0x66,
0x66,
0x7e,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character ?(0xc5):
   ht=15, width=8
   +--------+
   |  ****  |
   | **  ** |
   |  ****  |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | ****** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x3c,
0x66,
0x3c,
0x18,
0x3c,
0x66,
0x66,
0x66,
0x7e,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character ?(0xc6):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |    ****|
   |   ***  |
   |  ****  |
   | ** **  |
   | ** ****|
   | *****  |
   | ** **  |
   | ** **  |
   | ** ****|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x0f,
0x1c,
0x3c,
0x6c,
0x6f,
0x7c,
0x6c,
0x6c,
0x6f,
0x00,
0x00,
0x00,

/* Character ?(0xc7):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **     |
   | **     |
   | **     |
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   |    **  |
   |  ***   |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x60,
0x60,
0x60,
0x66,
0x66,
0x3c,
0x18,
0x0c,
0x38,

/* Character ?(0xc8):
   ht=15, width=8
   +--------+
   |  **    |
   |   **   |
   |        |
   | ****** |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **     |
   | **     |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x30,
0x18,
0x00,
0x7e,
0x60,
0x60,
0x60,
0x7c,
0x60,
0x60,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xc9):
   ht=15, width=8
   +--------+
   |    **  |
   |   **   |
   |        |
   | ****** |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **     |
   | **     |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x00,
0x7e,
0x60,
0x60,
0x60,
0x7c,
0x60,
0x60,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xca):
   ht=15, width=8
   +--------+
   |  ****  |
   | **  ** |
   |        |
   | ****** |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **     |
   | **     |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x3c,
0x66,
0x00,
0x7e,
0x60,
0x60,
0x60,
0x7c,
0x60,
0x60,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xcb):
   ht=15, width=8
   +--------+
   | **  ** |
   | **  ** |
   |        |
   | ****** |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **     |
   | **     |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x00,
0x7e,
0x60,
0x60,
0x60,
0x7c,
0x60,
0x60,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xcc):
   ht=15, width=8
   +--------+
   |  **    |
   |   **   |
   |        |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x30,
0x18,
0x00,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xcd):
   ht=15, width=8
   +--------+
   |    **  |
   |   **   |
   |        |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x00,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xce):
   ht=15, width=8
   +--------+
   |  ****  |
   | **  ** |
   |        |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x3c,
0x66,
0x00,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xcf):
   ht=15, width=8
   +--------+
   | **  ** |
   | **  ** |
   |        |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x00,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xd0):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****   |
   | ** **  |
   | **  ** |
   | **  ** |
   |**** ** |
   | **  ** |
   | **  ** |
   | ** **  |
   | ****   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x78,
0x6c,
0x66,
0x66,
0xf6,
0x66,
0x66,
0x6c,
0x78,
0x00,
0x00,
0x00,

/* Character ?(0xd1):
   ht=15, width=8
   +--------+
   |  *** **|
   | ** *** |
   |        |
   | **   **|
   | **   **|
   | ***  **|
   | **** **|
   | ** ****|
   | **  ***|
   | **   **|
   | **   **|
   | **   **|
   |        |
   |        |
   |        |
   +--------+ */
0x3b,
0x6e,
0x00,
0x63,
0x63,
0x73,
0x7b,
0x6f,
0x67,
0x63,
0x63,
0x63,
0x00,
0x00,
0x00,

/* Character ?(0xd2):
   ht=15, width=8
   +--------+
   |  **    |
   |   **   |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x30,
0x18,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xd3):
   ht=15, width=8
   +--------+
   |    **  |
   |   **   |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xd4):
   ht=15, width=8
   +--------+
   |  ****  |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x3c,
0x66,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xd5):
   ht=15, width=8
   +--------+
   |  *** **|
   | ** *** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x3b,
0x6e,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xd6):
   ht=15, width=8
   +--------+
   | **  ** |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xd7):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | *    * |
   | **  ** |
   |  ****  |
   |   **   |
   |  ****  |
   | **  ** |
   | *    * |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x42,
0x66,
0x3c,
0x18,
0x3c,
0x66,
0x42,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd8):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ***** |
   | **  ** |
   | ** *** |
   | ** *** |
   | ****** |
   | *** ** |
   | *** ** |
   | **  ** |
   | *****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3e,
0x66,
0x6e,
0x6e,
0x7e,
0x76,
0x76,
0x66,
0x7c,
0x00,
0x00,
0x00,

/* Character ?(0xd9):
   ht=15, width=8
   +--------+
   |  **    |
   |   **   |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x30,
0x18,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xda):
   ht=15, width=8
   +--------+
   |    **  |
   |   **   |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xdb):
   ht=15, width=8
   +--------+
   |  ****  |
   | **  ** |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x3c,
0x66,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xdc):
   ht=15, width=8
   +--------+
   | **  ** |
   | **  ** |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xdd):
   ht=15, width=8
   +--------+
   |    **  |
   |   **   |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x00,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character ?(0xde):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xdf):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ***   |
   | ** **  |
   | ** **  |
   | ** **  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | ** **  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x38,
0x6c,
0x6c,
0x6c,
0x66,
0x66,
0x66,
0x66,
0x6c,
0x00,
0x00,
0x00,

/* Character ?(0xe0):
   ht=15, width=8
   +--------+
   |        |
   | ***    |
   |  **    |
   |   **   |
   |        |
   |  ****  |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x70,
0x30,
0x18,
0x00,
0x3c,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe1):
   ht=15, width=8
   +--------+
   |        |
   |    *** |
   |    **  |
   |   **   |
   |        |
   |  ****  |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x0e,
0x0c,
0x18,
0x00,
0x3c,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe2):
   ht=15, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   |  ****  |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x66,
0x00,
0x3c,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe3):
   ht=15, width=8
   +--------+
   |        |
   | ***   *|
   |** ** **|
   |*   *** |
   |        |
   |  ****  |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x71,
0xdb,
0x8e,
0x00,
0x3c,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe4):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |  ****  |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x66,
0x66,
0x00,
0x3c,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe5):
   ht=15, width=8
   +--------+
   |        |
   |  ****  |
   | **  ** |
   |  ****  |
   |        |
   |  ****  |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x66,
0x3c,
0x00,
0x3c,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe6):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | ** *** |
   |   ** **|
   |   ** **|
   | *******|
   |** **   |
   |** **   |
   | *** ***|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x6e,
0x1b,
0x1b,
0x7f,
0xd8,
0xd8,
0x77,
0x00,
0x00,
0x00,

/* Character ?(0xe7):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **     |
   | **     |
   | **     |
   | **  ** |
   |  ****  |
   |   **   |
   |    **  |
   |  ***   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x60,
0x60,
0x66,
0x3c,
0x18,
0x0c,
0x38,

/* Character ?(0xe8):
   ht=15, width=8
   +--------+
   |        |
   | ***    |
   |  **    |
   |   **   |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x70,
0x30,
0x18,
0x00,
0x3c,
0x66,
0x66,
0x7e,
0x60,
0x60,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xe9):
   ht=15, width=8
   +--------+
   |        |
   |    *** |
   |    **  |
   |   **   |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x0e,
0x0c,
0x18,
0x00,
0x3c,
0x66,
0x66,
0x7e,
0x60,
0x60,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xea):
   ht=15, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x66,
0x00,
0x3c,
0x66,
0x66,
0x7e,
0x60,
0x60,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xeb):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x66,
0x66,
0x00,
0x3c,
0x66,
0x66,
0x7e,
0x60,
0x60,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xec):
   ht=15, width=8
   +--------+
   |        |
   | ***    |
   |  **    |
   |   **   |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x70,
0x30,
0x18,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xed):
   ht=15, width=8
   +--------+
   |        |
   |    *** |
   |    **  |
   |   **   |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x0e,
0x0c,
0x18,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xee):
   ht=15, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x66,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xef):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x66,
0x66,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xf0):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ** ** |
   |   **   |
   | ** **  |
   |   **** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x36,
0x18,
0x6c,
0x1e,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf1):
   ht=15, width=8
   +--------+
   |        |
   | ***   *|
   |** ** **|
   |*   *** |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x71,
0xdb,
0x8e,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character ?(0xf2):
   ht=15, width=8
   +--------+
   |        |
   | ***    |
   |  **    |
   |   **   |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x70,
0x30,
0x18,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf3):
   ht=15, width=8
   +--------+
   |        |
   |    *** |
   |    **  |
   |   **   |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x0e,
0x0c,
0x18,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf4):
   ht=15, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x66,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf5):
   ht=15, width=8
   +--------+
   |        |
   | ***   *|
   |** ** **|
   |*   *** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x71,
0xdb,
0x8e,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf6):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x66,
0x66,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf7):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |        |
   | ****** |
   |        |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x00,
0x7e,
0x00,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xf8):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***** |
   | **  ** |
   | ** *** |
   | ****** |
   | *** ** |
   | **  ** |
   | *****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3e,
0x66,
0x6e,
0x7e,
0x76,
0x66,
0x7c,
0x00,
0x00,
0x00,

/* Character ?(0xf9):
   ht=15, width=8
   +--------+
   |        |
   | ***    |
   |  **    |
   |   **   |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x70,
0x30,
0x18,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xfa):
   ht=15, width=8
   +--------+
   |        |
   |    *** |
   |    **  |
   |   **   |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x0e,
0x0c,
0x18,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xfb):
   ht=15, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x66,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xfc):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x66,
0x66,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xfd):
   ht=15, width=8
   +--------+
   |        |
   |    *** |
   |    **  |
   |   **   |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |    **  |
   |   **   |
   |****    |
   +--------+ */
0x00,
0x0e,
0x0c,
0x18,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x0c,
0x18,
0xf0,

/* Character ?(0xfe):
   ht=15, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   | **     |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0x60,

/* Character ? (0xff):
   ht=15, width=8
   +--------+
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |    **  |
   |   **   |
   |****    |
   +--------+ */
0x00,
0x00,
0x66,
0x66,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x0c,
0x18,
0xf0,

};

static RBFINFO rbfinfo = {
    sizeof(font_data)/ (((8+7)>>3) * (15)), 
    8, 15, 
    (unsigned char*) font_data, sizeof(font_data),
};

/* Exported structure definition. */
INCORE_RBFINFO __mgif_rbf_fixedsys_8x15 = {
    "rbf-FixedSys-rrncnn-8-15-ISO8859-1",
    &rbfinfo 
};
#endif /* _MGINCORERBF_LATIN1_FIXEDSYS */
#endif /* _MGFONT_RBF */

