///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/blog/minigui-licensing-policy/>.
 */
/*
** terminal_8x12.c: Terminal 8x12 VBF font data.
*/

#include <stdio.h>
#include <stdlib.h>

#include "common.h"
#include "minigui.h"
#include "gdi.h"
#include "devfont.h"

#ifdef _MGFONT_RBF
#ifdef _MGINCORERBF_LATIN1_TERMINAL

#include "rawbitmap.h"

static const unsigned char font_data [] = {

/* Character   (0x00):
   ht=12, width=8
   +--------+
   |        |
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |        |
   |        |
   +--------+ */
0x00,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0x00,
0x00,

/* Character   (0x01):
   ht=12, width=8
   +--------+
   |        |
   | ****** |
   |**    **|
   |*      *|
   |* *  * *|
   |*      *|
   |* **** *|
   |*  **  *|
   |**    **|
   | ****** |
   |        |
   |        |
   +--------+ */
0x00,
0x7e,
0xc3,
0x81,
0xa5,
0x81,
0xbd,
0x99,
0xc3,
0x7e,
0x00,
0x00,

/* Character   (0x02):
   ht=12, width=8
   +--------+
   |        |
   | ****** |
   |********|
   |********|
   |** ** **|
   |********|
   |**    **|
   |***  ***|
   |********|
   | ****** |
   |        |
   |        |
   +--------+ */
0x00,
0x7e,
0xff,
0xff,
0xdb,
0xff,
0xc3,
0xe7,
0xff,
0x7e,
0x00,
0x00,

/* Character   (0x03):
   ht=12, width=8
   +--------+
   |        |
   |        |
   | *   *  |
   |*** *** |
   |******* |
   |******* |
   |******* |
   | *****  |
   |  ***   |
   |   *    |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x44,
0xee,
0xfe,
0xfe,
0xfe,
0x7c,
0x38,
0x10,
0x00,
0x00,

/* Character   (0x04):
   ht=12, width=8
   +--------+
   |        |
   |   *    |
   |  ***   |
   | *****  |
   |******* |
   |******* |
   | *****  |
   |  ***   |
   |   *    |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x10,
0x38,
0x7c,
0xfe,
0xfe,
0x7c,
0x38,
0x10,
0x00,
0x00,
0x00,

/* Character   (0x05):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   |  ****  |
   |********|
   |***  ***|
   |***  ***|
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x3c,
0xff,
0xe7,
0xe7,
0x18,
0x18,
0x7e,
0x00,
0x00,

/* Character   (0x06):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | ****** |
   |********|
   |********|
   | ****** |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x7e,
0xff,
0xff,
0x7e,
0x18,
0x18,
0x7e,
0x00,
0x00,

/* Character   (0x07):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | ****** |
   | ****** |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x3c,
0x7e,
0x7e,
0x3c,
0x00,
0x00,
0x00,
0x00,

/* Character   (0x08):
   ht=12, width=8
   +--------+
   |********|
   |********|
   |********|
   |********|
   |**    **|
   |*      *|
   |*      *|
   |**    **|
   |********|
   |********|
   |********|
   |********|
   +--------+ */
0xff,
0xff,
0xff,
0xff,
0xc3,
0x81,
0x81,
0xc3,
0xff,
0xff,
0xff,
0xff,

/* Character   (0x09):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   | ****** |
   | **  ** |
   | *    * |
   | *    * |
   | **  ** |
   | ****** |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x7e,
0x66,
0x42,
0x42,
0x66,
0x7e,
0x3c,
0x00,
0x00,

/* Character   (0x0a):
   ht=12, width=8
   +--------+
   |********|
   |********|
   |**    **|
   |*      *|
   |*  **  *|
   |* **** *|
   |* **** *|
   |*  **  *|
   |*      *|
   |**    **|
   |********|
   |********|
   +--------+ */
0xff,
0xff,
0xc3,
0x81,
0x99,
0xbd,
0xbd,
0x99,
0x81,
0xc3,
0xff,
0xff,

/* Character   (0x0b):
   ht=12, width=8
   +--------+
   |        |
   |  ***** |
   |    *** |
   |  *** * |
   | ***  * |
   |*****   |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x3e,
0x0e,
0x3a,
0x72,
0xf8,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character   (0x0c):
   ht=12, width=8
   +--------+
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x66,
0x66,
0x66,
0x3c,
0x18,
0x7e,
0x18,
0x18,
0x00,
0x00,

/* Character   (0x0d):
   ht=12, width=8
   +--------+
   |        |
   |   *****|
   |   **  *|
   |   **  *|
   |   *****|
   |   **   |
   |   **   |
   | ****   |
   |*****   |
   | ***    |
   |        |
   |        |
   +--------+ */
0x00,
0x1f,
0x19,
0x19,
0x1f,
0x18,
0x18,
0x78,
0xf8,
0x70,
0x00,
0x00,

/* Character   (0x0e):
   ht=12, width=8
   +--------+
   |        |
   | *******|
   | **   **|
   | *******|
   | **   **|
   | **   **|
   | **   **|
   | **  ***|
   |***  ***|
   |***  ** |
   |**      |
   |        |
   +--------+ */
0x00,
0x7f,
0x63,
0x7f,
0x63,
0x63,
0x63,
0x67,
0xe7,
0xe6,
0xc0,
0x00,

/* Character   (0x0f):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |** ** **|
   | ****** |
   |***  ***|
   |***  ***|
   | ****** |
   |** ** **|
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0xdb,
0x7e,
0xe7,
0xe7,
0x7e,
0xdb,
0x18,
0x00,
0x00,

/* Character   (0x10):
   ht=12, width=8
   +--------+
   |        |
   |*       |
   |**      |
   |***     |
   |*****   |
   |******* |
   |*****   |
   |***     |
   |**      |
   |*       |
   |        |
   |        |
   +--------+ */
0x00,
0x80,
0xc0,
0xe0,
0xf8,
0xfe,
0xf8,
0xe0,
0xc0,
0x80,
0x00,
0x00,

/* Character   (0x11):
   ht=12, width=8
   +--------+
   |        |
   |      * |
   |     ** |
   |    *** |
   |  ***** |
   |******* |
   |  ***** |
   |    *** |
   |     ** |
   |      * |
   |        |
   |        |
   +--------+ */
0x00,
0x02,
0x06,
0x0e,
0x3e,
0xfe,
0x3e,
0x0e,
0x06,
0x02,
0x00,
0x00,

/* Character   (0x12):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | ****** |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |  ****  |
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x7e,
0x18,
0x18,
0x18,
0x7e,
0x3c,
0x18,
0x00,
0x00,

/* Character   (0x13):
   ht=12, width=8
   +--------+
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |        |
   +--------+ */
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x66,
0x66,
0x00,
0x00,

/* Character   (0x14):
   ht=12, width=8
   +--------+
   |        |
   | *******|
   |** ** **|
   |** ** **|
   |** ** **|
   | **** **|
   |   ** **|
   |   ** **|
   |   ** **|
   |   ** **|
   |        |
   |        |
   +--------+ */
0x00,
0x7f,
0xdb,
0xdb,
0xdb,
0x7b,
0x1b,
0x1b,
0x1b,
0x1b,
0x00,
0x00,

/* Character   (0x15):
   ht=12, width=8
   +--------+
   |        |
   | ****** |
   | **   **|
   |  **    |
   |  ****  |
   | **  ** |
   | **  ** |
   |  ****  |
   |    **  |
   |**   ** |
   | ****** |
   |        |
   +--------+ */
0x00,
0x7e,
0x63,
0x30,
0x3c,
0x66,
0x66,
0x3c,
0x0c,
0xc6,
0x7e,
0x00,

/* Character   (0x16):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |******* |
   |******* |
   |******* |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xfe,
0xfe,
0xfe,
0x00,
0x00,

/* Character   (0x17):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | ****** |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |  ****  |
   |   **   |
   | ****** |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x7e,
0x18,
0x18,
0x18,
0x7e,
0x3c,
0x18,
0x7e,
0x00,

/* Character   (0x18):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |  ****  |
   | ****** |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x3c,
0x7e,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,

/* Character   (0x19):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |  ****  |
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x3c,
0x18,
0x00,
0x00,

/* Character   (0x1a):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |    **  |
   |******* |
   |    **  |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x0c,
0xfe,
0x0c,
0x18,
0x00,
0x00,
0x00,
0x00,

/* Character   (0x1b):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |  **    |
   | **     |
   |******* |
   | **     |
   |  **    |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x30,
0x60,
0xfe,
0x60,
0x30,
0x00,
0x00,
0x00,
0x00,

/* Character   (0x1c):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |**      |
   |**      |
   |**      |
   |******* |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xc0,
0xc0,
0xc0,
0xfe,
0x00,
0x00,
0x00,
0x00,

/* Character   (0x1d):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |  *  *  |
   | **  ** |
   |********|
   | **  ** |
   |  *  *  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x24,
0x66,
0xff,
0x66,
0x24,
0x00,
0x00,
0x00,
0x00,

/* Character   (0x1e):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |   *    |
   |   *    |
   |  ***   |
   |  ***   |
   | *****  |
   | *****  |
   |******* |
   |******* |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x10,
0x10,
0x38,
0x38,
0x7c,
0x7c,
0xfe,
0xfe,
0x00,
0x00,

/* Character   (0x1f):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |******* |
   |******* |
   | *****  |
   | *****  |
   |  ***   |
   |  ***   |
   |   *    |
   |   *    |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfe,
0xfe,
0x7c,
0x7c,
0x38,
0x38,
0x10,
0x10,
0x00,
0x00,

/* Character   (0x20):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ! (0x21):
   ht=12, width=8
   +--------+
   |        |
   |  **    |
   | ****   |
   | ****   |
   | ****   |
   |  **    |
   |  **    |
   |        |
   |  **    |
   |  **    |
   |        |
   |        |
   +--------+ */
0x00,
0x30,
0x78,
0x78,
0x78,
0x30,
0x30,
0x00,
0x30,
0x30,
0x00,
0x00,

/* Character " (0x22):
   ht=12, width=8
   +--------+
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   |  *  *  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x66,
0x66,
0x66,
0x24,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character # (0x23):
   ht=12, width=8
   +--------+
   |        |
   | ** **  |
   | ** **  |
   |******* |
   | ** **  |
   | ** **  |
   | ** **  |
   |******* |
   | ** **  |
   | ** **  |
   |        |
   |        |
   +--------+ */
0x00,
0x6c,
0x6c,
0xfe,
0x6c,
0x6c,
0x6c,
0xfe,
0x6c,
0x6c,
0x00,
0x00,

/* Character $ (0x24):
   ht=12, width=8
   +--------+
   |  **    |
   |  **    |
   | *****  |
   |**      |
   |**      |
   | ****   |
   |    **  |
   |    **  |
   |*****   |
   |  **    |
   |  **    |
   |        |
   +--------+ */
0x30,
0x30,
0x7c,
0xc0,
0xc0,
0x78,
0x0c,
0x0c,
0xf8,
0x30,
0x30,
0x00,

/* Character % (0x25):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |**   *  |
   |**  **  |
   |   **   |
   |  **    |
   | **     |
   |**  **  |
   |*   **  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0xc4,
0xcc,
0x18,
0x30,
0x60,
0xcc,
0x8c,
0x00,
0x00,

/* Character & (0x26):
   ht=12, width=8
   +--------+
   |        |
   | ***    |
   |** **   |
   |** **   |
   | ***    |
   |***** * |
   |** **** |
   |**  **  |
   |** ***  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x00,
0x70,
0xd8,
0xd8,
0x70,
0xfa,
0xde,
0xcc,
0xdc,
0x76,
0x00,
0x00,

/* Character ' (0x27):
   ht=12, width=8
   +--------+
   |        |
   |  **    |
   |  **    |
   |  **    |
   | **     |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x30,
0x30,
0x30,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ( (0x28):
   ht=12, width=8
   +--------+
   |        |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   | **     |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |        |
   |        |
   +--------+ */
0x00,
0x0c,
0x18,
0x30,
0x60,
0x60,
0x60,
0x30,
0x18,
0x0c,
0x00,
0x00,

/* Character ) (0x29):
   ht=12, width=8
   +--------+
   |        |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |    **  |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |        |
   |        |
   +--------+ */
0x00,
0x60,
0x30,
0x18,
0x0c,
0x0c,
0x0c,
0x18,
0x30,
0x60,
0x00,
0x00,

/* Character * (0x2a):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   |  ****  |
   |********|
   |  ****  |
   | **  ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x3c,
0xff,
0x3c,
0x66,
0x00,
0x00,
0x00,
0x00,

/* Character + (0x2b):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x18,
0x7e,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,

/* Character , (0x2c):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***   |
   |  ***   |
   | **     |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x38,
0x38,
0x60,
0x00,

/* Character - (0x2d):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |******* |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xfe,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character . (0x2e):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***   |
   |  ***   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x38,
0x38,
0x00,
0x00,

/* Character / (0x2f):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |      * |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |**      |
   |*       |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x02,
0x06,
0x0c,
0x18,
0x30,
0x60,
0xc0,
0x80,
0x00,
0x00,

/* Character 0 (0x30):
   ht=12, width=8
   +--------+
   |        |
   | *****  |
   |**   ** |
   |**  *** |
   |** **** |
   |** * ** |
   |**** ** |
   |***  ** |
   |**   ** |
   | *****  |
   |        |
   |        |
   +--------+ */
0x00,
0x7c,
0xc6,
0xce,
0xde,
0xd6,
0xf6,
0xe6,
0xc6,
0x7c,
0x00,
0x00,

/* Character 1 (0x31):
   ht=12, width=8
   +--------+
   |        |
   |   *    |
   |  **    |
   |****    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |******  |
   |        |
   |        |
   +--------+ */
0x00,
0x10,
0x30,
0xf0,
0x30,
0x30,
0x30,
0x30,
0x30,
0xfc,
0x00,
0x00,

/* Character 2 (0x32):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |**  **  |
   |******  |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0x0c,
0x18,
0x30,
0x60,
0xcc,
0xfc,
0x00,
0x00,

/* Character 3 (0x33):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |    **  |
   |    **  |
   |  ***   |
   |    **  |
   |    **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0x0c,
0x0c,
0x38,
0x0c,
0x0c,
0xcc,
0x78,
0x00,
0x00,

/* Character 4 (0x34):
   ht=12, width=8
   +--------+
   |        |
   |    **  |
   |   ***  |
   |  ****  |
   | ** **  |
   |**  **  |
   |******* |
   |    **  |
   |    **  |
   |   **** |
   |        |
   |        |
   +--------+ */
0x00,
0x0c,
0x1c,
0x3c,
0x6c,
0xcc,
0xfe,
0x0c,
0x0c,
0x1e,
0x00,
0x00,

/* Character 5 (0x35):
   ht=12, width=8
   +--------+
   |        |
   |******  |
   |**      |
   |**      |
   |**      |
   |*****   |
   |    **  |
   |    **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0xfc,
0xc0,
0xc0,
0xc0,
0xf8,
0x0c,
0x0c,
0xcc,
0x78,
0x00,
0x00,

/* Character 6 (0x36):
   ht=12, width=8
   +--------+
   |        |
   |  ***   |
   | **     |
   |**      |
   |**      |
   |*****   |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x38,
0x60,
0xc0,
0xc0,
0xf8,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character 7 (0x37):
   ht=12, width=8
   +--------+
   |        |
   |******* |
   |**   ** |
   |**   ** |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   |  **    |
   |  **    |
   |        |
   |        |
   +--------+ */
0x00,
0xfe,
0xc6,
0xc6,
0x06,
0x0c,
0x18,
0x30,
0x30,
0x30,
0x00,
0x00,

/* Character 8 (0x38):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |*** **  |
   | ****   |
   |** ***  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0xec,
0x78,
0xdc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character 9 (0x39):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   | *****  |
   |   **   |
   |   **   |
   |  **    |
   | ***    |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0x7c,
0x18,
0x18,
0x30,
0x70,
0x00,
0x00,

/* Character : (0x3a):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ***   |
   |  ***   |
   |        |
   |        |
   |  ***   |
   |  ***   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x38,
0x38,
0x00,
0x00,
0x38,
0x38,
0x00,
0x00,
0x00,

/* Character ; (0x3b):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ***   |
   |  ***   |
   |        |
   |        |
   |  ***   |
   |  ***   |
   |   **   |
   |  **    |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x38,
0x38,
0x00,
0x00,
0x38,
0x38,
0x18,
0x30,
0x00,

/* Character < (0x3c):
   ht=12, width=8
   +--------+
   |        |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |**      |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |        |
   |        |
   +--------+ */
0x00,
0x0c,
0x18,
0x30,
0x60,
0xc0,
0x60,
0x30,
0x18,
0x0c,
0x00,
0x00,

/* Character = (0x3d):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x7e,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character > (0x3e):
   ht=12, width=8
   +--------+
   |        |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |        |
   |        |
   +--------+ */
0x00,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x00,
0x00,

/* Character ? (0x3f):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |    **  |
   |   **   |
   |  **    |
   |  **    |
   |        |
   |  **    |
   |  **    |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0x0c,
0x18,
0x30,
0x30,
0x00,
0x30,
0x30,
0x00,
0x00,

/* Character @ (0x40):
   ht=12, width=8
   +--------+
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |** **** |
   |** **** |
   |** **** |
   |**      |
   |**      |
   | *****  |
   |        |
   |        |
   +--------+ */
0x00,
0x7c,
0xc6,
0xc6,
0xde,
0xde,
0xde,
0xc0,
0xc0,
0x7c,
0x00,
0x00,

/* Character A (0x41):
   ht=12, width=8
   +--------+
   |        |
   |  **    |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |******  |
   |**  **  |
   |**  **  |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x00,
0x30,
0x78,
0xcc,
0xcc,
0xcc,
0xfc,
0xcc,
0xcc,
0xcc,
0x00,
0x00,

/* Character B (0x42):
   ht=12, width=8
   +--------+
   |        |
   |******  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   |******  |
   |        |
   |        |
   +--------+ */
0x00,
0xfc,
0x66,
0x66,
0x66,
0x7c,
0x66,
0x66,
0x66,
0xfc,
0x00,
0x00,

/* Character C (0x43):
   ht=12, width=8
   +--------+
   |        |
   |  ****  |
   | **  ** |
   |**   ** |
   |**      |
   |**      |
   |**      |
   |**   ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x66,
0xc6,
0xc0,
0xc0,
0xc0,
0xc6,
0x66,
0x3c,
0x00,
0x00,

/* Character D (0x44):
   ht=12, width=8
   +--------+
   |        |
   |*****   |
   | ** **  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | ** **  |
   |*****   |
   |        |
   |        |
   +--------+ */
0x00,
0xf8,
0x6c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x6c,
0xf8,
0x00,
0x00,

/* Character E (0x45):
   ht=12, width=8
   +--------+
   |        |
   |******* |
   | **   * |
   | **     |
   | **  *  |
   | *****  |
   | **  *  |
   | **     |
   | **   * |
   |******* |
   |        |
   |        |
   +--------+ */
0x00,
0xfe,
0x62,
0x60,
0x64,
0x7c,
0x64,
0x60,
0x62,
0xfe,
0x00,
0x00,

/* Character F (0x46):
   ht=12, width=8
   +--------+
   |        |
   |******* |
   | **  ** |
   | **   * |
   | **  *  |
   | *****  |
   | **  *  |
   | **     |
   | **     |
   |****    |
   |        |
   |        |
   +--------+ */
0x00,
0xfe,
0x66,
0x62,
0x64,
0x7c,
0x64,
0x60,
0x60,
0xf0,
0x00,
0x00,

/* Character G (0x47):
   ht=12, width=8
   +--------+
   |        |
   |  ****  |
   | **  ** |
   |**   ** |
   |**      |
   |**      |
   |**  *** |
   |**   ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x66,
0xc6,
0xc0,
0xc0,
0xce,
0xc6,
0x66,
0x3e,
0x00,
0x00,

/* Character H (0x48):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |******  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xfc,
0xcc,
0xcc,
0xcc,
0xcc,
0x00,
0x00,

/* Character I (0x49):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x78,
0x00,
0x00,

/* Character J (0x4a):
   ht=12, width=8
   +--------+
   |        |
   |   **** |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x1e,
0x0c,
0x0c,
0x0c,
0x0c,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character K (0x4b):
   ht=12, width=8
   +--------+
   |        |
   |***  ** |
   | **  ** |
   | ** **  |
   | ** **  |
   | ****   |
   | ** **  |
   | ** **  |
   | **  ** |
   |***  ** |
   |        |
   |        |
   +--------+ */
0x00,
0xe6,
0x66,
0x6c,
0x6c,
0x78,
0x6c,
0x6c,
0x66,
0xe6,
0x00,
0x00,

/* Character L (0x4c):
   ht=12, width=8
   +--------+
   |        |
   |****    |
   | **     |
   | **     |
   | **     |
   | **     |
   | **   * |
   | **  ** |
   | **  ** |
   |******* |
   |        |
   |        |
   +--------+ */
0x00,
0xf0,
0x60,
0x60,
0x60,
0x60,
0x62,
0x66,
0x66,
0xfe,
0x00,
0x00,

/* Character M (0x4d):
   ht=12, width=8
   +--------+
   |        |
   |**   ** |
   |*** *** |
   |******* |
   |******* |
   |** * ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   +--------+ */
0x00,
0xc6,
0xee,
0xfe,
0xfe,
0xd6,
0xc6,
0xc6,
0xc6,
0xc6,
0x00,
0x00,

/* Character N (0x4e):
   ht=12, width=8
   +--------+
   |        |
   |**   ** |
   |**   ** |
   |***  ** |
   |**** ** |
   |******* |
   |** **** |
   |**  *** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   +--------+ */
0x00,
0xc6,
0xc6,
0xe6,
0xf6,
0xfe,
0xde,
0xce,
0xc6,
0xc6,
0x00,
0x00,

/* Character O (0x4f):
   ht=12, width=8
   +--------+
   |        |
   |  ***   |
   | ** **  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | ** **  |
   |  ***   |
   |        |
   |        |
   +--------+ */
0x00,
0x38,
0x6c,
0xc6,
0xc6,
0xc6,
0xc6,
0xc6,
0x6c,
0x38,
0x00,
0x00,

/* Character P (0x50):
   ht=12, width=8
   +--------+
   |        |
   |******  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   | **     |
   |****    |
   |        |
   |        |
   +--------+ */
0x00,
0xfc,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0x60,
0xf0,
0x00,
0x00,

/* Character Q (0x51):
   ht=12, width=8
   +--------+
   |        |
   |  ***   |
   | ** **  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**  *** |
   |** **** |
   | *****  |
   |    **  |
   |   **** |
   |        |
   +--------+ */
0x00,
0x38,
0x6c,
0xc6,
0xc6,
0xc6,
0xce,
0xde,
0x7c,
0x0c,
0x1e,
0x00,

/* Character R (0x52):
   ht=12, width=8
   +--------+
   |        |
   |******  |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | ** **  |
   | **  ** |
   | **  ** |
   |***  ** |
   |        |
   |        |
   +--------+ */
0x00,
0xfc,
0x66,
0x66,
0x66,
0x7c,
0x6c,
0x66,
0x66,
0xe6,
0x00,
0x00,

/* Character S (0x53):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**      |
   | ***    |
   |   **   |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0xc0,
0x70,
0x18,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character T (0x54):
   ht=12, width=8
   +--------+
   |        |
   |******  |
   |* ** *  |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0xfc,
0xb4,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x78,
0x00,
0x00,

/* Character U (0x55):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character V (0x56):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |  **    |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x30,
0x00,
0x00,

/* Character W (0x57):
   ht=12, width=8
   +--------+
   |        |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   |** * ** |
   |** * ** |
   | ** **  |
   | ** **  |
   | ** **  |
   |        |
   |        |
   +--------+ */
0x00,
0xc6,
0xc6,
0xc6,
0xc6,
0xd6,
0xd6,
0x6c,
0x6c,
0x6c,
0x00,
0x00,

/* Character X (0x58):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |  **    |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0xcc,
0x78,
0x30,
0x78,
0xcc,
0xcc,
0xcc,
0x00,
0x00,

/* Character Y (0x59):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |  **    |
   |  **    |
   |  **    |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x30,
0x30,
0x30,
0x78,
0x00,
0x00,

/* Character Z (0x5a):
   ht=12, width=8
   +--------+
   |        |
   |******* |
   |**  *** |
   |*  **   |
   |   **   |
   |  **    |
   | **     |
   | **   * |
   |**   ** |
   |******* |
   |        |
   |        |
   +--------+ */
0x00,
0xfe,
0xce,
0x98,
0x18,
0x30,
0x60,
0x62,
0xc6,
0xfe,
0x00,
0x00,

/* Character [ (0x5b):
   ht=12, width=8
   +--------+
   |        |
   |  ****  |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  **    |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x30,
0x3c,
0x00,
0x00,

/* Character \ (0x5c):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |*       |
   |**      |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   |      * |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x80,
0xc0,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x02,
0x00,
0x00,

/* Character ] (0x5d):
   ht=12, width=8
   +--------+
   |        |
   |  ****  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x3c,
0x00,
0x00,

/* Character ^ (0x5e):
   ht=12, width=8
   +--------+
   |   *    |
   |  ***   |
   | ** **  |
   |**   ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x10,
0x38,
0x6c,
0xc6,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character _ (0x5f):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |********|
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,
0x00,

/* Character ` (0x60):
   ht=12, width=8
   +--------+
   |  **    |
   |  **    |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x30,
0x30,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character a (0x61):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | ****   |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x78,
0x0c,
0x7c,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character b (0x62):
   ht=12, width=8
   +--------+
   |        |
   |***     |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |** ***  |
   |        |
   |        |
   +--------+ */
0x00,
0xe0,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0xdc,
0x00,
0x00,

/* Character c (0x63):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | ****   |
   |**  **  |
   |**      |
   |**      |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x78,
0xcc,
0xc0,
0xc0,
0xcc,
0x78,
0x00,
0x00,

/* Character d (0x64):
   ht=12, width=8
   +--------+
   |        |
   |   ***  |
   |    **  |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x00,
0x1c,
0x0c,
0x0c,
0x7c,
0xcc,
0xcc,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character e (0x65):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | ****   |
   |**  **  |
   |******  |
   |**      |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x78,
0xcc,
0xfc,
0xc0,
0xcc,
0x78,
0x00,
0x00,

/* Character f (0x66):
   ht=12, width=8
   +--------+
   |        |
   |  ***   |
   | ** **  |
   | **     |
   | **     |
   |*****   |
   | **     |
   | **     |
   | **     |
   |****    |
   |        |
   |        |
   +--------+ */
0x00,
0x38,
0x6c,
0x60,
0x60,
0xf8,
0x60,
0x60,
0x60,
0xf0,
0x00,
0x00,

/* Character g (0x67):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | *** ** |
   |**  **  |
   |**  **  |
   |**  **  |
   | *****  |
   |    **  |
   |**  **  |
   | ****   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x76,
0xcc,
0xcc,
0xcc,
0x7c,
0x0c,
0xcc,
0x78,

/* Character h (0x68):
   ht=12, width=8
   +--------+
   |        |
   |***     |
   | **     |
   | **     |
   | ** **  |
   | *** ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |***  ** |
   |        |
   |        |
   +--------+ */
0x00,
0xe0,
0x60,
0x60,
0x6c,
0x76,
0x66,
0x66,
0x66,
0xe6,
0x00,
0x00,

/* Character i (0x69):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |   **   |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x18,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,

/* Character j (0x6a):
   ht=12, width=8
   +--------+
   |        |
   |    **  |
   |    **  |
   |        |
   |  ****  |
   |    **  |
   |    **  |
   |    **  |
   |    **  |
   |**  **  |
   |**  **  |
   | ****   |
   +--------+ */
0x00,
0x0c,
0x0c,
0x00,
0x3c,
0x0c,
0x0c,
0x0c,
0x0c,
0xcc,
0xcc,
0x78,

/* Character k (0x6b):
   ht=12, width=8
   +--------+
   |        |
   |***     |
   | **     |
   | **     |
   | **  ** |
   | ** **  |
   | ****   |
   | ** **  |
   | **  ** |
   |***  ** |
   |        |
   |        |
   +--------+ */
0x00,
0xe0,
0x60,
0x60,
0x66,
0x6c,
0x78,
0x6c,
0x66,
0xe6,
0x00,
0x00,

/* Character l (0x6c):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,

/* Character m (0x6d):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |******  |
   |** * ** |
   |** * ** |
   |** * ** |
   |** * ** |
   |**   ** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xfc,
0xd6,
0xd6,
0xd6,
0xd6,
0xc6,
0x00,
0x00,

/* Character n (0x6e):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |*****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xf8,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x00,
0x00,

/* Character o (0x6f):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character p (0x70):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |** ***  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   |****    |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xdc,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x60,
0xf0,

/* Character q (0x71):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | *** ** |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *****  |
   |    **  |
   |   **** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x76,
0xcc,
0xcc,
0xcc,
0xcc,
0x7c,
0x0c,
0x1e,

/* Character r (0x72):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |*** **  |
   | ** *** |
   | *** ** |
   | **     |
   | **     |
   |****    |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xec,
0x6e,
0x76,
0x60,
0x60,
0xf0,
0x00,
0x00,

/* Character s (0x73):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | ****   |
   |**  **  |
   | **     |
   |   **   |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x78,
0xcc,
0x60,
0x18,
0xcc,
0x78,
0x00,
0x00,

/* Character t (0x74):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |  *     |
   | **     |
   |******  |
   | **     |
   | **     |
   | **     |
   | ** **  |
   |  ***   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x20,
0x60,
0xfc,
0x60,
0x60,
0x60,
0x6c,
0x38,
0x00,
0x00,

/* Character u (0x75):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character v (0x76):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |  **    |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x30,
0x00,
0x00,

/* Character w (0x77):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |**   ** |
   |**   ** |
   |** * ** |
   |** * ** |
   | ** **  |
   | ** **  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xc6,
0xc6,
0xd6,
0xd6,
0x6c,
0x6c,
0x00,
0x00,

/* Character x (0x78):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |**   ** |
   | ** **  |
   |  ***   |
   |  ***   |
   | ** **  |
   |**   ** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xc6,
0x6c,
0x38,
0x38,
0x6c,
0xc6,
0x00,
0x00,

/* Character y (0x79):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |    **  |
   |   **   |
   |****    |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x0c,
0x18,
0xf0,

/* Character z (0x7a):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |******  |
   |*   **  |
   |   **   |
   | **     |
   |**   *  |
   |******  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xfc,
0x8c,
0x18,
0x60,
0xc4,
0xfc,
0x00,
0x00,

/* Character { (0x7b):
   ht=12, width=8
   +--------+
   |        |
   |   ***  |
   |  **    |
   |  **    |
   | **     |
   |**      |
   | **     |
   |  **    |
   |  **    |
   |   ***  |
   |        |
   |        |
   +--------+ */
0x00,
0x1c,
0x30,
0x30,
0x60,
0xc0,
0x60,
0x30,
0x30,
0x1c,
0x00,
0x00,

/* Character | (0x7c):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x18,
0x18,
0x18,
0x00,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,

/* Character } (0x7d):
   ht=12, width=8
   +--------+
   |        |
   |***     |
   |  **    |
   |  **    |
   |   **   |
   |    **  |
   |   **   |
   |  **    |
   |  **    |
   |***     |
   |        |
   |        |
   +--------+ */
0x00,
0xe0,
0x30,
0x30,
0x18,
0x0c,
0x18,
0x30,
0x30,
0xe0,
0x00,
0x00,

/* Character ~ (0x7e):
   ht=12, width=8
   +--------+
   |        |
   | ***  **|
   |** ** * |
   |**  *** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x73,
0xda,
0xce,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character  (0x7f):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |   *    |
   |  ***   |
   | ** **  |
   |**   ** |
   |**   ** |
   |******* |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x10,
0x38,
0x6c,
0xc6,
0xc6,
0xfe,
0x00,
0x00,
0x00,

/* Character ? (0x80):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**      |
   |**      |
   |**      |
   |**  **  |
   |**  **  |
   | ****   |
   |  **    |
   |****    |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0xc0,
0xc0,
0xc0,
0xcc,
0xcc,
0x78,
0x30,
0xf0,

/* Character ?(0x81):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0x82):
   ht=12, width=8
   +--------+
   |    **  |
   |   **   |
   |  **    |
   |        |
   | ****   |
   |**  **  |
   |******  |
   |**      |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x30,
0x00,
0x78,
0xcc,
0xfc,
0xc0,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0x83):
   ht=12, width=8
   +--------+
   |  **    |
   | ****   |
   |**  **  |
   |        |
   | ****   |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x30,
0x78,
0xcc,
0x00,
0x78,
0x0c,
0x7c,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0x84):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |        |
   | ****   |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0x00,
0x78,
0x0c,
0x7c,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0x85):
   ht=12, width=8
   +--------+
   |**      |
   | **     |
   |  **    |
   |        |
   | ****   |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0xc0,
0x60,
0x30,
0x00,
0x78,
0x0c,
0x7c,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0x86):
   ht=12, width=8
   +--------+
   |  ***   |
   | ** **  |
   | ** **  |
   |  ***   |
   |*****   |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x38,
0x6c,
0x6c,
0x38,
0xf8,
0x0c,
0x7c,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0x87):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | ****   |
   |**  **  |
   |**      |
   |**      |
   |**  **  |
   | ****   |
   |  **    |
   |****    |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x78,
0xcc,
0xc0,
0xc0,
0xcc,
0x78,
0x30,
0xf0,

/* Character ?(0x88):
   ht=12, width=8
   +--------+
   |  **    |
   | ****   |
   |**  **  |
   |        |
   | ****   |
   |**  **  |
   |******  |
   |**      |
   |**      |
   | *****  |
   |        |
   |        |
   +--------+ */
0x30,
0x78,
0xcc,
0x00,
0x78,
0xcc,
0xfc,
0xc0,
0xc0,
0x7c,
0x00,
0x00,

/* Character ?(0x89):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |        |
   | ****   |
   |**  **  |
   |******  |
   |**      |
   |**      |
   | *****  |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0x00,
0x78,
0xcc,
0xfc,
0xc0,
0xc0,
0x7c,
0x00,
0x00,

/* Character ?(0x8a):
   ht=12, width=8
   +--------+
   |**      |
   | **     |
   |  **    |
   |        |
   | ****   |
   |**  **  |
   |******  |
   |**      |
   |**      |
   | *****  |
   |        |
   |        |
   +--------+ */
0xc0,
0x60,
0x30,
0x00,
0x78,
0xcc,
0xfc,
0xc0,
0xc0,
0x7c,
0x00,
0x00,

/* Character ?(0x8b):
   ht=12, width=8
   +--------+
   |        |
   | ** **  |
   | ** **  |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   +--------+ */
0x00,
0x6c,
0x6c,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,

/* Character ?(0x8c):
   ht=12, width=8
   +--------+
   |   *    |
   |  ***   |
   | ** **  |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   +--------+ */
0x10,
0x38,
0x6c,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,

/* Character ?(0x8d):
   ht=12, width=8
   +--------+
   | **     |
   |  **    |
   |   **   |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   +--------+ */
0x60,
0x30,
0x18,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,

/* Character ?(0x8e):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |        |
   |  **    |
   | ****   |
   |**  **  |
   |**  **  |
   |******  |
   |**  **  |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0x00,
0x30,
0x78,
0xcc,
0xcc,
0xfc,
0xcc,
0xcc,
0x00,
0x00,

/* Character ?(0x8f):
   ht=12, width=8
   +--------+
   | ****   |
   |**  **  |
   |**  **  |
   | ****   |
   | ****   |
   |**  **  |
   |**  **  |
   |******  |
   |**  **  |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x78,
0xcc,
0xcc,
0x78,
0x78,
0xcc,
0xcc,
0xfc,
0xcc,
0xcc,
0x00,
0x00,

/* Character ?(0x90):
   ht=12, width=8
   +--------+
   |    **  |
   |   **   |
   |  **    |
   |******  |
   |**   *  |
   |**      |
   |*****   |
   |**      |
   |**   *  |
   |******  |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x30,
0xfc,
0xc4,
0xc0,
0xf8,
0xc0,
0xc4,
0xfc,
0x00,
0x00,

/* Character ?(0x91):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |******* |
   |   ** **|
   | *******|
   |** **   |
   |** **   |
   |*** ****|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xfe,
0x1b,
0x7f,
0xd8,
0xd8,
0xef,
0x00,
0x00,

/* Character ?(0x92):
   ht=12, width=8
   +--------+
   |        |
   |  ***** |
   | ****   |
   |** **   |
   |** **   |
   |******* |
   |** **   |
   |** **   |
   |** **   |
   |** **** |
   |        |
   |        |
   +--------+ */
0x00,
0x3e,
0x78,
0xd8,
0xd8,
0xfe,
0xd8,
0xd8,
0xd8,
0xde,
0x00,
0x00,

/* Character ?(0x93):
   ht=12, width=8
   +--------+
   |  **    |
   | ****   |
   |**  **  |
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x30,
0x78,
0xcc,
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0x94):
   ht=12, width=8
   +--------+
   |        |
   |**  **  |
   |**  **  |
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0xcc,
0xcc,
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0x95):
   ht=12, width=8
   +--------+
   |**      |
   | **     |
   |  **    |
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0xc0,
0x60,
0x30,
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0x96):
   ht=12, width=8
   +--------+
   |  **    |
   | ****   |
   |**  **  |
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x30,
0x78,
0xcc,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0x97):
   ht=12, width=8
   +--------+
   |**      |
   | **     |
   |  **    |
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0xc0,
0x60,
0x30,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0x98):
   ht=12, width=8
   +--------+
   |        |
   | **  ** |
   | **  ** |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |    **  |
   |   **   |
   |****    |
   +--------+ */
0x00,
0x66,
0x66,
0x00,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x0c,
0x18,
0xf0,

/* Character ?(0x99):
   ht=12, width=8
   +--------+
   |**  **  |
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0xcc,
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0x9a):
   ht=12, width=8
   +--------+
   |**  **  |
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0xcc,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0x9b):
   ht=12, width=8
   +--------+
   |        |
   |  **    |
   |  **    |
   | ****   |
   |**  **  |
   |**      |
   |**      |
   |**  **  |
   | ****   |
   |  **    |
   |  **    |
   |        |
   +--------+ */
0x00,
0x30,
0x30,
0x78,
0xcc,
0xc0,
0xc0,
0xcc,
0x78,
0x30,
0x30,
0x00,

/* Character ?(0x9c):
   ht=12, width=8
   +--------+
   |  ****  |
   | **  ** |
   | **     |
   | **     |
   | **     |
   |******  |
   | **     |
   | **     |
   |**      |
   |******* |
   |        |
   |        |
   +--------+ */
0x3c,
0x66,
0x60,
0x60,
0x60,
0xfc,
0x60,
0x60,
0xc0,
0xfe,
0x00,
0x00,

/* Character ?(0x9d):
   ht=12, width=8
   +--------+
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |******  |
   |  **    |
   |******  |
   |  **    |
   |  **    |
   |        |
   |        |
   +--------+ */
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0xfc,
0x30,
0xfc,
0x30,
0x30,
0x00,
0x00,

/* Character ?(0x9e):
   ht=12, width=8
   +--------+
   |****    |
   |*   *   |
   |*   *   |
   |*   *   |
   |****    |
   |*   *   |
   |*  **** |
   |*   **  |
   |*   ** *|
   |*    ** |
   |        |
   |        |
   +--------+ */
0xf0,
0x88,
0x88,
0x88,
0xf0,
0x88,
0x9e,
0x8c,
0x8d,
0x86,
0x00,
0x00,

/* Character ?(0x9f):
   ht=12, width=8
   +--------+
   |    *** |
   |   ** **|
   |   **   |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |   **   |
   |** **   |
   | ***    |
   |        |
   |        |
   +--------+ */
0x0e,
0x1b,
0x18,
0x18,
0x7e,
0x18,
0x18,
0x18,
0xd8,
0x70,
0x00,
0x00,

/* Character ?(0xa0):
   ht=12, width=8
   +--------+
   |    **  |
   |   **   |
   |  **    |
   |        |
   | ****   |
   |    **  |
   | *****  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x30,
0x00,
0x78,
0x0c,
0x7c,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0xa1):
   ht=12, width=8
   +--------+
   |    **  |
   |   **   |
   |  **    |
   |        |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x30,
0x00,
0x78,
0x18,
0x18,
0x18,
0x18,
0x7e,
0x00,
0x00,

/* Character ?(0xa2):
   ht=12, width=8
   +--------+
   |    **  |
   |   **   |
   |  **    |
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x30,
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0xa3):
   ht=12, width=8
   +--------+
   |    **  |
   |   **   |
   |  **    |
   |        |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x0c,
0x18,
0x30,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x76,
0x00,
0x00,

/* Character ?(0xa4):
   ht=12, width=8
   +--------+
   |        |
   | *** ** |
   |** ***  |
   |        |
   |*****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x00,
0x76,
0xdc,
0x00,
0xf8,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x00,
0x00,

/* Character ?(0xa5):
   ht=12, width=8
   +--------+
   | *** ** |
   |** ***  |
   |        |
   |**   ** |
   |***  ** |
   |**** ** |
   |** **** |
   |**  *** |
   |**   ** |
   |**   ** |
   |        |
   |        |
   +--------+ */
0x76,
0xdc,
0x00,
0xc6,
0xe6,
0xf6,
0xde,
0xce,
0xc6,
0xc6,
0x00,
0x00,

/* Character ?(0xa6):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   | ****** |
   |        |
   |******* |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0x7e,
0x00,
0xfe,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa7):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |******* |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0x78,
0x00,
0xfe,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa8):
   ht=12, width=8
   +--------+
   |        |
   |  **    |
   |  **    |
   |        |
   |  **    |
   | **     |
   |**      |
   |**      |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x30,
0x30,
0x00,
0x30,
0x60,
0xc0,
0xc0,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0xa9):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |******  |
   |**      |
   |**      |
   |**      |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xfc,
0xc0,
0xc0,
0xc0,
0x00,
0x00,
0x00,

/* Character ?(0xaa):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |******  |
   |    **  |
   |    **  |
   |    **  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xfc,
0x0c,
0x0c,
0x0c,
0x00,
0x00,
0x00,

/* Character ?(0xab):
   ht=12, width=8
   +--------+
   |        |
   | *    * |
   |**   ** |
   |**  **  |
   |** **   |
   |  **    |
   | ** *** |
   |**    **|
   |*    ** |
   |    **  |
   |   *****|
   |        |
   +--------+ */
0x00,
0x42,
0xc6,
0xcc,
0xd8,
0x30,
0x6e,
0xc3,
0x86,
0x0c,
0x1f,
0x00,

/* Character ?(0xac):
   ht=12, width=8
   +--------+
   |        |
   | **   **|
   |***  ** |
   | ** **  |
   | ****   |
   |  ** ***|
   | ** ****|
   |** ** **|
   |* **  **|
   |  ******|
   |      **|
   |        |
   +--------+ */
0x00,
0x63,
0xe6,
0x6c,
0x78,
0x37,
0x6f,
0xdb,
0xb3,
0x3f,
0x03,
0x00,

/* Character ?(0xad):
   ht=12, width=8
   +--------+
   |        |
   |  **    |
   |  **    |
   |        |
   |  **    |
   |  **    |
   | ****   |
   | ****   |
   | ****   |
   |  **    |
   |        |
   |        |
   +--------+ */
0x00,
0x30,
0x30,
0x00,
0x30,
0x30,
0x78,
0x78,
0x78,
0x30,
0x00,
0x00,

/* Character ?(0xae):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |  **  **|
   | **  ** |
   |**  **  |
   |**  **  |
   | **  ** |
   |  **  **|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x33,
0x66,
0xcc,
0xcc,
0x66,
0x33,
0x00,
0x00,

/* Character ?(0xaf):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |**  **  |
   | **  ** |
   |  **  **|
   |  **  **|
   | **  ** |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xcc,
0x66,
0x33,
0x33,
0x66,
0xcc,
0x00,
0x00,

/* Character ?(0xb0):
   ht=12, width=8
   +--------+
   |  *  *  |
   |*  *  * |
   | *  *  *|
   |  *  *  |
   |*  *  * |
   | *  *  *|
   |  *  *  |
   |*  *  * |
   | *  *  *|
   |  *  *  |
   |*  *  * |
   | *  *  *|
   +--------+ */
0x24,
0x92,
0x49,
0x24,
0x92,
0x49,
0x24,
0x92,
0x49,
0x24,
0x92,
0x49,

/* Character ?(0xb1):
   ht=12, width=8
   +--------+
   | * * * *|
   |* * * * |
   | * * * *|
   |* * * * |
   | * * * *|
   |* * * * |
   | * * * *|
   |* * * * |
   | * * * *|
   |* * * * |
   | * * * *|
   |* * * * |
   +--------+ */
0x55,
0xaa,
0x55,
0xaa,
0x55,
0xaa,
0x55,
0xaa,
0x55,
0xaa,
0x55,
0xaa,

/* Character ?(0xb2):
   ht=12, width=8
   +--------+
   | ** ** *|
   |** ** **|
   |* ** ** |
   | ** ** *|
   |** ** **|
   |* ** ** |
   | ** ** *|
   |** ** **|
   |* ** ** |
   | ** ** *|
   |** ** **|
   |* ** ** |
   +--------+ */
0x6d,
0xdb,
0xb6,
0x6d,
0xdb,
0xb6,
0x6d,
0xdb,
0xb6,
0x6d,
0xdb,
0xb6,

/* Character ?(0xb3):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xb4):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |*****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x18,
0xf8,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xb5):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |*****   |
   |   **   |
   |   **   |
   |*****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0xf8,
0x18,
0x18,
0xf8,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xb6):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |***  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x66,
0xe6,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xb7):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |******* |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xfe,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xb8):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |*****   |
   |   **   |
   |   **   |
   |*****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xf8,
0x18,
0x18,
0xf8,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xb9):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |***  ** |
   |     ** |
   |     ** |
   |***  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0xe6,
0x06,
0x06,
0xe6,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xba):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xbb):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |******* |
   |     ** |
   |     ** |
   |***  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xfe,
0x06,
0x06,
0xe6,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xbc):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |***  ** |
   |     ** |
   |     ** |
   |******* |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0xe6,
0x06,
0x06,
0xfe,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbd):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |******* |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x66,
0xfe,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbe):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |*****   |
   |   **   |
   |   **   |
   |*****   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0xf8,
0x18,
0x18,
0xf8,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbf):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |*****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xf8,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xc0):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   *****|
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x18,
0x1f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xc1):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |********|
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x18,
0xff,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xc2):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |********|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xc3):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   *****|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x18,
0x1f,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xc4):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |********|
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xc5):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |********|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x18,
0xff,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xc6):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   *****|
   |   **   |
   |   **   |
   |   *****|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x1f,
0x18,
0x18,
0x1f,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xc7):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ***|
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x66,
0x67,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xc8):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ***|
   | **     |
   | **     |
   | *******|
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x67,
0x60,
0x60,
0x7f,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xc9):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | *******|
   | **     |
   | **     |
   | **  ***|
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x7f,
0x60,
0x60,
0x67,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xca):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |***  ***|
   |        |
   |        |
   |********|
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0xe7,
0x00,
0x00,
0xff,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xcb):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |********|
   |        |
   |        |
   |***  ***|
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xff,
0x00,
0x00,
0xe7,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xcc):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ***|
   | **     |
   | **     |
   | **  ***|
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x67,
0x60,
0x60,
0x67,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xcd):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |********|
   |        |
   |        |
   |********|
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xff,
0x00,
0x00,
0xff,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xce):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |***  ***|
   |        |
   |        |
   |***  ***|
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0xe7,
0x00,
0x00,
0xe7,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xcf):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |********|
   |        |
   |        |
   |********|
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0xff,
0x00,
0x00,
0xff,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd0):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |********|
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x66,
0xff,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd1):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |********|
   |        |
   |        |
   |********|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0xff,
0x00,
0x00,
0xff,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xd2):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |********|
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xd3):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *******|
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x66,
0x7f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd4):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   *****|
   |   **   |
   |   **   |
   |   *****|
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x1f,
0x18,
0x18,
0x1f,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd5):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |   *****|
   |   **   |
   |   **   |
   |   *****|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x1f,
0x18,
0x18,
0x1f,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xd6):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *******|
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x7f,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xd7):
   ht=12, width=8
   +--------+
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |***  ***|
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   +--------+ */
0x66,
0x66,
0x66,
0x66,
0x66,
0xe7,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,

/* Character ?(0xd8):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |********|
   |        |
   |        |
   |********|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0xff,
0x00,
0x00,
0xff,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xd9):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |*****   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x18,
0xf8,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xda):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   *****|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x1f,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xdb):
   ht=12, width=8
   +--------+
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   +--------+ */
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,

/* Character ?(0xdc):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,

/* Character ?(0xdd):
   ht=12, width=8
   +--------+
   |****    |
   |****    |
   |****    |
   |****    |
   |****    |
   |****    |
   |****    |
   |****    |
   |****    |
   |****    |
   |****    |
   |****    |
   +--------+ */
0xf0,
0xf0,
0xf0,
0xf0,
0xf0,
0xf0,
0xf0,
0xf0,
0xf0,
0xf0,
0xf0,
0xf0,

/* Character ?(0xde):
   ht=12, width=8
   +--------+
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   |    ****|
   +--------+ */
0x0f,
0x0f,
0x0f,
0x0f,
0x0f,
0x0f,
0x0f,
0x0f,
0x0f,
0x0f,
0x0f,
0x0f,

/* Character ?(0xdf):
   ht=12, width=8
   +--------+
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xe0):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | *** ** |
   |** **** |
   |**  **  |
   |**  **  |
   |** **** |
   | *** ** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x76,
0xde,
0xcc,
0xcc,
0xde,
0x76,
0x00,
0x00,

/* Character ?(0xe1):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |** **   |
   |**  **  |
   |**  **  |
   |**  **  |
   |*****   |
   |**      |
   | **     |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0xd8,
0xcc,
0xcc,
0xcc,
0xf8,
0xc0,
0x60,
0x00,

/* Character ?(0xe2):
   ht=12, width=8
   +--------+
   |        |
   |******  |
   |**  **  |
   |**  **  |
   |**      |
   |**      |
   |**      |
   |**      |
   |**      |
   |**      |
   |        |
   |        |
   +--------+ */
0x00,
0xfc,
0xcc,
0xcc,
0xc0,
0xc0,
0xc0,
0xc0,
0xc0,
0xc0,
0x00,
0x00,

/* Character ?(0xe3):
   ht=12, width=8
   +--------+
   |        |
   |******* |
   | ** **  |
   | ** **  |
   | ** **  |
   | ** **  |
   | ** **  |
   | ** **  |
   | ** **  |
   | **  ** |
   |        |
   |        |
   +--------+ */
0x00,
0xfe,
0x6c,
0x6c,
0x6c,
0x6c,
0x6c,
0x6c,
0x6c,
0x66,
0x00,
0x00,

/* Character ?(0xe4):
   ht=12, width=8
   +--------+
   |        |
   |******  |
   |**   *  |
   | **  *  |
   | **     |
   |  **    |
   | **     |
   | **  *  |
   |**   *  |
   |******  |
   |        |
   |        |
   +--------+ */
0x00,
0xfc,
0xc4,
0x64,
0x60,
0x30,
0x60,
0x64,
0xc4,
0xfc,
0x00,
0x00,

/* Character ?(0xe5):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |**  *   |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x7e,
0xc8,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0xe6):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **** **|
   | **     |
   |**      |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x7b,
0x60,
0xc0,

/* Character ?(0xe7):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   | *** ** |
   |** ***  |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |    *** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x76,
0xdc,
0x18,
0x18,
0x18,
0x18,
0x0e,
0x00,
0x00,

/* Character ?(0xe8):
   ht=12, width=8
   +--------+
   |        |
   |******  |
   |  **    |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |  **    |
   |******  |
   |        |
   |        |
   +--------+ */
0x00,
0xfc,
0x30,
0x78,
0xcc,
0xcc,
0xcc,
0x78,
0x30,
0xfc,
0x00,
0x00,

/* Character ?(0xe9):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |******  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0xfc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0xea):
   ht=12, width=8
   +--------+
   |        |
   | *****  |
   |**   ** |
   |**   ** |
   |**   ** |
   |**   ** |
   | ** **  |
   | ** **  |
   | ** **  |
   |*** *** |
   |        |
   |        |
   +--------+ */
0x00,
0x7c,
0xc6,
0xc6,
0xc6,
0xc6,
0x6c,
0x6c,
0x6c,
0xee,
0x00,
0x00,

/* Character ?(0xeb):
   ht=12, width=8
   +--------+
   |        |
   |  ****  |
   | **     |
   |  **    |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x60,
0x30,
0x78,
0xcc,
0xcc,
0xcc,
0xcc,
0x78,
0x00,
0x00,

/* Character ?(0xec):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   | *** ** |
   |** ** **|
   |** ** **|
   |** ** **|
   | ** *** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x76,
0xdb,
0xdb,
0xdb,
0x6e,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xed):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |     ** |
   | *****  |
   |** **** |
   |** * ** |
   |**** ** |
   | *****  |
   |**      |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x06,
0x7c,
0xde,
0xd6,
0xf6,
0x7c,
0xc0,
0x00,
0x00,
0x00,

/* Character ?(0xee):
   ht=12, width=8
   +--------+
   |        |
   |  ****  |
   | **     |
   |**      |
   |**      |
   |******  |
   |**      |
   |**      |
   | **     |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x60,
0xc0,
0xc0,
0xfc,
0xc0,
0xc0,
0x60,
0x3c,
0x00,
0x00,

/* Character ?(0xef):
   ht=12, width=8
   +--------+
   |        |
   |        |
   | ****   |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |**  **  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x78,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0xcc,
0x00,
0x00,

/* Character ?(0xf0):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |******  |
   |        |
   |        |
   |******  |
   |        |
   |        |
   |******  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0xfc,
0x00,
0x00,
0xfc,
0x00,
0x00,
0xfc,
0x00,
0x00,
0x00,

/* Character ?(0xf1):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |  **    |
   |  **    |
   |******  |
   |  **    |
   |  **    |
   |        |
   |******  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x30,
0x30,
0xfc,
0x30,
0x30,
0x00,
0xfc,
0x00,
0x00,
0x00,

/* Character ?(0xf2):
   ht=12, width=8
   +--------+
   |        |
   | **     |
   |  **    |
   |   **   |
   |   **   |
   |  **    |
   | **     |
   |        |
   |******  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x60,
0x30,
0x18,
0x18,
0x30,
0x60,
0x00,
0xfc,
0x00,
0x00,
0x00,

/* Character ?(0xf3):
   ht=12, width=8
   +--------+
   |        |
   |   **   |
   |  **    |
   | **     |
   | **     |
   |  **    |
   |   **   |
   |        |
   |******  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x18,
0x30,
0x60,
0x60,
0x30,
0x18,
0x00,
0xfc,
0x00,
0x00,
0x00,

/* Character ?(0xf4):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |    *** |
   |   ** **|
   |   ** **|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   +--------+ */
0x00,
0x00,
0x0e,
0x1b,
0x1b,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,

/* Character ?(0xf5):
   ht=12, width=8
   +--------+
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |** **   |
   |** **   |
   | ***    |
   |        |
   |        |
   +--------+ */
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0xd8,
0xd8,
0x70,
0x00,
0x00,

/* Character ?(0xf6):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |  **    |
   |  **    |
   |        |
   |******  |
   |        |
   |  **    |
   |  **    |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x30,
0x30,
0x00,
0xfc,
0x00,
0x30,
0x30,
0x00,
0x00,
0x00,

/* Character ?(0xf7):
   ht=12, width=8
   +--------+
   |        |
   |        |
   | ***  **|
   |** ** **|
   |**  *** |
   |        |
   | ***  **|
   |** ** **|
   |**  *** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x73,
0xdb,
0xce,
0x00,
0x73,
0xdb,
0xce,
0x00,
0x00,
0x00,

/* Character ?(0xf8):
   ht=12, width=8
   +--------+
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x3c,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xf9):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |   ***  |
   |   ***  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x1c,
0x1c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xfa):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xfb):
   ht=12, width=8
   +--------+
   |        |
   |     ***|
   |     *  |
   |     *  |
   |     *  |
   | *   *  |
   | **  *  |
   |  ** *  |
   |   ***  |
   |    **  |
   |        |
   |        |
   +--------+ */
0x00,
0x07,
0x04,
0x04,
0x04,
0x44,
0x64,
0x34,
0x1c,
0x0c,
0x00,
0x00,

/* Character ?(0xfc):
   ht=12, width=8
   +--------+
   |        |
   |** **   |
   | ** **  |
   | ** **  |
   | ** **  |
   | ** **  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0xd8,
0x6c,
0x6c,
0x6c,
0x6c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xfd):
   ht=12, width=8
   +--------+
   |        |
   | ****   |
   |    **  |
   |   **   |
   |  **    |
   | *****  |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x78,
0x0c,
0x18,
0x30,
0x7c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xfe):
   ht=12, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   |  ****  |
   |  ****  |
   |  ****  |
   |  ****  |
   |  ****  |
   |  ****  |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x3c,
0x3c,
0x3c,
0x3c,
0x3c,
0x3c,
0x3c,
0x00,
0x00,

/* Character ?(0xff):
   ht=12, width=8
   +--------+
   |        |
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |********|
   |        |
   |        |
   +--------+ */
0x00,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0xff,
0x00,
0x00,

};

static RBFINFO rbfinfo = {
    sizeof(font_data)/ (((8+7)>>3) * (12)), 
    8, 12, 
    (unsigned char*) font_data, sizeof(font_data),
};

INCORE_RBFINFO __mgif_rbf_terminal_8x12 = {
    "rbf-Terminal-rrncnn-8-12-ISO8859-1",
    &rbfinfo
};

#endif /* _MGINCORERBF_LATIN1_TERMINAL */
#endif /* _MGFONT_RBF */
