///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/blog/minigui-licensing-policy/>.
 */
/*
** $Id: sansserif_11x13.c 8944 2007-12-29 08:29:16Z xwyan $
** 
** sansserif_11x13.c: SansSerif 11x13 VBF font data.
*/

#include <stdio.h>
#include <stdlib.h>

#include "common.h"
#include "minigui.h"
#include "gdi.h"
#include "devfont.h"

#ifdef _MGFONT_VBF
#ifdef _MGINCOREFONT_SANSSERIF

#include "varbitmap.h"

static const unsigned char bits[] = {

/* Character   (0x20):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ! (0x21):
   ht=13, width=3
   +---+
   |   |
   |   |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   |   |
   | * |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x40,
0x00,
0x00,

/* Character " (0x22):
   ht=13, width=5
   +-----+
   |     |
   |     |
   | *  *|
   | *  *|
   | *  *|
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x48,
0x48,
0x48,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character # (0x23):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |  *  * |
   |  *  * |
   | ******|
   |  *  * |
   |  *  * |
   |  *  * |
   | ******|
   |  *  * |
   |  *  * |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x24,
0x24,
0x7e,
0x24,
0x24,
0x24,
0x7e,
0x24,
0x24,
0x00,
0x00,

/* Character $ (0x24):
   ht=13, width=6
   +------+
   |      |
   |      |
   |   *  |
   |  *** |
   | * * *|
   | * *  |
   |  **  |
   |   ** |
   |   * *|
   | * * *|
   |  *** |
   |   *  |
   |      |
   +------+ */
0x00,
0x00,
0x10,
0x38,
0x54,
0x50,
0x30,
0x18,
0x14,
0x54,
0x38,
0x10,
0x00,

/* Character % (0x25):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |  **    |
   | *  *  *|
   |  **  * |
   |     *  |
   |    *   |
   |   *    |
   |  *  ** |
   | *  *  *|
   |     ** |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x30,
0x49,
0x32,
0x04,
0x08,
0x10,
0x26,
0x49,
0x06,
0x00,
0x00,

/* Character & (0x26):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *   |
   | * *  |
   | * *  |
   |  *   |
   |  *   |
   | * * *|
   | *  * |
   | *  * |
   |  ** *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x20,
0x50,
0x50,
0x20,
0x20,
0x54,
0x48,
0x48,
0x34,
0x00,
0x00,

/* Character ' (0x27):
   ht=13, width=2
   +--+
   |  |
   |  |
   | *|
   | *|
   | *|
   |  |
   |  |
   |  |
   |  |
   |  |
   |  |
   |  |
   |  |
   +--+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ( (0x28):
   ht=13, width=3
   +---+
   |   |
   |   |
   |  *|
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   |  *|
   +---+ */
0x00,
0x00,
0x20,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x20,

/* Character ) (0x29):
   ht=13, width=3
   +---+
   |   |
   |   |
   | * |
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   | * |
   +---+ */
0x00,
0x00,
0x40,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x40,

/* Character * (0x2a):
   ht=13, width=4
   +----+
   |    |
   |    |
   |    |
   | * *|
   |  * |
   | * *|
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x50,
0x20,
0x50,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character + (0x2b):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |   *  |
   |   *  |
   | *****|
   |   *  |
   |   *  |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x10,
0x10,
0x7c,
0x10,
0x10,
0x00,
0x00,
0x00,

/* Character , (0x2c):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |  *|
   | * |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x20,
0x40,
0x00,

/* Character - (0x2d):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   | **|
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character . (0x2e):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   | * |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x40,
0x00,
0x00,

/* Character / (0x2f):
   ht=13, width=5
   +-----+
   |     |
   |     |
   |    *|
   |    *|
   |    *|
   |   * |
   |   * |
   |  *  |
   |  *  |
   | *   |
   | *   |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x08,
0x08,
0x08,
0x10,
0x10,
0x20,
0x20,
0x40,
0x40,
0x00,
0x00,

/* Character 0 (0x30):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x44,
0x44,
0x44,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character 1 (0x31):
   ht=13, width=6
   +------+
   |      |
   |      |
   |   *  |
   | ***  |
   |   *  |
   |   *  |
   |   *  |
   |   *  |
   |   *  |
   |   *  |
   |   *  |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x10,
0x70,
0x10,
0x10,
0x10,
0x10,
0x10,
0x10,
0x10,
0x00,
0x00,

/* Character 2 (0x32):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   |     *|
   |     *|
   |    * |
   |   *  |
   |  *   |
   | *    |
   | *****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x04,
0x04,
0x08,
0x10,
0x20,
0x40,
0x7c,
0x00,
0x00,

/* Character 3 (0x33):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   |     *|
   |     *|
   |   ** |
   |     *|
   |     *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x04,
0x04,
0x18,
0x04,
0x04,
0x44,
0x38,
0x00,
0x00,

/* Character 4 (0x34):
   ht=13, width=6
   +------+
   |      |
   |      |
   |    * |
   |   ** |
   |   ** |
   |  * * |
   |  * * |
   | *  * |
   | *****|
   |    * |
   |    * |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x08,
0x18,
0x18,
0x28,
0x28,
0x48,
0x7c,
0x08,
0x08,
0x00,
0x00,

/* Character 5 (0x35):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *****|
   | *    |
   | *    |
   | **** |
   | *   *|
   |     *|
   |     *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x7c,
0x40,
0x40,
0x78,
0x44,
0x04,
0x04,
0x44,
0x38,
0x00,
0x00,

/* Character 6 (0x36):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   | *    |
   | *    |
   | **** |
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x40,
0x40,
0x78,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character 7 (0x37):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *****|
   |     *|
   |    * |
   |    * |
   |   *  |
   |   *  |
   |  *   |
   |  *   |
   |  *   |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x7c,
0x04,
0x08,
0x08,
0x10,
0x10,
0x20,
0x20,
0x20,
0x00,
0x00,

/* Character 8 (0x38):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x44,
0x44,
0x38,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character 9 (0x39):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   |  ****|
   |     *|
   |     *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x44,
0x44,
0x3c,
0x04,
0x04,
0x44,
0x38,
0x00,
0x00,

/* Character : (0x3a):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   | * |
   |   |
   |   |
   |   |
   |   |
   | * |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x40,
0x00,
0x00,
0x00,
0x00,
0x40,
0x00,
0x00,

/* Character ; (0x3b):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |  *|
   |   |
   |   |
   |   |
   |   |
   |  *|
   | * |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x20,
0x00,
0x00,
0x00,
0x00,
0x20,
0x40,
0x00,

/* Character < (0x3c):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |    * |
   |   *  |
   |  *   |
   | *    |
   |  *   |
   |   *  |
   |    * |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x08,
0x10,
0x20,
0x40,
0x20,
0x10,
0x08,
0x00,
0x00,

/* Character = (0x3d):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   | *****|
   |      |
   | *****|
   |      |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0x00,
0x7c,
0x00,
0x00,
0x00,
0x00,

/* Character > (0x3e):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   | *    |
   |  *   |
   |   *  |
   |    * |
   |   *  |
   |  *   |
   | *    |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x40,
0x20,
0x10,
0x08,
0x10,
0x20,
0x40,
0x00,
0x00,

/* Character ? (0x3f):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   |     *|
   |     *|
   |    * |
   |   *  |
   |   *  |
   |      |
   |   *  |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x04,
0x04,
0x08,
0x10,
0x10,
0x00,
0x10,
0x00,
0x00,

/* Character @ (0x40):
   ht=13, width=11
   +-----------+
   |           |
   |           |
   |    ****   |
   |  **    ** |
   |  *      * |
   | *   ***  *|
   | *  *  *  *|
   | *  *  *  *|
   | *   ** ***|
   |  *        |
   |  **       |
   |    *****  |
   |           |
   +-----------+ */
0x00,
0x00,
0x00,
0x00,
0x0f,
0x00,
0x30,
0xc0,
0x20,
0x40,
0x47,
0x20,
0x49,
0x20,
0x49,
0x20,
0x46,
0xe0,
0x20,
0x00,
0x30,
0x00,
0x0f,
0x80,
0x00,
0x00,

/* Character A (0x41):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |   *   |
   |   *   |
   |  * *  |
   |  * *  |
   | *   * |
   | *   * |
   | ***** |
   |*     *|
   |*     *|
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x10,
0x10,
0x28,
0x28,
0x44,
0x44,
0x7c,
0x82,
0x82,
0x00,
0x00,

/* Character B (0x42):
   ht=13, width=7
   +-------+
   |       |
   |       |
   | ****  |
   | *   * |
   | *   * |
   | *   * |
   | ****  |
   | *   * |
   | *   * |
   | *   * |
   | ****  |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x78,
0x44,
0x44,
0x44,
0x78,
0x44,
0x44,
0x44,
0x78,
0x00,
0x00,

/* Character C (0x43):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |  **** |
   | *    *|
   | *     |
   | *     |
   | *     |
   | *     |
   | *     |
   | *    *|
   |  **** |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x3c,
0x42,
0x40,
0x40,
0x40,
0x40,
0x40,
0x42,
0x3c,
0x00,
0x00,

/* Character D (0x44):
   ht=13, width=8
   +--------+
   |        |
   |        |
   | ****   |
   | *   *  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *   *  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x78,
0x44,
0x42,
0x42,
0x42,
0x42,
0x42,
0x44,
0x78,
0x00,
0x00,

/* Character E (0x45):
   ht=13, width=7
   +-------+
   |       |
   |       |
   | ***** |
   | *     |
   | *     |
   | *     |
   | ****  |
   | *     |
   | *     |
   | *     |
   | ***** |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x7c,
0x40,
0x40,
0x40,
0x78,
0x40,
0x40,
0x40,
0x7c,
0x00,
0x00,

/* Character F (0x46):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *****|
   | *    |
   | *    |
   | *    |
   | **** |
   | *    |
   | *    |
   | *    |
   | *    |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x7c,
0x40,
0x40,
0x40,
0x78,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character G (0x47):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   | *    * |
   | *      |
   | *      |
   | *  *** |
   | *    * |
   | *    * |
   | *   ** |
   |  *** * |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x42,
0x40,
0x40,
0x4e,
0x42,
0x42,
0x46,
0x3a,
0x00,
0x00,

/* Character H (0x48):
   ht=13, width=8
   +--------+
   |        |
   |        |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | ****** |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x42,
0x42,
0x42,
0x42,
0x7e,
0x42,
0x42,
0x42,
0x42,
0x00,
0x00,

/* Character I (0x49):
   ht=13, width=3
   +---+
   |   |
   |   |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character J (0x4a):
   ht=13, width=5
   +-----+
   |     |
   |     |
   |   * |
   |   * |
   |   * |
   |   * |
   |   * |
   |   * |
   |*  * |
   |*  * |
   | **  |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x10,
0x10,
0x10,
0x10,
0x10,
0x10,
0x90,
0x90,
0x60,
0x00,
0x00,

/* Character K (0x4b):
   ht=13, width=7
   +-------+
   |       |
   |       |
   | *   * |
   | *  *  |
   | * *   |
   | **    |
   | **    |
   | * *   |
   | *  *  |
   | *   * |
   | *    *|
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x44,
0x48,
0x50,
0x60,
0x60,
0x50,
0x48,
0x44,
0x42,
0x00,
0x00,

/* Character L (0x4c):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *    |
   | *    |
   | *    |
   | *    |
   | *    |
   | *    |
   | *    |
   | *    |
   | *****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x7c,
0x00,
0x00,

/* Character M (0x4d):
   ht=13, width=9
   +---------+
   |         |
   |         |
   | *     * |
   | *     * |
   | **   ** |
   | **   ** |
   | * * * * |
   | * * * * |
   | *  *  * |
   | *  *  * |
   | *     * |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x41,
0x00,
0x41,
0x00,
0x63,
0x00,
0x63,
0x00,
0x55,
0x00,
0x55,
0x00,
0x49,
0x00,
0x49,
0x00,
0x41,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character N (0x4e):
   ht=13, width=8
   +--------+
   |        |
   |        |
   | *    * |
   | **   * |
   | **   * |
   | * *  * |
   | * *  * |
   | *  * * |
   | *   ** |
   | *   ** |
   | *    * |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x42,
0x62,
0x62,
0x52,
0x52,
0x4a,
0x46,
0x46,
0x42,
0x00,
0x00,

/* Character O (0x4f):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character P (0x50):
   ht=13, width=7
   +-------+
   |       |
   |       |
   | ***** |
   | *    *|
   | *    *|
   | *    *|
   | ***** |
   | *     |
   | *     |
   | *     |
   | *     |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x7c,
0x42,
0x42,
0x42,
0x7c,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character Q (0x51):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |  ****  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *  * * |
   | *   ** |
   |  ****  |
   |      * |
   |        |
   +--------+ */
0x00,
0x00,
0x3c,
0x42,
0x42,
0x42,
0x42,
0x42,
0x4a,
0x46,
0x3c,
0x02,
0x00,

/* Character R (0x52):
   ht=13, width=8
   +--------+
   |        |
   |        |
   | *****  |
   | *    * |
   | *    * |
   | *    * |
   | *****  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x7c,
0x42,
0x42,
0x42,
0x7c,
0x42,
0x42,
0x42,
0x42,
0x00,
0x00,

/* Character S (0x53):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |  ***  |
   | *   * |
   | *     |
   | *     |
   |  ***  |
   |     * |
   |     * |
   | *   * |
   |  ***  |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x38,
0x44,
0x40,
0x40,
0x38,
0x04,
0x04,
0x44,
0x38,
0x00,
0x00,

/* Character T (0x54):
   ht=13, width=7
   +-------+
   |       |
   |       |
   | ***** |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x7c,
0x10,
0x10,
0x10,
0x10,
0x10,
0x10,
0x10,
0x10,
0x00,
0x00,

/* Character U (0x55):
   ht=13, width=8
   +--------+
   |        |
   |        |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character V (0x56):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |*     *|
   |*     *|
   | *   * |
   | *   * |
   | *   * |
   |  * *  |
   |  * *  |
   |   *   |
   |   *   |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x82,
0x82,
0x44,
0x44,
0x44,
0x28,
0x28,
0x10,
0x10,
0x00,
0x00,

/* Character W (0x57):
   ht=13, width=11
   +-----------+
   |           |
   |           |
   |*         *|
   |*         *|
   | *   *   * |
   | *   *   * |
   | *   *   * |
   |  * * * *  |
   |  * * * *  |
   |   *   *   |
   |   *   *   |
   |           |
   |           |
   +-----------+ */
0x00,
0x00,
0x00,
0x00,
0x80,
0x20,
0x80,
0x20,
0x44,
0x40,
0x44,
0x40,
0x44,
0x40,
0x2a,
0x80,
0x2a,
0x80,
0x11,
0x00,
0x11,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character X (0x58):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |*     *|
   |*     *|
   | *   * |
   |  * *  |
   |   *   |
   |  * *  |
   | *   * |
   |*     *|
   |*     *|
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x82,
0x82,
0x44,
0x28,
0x10,
0x28,
0x44,
0x82,
0x82,
0x00,
0x00,

/* Character Y (0x59):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |*     *|
   |*     *|
   | *   * |
   |  * *  |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x82,
0x82,
0x44,
0x28,
0x10,
0x10,
0x10,
0x10,
0x10,
0x00,
0x00,

/* Character Z (0x5a):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |*******|
   |      *|
   |     * |
   |    *  |
   |   *   |
   |  *    |
   | *     |
   |*      |
   |*******|
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0xfe,
0x02,
0x04,
0x08,
0x10,
0x20,
0x40,
0x80,
0xfe,
0x00,
0x00,

/* Character [ (0x5b):
   ht=13, width=3
   +---+
   |   |
   |   |
   | **|
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | **|
   +---+ */
0x00,
0x00,
0x60,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x60,

/* Character \ (0x5c):
   ht=13, width=5
   +-----+
   |     |
   |     |
   | *   |
   | *   |
   | *   |
   |  *  |
   |  *  |
   |   * |
   |   * |
   |    *|
   |    *|
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x20,
0x20,
0x10,
0x10,
0x08,
0x08,
0x00,
0x00,

/* Character ] (0x5d):
   ht=13, width=3
   +---+
   |   |
   |   |
   | **|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   |  *|
   | **|
   +---+ */
0x00,
0x00,
0x60,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x60,

/* Character ^ (0x5e):
   ht=13, width=6
   +------+
   |      |
   |   *  |
   |  * * |
   | *   *|
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x10,
0x28,
0x44,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character _ (0x5f):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |******|
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xfc,

/* Character ` (0x60):
   ht=13, width=3
   +---+
   |   |
   |   |
   | * |
   |  *|
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x40,
0x20,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character a (0x61):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  *** |
   |     *|
   |  ****|
   | *   *|
   | *   *|
   |  ****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x38,
0x04,
0x3c,
0x44,
0x44,
0x3c,
0x00,
0x00,

/* Character b (0x62):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *    |
   | *    |
   | *    |
   | **** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | **** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x78,
0x44,
0x44,
0x44,
0x44,
0x78,
0x00,
0x00,

/* Character c (0x63):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  *** |
   | *   *|
   | *    |
   | *    |
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x38,
0x44,
0x40,
0x40,
0x44,
0x38,
0x00,
0x00,

/* Character d (0x64):
   ht=13, width=6
   +------+
   |      |
   |      |
   |     *|
   |     *|
   |     *|
   |  ****|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  ****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x04,
0x04,
0x04,
0x3c,
0x44,
0x44,
0x44,
0x44,
0x3c,
0x00,
0x00,

/* Character e (0x65):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  *** |
   | *   *|
   | *****|
   | *    |
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x38,
0x44,
0x7c,
0x40,
0x44,
0x38,
0x00,
0x00,

/* Character f (0x66):
   ht=13, width=3
   +---+
   |   |
   |   |
   |  *|
   | * |
   | * |
   | **|
   | * |
   | * |
   | * |
   | * |
   | * |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x20,
0x40,
0x40,
0x60,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character g (0x67):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  ****|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  ****|
   |     *|
   | **** |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x44,
0x44,
0x44,
0x44,
0x3c,
0x04,
0x78,

/* Character h (0x68):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *    |
   | *    |
   | *    |
   | * ** |
   | **  *|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x58,
0x64,
0x44,
0x44,
0x44,
0x44,
0x00,
0x00,

/* Character i (0x69):
   ht=13, width=2
   +--+
   |  |
   |  |
   | *|
   |  |
   |  |
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   |  |
   |  |
   +--+ */
0x00,
0x00,
0x40,
0x00,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character j (0x6a):
   ht=13, width=2
   +--+
   |  |
   |  |
   | *|
   |  |
   |  |
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   +--+ */
0x00,
0x00,
0x40,
0x00,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,

/* Character k (0x6b):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *    |
   | *    |
   | *    |
   | *  * |
   | * *  |
   | **   |
   | * *  |
   | *  * |
   | *   *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x48,
0x50,
0x60,
0x50,
0x48,
0x44,
0x00,
0x00,

/* Character l (0x6c):
   ht=13, width=2
   +--+
   |  |
   |  |
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   |  |
   |  |
   +--+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character m (0x6d):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *** ** |
   | *  *  *|
   | *  *  *|
   | *  *  *|
   | *  *  *|
   | *  *  *|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x76,
0x49,
0x49,
0x49,
0x49,
0x49,
0x00,
0x00,

/* Character n (0x6e):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   | * ** |
   | **  *|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x58,
0x64,
0x44,
0x44,
0x44,
0x44,
0x00,
0x00,

/* Character o (0x6f):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x38,
0x44,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character p (0x70):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   | **** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | **** |
   | *    |
   | *    |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x78,
0x44,
0x44,
0x44,
0x44,
0x78,
0x40,
0x40,

/* Character q (0x71):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  ****|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  ****|
   |     *|
   |     *|
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x44,
0x44,
0x44,
0x44,
0x3c,
0x04,
0x04,

/* Character r (0x72):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   | **|
   | * |
   | * |
   | * |
   | * |
   | * |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character s (0x73):
   ht=13, width=5
   +-----+
   |     |
   |     |
   |     |
   |     |
   |     |
   |  ** |
   | *  *|
   |  *  |
   |   * |
   | *  *|
   |  ** |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x30,
0x48,
0x20,
0x10,
0x48,
0x30,
0x00,
0x00,

/* Character t (0x74):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | * |
   | * |
   | **|
   | * |
   | * |
   | * |
   | * |
   |  *|
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x40,
0x40,
0x60,
0x40,
0x40,
0x40,
0x40,
0x20,
0x00,
0x00,

/* Character u (0x75):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | *  **|
   |  ** *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x44,
0x44,
0x44,
0x44,
0x4c,
0x34,
0x00,
0x00,

/* Character v (0x76):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   | *   *|
   | *   *|
   |  * * |
   |  * * |
   |   *  |
   |   *  |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x44,
0x44,
0x28,
0x28,
0x10,
0x10,
0x00,
0x00,

/* Character w (0x77):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | *  *  *|
   | *  *  *|
   | * * * *|
   | * * * *|
   |  *   * |
   |  *   * |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x49,
0x49,
0x55,
0x55,
0x22,
0x22,
0x00,
0x00,

/* Character x (0x78):
   ht=13, width=5
   +-----+
   |     |
   |     |
   |     |
   |     |
   |     |
   | *  *|
   | *  *|
   |  ** |
   |  ** |
   | *  *|
   | *  *|
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x48,
0x48,
0x30,
0x30,
0x48,
0x48,
0x00,
0x00,

/* Character y (0x79):
   ht=13, width=5
   +-----+
   |     |
   |     |
   |     |
   |     |
   |     |
   | *  *|
   | *  *|
   | *  *|
   | *  *|
   |  ** |
   |  *  |
   |  *  |
   |**   |
   +-----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x48,
0x48,
0x48,
0x48,
0x30,
0x20,
0x20,
0xc0,

/* Character z (0x7a):
   ht=13, width=5
   +-----+
   |     |
   |     |
   |     |
   |     |
   |     |
   | ****|
   |    *|
   |   * |
   |  *  |
   | *   |
   | ****|
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x78,
0x08,
0x10,
0x20,
0x40,
0x78,
0x00,
0x00,

/* Character { (0x7b):
   ht=13, width=4
   +----+
   |    |
   |   *|
   |  * |
   |  * |
   |  * |
   |  * |
   | *  |
   |  * |
   |  * |
   |  * |
   |  * |
   |   *|
   |    |
   +----+ */
0x00,
0x10,
0x20,
0x20,
0x20,
0x20,
0x40,
0x20,
0x20,
0x20,
0x20,
0x10,
0x00,

/* Character | (0x7c):
   ht=13, width=2
   +--+
   |  |
   |  |
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   |  |
   +--+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,

/* Character } (0x7d):
   ht=13, width=4
   +----+
   |    |
   | *  |
   |  * |
   |  * |
   |  * |
   |  * |
   |   *|
   |  * |
   |  * |
   |  * |
   |  * |
   | *  |
   |    |
   +----+ */
0x00,
0x40,
0x20,
0x20,
0x20,
0x20,
0x10,
0x20,
0x20,
0x20,
0x20,
0x40,
0x00,

/* Character ~ (0x7e):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |       |
   |  **  *|
   | *  ** |
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x00,
0x32,
0x4c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character  (0x7f):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character  (0x80):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   | *   *|
   |****  |
   | *    |
   |***   |
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x44,
0xf0,
0x40,
0xe0,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0x81):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x82):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x83):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x84):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x85):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x86):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x87):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x88):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x89):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x8a):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x8b):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x8c):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x8d):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x8e):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x8f):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x90):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x91):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |  *|
   | * |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x20,
0x40,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0x92):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |  *|
   | * |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x20,
0x40,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0x93):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x94):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x95):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x96):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x97):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x98):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x99):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x9a):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x9b):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x9c):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x9d):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x9e):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0x9f):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   | **|
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,

/* Character ?(0xa0):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa1):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   | * |
   |   |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x40,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,

/* Character ?(0xa2):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |    * |
   |  *** |
   | *   *|
   | *    |
   | *    |
   | *   *|
   |  *** |
   |  *   |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x08,
0x38,
0x44,
0x40,
0x40,
0x44,
0x38,
0x20,
0x00,

/* Character ?(0xa3):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  **  |
   | *  * |
   | *    |
   |  *   |
   | ***  |
   |  *   |
   | *    |
   | *    |
   | *****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x30,
0x48,
0x40,
0x20,
0x70,
0x20,
0x40,
0x40,
0x7c,
0x00,
0x00,

/* Character ?(0xa4):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *   *|
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   | *   *|
   |      |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x44,
0x38,
0x44,
0x44,
0x44,
0x38,
0x44,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa5):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *   *|
   | *   *|
   | *   *|
   |  * * |
   | *****|
   |   *  |
   | *****|
   |   *  |
   |   *  |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x44,
0x44,
0x44,
0x28,
0x7c,
0x10,
0x7c,
0x10,
0x10,
0x00,
0x00,

/* Character ?(0xa6):
   ht=13, width=2
   +--+
   |  |
   |  |
   | *|
   | *|
   | *|
   | *|
   | *|
   |  |
   | *|
   | *|
   | *|
   | *|
   | *|
   +--+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,

/* Character ?(0xa7):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *** |
   | *   *|
   |  *   |
   | * *  |
   | *  * |
   |  *  *|
   |   * *|
   |    * |
   | *   *|
   |  *** |
   |      |
   +------+ */
0x00,
0x00,
0x38,
0x44,
0x20,
0x50,
0x48,
0x24,
0x14,
0x08,
0x44,
0x38,
0x00,

/* Character ?(0xa8):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |* *|
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0xa0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa9):
   ht=13, width=9
   +---------+
   |         |
   |         |
   |   ****  |
   |  *    * |
   | *  **  *|
   | * *    *|
   | *  **  *|
   |  *    * |
   |   ****  |
   |         |
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x1e,
0x00,
0x21,
0x00,
0x4c,
0x80,
0x50,
0x80,
0x4c,
0x80,
0x21,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xaa):
   ht=13, width=4
   +----+
   |    |
   |    |
   | ** |
   |  **|
   | * *|
   | ***|
   |    |
   | ***|
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x60,
0x30,
0x50,
0x70,
0x00,
0x70,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xab):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |   * *|
   |  * * |
   | * *  |
   |  * * |
   |   * *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x14,
0x28,
0x50,
0x28,
0x14,
0x00,
0x00,

/* Character ?(0xac):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   | *****|
   |     *|
   |      |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0x04,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xad):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   | **|
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xae):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |   ***  |
   |  *   * |
   | * *** *|
   | * **  *|
   | * * * *|
   |  *   * |
   |   ***  |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x1c,
0x22,
0x5d,
0x59,
0x55,
0x22,
0x1c,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xaf):
   ht=13, width=6
   +------+
   |      |
   |******|
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0xfc,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb0):
   ht=13, width=4
   +----+
   |    |
   |    |
   |  * |
   | * *|
   |  * |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x20,
0x50,
0x20,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb1):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |   *  |
   |   *  |
   | *****|
   |   *  |
   |   *  |
   |      |
   | *****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x10,
0x10,
0x7c,
0x10,
0x10,
0x00,
0x7c,
0x00,
0x00,

/* Character ?(0xb2):
   ht=13, width=3
   +---+
   |   |
   |   |
   |** |
   |  *|
   | * |
   |*  |
   |***|
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0xc0,
0x20,
0x40,
0x80,
0xe0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb3):
   ht=13, width=3
   +---+
   |   |
   |   |
   |** |
   |  *|
   | * |
   |  *|
   |** |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0xc0,
0x20,
0x40,
0x20,
0xc0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb4):
   ht=13, width=3
   +---+
   |   |
   |   |
   |  *|
   | * |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x20,
0x40,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb5):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   | *  * |
   | *  * |
   | *  * |
   | *  * |
   | *  * |
   | *** *|
   | *    |
   | *    |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x48,
0x48,
0x48,
0x48,
0x48,
0x74,
0x40,
0x40,

/* Character ?(0xb6):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  ****|
   | *****|
   | *****|
   | *****|
   |  ****|
   |   * *|
   |   * *|
   |   * *|
   |   * *|
   |   * *|
   |      |
   +------+ */
0x00,
0x00,
0x3c,
0x7c,
0x7c,
0x7c,
0x3c,
0x14,
0x14,
0x14,
0x14,
0x14,
0x00,

/* Character ?(0xb7):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   | * |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x40,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb8):
   ht=13, width=3
   +---+
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   |  *|
   | **|
   +---+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x20,
0x60,

/* Character ?(0xb9):
   ht=13, width=3
   +---+
   |   |
   |   |
   |  *|
   | **|
   |  *|
   |  *|
   |  *|
   |   |
   |   |
   |   |
   |   |
   |   |
   |   |
   +---+ */
0x00,
0x00,
0x20,
0x60,
0x20,
0x20,
0x20,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xba):
   ht=13, width=4
   +----+
   |    |
   |    |
   | ***|
   | * *|
   | * *|
   | ***|
   |    |
   | ***|
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x70,
0x50,
0x50,
0x70,
0x00,
0x70,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbb):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   | * *  |
   |  * * |
   |   * *|
   |  * * |
   | * *  |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x50,
0x28,
0x14,
0x28,
0x50,
0x00,
0x00,

/* Character ?(0xbc):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |  *     |
   | **    *|
   |  *   * |
   |  *  *  |
   |  * *  *|
   |   *  **|
   |  *  * *|
   | *   ***|
   |       *|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x20,
0x61,
0x22,
0x24,
0x29,
0x13,
0x25,
0x47,
0x01,
0x00,
0x00,

/* Character ?(0xbd):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |  *     |
   | **    *|
   |  *   * |
   |  *  *  |
   |  * *** |
   |   *   *|
   |  *   * |
   | *   *  |
   |     ***|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x20,
0x61,
0x22,
0x24,
0x2e,
0x11,
0x22,
0x44,
0x07,
0x00,
0x00,

/* Character ?(0xbe):
   ht=13, width=8
   +--------+
   |        |
   |        |
   | **     |
   |   *   *|
   |  *   * |
   |   * *  |
   | ** *  *|
   |   *  **|
   |  *  * *|
   | *   ***|
   |       *|
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x60,
0x11,
0x22,
0x14,
0x69,
0x13,
0x25,
0x47,
0x01,
0x00,
0x00,

/* Character ?(0xbf):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |   *  |
   |      |
   |   *  |
   |   *  |
   |  *   |
   | *    |
   | *    |
   | *   *|
   |  *** |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x10,
0x00,
0x10,
0x10,
0x20,
0x40,
0x40,
0x44,
0x38,

/* Character ?(0xc0):
   ht=13, width=7
   +-------+
   |  *    |
   |   *   |
   |   *   |
   |   *   |
   |  * *  |
   |  * *  |
   | *   * |
   | *   * |
   | ***** |
   |*     *|
   |*     *|
   |       |
   |       |
   +-------+ */
0x20,
0x10,
0x10,
0x10,
0x28,
0x28,
0x44,
0x44,
0x7c,
0x82,
0x82,
0x00,
0x00,

/* Character ?(0xc1):
   ht=13, width=7
   +-------+
   |    *  |
   |   *   |
   |   *   |
   |   *   |
   |  * *  |
   |  * *  |
   | *   * |
   | *   * |
   | ***** |
   |*     *|
   |*     *|
   |       |
   |       |
   +-------+ */
0x08,
0x10,
0x10,
0x10,
0x28,
0x28,
0x44,
0x44,
0x7c,
0x82,
0x82,
0x00,
0x00,

/* Character ?(0xc2):
   ht=13, width=7
   +-------+
   |   *   |
   |  * *  |
   |       |
   |   *   |
   |  * *  |
   |  * *  |
   | *   * |
   | *   * |
   | ***** |
   |*     *|
   |*     *|
   |       |
   |       |
   +-------+ */
0x10,
0x28,
0x00,
0x10,
0x28,
0x28,
0x44,
0x44,
0x7c,
0x82,
0x82,
0x00,
0x00,

/* Character ?(0xc3):
   ht=13, width=7
   +-------+
   |  ** * |
   | * **  |
   |   *   |
   |   *   |
   |  * *  |
   |  * *  |
   | *   * |
   | *   * |
   | ***** |
   |*     *|
   |*     *|
   |       |
   |       |
   +-------+ */
0x34,
0x58,
0x10,
0x10,
0x28,
0x28,
0x44,
0x44,
0x7c,
0x82,
0x82,
0x00,
0x00,

/* Character ?(0xc4):
   ht=13, width=7
   +-------+
   | *   * |
   |       |
   |   *   |
   |   *   |
   |  * *  |
   |  * *  |
   | *   * |
   | *   * |
   | ***** |
   |*     *|
   |*     *|
   |       |
   |       |
   +-------+ */
0x44,
0x00,
0x10,
0x10,
0x28,
0x28,
0x44,
0x44,
0x7c,
0x82,
0x82,
0x00,
0x00,

/* Character ?(0xc5):
   ht=13, width=7
   +-------+
   |   *   |
   |  * *  |
   |   *   |
   |   *   |
   |  * *  |
   |  * *  |
   | *   * |
   | *   * |
   | ***** |
   |*     *|
   |*     *|
   |       |
   |       |
   +-------+ */
0x10,
0x28,
0x10,
0x10,
0x28,
0x28,
0x44,
0x44,
0x7c,
0x82,
0x82,
0x00,
0x00,

/* Character ?(0xc6):
   ht=13, width=10
   +----------+
   |          |
   |          |
   |   ****** |
   |   **     |
   |  * *     |
   |  * *     |
   | *  ****  |
   | ****     |
   | *  *     |
   |*   *     |
   |*   ***** |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x1f,
0x80,
0x18,
0x00,
0x28,
0x00,
0x28,
0x00,
0x4f,
0x00,
0x78,
0x00,
0x48,
0x00,
0x88,
0x00,
0x8f,
0x80,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xc7):
   ht=13, width=7
   +-------+
   |       |
   |       |
   |  **** |
   | *    *|
   | *     |
   | *     |
   | *     |
   | *     |
   | *     |
   | *    *|
   |  **** |
   |    *  |
   |   **  |
   +-------+ */
0x00,
0x00,
0x3c,
0x42,
0x40,
0x40,
0x40,
0x40,
0x40,
0x42,
0x3c,
0x08,
0x18,

/* Character ?(0xc8):
   ht=13, width=7
   +-------+
   |  *    |
   |   *   |
   | ***** |
   | *     |
   | *     |
   | *     |
   | ****  |
   | *     |
   | *     |
   | *     |
   | ***** |
   |       |
   |       |
   +-------+ */
0x20,
0x10,
0x7c,
0x40,
0x40,
0x40,
0x78,
0x40,
0x40,
0x40,
0x7c,
0x00,
0x00,

/* Character ?(0xc9):
   ht=13, width=7
   +-------+
   |    *  |
   |   *   |
   | ***** |
   | *     |
   | *     |
   | *     |
   | ****  |
   | *     |
   | *     |
   | *     |
   | ***** |
   |       |
   |       |
   +-------+ */
0x08,
0x10,
0x7c,
0x40,
0x40,
0x40,
0x78,
0x40,
0x40,
0x40,
0x7c,
0x00,
0x00,

/* Character ?(0xca):
   ht=13, width=7
   +-------+
   |   *   |
   |  * *  |
   | ***** |
   | *     |
   | *     |
   | *     |
   | ****  |
   | *     |
   | *     |
   | *     |
   | ***** |
   |       |
   |       |
   +-------+ */
0x10,
0x28,
0x7c,
0x40,
0x40,
0x40,
0x78,
0x40,
0x40,
0x40,
0x7c,
0x00,
0x00,

/* Character ?(0xcb):
   ht=13, width=7
   +-------+
   | *   * |
   |       |
   | ***** |
   | *     |
   | *     |
   | *     |
   | ****  |
   | *     |
   | *     |
   | *     |
   | ***** |
   |       |
   |       |
   +-------+ */
0x44,
0x00,
0x7c,
0x40,
0x40,
0x40,
0x78,
0x40,
0x40,
0x40,
0x7c,
0x00,
0x00,

/* Character ?(0xcc):
   ht=13, width=3
   +---+
   |*  |
   | * |
   |   |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   |   |
   |   |
   +---+ */
0x80,
0x40,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character ?(0xcd):
   ht=13, width=3
   +---+
   |  *|
   | * |
   |   |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   |   |
   |   |
   +---+ */
0x20,
0x40,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character ?(0xce):
   ht=13, width=3
   +---+
   | * |
   |* *|
   |   |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   |   |
   |   |
   +---+ */
0x40,
0xa0,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character ?(0xcf):
   ht=13, width=3
   +---+
   |* *|
   |   |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   | * |
   |   |
   |   |
   +---+ */
0xa0,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character ?(0xd0):
   ht=13, width=8
   +--------+
   |        |
   |        |
   | ****   |
   | *   *  |
   | *    * |
   | *    * |
   |****  * |
   | *    * |
   | *    * |
   | *   *  |
   | ****   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x78,
0x44,
0x42,
0x42,
0xf2,
0x42,
0x42,
0x44,
0x78,
0x00,
0x00,

/* Character ?(0xd1):
   ht=13, width=8
   +--------+
   |  **  * |
   | *  **  |
   | *    * |
   | **   * |
   | **   * |
   | * *  * |
   | * *  * |
   | *  * * |
   | *   ** |
   | *   ** |
   | *    * |
   |        |
   |        |
   +--------+ */
0x32,
0x4c,
0x42,
0x62,
0x62,
0x52,
0x52,
0x4a,
0x46,
0x46,
0x42,
0x00,
0x00,

/* Character ?(0xd2):
   ht=13, width=8
   +--------+
   |   *    |
   |    *   |
   |  ****  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x10,
0x08,
0x3c,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xd3):
   ht=13, width=8
   +--------+
   |    *   |
   |   *    |
   |  ****  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x08,
0x10,
0x3c,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xd4):
   ht=13, width=8
   +--------+
   |   **   |
   |  *  *  |
   |  ****  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x18,
0x24,
0x3c,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xd5):
   ht=13, width=8
   +--------+
   |  **  * |
   | *  **  |
   |  ****  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x32,
0x4c,
0x3c,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xd6):
   ht=13, width=8
   +--------+
   |  *  *  |
   |        |
   |  ****  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x24,
0x00,
0x3c,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xd7):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   | *   *|
   |  * * |
   |   *  |
   |  * * |
   | *   *|
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x44,
0x28,
0x10,
0x28,
0x44,
0x00,
0x00,
0x00,

/* Character ?(0xd8):
   ht=13, width=8
   +--------+
   |        |
   |        |
   |  ***** |
   | *   ** |
   | *  * * |
   | *  * * |
   | * *  * |
   | * *  * |
   | **   * |
   | **   * |
   | *****  |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x3e,
0x46,
0x4a,
0x4a,
0x52,
0x52,
0x62,
0x62,
0x7c,
0x00,
0x00,

/* Character ?(0xd9):
   ht=13, width=8
   +--------+
   |   *    |
   |    *   |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x10,
0x08,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xda):
   ht=13, width=8
   +--------+
   |    *   |
   |   *    |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x08,
0x10,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xdb):
   ht=13, width=8
   +--------+
   |   **   |
   |  *  *  |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x18,
0x24,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xdc):
   ht=13, width=8
   +--------+
   |  *  *  |
   |        |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   | *    * |
   |  ****  |
   |        |
   |        |
   +--------+ */
0x24,
0x00,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x42,
0x3c,
0x00,
0x00,

/* Character ?(0xdd):
   ht=13, width=7
   +-------+
   |    *  |
   |   *   |
   |*     *|
   |*     *|
   | *   * |
   |  * *  |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |   *   |
   |       |
   |       |
   +-------+ */
0x08,
0x10,
0x82,
0x82,
0x44,
0x28,
0x10,
0x10,
0x10,
0x10,
0x10,
0x00,
0x00,

/* Character ?(0xde):
   ht=13, width=7
   +-------+
   |       |
   |       |
   | *     |
   | *     |
   | ***** |
   | *    *|
   | *    *|
   | *    *|
   | ***** |
   | *     |
   | *     |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x40,
0x40,
0x7c,
0x42,
0x42,
0x42,
0x7c,
0x40,
0x40,
0x00,
0x00,

/* Character ?(0xdf):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  **  |
   | *  * |
   | *  * |
   | *  * |
   | * ** |
   | *   *|
   | *   *|
   | *   *|
   | * ** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x30,
0x48,
0x48,
0x48,
0x58,
0x44,
0x44,
0x44,
0x58,
0x00,
0x00,

/* Character ?(0xe0):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *   |
   |   *  |
   |      |
   |  *** |
   |     *|
   |  ****|
   | *   *|
   | *   *|
   |  ****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x20,
0x10,
0x00,
0x38,
0x04,
0x3c,
0x44,
0x44,
0x3c,
0x00,
0x00,

/* Character ?(0xe1):
   ht=13, width=6
   +------+
   |      |
   |      |
   |    * |
   |   *  |
   |      |
   |  *** |
   |     *|
   |  ****|
   | *   *|
   | *   *|
   |  ****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x08,
0x10,
0x00,
0x38,
0x04,
0x3c,
0x44,
0x44,
0x3c,
0x00,
0x00,

/* Character ?(0xe2):
   ht=13, width=6
   +------+
   |      |
   |      |
   |   *  |
   |  * * |
   |      |
   |  *** |
   |     *|
   |  ****|
   | *   *|
   | *   *|
   |  ****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x10,
0x28,
0x00,
0x38,
0x04,
0x3c,
0x44,
0x44,
0x3c,
0x00,
0x00,

/* Character ?(0xe3):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  ** *|
   | * ** |
   |      |
   |  *** |
   |     *|
   |  ****|
   | *   *|
   | *   *|
   |  ****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x34,
0x58,
0x00,
0x38,
0x04,
0x3c,
0x44,
0x44,
0x3c,
0x00,
0x00,

/* Character ?(0xe4):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *  *|
   |      |
   |      |
   |  *** |
   |     *|
   |  ****|
   | *   *|
   | *   *|
   |  ****|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x24,
0x00,
0x00,
0x38,
0x04,
0x3c,
0x44,
0x44,
0x3c,
0x00,
0x00,

/* Character ?(0xe5):
   ht=13, width=6
   +------+
   |      |
   |   *  |
   |  * * |
   |   *  |
   |      |
   |  *** |
   |     *|
   |  ****|
   | *   *|
   | *   *|
   |  ****|
   |      |
   |      |
   +------+ */
0x00,
0x10,
0x28,
0x10,
0x00,
0x38,
0x04,
0x3c,
0x44,
0x44,
0x3c,
0x00,
0x00,

/* Character ?(0xe6):
   ht=13, width=10
   +----------+
   |          |
   |          |
   |          |
   |          |
   |          |
   |  *** *** |
   |     *   *|
   |  ********|
   | *   *    |
   | *   *   *|
   |  *** *** |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3b,
0x80,
0x04,
0x40,
0x3f,
0xc0,
0x44,
0x00,
0x44,
0x40,
0x3b,
0x80,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xe7):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  *** |
   | *   *|
   | *    |
   | *    |
   | *   *|
   |  *** |
   |   *  |
   |  **  |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x38,
0x44,
0x40,
0x40,
0x44,
0x38,
0x10,
0x30,

/* Character ?(0xe8):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *   |
   |   *  |
   |      |
   |  *** |
   | *   *|
   | *****|
   | *    |
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x20,
0x10,
0x00,
0x38,
0x44,
0x7c,
0x40,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xe9):
   ht=13, width=6
   +------+
   |      |
   |      |
   |    * |
   |   *  |
   |      |
   |  *** |
   | *   *|
   | *****|
   | *    |
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x08,
0x10,
0x00,
0x38,
0x44,
0x7c,
0x40,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xea):
   ht=13, width=6
   +------+
   |      |
   |      |
   |   *  |
   |  * * |
   |      |
   |  *** |
   | *   *|
   | *****|
   | *    |
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x10,
0x28,
0x00,
0x38,
0x44,
0x7c,
0x40,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xeb):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *   *|
   |      |
   |      |
   |  *** |
   | *   *|
   | *****|
   | *    |
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x44,
0x00,
0x00,
0x38,
0x44,
0x7c,
0x40,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xec):
   ht=13, width=2
   +--+
   |  |
   |  |
   |* |
   | *|
   |  |
   | *|
   | *|
   | *|
   | *|
   | *|
   | *|
   |  |
   |  |
   +--+ */
0x00,
0x00,
0x80,
0x40,
0x00,
0x40,
0x40,
0x40,
0x40,
0x40,
0x40,
0x00,
0x00,

/* Character ?(0xed):
   ht=13, width=4
   +----+
   |    |
   |    |
   |   *|
   |  * |
   |    |
   |  * |
   |  * |
   |  * |
   |  * |
   |  * |
   |  * |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x10,
0x20,
0x00,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x00,
0x00,

/* Character ?(0xee):
   ht=13, width=4
   +----+
   |    |
   |    |
   |  * |
   | * *|
   |    |
   |  * |
   |  * |
   |  * |
   |  * |
   |  * |
   |  * |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x20,
0x50,
0x00,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x00,
0x00,

/* Character ?(0xef):
   ht=13, width=4
   +----+
   |    |
   |    |
   | * *|
   |    |
   |    |
   |  * |
   |  * |
   |  * |
   |  * |
   |  * |
   |  * |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x50,
0x00,
0x00,
0x20,
0x20,
0x20,
0x20,
0x20,
0x20,
0x00,
0x00,

/* Character ?(0xf0):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  * * |
   |   *  |
   |  * * |
   |    * |
   |  ****|
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x28,
0x10,
0x28,
0x08,
0x3c,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xf1):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  ** *|
   | * ** |
   |      |
   | * ** |
   | **  *|
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x34,
0x58,
0x00,
0x58,
0x64,
0x44,
0x44,
0x44,
0x44,
0x00,
0x00,

/* Character ?(0xf2):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *   |
   |   *  |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x20,
0x10,
0x00,
0x38,
0x44,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xf3):
   ht=13, width=6
   +------+
   |      |
   |      |
   |    * |
   |   *  |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x08,
0x10,
0x00,
0x38,
0x44,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xf4):
   ht=13, width=6
   +------+
   |      |
   |      |
   |   *  |
   |  * * |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x10,
0x28,
0x00,
0x38,
0x44,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xf5):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  ** *|
   | * ** |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x34,
0x58,
0x00,
0x38,
0x44,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xf6):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *   *|
   |      |
   |      |
   |  *** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   |  *** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x44,
0x00,
0x00,
0x38,
0x44,
0x44,
0x44,
0x44,
0x38,
0x00,
0x00,

/* Character ?(0xf7):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |   *  |
   |      |
   | *****|
   |      |
   |   *  |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x10,
0x00,
0x7c,
0x00,
0x10,
0x00,
0x00,
0x00,

/* Character ?(0xf8):
   ht=13, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  ****|
   | *  **|
   | * * *|
   | * * *|
   | **  *|
   | **** |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x4c,
0x54,
0x54,
0x64,
0x78,
0x00,
0x00,

/* Character ?(0xf9):
   ht=13, width=6
   +------+
   |      |
   |      |
   |  *   |
   |   *  |
   |      |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | *  **|
   |  ** *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x20,
0x10,
0x00,
0x44,
0x44,
0x44,
0x44,
0x4c,
0x34,
0x00,
0x00,

/* Character ?(0xfa):
   ht=13, width=6
   +------+
   |      |
   |      |
   |    * |
   |   *  |
   |      |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | *  **|
   |  ** *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x08,
0x10,
0x00,
0x44,
0x44,
0x44,
0x44,
0x4c,
0x34,
0x00,
0x00,

/* Character ?(0xfb):
   ht=13, width=6
   +------+
   |      |
   |      |
   |   *  |
   |  * * |
   |      |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | *  **|
   |  ** *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x10,
0x28,
0x00,
0x44,
0x44,
0x44,
0x44,
0x4c,
0x34,
0x00,
0x00,

/* Character ?(0xfc):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *   *|
   |      |
   |      |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | *  **|
   |  ** *|
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x44,
0x00,
0x00,
0x44,
0x44,
0x44,
0x44,
0x4c,
0x34,
0x00,
0x00,

/* Character ?(0xfd):
   ht=13, width=5
   +-----+
   |     |
   |     |
   |   * |
   |  *  |
   |     |
   | *  *|
   | *  *|
   | *  *|
   | *  *|
   |  ** |
   |  *  |
   |  *  |
   |**   |
   +-----+ */
0x00,
0x00,
0x10,
0x20,
0x00,
0x48,
0x48,
0x48,
0x48,
0x30,
0x20,
0x20,
0xc0,

/* Character ?(0xfe):
   ht=13, width=6
   +------+
   |      |
   |      |
   | *    |
   | *    |
   | *    |
   | **** |
   | *   *|
   | *   *|
   | *   *|
   | *   *|
   | **** |
   | *    |
   | *    |
   +------+ */
0x00,
0x00,
0x40,
0x40,
0x40,
0x78,
0x44,
0x44,
0x44,
0x44,
0x78,
0x40,
0x40,

/* Character  (0xff):
   ht=13, width=5
   +-----+
   |     |
   |     |
   | *  *|
   |     |
   |     |
   | *  *|
   | *  *|
   | *  *|
   | *  *|
   |  ** |
   |  *  |
   |  *  |
   |**   |
   +-----+ */
0x00,
0x00,
0x48,
0x00,
0x00,
0x48,
0x48,
0x48,
0x48,
0x30,
0x20,
0x20,
0xc0,


};

/* Character->glyph data. */
static const unsigned int offset[] = {
  0,
  13,
  26,
  39,
  52,
  65,
  78,
  91,
  104,
  117,
  130,
  143,
  156,
  169,
  182,
  195,
  208,
  221,
  234,
  247,
  260,
  273,
  286,
  299,
  312,
  325,
  338,
  351,
  364,
  377,
  390,
  403,
  416,
  442,
  455,
  468,
  481,
  494,
  507,
  520,
  533,
  546,
  559,
  572,
  585,
  598,
  624,
  637,
  650,
  663,
  676,
  689,
  702,
  715,
  728,
  741,
  767,
  780,
  793,
  806,
  819,
  832,
  845,
  858,
  871,
  884,
  897,
  910,
  923,
  936,
  949,
  962,
  975,
  988,
  1001,
  1014,
  1027,
  1040,
  1053,
  1066,
  1079,
  1092,
  1105,
  1118,
  1131,
  1144,
  1157,
  1170,
  1183,
  1196,
  1209,
  1222,
  1235,
  1248,
  1261,
  1274,
  1287,
  1300,
  1313,
  1326,
  1339,
  1352,
  1365,
  1378,
  1391,
  1404,
  1417,
  1430,
  1443,
  1456,
  1469,
  1482,
  1495,
  1508,
  1521,
  1534,
  1547,
  1560,
  1573,
  1586,
  1599,
  1612,
  1625,
  1638,
  1651,
  1664,
  1677,
  1690,
  1703,
  1716,
  1729,
  1742,
  1755,
  1768,
  1781,
  1794,
  1807,
  1820,
  1846,
  1859,
  1872,
  1885,
  1898,
  1911,
  1924,
  1937,
  1950,
  1963,
  1976,
  1989,
  2002,
  2015,
  2028,
  2041,
  2054,
  2067,
  2080,
  2093,
  2106,
  2119,
  2132,
  2145,
  2158,
  2171,
  2184,
  2197,
  2210,
  2236,
  2249,
  2262,
  2275,
  2288,
  2301,
  2314,
  2327,
  2340,
  2353,
  2366,
  2379,
  2392,
  2405,
  2418,
  2431,
  2444,
  2457,
  2470,
  2483,
  2496,
  2509,
  2522,
  2535,
  2548,
  2561,
  2574,
  2587,
  2600,
  2613,
  2626,
  2639,
  2665,
  2678,
  2691,
  2704,
  2717,
  2730,
  2743,
  2756,
  2769,
  2782,
  2795,
  2808,
  2821,
  2834,
  2847,
  2860,
  2873,
  2886,
  2899,
  2912,
  2925,
  2938,
  2951,
  2964,
  2977,
};

/* Character width data. */
static const char advance_x[] = {
  3,
  3,
  5,
  7,
  6,
  8,
  6,
  2,
  3,
  3,
  4,
  6,
  3,
  3,
  3,
  5,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  3,
  3,
  6,
  6,
  6,
  6,
  11,
  7,
  7,
  7,
  8,
  7,
  6,
  8,
  8,
  3,
  5,
  7,
  6,
  9,
  8,
  8,
  7,
  8,
  8,
  7,
  7,
  8,
  7,
  11,
  7,
  7,
  7,
  3,
  5,
  3,
  6,
  6,
  3,
  6,
  6,
  6,
  6,
  6,
  3,
  6,
  6,
  2,
  2,
  6,
  2,
  8,
  6,
  6,
  6,
  6,
  3,
  5,
  3,
  6,
  6,
  8,
  5,
  5,
  5,
  4,
  2,
  4,
  7,
  3,
  6,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  3,
  6,
  6,
  6,
  6,
  2,
  6,
  3,
  9,
  4,
  6,
  6,
  3,
  8,
  6,
  4,
  6,
  3,
  3,
  3,
  6,
  6,
  3,
  3,
  3,
  4,
  6,
  8,
  8,
  8,
  6,
  7,
  7,
  7,
  7,
  7,
  7,
  10,
  7,
  7,
  7,
  7,
  7,
  3,
  3,
  3,
  3,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  6,
  8,
  8,
  8,
  8,
  8,
  7,
  7,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  10,
  6,
  6,
  6,
  6,
  6,
  2,
  4,
  4,
  4,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  6,
  5,
  6,
  5,
};

/* Exported structure definition. */
VBFINFO __mgif_vbf_SansSerif11x13 = {
   "3.0",
   "vbf-SansSerif-rrncnn-11-13-ISO8859-1",

   11,
   8,
   13,
   1,

   32,
   255,
   0x3f,

   0,

   NULL,
   advance_x,
   NULL,
   offset,
   bits,
};

#endif /* _MGINCOREFONT_SANSSERIF */
#endif /* _MGFONT_VBF */
