///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/blog/minigui-licensing-policy/>.
 */
/*
** $Id: system_14x16.c 8944 2007-12-29 08:29:16Z xwyan $
** 
** system_14x16.c: System 14x16 VBF font data.
**
*/

#include <stdio.h>
#include <stdlib.h>

#include "common.h"
#include "minigui.h"
#include "gdi.h"
#include "devfont.h"

#ifdef _MGFONT_VBF
#ifdef _MGINCOREFONT_SYSTEM

#include "varbitmap.h"

static const unsigned char bits[] = {

/* Character   (0x20):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ! (0x21):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character " (0x22):
   ht=16, width=6
   +------+
   |      |
   |      |
   |      |
   |**  **|
   |**  **|
   |**  **|
   |**  **|
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0xcc,
0xcc,
0xcc,
0xcc,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character # (0x23):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ** ** |
   |  ** ** |
   | *******|
   |  ** ** |
   |  ** ** |
   | ** **  |
   | ** **  |
   |******* |
   | ** **  |
   | ** **  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x36,
0x36,
0x7f,
0x36,
0x36,
0x6c,
0x6c,
0xfe,
0x6c,
0x6c,
0x00,
0x00,
0x00,

/* Character $ (0x24):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   | **  ** |
   | **     |
   |  ****  |
   |     ** |
   |     ** |
   | **  ** |
   |  ****  |
   |   **   |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x3c,
0x66,
0x66,
0x60,
0x3c,
0x06,
0x06,
0x66,
0x3c,
0x18,
0x00,
0x00,

/* Character % (0x25):
   ht=16, width=11
   +-----------+
   |           |
   |           |
   |           |
   | ***     **|
   |** **   ** |
   |** **  **  |
   |** ** **   |
   | *** **    |
   |    ** *** |
   |   ** ** **|
   |  **  ** **|
   | **   ** **|
   |**     *** |
   |           |
   |           |
   |           |
   +-----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x70,
0x60,
0xd8,
0xc0,
0xd9,
0x80,
0xdb,
0x00,
0x76,
0x00,
0x0d,
0xc0,
0x1b,
0x60,
0x33,
0x60,
0x63,
0x60,
0xc1,
0xc0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character & (0x26):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   |   ***   |
   |  ** **  |
   |  ** **  |
   |  ** **  |
   |   ***   |
   |  ***    |
   | ** ** * |
   | **  *** |
   | **  **  |
   |  ****** |
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1c,
0x00,
0x36,
0x00,
0x36,
0x00,
0x36,
0x00,
0x1c,
0x00,
0x38,
0x00,
0x6d,
0x00,
0x67,
0x00,
0x66,
0x00,
0x3f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ' (0x27):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ( (0x28):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |  **|
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |  **|
   +----+ */
0x00,
0x00,
0x00,
0x30,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x30,

/* Character ) (0x29):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |**  |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |**  |
   +----+ */
0x00,
0x00,
0x00,
0xc0,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0xc0,

/* Character * (0x2a):
   ht=16, width=6
   +------+
   |      |
   |      |
   |      |
   |  **  |
   |******|
   |  **  |
   | **** |
   | *  * |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x30,
0xfc,
0x30,
0x78,
0x48,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character + (0x2b):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x18,
0x7e,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,
0x00,

/* Character , (0x2c):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |**  |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0xc0,
0x00,
0x00,

/* Character - (0x2d):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |****|
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xf0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character . (0x2e):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character / (0x2f):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |  **|
   |  **|
   |  **|
   |  **|
   | ** |
   | ** |
   | ** |
   | ** |
   |**  |
   |**  |
   |**  |
   |**  |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x30,
0x30,
0x30,
0x30,
0x60,
0x60,
0x60,
0x60,
0xc0,
0xc0,
0xc0,
0xc0,
0x00,

/* Character 0 (0x30):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character 1 (0x31):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   | ****   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x78,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character 2 (0x32):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character 3 (0x33):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   |     ** |
   |     ** |
   |   ***  |
   |     ** |
   |     ** |
   |     ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x06,
0x06,
0x1c,
0x06,
0x06,
0x06,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character 4 (0x34):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |     ** |
   |    *** |
   |   **** |
   |   **** |
   |  ** ** |
   |  ** ** |
   | **  ** |
   | ****** |
   |     ** |
   |     ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x06,
0x0e,
0x1e,
0x1e,
0x36,
0x36,
0x66,
0x7e,
0x06,
0x06,
0x00,
0x00,
0x00,

/* Character 5 (0x35):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   |     ** |
   |     ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x60,
0x60,
0x60,
0x7c,
0x66,
0x06,
0x06,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character 6 (0x36):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character 7 (0x37):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | ****** |
   |     ** |
   |    **  |
   |    **  |
   |   **   |
   |   **   |
   |   **   |
   |  **    |
   |  **    |
   |  **    |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7e,
0x06,
0x0c,
0x0c,
0x18,
0x18,
0x18,
0x30,
0x30,
0x30,
0x00,
0x00,
0x00,

/* Character 8 (0x38):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character 9 (0x39):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |     ** |
   |     ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x06,
0x06,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character : (0x3a):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ; (0x3b):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |**  |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0xc0,
0x00,
0x00,

/* Character < (0x3c):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x00,
0x00,
0x00,

/* Character = (0x3d):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |        |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x00,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character > (0x3e):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   | **     |
   |  **    |
   |   **   |
   |    **  |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x30,
0x18,
0x0c,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x00,
0x00,
0x00,

/* Character ? (0x3f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   |     ** |
   |    **  |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x06,
0x0c,
0x18,
0x18,
0x00,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character @ (0x40):
   ht=16, width=14
   +--------------+
   |              |
   |              |
   |     ****     |
   |   ***  ***   |
   |  **      **  |
   |  **  *** **  |
   | **  ** ** ** |
   | **  ** ** ** |
   | ** **  ** ** |
   | ** ** **  ** |
   | ** ** **  ** |
   |  ** ** ****  |
   |  **          |
   |   ***   ***  |
   |     *****    |
   |              |
   +--------------+ */
0x00,
0x00,
0x00,
0x00,
0x07,
0x80,
0x1c,
0xe0,
0x30,
0x30,
0x33,
0xb0,
0x66,
0xd8,
0x66,
0xd8,
0x6c,
0xd8,
0x6d,
0x98,
0x6d,
0x98,
0x36,
0xf0,
0x30,
0x00,
0x1c,
0x70,
0x07,
0xc0,
0x00,
0x00,

/* Character A (0x41):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |  ****  |
   |  ****  |
   |  *  *  |
   | **  ** |
   | **  ** |
   | ****** |
   |**    **|
   |**    **|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x18,
0x3c,
0x3c,
0x24,
0x66,
0x66,
0x7e,
0xc3,
0xc3,
0x00,
0x00,
0x00,

/* Character B (0x42):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   | *******  |
   | **    ** |
   | **    ** |
   | **    ** |
   | *******  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | *******  |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7f,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x7f,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x7f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character C (0x43):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   |   ****  |
   |  **  ** |
   | **    * |
   | **      |
   | **      |
   | **      |
   | **      |
   | **    * |
   |  **  ** |
   |   ****  |
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x61,
0x00,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character D (0x44):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   | ******   |
   | **   **  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **   **  |
   | ******   |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x00,
0x63,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x63,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character E (0x45):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   | ******* |
   | **      |
   | **      |
   | **      |
   | ******  |
   | **      |
   | **      |
   | **      |
   | **      |
   | ******* |
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7f,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7e,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character F (0x46):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | *******|
   | **     |
   | **     |
   | **     |
   | ****** |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7f,
0x60,
0x60,
0x60,
0x7e,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character G (0x47):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   |   *****  |
   |  **   ** |
   | **     * |
   | **       |
   | **       |
   | **  **** |
   | **    ** |
   | **    ** |
   |  **   ** |
   |   **** * |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1f,
0x00,
0x31,
0x80,
0x60,
0x80,
0x60,
0x00,
0x60,
0x00,
0x67,
0x80,
0x61,
0x80,
0x61,
0x80,
0x31,
0x80,
0x1e,
0x80,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character H (0x48):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | ******** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x7f,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character I (0x49):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character J (0x4a):
   ht=16, width=7
   +-------+
   |       |
   |       |
   |       |
   |    ** |
   |    ** |
   |    ** |
   |    ** |
   |    ** |
   |    ** |
   |    ** |
   |**  ** |
   |**  ** |
   | ****  |
   |       |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x00,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0x0c,
0xcc,
0xcc,
0x78,
0x00,
0x00,
0x00,

/* Character K (0x4b):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   | **   ** |
   | **  **  |
   | ** **   |
   | ****    |
   | ***     |
   | ****    |
   | ** **   |
   | **  **  |
   | **   ** |
   | **    **|
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x63,
0x00,
0x66,
0x00,
0x6c,
0x00,
0x78,
0x00,
0x70,
0x00,
0x78,
0x00,
0x6c,
0x00,
0x66,
0x00,
0x63,
0x00,
0x61,
0x80,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character L (0x4c):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | **     |
   | *******|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x7f,
0x00,
0x00,
0x00,

/* Character M (0x4d):
   ht=16, width=12
   +------------+
   |            |
   |            |
   |            |
   | **      ** |
   | **      ** |
   | ***    *** |
   | ***    *** |
   | ****  **** |
   | ****  **** |
   | ** **** ** |
   | ** **** ** |
   | **  **  ** |
   | **  **  ** |
   |            |
   |            |
   |            |
   +------------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x70,
0xe0,
0x70,
0xe0,
0x79,
0xe0,
0x79,
0xe0,
0x6f,
0x60,
0x6f,
0x60,
0x66,
0x60,
0x66,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character N (0x4e):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   | **    ** |
   | ***   ** |
   | ****  ** |
   | ****  ** |
   | ** ** ** |
   | ** ** ** |
   | **  **** |
   | **  **** |
   | **   *** |
   | **    ** |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x61,
0x80,
0x71,
0x80,
0x79,
0x80,
0x79,
0x80,
0x6d,
0x80,
0x6d,
0x80,
0x67,
0x80,
0x67,
0x80,
0x63,
0x80,
0x61,
0x80,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character O (0x4f):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   |   ****   |
   |  **  **  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character P (0x50):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   | ******* |
   | **    **|
   | **    **|
   | **    **|
   | **    **|
   | ******* |
   | **      |
   | **      |
   | **      |
   | **      |
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7f,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x7f,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character Q (0x51):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   |   ****   |
   |  **  **  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **  **** |
   |  **  **  |
   |   ****** |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x67,
0x80,
0x33,
0x00,
0x1f,
0x80,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character R (0x52):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   | *******  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | *******  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **     **|
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7f,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x7f,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x60,
0xc0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character S (0x53):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   |  *****  |
   | **   ** |
   | **   ** |
   | **      |
   |  ***    |
   |    ***  |
   |      ** |
   | **   ** |
   | **   ** |
   |  *****  |
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3e,
0x00,
0x63,
0x00,
0x63,
0x00,
0x60,
0x00,
0x38,
0x00,
0x0e,
0x00,
0x03,
0x00,
0x63,
0x00,
0x63,
0x00,
0x3e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character T (0x54):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |********|
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0xff,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character U (0x55):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character V (0x56):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |**    **|
   |**    **|
   | **  ** |
   | **  ** |
   | **  ** |
   |  *  *  |
   |  ****  |
   |  ****  |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0xc3,
0xc3,
0x66,
0x66,
0x66,
0x24,
0x3c,
0x3c,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character W (0x57):
   ht=16, width=14
   +--------------+
   |              |
   |              |
   |              |
   |**    **    **|
   |**    **    **|
   |**    **    **|
   | **  ****  ** |
   | **  ****  ** |
   |  ** *  * **  |
   |  ****  ****  |
   |   **    **   |
   |   **    **   |
   |   **    **   |
   |              |
   |              |
   |              |
   +--------------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xc3,
0x0c,
0xc3,
0x0c,
0xc3,
0x0c,
0x67,
0x98,
0x67,
0x98,
0x34,
0xb0,
0x3c,
0xf0,
0x18,
0x60,
0x18,
0x60,
0x18,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character X (0x58):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   |**     **|
   |**     **|
   | **   ** |
   |  ** **  |
   |   ***   |
   |   ***   |
   |  ** **  |
   | **   ** |
   |**     **|
   |**     **|
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xc1,
0x80,
0xc1,
0x80,
0x63,
0x00,
0x36,
0x00,
0x1c,
0x00,
0x1c,
0x00,
0x36,
0x00,
0x63,
0x00,
0xc1,
0x80,
0xc1,
0x80,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character Y (0x59):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   |**      **|
   |**      **|
   | **    ** |
   |  **  **  |
   |   ****   |
   |    **    |
   |    **    |
   |    **    |
   |    **    |
   |    **    |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xc0,
0xc0,
0xc0,
0xc0,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x0c,
0x00,
0x0c,
0x00,
0x0c,
0x00,
0x0c,
0x00,
0x0c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character Z (0x5a):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   |*********|
   |       **|
   |      ** |
   |     **  |
   |    **   |
   |   **    |
   |  **     |
   | **      |
   |**       |
   |*********|
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,
0x80,
0x01,
0x80,
0x03,
0x00,
0x06,
0x00,
0x0c,
0x00,
0x18,
0x00,
0x30,
0x00,
0x60,
0x00,
0xc0,
0x00,
0xff,
0x80,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character [ (0x5b):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ***|
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ***|
   +----+ */
0x00,
0x00,
0x00,
0x70,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x70,

/* Character \ (0x5c):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |**  |
   |**  |
   |**  |
   |**  |
   | ** |
   | ** |
   | ** |
   | ** |
   |  **|
   |  **|
   |  **|
   |  **|
   |    |
   +----+ */
0x00,
0x00,
0x00,
0xc0,
0xc0,
0xc0,
0xc0,
0x60,
0x60,
0x60,
0x60,
0x30,
0x30,
0x30,
0x30,
0x00,

/* Character ] (0x5d):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |*** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |*** |
   +----+ */
0x00,
0x00,
0x00,
0xe0,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0xe0,

/* Character ^ (0x5e):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   |  *  |
   | *** |
   |** **|
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0x20,
0x70,
0xd8,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character _ (0x5f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |********|
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xff,

/* Character ` (0x60):
   ht=16, width=5
   +-----+
   |     |
   |     |
   | *** |
   |  ** |
   |   **|
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x70,
0x30,
0x18,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character a (0x61):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   |   **** |
   |  ** ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x1e,
0x36,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character b (0x62):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x00,
0x00,
0x00,

/* Character c (0x63):
   ht=16, width=7
   +-------+
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   |  **** |
   | **  **|
   | **    |
   | **    |
   | **    |
   | **  **|
   |  **** |
   |       |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x60,
0x60,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character d (0x64):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |     ** |
   |     ** |
   |     ** |
   |  ***** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x06,
0x06,
0x06,
0x3e,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character e (0x65):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x7e,
0x60,
0x60,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character f (0x66):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |  **|
   | ** |
   | ** |
   |****|
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x30,
0x60,
0x60,
0xf0,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character g (0x67):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |     ** |
   | **  ** |
   |  ****  |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3e,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x06,
0x66,
0x3c,

/* Character h (0x68):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character i (0x69):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character j (0x6a):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |**  |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0xc0,

/* Character k (0x6b):
   ht=16, width=7
   +-------+
   |       |
   |       |
   |       |
   | **    |
   | **    |
   | **    |
   | **  **|
   | ** ** |
   | ****  |
   | ***   |
   | ****  |
   | ** ** |
   | **  **|
   |       |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x66,
0x6c,
0x78,
0x70,
0x78,
0x6c,
0x66,
0x00,
0x00,
0x00,

/* Character l (0x6c):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character m (0x6d):
   ht=16, width=12
   +------------+
   |            |
   |            |
   |            |
   |            |
   |            |
   |            |
   | *********  |
   | **  **  ** |
   | **  **  ** |
   | **  **  ** |
   | **  **  ** |
   | **  **  ** |
   | **  **  ** |
   |            |
   |            |
   |            |
   +------------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7f,
0xc0,
0x66,
0x60,
0x66,
0x60,
0x66,
0x60,
0x66,
0x60,
0x66,
0x60,
0x66,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character n (0x6e):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character o (0x6f):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character p (0x70):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   | **     |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0x60,

/* Character q (0x71):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |     ** |
   |     ** |
   |     ** |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3e,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x06,
0x06,
0x06,

/* Character r (0x72):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   | ****|
   | *** |
   | **  |
   | **  |
   | **  |
   | **  |
   | **  |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x78,
0x70,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character s (0x73):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **     |
   |  ****  |
   |     ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x3c,
0x06,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character t (0x74):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |****|
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |  **|
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0xf0,
0x60,
0x60,
0x60,
0x60,
0x60,
0x30,
0x00,
0x00,
0x00,

/* Character u (0x75):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character v (0x76):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |**    **|
   |**    **|
   | **  ** |
   | **  ** |
   |  ****  |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xc3,
0xc3,
0x66,
0x66,
0x3c,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character w (0x77):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   |          |
   |          |
   |          |
   |**      **|
   |**  **  **|
   | ** ** ** |
   | ** ** ** |
   | ******** |
   |  **  **  |
   |  **  **  |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xc0,
0xc0,
0xcc,
0xc0,
0x6d,
0x80,
0x6d,
0x80,
0x7f,
0x80,
0x33,
0x00,
0x33,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character x (0x78):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |**    **|
   | **  ** |
   |  ****  |
   |   **   |
   |  ****  |
   | **  ** |
   |**    **|
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xc3,
0x66,
0x3c,
0x18,
0x3c,
0x66,
0xc3,
0x00,
0x00,
0x00,

/* Character y (0x79):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |**    **|
   |**    **|
   | **  ** |
   | **  ** |
   |  ****  |
   |  ****  |
   |   **   |
   |   **   |
   |  **    |
   | **     |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xc3,
0xc3,
0x66,
0x66,
0x3c,
0x3c,
0x18,
0x18,
0x30,
0x60,

/* Character z (0x7a):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |     ** |
   |    **  |
   |   **   |
   |  **    |
   | **     |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x06,
0x0c,
0x18,
0x30,
0x60,
0x7e,
0x00,
0x00,
0x00,

/* Character { (0x7b):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   |   **|
   |  ** |
   |  ** |
   |  ** |
   |  ** |
   |  ** |
   | **  |
   |  ** |
   |  ** |
   |  ** |
   |  ** |
   |  ** |
   |   **|
   +-----+ */
0x00,
0x00,
0x00,
0x18,
0x30,
0x30,
0x30,
0x30,
0x30,
0x60,
0x30,
0x30,
0x30,
0x30,
0x30,
0x18,

/* Character | (0x7c):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,

/* Character } (0x7d):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   |**   |
   | **  |
   | **  |
   | **  |
   | **  |
   | **  |
   |  ** |
   | **  |
   | **  |
   | **  |
   | **  |
   | **  |
   |**   |
   +-----+ */
0x00,
0x00,
0x00,
0xc0,
0x60,
0x60,
0x60,
0x60,
0x60,
0x30,
0x60,
0x60,
0x60,
0x60,
0x60,
0xc0,

/* Character ~ (0x7e):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   |*** *|
   |* ***|
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0xe8,
0xb8,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character  (0x7f):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character  (0x80):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x81):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x82):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x83):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x84):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x85):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x86):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x87):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x88):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x89):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x8a):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x8b):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x8c):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x8d):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x8e):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x8f):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x90):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x91):
   ht=16, width=4
   +----+
   |    |
   |    |
   |  **|
   | ** |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x30,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0x92):
   ht=16, width=4
   +----+
   |    |
   |    |
   | ** |
   |**  |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x60,
0xc0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0x93):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x94):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x95):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x96):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x97):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x98):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x99):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x9a):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x9b):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x9c):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x9d):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x9e):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0x9f):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xa0):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa1):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xa2):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |    **  |
   |  ****  |
   | ** *** |
   | ** *   |
   | ** *   |
   | ***    |
   | *** ** |
   |  ****  |
   |  **    |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x0c,
0x3c,
0x6e,
0x68,
0x68,
0x70,
0x76,
0x3c,
0x30,
0x00,
0x00,

/* Character ?(0xa3):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ***   |
   | ** **  |
   | **     |
   | **     |
   |  **    |
   | ****   |
   |  **    |
   |  **    |
   | **  ** |
   | *****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x38,
0x6c,
0x60,
0x60,
0x30,
0x78,
0x30,
0x30,
0x66,
0x7c,
0x00,
0x00,
0x00,

/* Character ?(0xa4):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   |  ****  |
   |  *  *  |
   |  *  *  |
   |  ****  |
   | **  ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x3c,
0x24,
0x24,
0x3c,
0x66,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa5):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |**    **|
   |**    **|
   | **  ** |
   | **  ** |
   |********|
   |   **   |
   |********|
   |   **   |
   |   **   |
   |   **   |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0xc3,
0xc3,
0x66,
0x66,
0xff,
0x18,
0xff,
0x18,
0x18,
0x18,
0x00,
0x00,
0x00,

/* Character ?(0xa6):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,

/* Character ?(0xa7):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   |  ***   |
   |  ***   |
   | ** **  |
   |  ** ** |
   |   ***  |
   |   ***  |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x38,
0x38,
0x6c,
0x36,
0x1c,
0x1c,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xa8):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   |** **|
   |** **|
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0xd8,
0xd8,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xa9):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   |  ******  |
   | **    ** |
   |**  **  **|
   |** *  * **|
   |** *    **|
   |** *    **|
   |** *  * **|
   |**  **  **|
   | **    ** |
   |  ******  |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3f,
0x00,
0x61,
0x80,
0xcc,
0xc0,
0xd2,
0xc0,
0xd0,
0xc0,
0xd0,
0xc0,
0xd2,
0xc0,
0xcc,
0xc0,
0x61,
0x80,
0x3f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xaa):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   |  *  |
   |   * |
   |  ** |
   | * * |
   |  ** |
   |     |
   | *** |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0x20,
0x10,
0x30,
0x50,
0x30,
0x00,
0x70,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xab):
   ht=16, width=7
   +-------+
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   |  ** **|
   | ** ** |
   |** **  |
   | ** ** |
   |  ** **|
   |       |
   |       |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x36,
0x6c,
0xd8,
0x6c,
0x36,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xac):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | ****** |
   |     ** |
   |     ** |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x06,
0x06,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xad):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |****|
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xf0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xae):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   |  ******  |
   | **    ** |
   |** ***  **|
   |** *  * **|
   |** *  * **|
   |** ***  **|
   |** * *  **|
   |** *  * **|
   | **    ** |
   |  ******  |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3f,
0x00,
0x61,
0x80,
0xdc,
0xc0,
0xd2,
0xc0,
0xd2,
0xc0,
0xdc,
0xc0,
0xd4,
0xc0,
0xd2,
0xc0,
0x61,
0x80,
0x3f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xaf):
   ht=16, width=8
   +--------+
   |        |
   |********|
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0xff,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb0):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   | *** |
   | * * |
   | * * |
   | *** |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0x70,
0x50,
0x50,
0x70,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb1):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   | ****** |
   |   **   |
   |   **   |
   |        |
   | ****** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x18,
0x18,
0x7e,
0x18,
0x18,
0x00,
0x7e,
0x00,
0x00,
0x00,

/* Character ?(0xb2):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   |* **|
   |  **|
   | ** |
   |****|
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0xb0,
0x30,
0x60,
0xf0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb3):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   |* **|
   | ** |
   |* **|
   | ** |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0xb0,
0x60,
0xb0,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb4):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |  ***|
   |  ** |
   | **  |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x38,
0x30,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb5):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *******|
   | **     |
   | **     |
   | **     |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x7f,
0x60,
0x60,
0x60,

/* Character ?(0xb6):
   ht=16, width=7
   +-------+
   |       |
   |       |
   |       |
   |  **** |
   | ***** |
   | ***** |
   | ***** |
   | ***** |
   |  **** |
   |    ** |
   |    ** |
   |    ** |
   |    ** |
   |       |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x00,
0x3c,
0x7c,
0x7c,
0x7c,
0x7c,
0x3c,
0x0c,
0x0c,
0x0c,
0x0c,
0x00,
0x00,
0x00,

/* Character ?(0xb7):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xb8):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   |  ** |
   |   **|
   | *** |
   +-----+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x30,
0x18,
0x70,

/* Character ?(0xb9):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   | ** |
   |*** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x60,
0xe0,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xba):
   ht=16, width=5
   +-----+
   |     |
   |     |
   |     |
   | *** |
   | * * |
   | * * |
   | * * |
   | *** |
   |     |
   | *** |
   |     |
   |     |
   |     |
   |     |
   |     |
   |     |
   +-----+ */
0x00,
0x00,
0x00,
0x70,
0x50,
0x50,
0x50,
0x70,
0x00,
0x70,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbb):
   ht=16, width=7
   +-------+
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   |** **  |
   | ** ** |
   |  ** **|
   | ** ** |
   |** **  |
   |       |
   |       |
   |       |
   |       |
   +-------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0xd8,
0x6c,
0x36,
0x6c,
0xd8,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbc):
   ht=16, width=11
   +-----------+
   |           |
   |           |
   |           |
   |  **     **|
   | ***    ** |
   |  **   **  |
   |  **  **   |
   |  ** **    |
   |    **  ** |
   |   **  *** |
   |  **  ** * |
   | **   **** |
   |**      ** |
   |           |
   |           |
   |           |
   +-----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x30,
0x60,
0x70,
0xc0,
0x31,
0x80,
0x33,
0x00,
0x36,
0x00,
0x0c,
0xc0,
0x19,
0xc0,
0x33,
0x40,
0x63,
0xc0,
0xc0,
0xc0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbd):
   ht=16, width=11
   +-----------+
   |           |
   |           |
   |           |
   |  **     **|
   | ***    ** |
   |  **   **  |
   |  **  **   |
   |  ** **    |
   |    ** **  |
   |   ** * ** |
   |  **    ** |
   | **    **  |
   |**    **** |
   |           |
   |           |
   |           |
   +-----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x30,
0x60,
0x70,
0xc0,
0x31,
0x80,
0x33,
0x00,
0x36,
0x00,
0x0d,
0x80,
0x1a,
0xc0,
0x30,
0xc0,
0x61,
0x80,
0xc3,
0xc0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbe):
   ht=16, width=11
   +-----------+
   |           |
   |           |
   |           |
   |  **     **|
   | * **   ** |
   |  **   **  |
   | * ** **   |
   |  ** **    |
   |    **  ** |
   |   **  *** |
   |  **  ** * |
   | **   **** |
   |**      ** |
   |           |
   |           |
   |           |
   +-----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x30,
0x60,
0x58,
0xc0,
0x31,
0x80,
0x5b,
0x00,
0x36,
0x00,
0x0c,
0xc0,
0x19,
0xc0,
0x33,
0x40,
0x63,
0xc0,
0xc0,
0xc0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xbf):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |   **   |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |  **    |
   | **     |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x18,
0x18,
0x00,
0x18,
0x18,
0x30,
0x60,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xc0):
   ht=16, width=8
   +--------+
   |  ***   |
   |   **   |
   |    **  |
   |   **   |
   |   **   |
   |  ****  |
   |  ****  |
   |  *  *  |
   | **  ** |
   | **  ** |
   | ****** |
   |**    **|
   |**    **|
   |        |
   |        |
   |        |
   +--------+ */
0x38,
0x18,
0x0c,
0x18,
0x18,
0x3c,
0x3c,
0x24,
0x66,
0x66,
0x7e,
0xc3,
0xc3,
0x00,
0x00,
0x00,

/* Character ?(0xc1):
   ht=16, width=8
   +--------+
   |   ***  |
   |   **   |
   |  **    |
   |   **   |
   |   **   |
   |  ****  |
   |  ****  |
   |  *  *  |
   | **  ** |
   | **  ** |
   | ****** |
   |**    **|
   |**    **|
   |        |
   |        |
   |        |
   +--------+ */
0x1c,
0x18,
0x30,
0x18,
0x18,
0x3c,
0x3c,
0x24,
0x66,
0x66,
0x7e,
0xc3,
0xc3,
0x00,
0x00,
0x00,

/* Character ?(0xc2):
   ht=16, width=8
   +--------+
   |   **   |
   |  ****  |
   | **  ** |
   |   **   |
   |   **   |
   |  ****  |
   |  ****  |
   |  *  *  |
   | **  ** |
   | **  ** |
   | ****** |
   |**    **|
   |**    **|
   |        |
   |        |
   |        |
   +--------+ */
0x18,
0x3c,
0x66,
0x18,
0x18,
0x3c,
0x3c,
0x24,
0x66,
0x66,
0x7e,
0xc3,
0xc3,
0x00,
0x00,
0x00,

/* Character ?(0xc3):
   ht=16, width=8
   +--------+
   | **** * |
   | * **** |
   |        |
   |   **   |
   |   **   |
   |  ****  |
   |  ****  |
   |  *  *  |
   | **  ** |
   | **  ** |
   | ****** |
   |**    **|
   |**    **|
   |        |
   |        |
   |        |
   +--------+ */
0x7a,
0x5e,
0x00,
0x18,
0x18,
0x3c,
0x3c,
0x24,
0x66,
0x66,
0x7e,
0xc3,
0xc3,
0x00,
0x00,
0x00,

/* Character ?(0xc4):
   ht=16, width=8
   +--------+
   | **  ** |
   | **  ** |
   |        |
   |   **   |
   |   **   |
   |  ****  |
   |  ****  |
   |  *  *  |
   | **  ** |
   | **  ** |
   | ****** |
   |**    **|
   |**    **|
   |        |
   |        |
   |        |
   +--------+ */
0x66,
0x66,
0x00,
0x18,
0x18,
0x3c,
0x3c,
0x24,
0x66,
0x66,
0x7e,
0xc3,
0xc3,
0x00,
0x00,
0x00,

/* Character ?(0xc5):
   ht=16, width=8
   +--------+
   |   **   |
   |  ****  |
   |   **   |
   |        |
   |   **   |
   |   **   |
   |  ****  |
   |  *  *  |
   | **  ** |
   | **  ** |
   | ****** |
   |**    **|
   |**    **|
   |        |
   |        |
   |        |
   +--------+ */
0x18,
0x3c,
0x18,
0x00,
0x18,
0x18,
0x3c,
0x24,
0x66,
0x66,
0x7e,
0xc3,
0xc3,
0x00,
0x00,
0x00,

/* Character ?(0xc6):
   ht=16, width=13
   +-------------+
   |             |
   |             |
   |             |
   |   ********* |
   |   ****      |
   |  ** **      |
   |  ** **      |
   |  ** ******  |
   | **  **      |
   | **  **      |
   | ******      |
   |**   **      |
   |**   ******* |
   |             |
   |             |
   |             |
   +-------------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1f,
0xf0,
0x1e,
0x00,
0x36,
0x00,
0x36,
0x00,
0x37,
0xe0,
0x66,
0x00,
0x66,
0x00,
0x7e,
0x00,
0xc6,
0x00,
0xc7,
0xf0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xc7):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   |   ****  |
   |  **  ** |
   | **    * |
   | **      |
   | **      |
   | **      |
   | **      |
   | **    * |
   |  **  ** |
   |   ****  |
   |    **   |
   |     **  |
   |   ***   |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x61,
0x00,
0x33,
0x00,
0x1e,
0x00,
0x0c,
0x00,
0x06,
0x00,
0x1c,
0x00,

/* Character ?(0xc8):
   ht=16, width=9
   +---------+
   |   ***   |
   |    **   |
   |     **  |
   | ******* |
   | **      |
   | **      |
   | **      |
   | ******  |
   | **      |
   | **      |
   | **      |
   | **      |
   | ******* |
   |         |
   |         |
   |         |
   +---------+ */
0x1c,
0x00,
0x0c,
0x00,
0x06,
0x00,
0x7f,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7e,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xc9):
   ht=16, width=9
   +---------+
   |    ***  |
   |    **   |
   |   **    |
   | ******* |
   | **      |
   | **      |
   | **      |
   | ******  |
   | **      |
   | **      |
   | **      |
   | **      |
   | ******* |
   |         |
   |         |
   |         |
   +---------+ */
0x0e,
0x00,
0x0c,
0x00,
0x18,
0x00,
0x7f,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7e,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xca):
   ht=16, width=9
   +---------+
   |    **   |
   |   ****  |
   |  **  ** |
   | ******* |
   | **      |
   | **      |
   | **      |
   | ******  |
   | **      |
   | **      |
   | **      |
   | **      |
   | ******* |
   |         |
   |         |
   |         |
   +---------+ */
0x0c,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x7f,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7e,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xcb):
   ht=16, width=9
   +---------+
   |  **  ** |
   |  **  ** |
   |         |
   | ******* |
   | **      |
   | **      |
   | **      |
   | ******  |
   | **      |
   | **      |
   | **      |
   | **      |
   | ******* |
   |         |
   |         |
   |         |
   +---------+ */
0x33,
0x00,
0x33,
0x00,
0x00,
0x00,
0x7f,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7e,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7f,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xcc):
   ht=16, width=4
   +----+
   |**  |
   | ** |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0xc0,
0x60,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xcd):
   ht=16, width=4
   +----+
   |  **|
   | ** |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x30,
0x60,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xce):
   ht=16, width=4
   +----+
   | ** |
   |*  *|
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x60,
0x90,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xcf):
   ht=16, width=4
   +----+
   |*  *|
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x90,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xd0):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   | ******   |
   | **   **  |
   | **    ** |
   | **    ** |
   |*****  ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **   **  |
   | ******   |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x7e,
0x00,
0x63,
0x00,
0x61,
0x80,
0x61,
0x80,
0xf9,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x63,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd1):
   ht=16, width=10
   +----------+
   |  **** *  |
   |  * ****  |
   |          |
   | **    ** |
   | ***   ** |
   | ****  ** |
   | ****  ** |
   | ** ** ** |
   | ** ** ** |
   | **  **** |
   | **  **** |
   | **   *** |
   | **    ** |
   |          |
   |          |
   |          |
   +----------+ */
0x3d,
0x00,
0x2f,
0x00,
0x00,
0x00,
0x61,
0x80,
0x71,
0x80,
0x79,
0x80,
0x79,
0x80,
0x6d,
0x80,
0x6d,
0x80,
0x67,
0x80,
0x67,
0x80,
0x63,
0x80,
0x61,
0x80,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd2):
   ht=16, width=10
   +----------+
   |   ***    |
   |    **    |
   |     **   |
   |   ****   |
   |  **  **  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x1c,
0x00,
0x0c,
0x00,
0x06,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd3):
   ht=16, width=10
   +----------+
   |    ***   |
   |    **    |
   |   **     |
   |   ****   |
   |  **  **  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x0e,
0x00,
0x0c,
0x00,
0x18,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd4):
   ht=16, width=10
   +----------+
   |    **    |
   |   ****   |
   |  **  **  |
   |   ****   |
   |  **  **  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x0c,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd5):
   ht=16, width=10
   +----------+
   |  **** *  |
   |  * ****  |
   |          |
   |   ****   |
   |  **  **  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x3d,
0x00,
0x2f,
0x00,
0x00,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd6):
   ht=16, width=10
   +----------+
   |  **  **  |
   |  **  **  |
   |          |
   |   ****   |
   |  **  **  |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x33,
0x00,
0x33,
0x00,
0x00,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd7):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   | **  ** |
   |  ****  |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x66,
0x3c,
0x18,
0x3c,
0x66,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd8):
   ht=16, width=10
   +----------+
   |          |
   |          |
   |          |
   |   ****** |
   |  **  **  |
   | **   *** |
   | **  **** |
   | ** ** ** |
   | ** ** ** |
   | ****  ** |
   | ***   ** |
   |  **  **  |
   | ******   |
   |          |
   |          |
   |          |
   +----------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x1f,
0x80,
0x33,
0x00,
0x63,
0x80,
0x67,
0x80,
0x6d,
0x80,
0x6d,
0x80,
0x79,
0x80,
0x71,
0x80,
0x33,
0x00,
0x7e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xd9):
   ht=16, width=10
   +----------+
   |   ***    |
   |    **    |
   |     **   |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x1c,
0x00,
0x0c,
0x00,
0x06,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xda):
   ht=16, width=10
   +----------+
   |    ***   |
   |    **    |
   |   **     |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x0e,
0x00,
0x0c,
0x00,
0x18,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xdb):
   ht=16, width=10
   +----------+
   |    **    |
   |   ****   |
   |  **  **  |
   |          |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x0c,
0x00,
0x1e,
0x00,
0x33,
0x00,
0x00,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xdc):
   ht=16, width=10
   +----------+
   |  **  **  |
   |  **  **  |
   |          |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   | **    ** |
   |  **  **  |
   |   ****   |
   |          |
   |          |
   |          |
   +----------+ */
0x33,
0x00,
0x33,
0x00,
0x00,
0x00,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xdd):
   ht=16, width=10
   +----------+
   |    ***   |
   |    **    |
   |   **     |
   |**      **|
   |**      **|
   | **    ** |
   |  **  **  |
   |   ****   |
   |    **    |
   |    **    |
   |    **    |
   |    **    |
   |    **    |
   |          |
   |          |
   |          |
   +----------+ */
0x0e,
0x00,
0x0c,
0x00,
0x18,
0x00,
0xc0,
0xc0,
0xc0,
0xc0,
0x61,
0x80,
0x33,
0x00,
0x1e,
0x00,
0x0c,
0x00,
0x0c,
0x00,
0x0c,
0x00,
0x0c,
0x00,
0x0c,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xde):
   ht=16, width=9
   +---------+
   |         |
   |         |
   |         |
   | **      |
   | **      |
   | ******  |
   | **   ** |
   | **   ** |
   | **   ** |
   | **   ** |
   | ******  |
   | **      |
   | **      |
   |         |
   |         |
   |         |
   +---------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x60,
0x00,
0x60,
0x00,
0x7e,
0x00,
0x63,
0x00,
0x63,
0x00,
0x63,
0x00,
0x63,
0x00,
0x7e,
0x00,
0x60,
0x00,
0x60,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xdf):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | ** **  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | ** **  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x6c,
0x66,
0x66,
0x66,
0x66,
0x6c,
0x00,
0x00,
0x00,

/* Character ?(0xe0):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ***   |
   |   **   |
   |    **  |
   |        |
   |  ****  |
   | **  ** |
   |   **** |
   |  ** ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x38,
0x18,
0x0c,
0x00,
0x3c,
0x66,
0x1e,
0x36,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe1):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   ***  |
   |   **   |
   |  **    |
   |        |
   |  ****  |
   | **  ** |
   |   **** |
   |  ** ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x1c,
0x18,
0x30,
0x00,
0x3c,
0x66,
0x1e,
0x36,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe2):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   |   **** |
   |  ** ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x3c,
0x66,
0x00,
0x3c,
0x66,
0x1e,
0x36,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe3):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **** * |
   | * **** |
   |        |
   |  ****  |
   | **  ** |
   |   **** |
   |  ** ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7a,
0x5e,
0x00,
0x3c,
0x66,
0x1e,
0x36,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe4):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   |   **** |
   |  ** ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x00,
0x3c,
0x66,
0x1e,
0x36,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe5):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |  ****  |
   |   **   |
   |        |
   |  ****  |
   | **  ** |
   |   **** |
   |  ** ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x3c,
0x18,
0x00,
0x3c,
0x66,
0x1e,
0x36,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xe6):
   ht=16, width=12
   +------------+
   |            |
   |            |
   |            |
   |            |
   |            |
   |            |
   |  ********  |
   | **  **  ** |
   |   ******** |
   |  ** **     |
   | **  **     |
   | **  **  ** |
   |  ********  |
   |            |
   |            |
   |            |
   +------------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3f,
0xc0,
0x66,
0x60,
0x1f,
0xe0,
0x36,
0x00,
0x66,
0x00,
0x66,
0x60,
0x3f,
0xc0,
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xe7):
   ht=16, width=7
   +-------+
   |       |
   |       |
   |       |
   |       |
   |       |
   |       |
   |  **** |
   | **  **|
   | **    |
   | **    |
   | **    |
   | **  **|
   |  **** |
   |   **  |
   |    ** |
   |  ***  |
   +-------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3c,
0x66,
0x60,
0x60,
0x60,
0x66,
0x3c,
0x18,
0x0c,
0x38,

/* Character ?(0xe8):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ***   |
   |   **   |
   |    **  |
   |        |
   |  ****  |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x38,
0x18,
0x0c,
0x00,
0x3c,
0x66,
0x7e,
0x60,
0x60,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xe9):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   ***  |
   |   **   |
   |  **    |
   |        |
   |  ****  |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x1c,
0x18,
0x30,
0x00,
0x3c,
0x66,
0x7e,
0x60,
0x60,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xea):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x3c,
0x66,
0x00,
0x3c,
0x66,
0x7e,
0x60,
0x60,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xeb):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | ****** |
   | **     |
   | **     |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x00,
0x3c,
0x66,
0x7e,
0x60,
0x60,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xec):
   ht=16, width=4
   +----+
   |    |
   |    |
   |*** |
   | ** |
   |  **|
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0xe0,
0x60,
0x30,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xed):
   ht=16, width=4
   +----+
   |    |
   |    |
   | ***|
   | ** |
   |**  |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x70,
0x60,
0xc0,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xee):
   ht=16, width=4
   +----+
   |    |
   |    |
   | ** |
   |****|
   |    |
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x60,
0xf0,
0x00,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xef):
   ht=16, width=4
   +----+
   |    |
   |    |
   |    |
   |*  *|
   |*  *|
   |    |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   | ** |
   |    |
   |    |
   |    |
   +----+ */
0x00,
0x00,
0x00,
0x90,
0x90,
0x00,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x60,
0x00,
0x00,
0x00,

/* Character ?(0xf0):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | *** ** |
   |   **   |
   | ** **  |
   |    **  |
   |  ***** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x76,
0x18,
0x6c,
0x0c,
0x3e,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf1):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **** * |
   | * **** |
   |        |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7a,
0x5e,
0x00,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x00,
0x00,
0x00,

/* Character ?(0xf2):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ***   |
   |   **   |
   |    **  |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x38,
0x18,
0x0c,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf3):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   ***  |
   |   **   |
   |  **    |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x1c,
0x18,
0x30,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf4):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x3c,
0x66,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf5):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **** * |
   | * **** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x7a,
0x5e,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf6):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |  ****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x00,
0x3c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3c,
0x00,
0x00,
0x00,

/* Character ?(0xf7):
   ht=16, width=6
   +------+
   |      |
   |      |
   |      |
   |      |
   |      |
   |  **  |
   |  **  |
   |      |
   | **** |
   |      |
   |  **  |
   |  **  |
   |      |
   |      |
   |      |
   |      |
   +------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x30,
0x30,
0x00,
0x78,
0x00,
0x30,
0x30,
0x00,
0x00,
0x00,
0x00,

/* Character ?(0xf8):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   |        |
   |        |
   |        |
   |  ***** |
   | ** *** |
   | ** *** |
   | **  ** |
   | *** ** |
   | *** ** |
   | *****  |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x00,
0x00,
0x00,
0x3e,
0x6e,
0x6e,
0x66,
0x76,
0x76,
0x7c,
0x00,
0x00,
0x00,

/* Character ?(0xf9):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |  ***   |
   |   **   |
   |    **  |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x38,
0x18,
0x0c,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xfa):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   ***  |
   |   **   |
   |  **    |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x1c,
0x18,
0x30,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xfb):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   **   |
   |  ****  |
   | **  ** |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x18,
0x3c,
0x66,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xfc):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   |  ***** |
   |        |
   |        |
   |        |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x00,
0x66,
0x66,
0x66,
0x66,
0x66,
0x66,
0x3e,
0x00,
0x00,
0x00,

/* Character ?(0xfd):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |   ***  |
   |   **   |
   |  **    |
   |        |
   |**    **|
   |**    **|
   | **  ** |
   | **  ** |
   |  ****  |
   |  ****  |
   |   **   |
   |   **   |
   |  **    |
   | **     |
   +--------+ */
0x00,
0x00,
0x1c,
0x18,
0x30,
0x00,
0xc3,
0xc3,
0x66,
0x66,
0x3c,
0x3c,
0x18,
0x18,
0x30,
0x60,

/* Character ?(0xfe):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **     |
   | **     |
   | **     |
   | *****  |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | **  ** |
   | *****  |
   | **     |
   | **     |
   | **     |
   +--------+ */
0x00,
0x00,
0x00,
0x60,
0x60,
0x60,
0x7c,
0x66,
0x66,
0x66,
0x66,
0x66,
0x7c,
0x60,
0x60,
0x60,

/* Character  (0xff):
   ht=16, width=8
   +--------+
   |        |
   |        |
   |        |
   | **  ** |
   | **  ** |
   |        |
   |**    **|
   |**    **|
   | **  ** |
   | **  ** |
   |  ****  |
   |  ****  |
   |   **   |
   |   **   |
   |  **    |
   | **     |
   +--------+ */
0x00,
0x00,
0x00,
0x66,
0x66,
0x00,
0xc3,
0xc3,
0x66,
0x66,
0x3c,
0x3c,
0x18,
0x18,
0x30,
0x60,


};

/* Character offset data. */
static const unsigned offset[] = {
  0,
  16,
  32,
  48,
  64,
  80,
  112,
  144,
  160,
  176,
  192,
  208,
  224,
  240,
  256,
  272,
  288,
  304,
  320,
  336,
  352,
  368,
  384,
  400,
  416,
  432,
  448,
  464,
  480,
  496,
  512,
  528,
  544,
  576,
  592,
  624,
  656,
  688,
  720,
  736,
  768,
  800,
  816,
  832,
  864,
  880,
  912,
  944,
  976,
  1008,
  1040,
  1072,
  1104,
  1120,
  1152,
  1168,
  1200,
  1232,
  1264,
  1296,
  1312,
  1328,
  1344,
  1360,
  1376,
  1392,
  1408,
  1424,
  1440,
  1456,
  1472,
  1488,
  1504,
  1520,
  1536,
  1552,
  1568,
  1584,
  1616,
  1632,
  1648,
  1664,
  1680,
  1696,
  1712,
  1728,
  1744,
  1760,
  1792,
  1808,
  1824,
  1840,
  1856,
  1872,
  1888,
  1904,
  1920,
  1936,
  1952,
  1968,
  1984,
  2000,
  2016,
  2032,
  2048,
  2064,
  2080,
  2096,
  2112,
  2128,
  2144,
  2160,
  2176,
  2192,
  2208,
  2224,
  2240,
  2256,
  2272,
  2288,
  2304,
  2320,
  2336,
  2352,
  2368,
  2384,
  2400,
  2416,
  2432,
  2464,
  2480,
  2496,
  2512,
  2528,
  2544,
  2560,
  2576,
  2592,
  2624,
  2640,
  2656,
  2672,
  2688,
  2720,
  2736,
  2752,
  2768,
  2784,
  2800,
  2816,
  2832,
  2848,
  2864,
  2880,
  2896,
  2912,
  2928,
  2960,
  2992,
  3024,
  3040,
  3056,
  3072,
  3088,
  3104,
  3120,
  3136,
  3168,
  3200,
  3232,
  3264,
  3296,
  3328,
  3344,
  3360,
  3376,
  3392,
  3424,
  3456,
  3488,
  3520,
  3552,
  3584,
  3616,
  3632,
  3664,
  3696,
  3728,
  3760,
  3792,
  3824,
  3856,
  3872,
  3888,
  3904,
  3920,
  3936,
  3952,
  3968,
  4000,
  4016,
  4032,
  4048,
  4064,
  4080,
  4096,
  4112,
  4128,
  4144,
  4160,
  4176,
  4192,
  4208,
  4224,
  4240,
  4256,
  4272,
  4288,
  4304,
  4320,
  4336,
  4352,
  4368,
  4384,
};

/* Character width data. */
static const char advance_x[] = {
  4,
  4,
  6,
  8,
  8,
  11,
  9,
  4,
  4,
  4,
  6,
  8,
  4,
  4,
  4,
  4,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  4,
  4,
  8,
  8,
  8,
  8,
  14,
  8,
  10,
  9,
  10,
  9,
  8,
  10,
  10,
  4,
  7,
  9,
  8,
  12,
  10,
  10,
  9,
  10,
  10,
  9,
  8,
  10,
  8,
  14,
  9,
  10,
  9,
  4,
  4,
  4,
  5,
  8,
  5,
  8,
  8,
  7,
  8,
  8,
  4,
  8,
  8,
  4,
  4,
  7,
  4,
  12,
  8,
  8,
  8,
  8,
  5,
  8,
  4,
  8,
  8,
  10,
  8,
  8,
  8,
  5,
  4,
  5,
  5,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  4,
  9,
  4,
  8,
  8,
  8,
  8,
  4,
  8,
  5,
  10,
  5,
  7,
  8,
  4,
  10,
  8,
  5,
  8,
  4,
  4,
  5,
  8,
  7,
  4,
  5,
  4,
  5,
  7,
  11,
  11,
  11,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  13,
  9,
  9,
  9,
  9,
  9,
  4,
  4,
  4,
  4,
  10,
  10,
  10,
  10,
  10,
  10,
  10,
  8,
  10,
  10,
  10,
  10,
  10,
  10,
  9,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  12,
  7,
  8,
  8,
  8,
  8,
  4,
  4,
  4,
  4,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  6,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
  8,
};

/* Exported structure definition. */
VBFINFO __mgif_vbf_System14x16 = {
   "3.0",
   "vbf-System-rrncnn-14-16-ISO8859-1",

   14,
   10,
   16,
    2,

   32,
   255,
   0x3f,

  0,    
  
  NULL,        /*bboxs*/
  advance_x,    /*advance_x*/
  NULL,        /*advance_y*/
  offset,   /*bits_offset*/
  bits,     /*all_glyph_bits*/
};

#endif /* _MGINCOREFONT_SYSTEM */
#endif /* _MGFONT_VBF */

