///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/blog/minigui-licensing-policy/>.
 */
/*
** mapunitobig5.c: Map UCS-2 to BIG5.
** 
** Create date: 2005/05/18
*/

#include "common.h"

#ifdef _MGCHARSET_BIG5

#ifdef _MGCHARSET_UNICODE

/* This is a machine-made file, do not modify. */
#include <stdlib.h>

static unsigned short uc16_min = 0x0000;
static unsigned short uc16_max = 0xFFE5;

static const unsigned char big5_chars_ban0 [] = {
    0xa1, 0xb1, 
};
static const unsigned char big5_chars_ban1 [] = {
    0xa1, 0xc2, 0xa2, 0x58, 0xa1, 0xd3, 
};
static const unsigned char big5_chars_ban2 [] = {
    0xa1, 0x50, 
};
static const unsigned char big5_chars_ban3 [] = {
    0xa1, 0xd1, 
};
static const unsigned char big5_chars_ban4 [] = {
    0xa1, 0xd2, 
};
static const unsigned char big5_chars_ban5 [] = {
    0xa3, 0xbe, 
};
static const unsigned char big5_chars_ban6 [] = {
    0xa3, 0xbc, 0xa3, 0xbd, 0xa3, 0xbf, 
};
static const unsigned char big5_chars_ban7 [] = {
    0xa1, 0xc5, 
};
static const unsigned char big5_chars_ban8 [] = {
    0xa3, 0xbb, 
};
static const unsigned char big5_chars_ban9 [] = {
    0xa3, 0x44, 0xa3, 0x45, 0xa3, 0x46, 0xa3, 0x47, 0xa3, 0x48, 
    0xa3, 0x49, 0xa3, 0x4a, 0xa3, 0x4b, 0xa3, 0x4c, 0xa3, 0x4d, 
    0xa3, 0x4e, 0xa3, 0x4f, 0xa3, 0x50, 0xa3, 0x51, 0xa3, 0x52, 
    0xa3, 0x53, 0xa3, 0x54, 
};
static const unsigned char big5_chars_ban10 [] = {
    0xa3, 0x55, 0xa3, 0x56, 0xa3, 0x57, 0xa3, 0x58, 0xa3, 0x59, 
    0xa3, 0x5a, 0xa3, 0x5b, 
};
static const unsigned char big5_chars_ban11 [] = {
    0xa3, 0x5c, 0xa3, 0x5d, 0xa3, 0x5e, 0xa3, 0x5f, 0xa3, 0x60, 
    0xa3, 0x61, 0xa3, 0x62, 0xa3, 0x63, 0xa3, 0x64, 0xa3, 0x65, 
    0xa3, 0x66, 0xa3, 0x67, 0xa3, 0x68, 0xa3, 0x69, 0xa3, 0x6a, 
    0xa3, 0x6b, 0xa3, 0x6c, 
};
static const unsigned char big5_chars_ban12 [] = {
    0xa3, 0x6d, 0xa3, 0x6e, 0xa3, 0x6f, 0xa3, 0x70, 0xa3, 0x71, 
    0xa3, 0x72, 0xa3, 0x73, 
};
static const unsigned char big5_chars_ban13 [] = {
    0xa1, 0x56, 0xa1, 0x58, 
};
static const unsigned char big5_chars_ban14 [] = {
    0xa1, 0xa5, 0xa1, 0xa6, 
};
static const unsigned char big5_chars_ban15 [] = {
    0xa1, 0xa7, 0xa1, 0xa8, 
};
static const unsigned char big5_chars_ban16 [] = {
    0xa1, 0x4c, 0xa1, 0x4b, 0xa1, 0x45, 
};
static const unsigned char big5_chars_ban17 [] = {
    0xa1, 0xac, 
};
static const unsigned char big5_chars_ban18 [] = {
    0xa1, 0xab, 
};
static const unsigned char big5_chars_ban19 [] = {
    0xa1, 0xb0, 
};
static const unsigned char big5_chars_ban20 [] = {
    0xa3, 0xe1, 
};
static const unsigned char big5_chars_ban21 [] = {
    0xa2, 0x4a, 
};
static const unsigned char big5_chars_ban22 [] = {
    0xa1, 0xc1, 
};
static const unsigned char big5_chars_ban23 [] = {
    0xa2, 0x4b, 
};
static const unsigned char big5_chars_ban24 [] = {
    0xa2, 0xb9, 0xa2, 0xba, 0xa2, 0xbb, 0xa2, 0xbc, 0xa2, 0xbd, 
    0xa2, 0xbe, 0xa2, 0xbf, 0xa2, 0xc0, 0xa2, 0xc1, 0xa2, 0xc2, 
};
static const unsigned char big5_chars_ban25 [] = {
    0xa1, 0xf6, 0xa1, 0xf4, 0xa1, 0xf7, 0xa1, 0xf5, 
};
static const unsigned char big5_chars_ban26 [] = {
    0xa1, 0xf8, 0xa1, 0xf9, 0xa1, 0xfb, 0xa1, 0xfa, 
};
static const unsigned char big5_chars_ban27 [] = {
    0xa2, 0x41, 
};
static const unsigned char big5_chars_ban28 [] = {
    0xa1, 0xd4, 
};
static const unsigned char big5_chars_ban29 [] = {
    0xa1, 0xdb, 0xa1, 0xe8, 0xa1, 0xe7, 
};
static const unsigned char big5_chars_ban30 [] = {
    0xa1, 0xfd, 
};
static const unsigned char big5_chars_ban31 [] = {
    0xa1, 0xfc, 
};
static const unsigned char big5_chars_ban32 [] = {
    0xa1, 0xe4, 0xa1, 0xe5, 0xa1, 0xec, 
};
static const unsigned char big5_chars_ban33 [] = {
    0xa1, 0xed, 
};
static const unsigned char big5_chars_ban34 [] = {
    0xa1, 0xef, 0xa1, 0xee, 
};
static const unsigned char big5_chars_ban35 [] = {
    0xa1, 0xdc, 
};
static const unsigned char big5_chars_ban36 [] = {
    0xa1, 0xda, 0xa1, 0xdd, 
};
static const unsigned char big5_chars_ban37 [] = {
    0xa1, 0xd8, 0xa1, 0xd9, 
};
static const unsigned char big5_chars_ban38 [] = {
    0xa1, 0xf2, 
};
static const unsigned char big5_chars_ban39 [] = {
    0xa1, 0xf3, 
};
static const unsigned char big5_chars_ban40 [] = {
    0xa1, 0xe6, 
};
static const unsigned char big5_chars_ban41 [] = {
    0xa1, 0xe9, 
};
static const unsigned char big5_chars_ban42 [] = {
    0xa2, 0x77, 
};
static const unsigned char big5_chars_ban43 [] = {
    0xa2, 0x78, 
};
static const unsigned char big5_chars_ban44 [] = {
    0xa2, 0x7a, 
};
static const unsigned char big5_chars_ban45 [] = {
    0xa2, 0x7b, 
};
static const unsigned char big5_chars_ban46 [] = {
    0xa2, 0x7c, 
};
static const unsigned char big5_chars_ban47 [] = {
    0xa2, 0x7d, 
};
static const unsigned char big5_chars_ban48 [] = {
    0xa2, 0x75, 
};
static const unsigned char big5_chars_ban49 [] = {
    0xa2, 0x74, 
};
static const unsigned char big5_chars_ban50 [] = {
    0xa2, 0x73, 
};
static const unsigned char big5_chars_ban51 [] = {
    0xa2, 0x72, 
};
static const unsigned char big5_chars_ban52 [] = {
    0xa2, 0x71, 
};
static const unsigned char big5_chars_ban53 [] = {
    0xf9, 0xf9, 0xf9, 0xf8, 0xf9, 0xe6, 0xf9, 0xef, 0xf9, 0xdd, 
    0xf9, 0xe8, 0xf9, 0xf1, 0xf9, 0xdf, 0xf9, 0xec, 0xf9, 0xf5, 
    0xf9, 0xe3, 0xf9, 0xee, 0xf9, 0xf7, 0xf9, 0xe5, 0xf9, 0xe9, 
    0xf9, 0xf2, 0xf9, 0xe0, 0xf9, 0xeb, 0xf9, 0xf4, 0xf9, 0xe2, 
    0xf9, 0xe7, 0xf9, 0xf0, 0xf9, 0xde, 0xf9, 0xed, 0xf9, 0xf6, 
    0xf9, 0xe4, 0xf9, 0xea, 0xf9, 0xf3, 0xf9, 0xe1, 0xf9, 0xfa, 
    0xf9, 0xfb, 0xf9, 0xfd, 0xf9, 0xfc, 0xa2, 0xac, 0xa2, 0xad, 
    0xa2, 0xae, 0xa1, 0x5a, 
};
static const unsigned char big5_chars_ban54 [] = {
    0xa2, 0x62, 0xa2, 0x63, 0xa2, 0x64, 0xa2, 0x65, 0xa2, 0x66, 
    0xa2, 0x67, 0xa2, 0x68, 0xa2, 0x69, 0xa2, 0x70, 0xa2, 0x6f, 
    0xa2, 0x6e, 0xa2, 0x6d, 0xa2, 0x6c, 0xa2, 0x6b, 0xa2, 0x6a, 
};
static const unsigned char big5_chars_ban55 [] = {
    0xf9, 0xfe, 0xa2, 0x76, 0xa2, 0x79, 
};
static const unsigned char big5_chars_ban56 [] = {
    0xa1, 0xbd, 0xa1, 0xbc, 
};
static const unsigned char big5_chars_ban57 [] = {
    0xa1, 0xb6, 0xa1, 0xb5, 
};
static const unsigned char big5_chars_ban58 [] = {
    0xa1, 0xbf, 0xa1, 0xbe, 
};
static const unsigned char big5_chars_ban59 [] = {
    0xa1, 0xbb, 0xa1, 0xba, 
};
static const unsigned char big5_chars_ban60 [] = {
    0xa1, 0xb3, 
};
static const unsigned char big5_chars_ban61 [] = {
    0xa1, 0xb7, 0xa1, 0xb4, 
};
static const unsigned char big5_chars_ban62 [] = {
    0xa2, 0xa8, 0xa2, 0xa9, 0xa2, 0xab, 0xa2, 0xaa, 
};
static const unsigned char big5_chars_ban63 [] = {
    0xa1, 0xb9, 0xa1, 0xb8, 
};
static const unsigned char big5_chars_ban64 [] = {
    0xa1, 0xf0, 
};
static const unsigned char big5_chars_ban65 [] = {
    0xa1, 0xf1, 
};
static const unsigned char big5_chars_ban66 [] = {
    0xa1, 0x40, 0xa1, 0x42, 0xa1, 0x43, 0xa1, 0xb2, 
};
static const unsigned char big5_chars_ban67 [] = {
    0xa1, 0x71, 0xa1, 0x72, 0xa1, 0x6d, 0xa1, 0x6e, 0xa1, 0x75, 
    0xa1, 0x76, 0xa1, 0x79, 0xa1, 0x7a, 0xa1, 0x69, 0xa1, 0x6a, 
    0xa2, 0x45, 
};
static const unsigned char big5_chars_ban68 [] = {
    0xa1, 0x65, 0xa1, 0x66, 
};
static const unsigned char big5_chars_ban69 [] = {
    0xa1, 0xa9, 0xa1, 0xaa, 
};
static const unsigned char big5_chars_ban70 [] = {
    0xa2, 0xc3, 0xa2, 0xc4, 0xa2, 0xc5, 0xa2, 0xc6, 0xa2, 0xc7, 
    0xa2, 0xc8, 0xa2, 0xc9, 0xa2, 0xca, 0xa2, 0xcb, 
};
static const unsigned char big5_chars_ban71 [] = {
    0xa3, 0x74, 0xa3, 0x75, 0xa3, 0x76, 0xa3, 0x77, 0xa3, 0x78, 
    0xa3, 0x79, 0xa3, 0x7a, 0xa3, 0x7b, 0xa3, 0x7c, 0xa3, 0x7d, 
    0xa3, 0x7e, 0xa3, 0xa1, 0xa3, 0xa2, 0xa3, 0xa3, 0xa3, 0xa4, 
    0xa3, 0xa5, 0xa3, 0xa6, 0xa3, 0xa7, 0xa3, 0xa8, 0xa3, 0xa9, 
    0xa3, 0xaa, 0xa3, 0xab, 0xa3, 0xac, 0xa3, 0xad, 0xa3, 0xae, 
    0xa3, 0xaf, 0xa3, 0xb0, 0xa3, 0xb1, 0xa3, 0xb2, 0xa3, 0xb3, 
    0xa3, 0xb4, 0xa3, 0xb5, 0xa3, 0xb6, 0xa3, 0xb7, 0xa3, 0xb8, 
    0xa3, 0xb9, 0xa3, 0xba, 
};
static const unsigned char big5_chars_ban72 [] = {
    0xa1, 0xc0, 
};
static const unsigned char big5_chars_ban73 [] = {
    0xa2, 0x55, 0xa2, 0x56, 
};
static const unsigned char big5_chars_ban74 [] = {
    0xa2, 0x50, 0xa2, 0x51, 0xa2, 0x52, 
};
static const unsigned char big5_chars_ban75 [] = {
    0xa2, 0x54, 
};
static const unsigned char big5_chars_ban76 [] = {
    0xa2, 0x57, 
};
static const unsigned char big5_chars_ban77 [] = {
    0xa2, 0x53, 
};
static const unsigned char big5_chars_ban78 [] = {
    0xa1, 0xeb, 0xa1, 0xea, 
};
static const unsigned char big5_chars_ban79 [] = {
    0xa2, 0x4f, 
};
static const unsigned char big5_chars_ban80 [] = {
    0xa4, 0x40, 0xa4, 0x42, 
};
static const unsigned char big5_chars_ban81 [] = {
    0xa4, 0x43, 
};
static const unsigned char big5_chars_ban82 [] = {
    0xc9, 0x45, 0xa4, 0x56, 0xa4, 0x54, 0xa4, 0x57, 0xa4, 0x55, 
    0xc9, 0x46, 0xa4, 0xa3, 0xc9, 0x4f, 0xc9, 0x4d, 0xa4, 0xa2, 
    0xa4, 0xa1, 
};
static const unsigned char big5_chars_ban83 [] = {
    0xa5, 0x42, 0xa5, 0x41, 0xa5, 0x40, 
};
static const unsigned char big5_chars_ban84 [] = {
    0xa5, 0x43, 0xa4, 0xfe, 
};
static const unsigned char big5_chars_ban85 [] = {
    0xa5, 0xe0, 0xa5, 0xe1, 
};
static const unsigned char big5_chars_ban86 [] = {
    0xa8, 0xc3, 
};
static const unsigned char big5_chars_ban87 [] = {
    0xa4, 0x58, 
};
static const unsigned char big5_chars_ban88 [] = {
    0xa4, 0xa4, 0xc9, 0x50, 
};
static const unsigned char big5_chars_ban89 [] = {
    0xa4, 0xa5, 0xc9, 0x63, 0xa6, 0xea, 0xcb, 0xb1, 
};
static const unsigned char big5_chars_ban90 [] = {
    0xa4, 0x59, 0xa4, 0xa6, 
};
static const unsigned char big5_chars_ban91 [] = {
    0xa5, 0x44, 0xc9, 0x64, 
};
static const unsigned char big5_chars_ban92 [] = {
    0xc9, 0x40, 0xa4, 0x44, 
};
static const unsigned char big5_chars_ban93 [] = {
    0xa4, 0x5b, 
};
static const unsigned char big5_chars_ban94 [] = {
    0xc9, 0x47, 0xa4, 0x5c, 
};
static const unsigned char big5_chars_ban95 [] = {
    0xa4, 0xa7, 
};
static const unsigned char big5_chars_ban96 [] = {
    0xa5, 0x45, 0xa5, 0x47, 0xa5, 0x46, 
};
static const unsigned char big5_chars_ban97 [] = {
    0xa5, 0xe2, 0xa5, 0xe3, 
};
static const unsigned char big5_chars_ban98 [] = {
    0xa8, 0xc4, 
};
static const unsigned char big5_chars_ban99 [] = {
    0xad, 0xbc, 0xa4, 0x41, 
};
static const unsigned char big5_chars_ban100 [] = {
    0xc9, 0x41, 0xa4, 0x45, 0xa4, 0x5e, 0xa4, 0x5d, 
};
static const unsigned char big5_chars_ban101 [] = {
    0xa5, 0xe4, 
};
static const unsigned char big5_chars_ban102 [] = {
    0xa8, 0xc5, 
};
static const unsigned char big5_chars_ban103 [] = {
    0xb0, 0xae, 0xd4, 0x4b, 
};
static const unsigned char big5_chars_ban104 [] = {
    0xb6, 0xc3, 0xdc, 0xb1, 0xdc, 0xb2, 
};
static const unsigned char big5_chars_ban105 [] = {
    0xa4, 0x46, 
};
static const unsigned char big5_chars_ban106 [] = {
    0xa4, 0xa9, 
};
static const unsigned char big5_chars_ban107 [] = {
    0xa8, 0xc6, 0xa4, 0x47, 0xc9, 0x48, 0xa4, 0x5f, 
};
static const unsigned char big5_chars_ban108 [] = {
    0xa4, 0xaa, 0xa4, 0xac, 0xc9, 0x51, 0xa4, 0xad, 0xa4, 0xab, 
};
static const unsigned char big5_chars_ban109 [] = {
    0xa5, 0xe5, 
};
static const unsigned char big5_chars_ban110 [] = {
    0xa8, 0xc7, 
};
static const unsigned char big5_chars_ban111 [] = {
    0xa8, 0xc8, 0xab, 0x45, 
};
static const unsigned char big5_chars_ban112 [] = {
    0xa4, 0x60, 0xa4, 0xae, 
};
static const unsigned char big5_chars_ban113 [] = {
    0xa5, 0xe6, 0xa5, 0xe8, 0xa5, 0xe7, 
};
static const unsigned char big5_chars_ban114 [] = {
    0xa6, 0xeb, 
};
static const unsigned char big5_chars_ban115 [] = {
    0xa8, 0xc9, 0xa8, 0xca, 0xab, 0x46, 0xab, 0x47, 
};
static const unsigned char big5_chars_ban116 [] = {
    0xad, 0xbd, 
};
static const unsigned char big5_chars_ban117 [] = {
    0xdc, 0xb3, 
};
static const unsigned char big5_chars_ban118 [] = {
    0xf6, 0xd6, 0xa4, 0x48, 
};
static const unsigned char big5_chars_ban119 [] = {
    0xa4, 0xb0, 0xa4, 0xaf, 0xc9, 0x52, 0xa4, 0xb1, 0xa4, 0xb7, 
};
static const unsigned char big5_chars_ban120 [] = {
    0xa4, 0xb2, 0xa4, 0xb3, 0xc9, 0x54, 0xc9, 0x53, 0xa4, 0xb5, 
    0xa4, 0xb6, 
};
static const unsigned char big5_chars_ban121 [] = {
    0xa4, 0xb4, 
};
static const unsigned char big5_chars_ban122 [] = {
    0xa5, 0x4a, 0xa5, 0x4b, 0xa5, 0x4c, 0xa5, 0x4d, 0xa5, 0x49, 
    0xa5, 0x50, 0xc9, 0x6a, 
};
static const unsigned char big5_chars_ban123 [] = {
    0xc9, 0x66, 0xc9, 0x69, 0xa5, 0x51, 0xa5, 0x61, 
};
static const unsigned char big5_chars_ban124 [] = {
    0xc9, 0x68, 
};
static const unsigned char big5_chars_ban125 [] = {
    0xa5, 0x4e, 0xa5, 0x4f, 0xa5, 0x48, 
};
static const unsigned char big5_chars_ban126 [] = {
    0xc9, 0x65, 0xc9, 0x67, 
};
static const unsigned char big5_chars_ban127 [] = {
    0xa5, 0xf5, 0xc9, 0xb0, 0xa5, 0xf2, 0xa5, 0xf6, 0xc9, 0xba, 
    0xc9, 0xae, 0xa5, 0xf3, 0xc9, 0xb2, 
};
static const unsigned char big5_chars_ban128 [] = {
    0xa5, 0xf4, 
};
static const unsigned char big5_chars_ban129 [] = {
    0xa5, 0xf7, 
};
static const unsigned char big5_chars_ban130 [] = {
    0xa5, 0xe9, 0xc9, 0xb1, 0xa5, 0xf8, 0xc9, 0xb5, 
};
static const unsigned char big5_chars_ban131 [] = {
    0xc9, 0xb9, 0xc9, 0xb6, 
};
static const unsigned char big5_chars_ban132 [] = {
    0xc9, 0xb3, 0xa5, 0xea, 0xa5, 0xec, 0xa5, 0xf9, 
};
static const unsigned char big5_chars_ban133 [] = {
    0xa5, 0xee, 0xc9, 0xab, 0xa5, 0xf1, 0xa5, 0xef, 0xa5, 0xf0, 
    0xc9, 0xbb, 0xc9, 0xb8, 0xc9, 0xaf, 0xa5, 0xed, 
};
static const unsigned char big5_chars_ban134 [] = {
    0xc9, 0xac, 0xa5, 0xeb, 
};
static const unsigned char big5_chars_ban135 [] = {
    0xc9, 0xb4, 
};
static const unsigned char big5_chars_ban136 [] = {
    0xc9, 0xb7, 
};
static const unsigned char big5_chars_ban137 [] = {
    0xc9, 0xad, 0xca, 0x66, 
};
static const unsigned char big5_chars_ban138 [] = {
    0xa7, 0x42, 0xa6, 0xf4, 
};
static const unsigned char big5_chars_ban139 [] = {
    0xca, 0x67, 0xa6, 0xf1, 
};
static const unsigned char big5_chars_ban140 [] = {
    0xa7, 0x44, 
};
static const unsigned char big5_chars_ban141 [] = {
    0xa6, 0xf9, 
};
static const unsigned char big5_chars_ban142 [] = {
    0xa6, 0xf8, 0xca, 0x5b, 0xa6, 0xfc, 0xa6, 0xf7, 0xca, 0x60, 
    0xca, 0x68, 
};
static const unsigned char big5_chars_ban143 [] = {
    0xca, 0x64, 
};
static const unsigned char big5_chars_ban144 [] = {
    0xa6, 0xfa, 
};
static const unsigned char big5_chars_ban145 [] = {
    0xa6, 0xfd, 0xa6, 0xee, 0xa7, 0x47, 0xca, 0x5d, 
};
static const unsigned char big5_chars_ban146 [] = {
    0xcb, 0xbd, 0xa6, 0xec, 0xa7, 0x43, 0xa6, 0xed, 0xa6, 0xf5, 
    0xa6, 0xf6, 0xca, 0x62, 0xca, 0x5e, 0xa6, 0xfb, 0xa6, 0xf3, 
    0xca, 0x5a, 0xa6, 0xef, 0xca, 0x65, 0xa7, 0x45, 0xa7, 0x48, 
    0xa6, 0xf2, 0xa7, 0x40, 0xa7, 0x46, 0xa6, 0xf0, 0xca, 0x63, 
    0xa7, 0x41, 0xca, 0x69, 0xca, 0x5c, 0xa6, 0xfe, 0xca, 0x5f, 
};
static const unsigned char big5_chars_ban147 [] = {
    0xca, 0x61, 
};
static const unsigned char big5_chars_ban148 [] = {
    0xa8, 0xd8, 0xcb, 0xbf, 0xcb, 0xcb, 0xa8, 0xd0, 
};
static const unsigned char big5_chars_ban149 [] = {
    0xcb, 0xcc, 0xa8, 0xcb, 0xa8, 0xd5, 
};
static const unsigned char big5_chars_ban150 [] = {
    0xa8, 0xce, 0xcb, 0xb9, 0xa8, 0xd6, 0xcb, 0xb8, 0xcb, 0xbc, 
    0xcb, 0xc3, 0xcb, 0xc1, 0xa8, 0xde, 0xa8, 0xd9, 0xcb, 0xb3, 
    0xcb, 0xb5, 0xa8, 0xdb, 0xa8, 0xcf, 0xcb, 0xb6, 0xcb, 0xc2, 
    0xcb, 0xc9, 0xa8, 0xd4, 0xcb, 0xbb, 0xcb, 0xb4, 0xa8, 0xd3, 
    0xcb, 0xb7, 0xa8, 0xd7, 0xcb, 0xba, 
};
static const unsigned char big5_chars_ban151 [] = {
    0xa8, 0xd2, 
};
static const unsigned char big5_chars_ban152 [] = {
    0xa8, 0xcd, 
};
static const unsigned char big5_chars_ban153 [] = {
    0xa8, 0xdc, 0xcb, 0xc4, 0xa8, 0xdd, 0xcb, 0xc8, 
};
static const unsigned char big5_chars_ban154 [] = {
    0xcb, 0xc6, 0xcb, 0xca, 0xa8, 0xda, 0xcb, 0xbe, 0xcb, 0xb2, 
};
static const unsigned char big5_chars_ban155 [] = {
    0xcb, 0xc0, 0xa8, 0xd1, 0xcb, 0xc5, 0xa8, 0xcc, 0xcb, 0xc7, 
};
static const unsigned char big5_chars_ban156 [] = {
    0xab, 0x56, 0xab, 0x4a, 
};
static const unsigned char big5_chars_ban157 [] = {
    0xcd, 0xe0, 0xcd, 0xe8, 
};
static const unsigned char big5_chars_ban158 [] = {
    0xab, 0x49, 0xab, 0x51, 0xab, 0x5d, 
};
static const unsigned char big5_chars_ban159 [] = {
    0xcd, 0xee, 0xcd, 0xec, 0xcd, 0xe7, 
};
static const unsigned char big5_chars_ban160 [] = {
    0xab, 0x4b, 0xcd, 0xed, 0xcd, 0xe3, 0xab, 0x59, 0xab, 0x50, 
    0xab, 0x58, 0xcd, 0xde, 
};
static const unsigned char big5_chars_ban161 [] = {
    0xcd, 0xea, 
};
static const unsigned char big5_chars_ban162 [] = {
    0xcd, 0xe1, 0xab, 0x54, 0xcd, 0xe2, 
};
static const unsigned char big5_chars_ban163 [] = {
    0xcd, 0xdd, 0xab, 0x5b, 0xab, 0x4e, 0xab, 0x57, 0xab, 0x4d, 
};
static const unsigned char big5_chars_ban164 [] = {
    0xcd, 0xdf, 0xcd, 0xe4, 
};
static const unsigned char big5_chars_ban165 [] = {
    0xcd, 0xeb, 0xab, 0x55, 0xab, 0x52, 0xcd, 0xe6, 0xab, 0x5a, 
    0xcd, 0xe9, 0xcd, 0xe5, 0xab, 0x4f, 0xab, 0x5c, 0xab, 0x53, 
    0xab, 0x4c, 0xab, 0x48, 
};
static const unsigned char big5_chars_ban166 [] = {
    0xcd, 0xef, 
};
static const unsigned char big5_chars_ban167 [] = {
    0xad, 0xd7, 0xad, 0xc1, 
};
static const unsigned char big5_chars_ban168 [] = {
    0xad, 0xd1, 
};
static const unsigned char big5_chars_ban169 [] = {
    0xad, 0xd6, 0xd0, 0xd0, 0xd0, 0xcf, 0xd0, 0xd4, 0xd0, 0xd5, 
    0xad, 0xc4, 
};
static const unsigned char big5_chars_ban170 [] = {
    0xad, 0xcd, 
};
static const unsigned char big5_chars_ban171 [] = {
    0xad, 0xda, 
};
static const unsigned char big5_chars_ban172 [] = {
    0xad, 0xce, 
};
static const unsigned char big5_chars_ban173 [] = {
    0xd0, 0xc9, 0xad, 0xc7, 0xd0, 0xca, 
};
static const unsigned char big5_chars_ban174 [] = {
    0xad, 0xdc, 
};
static const unsigned char big5_chars_ban175 [] = {
    0xad, 0xd3, 0xad, 0xbe, 0xad, 0xbf, 0xd0, 0xdd, 0xb0, 0xbf, 
};
static const unsigned char big5_chars_ban176 [] = {
    0xad, 0xcc, 0xad, 0xcb, 0xd0, 0xcb, 0xad, 0xcf, 0xd4, 0x5b, 
    0xad, 0xc6, 0xd0, 0xd6, 0xad, 0xd5, 0xad, 0xd4, 0xad, 0xca, 
    0xd0, 0xce, 0xd0, 0xd7, 
};
static const unsigned char big5_chars_ban177 [] = {
    0xd0, 0xc8, 0xad, 0xc9, 0xd0, 0xd8, 0xad, 0xd2, 0xd0, 0xcc, 
    0xad, 0xc0, 
};
static const unsigned char big5_chars_ban178 [] = {
    0xad, 0xc3, 0xad, 0xc2, 0xd0, 0xd9, 0xad, 0xd0, 0xad, 0xc5, 
    0xad, 0xd9, 0xad, 0xdb, 0xd0, 0xd3, 0xad, 0xd8, 
};
static const unsigned char big5_chars_ban179 [] = {
    0xd0, 0xdb, 0xd0, 0xcd, 0xd0, 0xdc, 
};
static const unsigned char big5_chars_ban180 [] = {
    0xd0, 0xd1, 
};
static const unsigned char big5_chars_ban181 [] = {
    0xd0, 0xda, 
};
static const unsigned char big5_chars_ban182 [] = {
    0xd0, 0xd2, 
};
static const unsigned char big5_chars_ban183 [] = {
    0xad, 0xc8, 
};
static const unsigned char big5_chars_ban184 [] = {
    0xd4, 0x63, 0xd4, 0x57, 
};
static const unsigned char big5_chars_ban185 [] = {
    0xb0, 0xb3, 
};
static const unsigned char big5_chars_ban186 [] = {
    0xd4, 0x5c, 0xd4, 0x62, 0xb0, 0xb2, 0xd4, 0x55, 0xb0, 0xb6, 
    0xd4, 0x59, 0xd4, 0x52, 0xb0, 0xb4, 0xd4, 0x56, 0xb0, 0xb9, 
    0xb0, 0xbe, 
};
static const unsigned char big5_chars_ban187 [] = {
    0xd4, 0x67, 
};
static const unsigned char big5_chars_ban188 [] = {
    0xd4, 0x51, 
};
static const unsigned char big5_chars_ban189 [] = {
    0xb0, 0xba, 
};
static const unsigned char big5_chars_ban190 [] = {
    0xd4, 0x66, 
};
static const unsigned char big5_chars_ban191 [] = {
    0xb0, 0xb5, 0xd4, 0x58, 0xb0, 0xb1, 0xd4, 0x53, 0xd4, 0x4f, 
    0xd4, 0x5d, 0xd4, 0x50, 0xd4, 0x4e, 0xd4, 0x5a, 0xd4, 0x60, 
    0xd4, 0x61, 0xb0, 0xb7, 
};
static const unsigned char big5_chars_ban192 [] = {
    0xd8, 0x5b, 0xd4, 0x5e, 0xd4, 0x4d, 0xd4, 0x5f, 
};
static const unsigned char big5_chars_ban193 [] = {
    0xb0, 0xc1, 0xd4, 0x64, 0xb0, 0xc0, 0xd4, 0x4c, 
};
static const unsigned char big5_chars_ban194 [] = {
    0xd4, 0x54, 0xd4, 0x65, 0xb0, 0xbc, 0xb0, 0xbb, 0xb0, 0xb8, 
    0xb0, 0xbd, 
};
static const unsigned char big5_chars_ban195 [] = {
    0xb0, 0xaf, 
};
static const unsigned char big5_chars_ban196 [] = {
    0xb0, 0xb0, 
};
static const unsigned char big5_chars_ban197 [] = {
    0xb3, 0xc8, 
};
static const unsigned char big5_chars_ban198 [] = {
    0xd8, 0x5e, 0xd8, 0x57, 
};
static const unsigned char big5_chars_ban199 [] = {
    0xb3, 0xc5, 
};
static const unsigned char big5_chars_ban200 [] = {
    0xd8, 0x5f, 
};
static const unsigned char big5_chars_ban201 [] = {
    0xd8, 0x55, 0xd8, 0x58, 0xb3, 0xc4, 0xd8, 0x59, 
};
static const unsigned char big5_chars_ban202 [] = {
    0xb3, 0xc7, 0xd8, 0x5d, 
};
static const unsigned char big5_chars_ban203 [] = {
    0xd8, 0x53, 0xd8, 0x52, 0xb3, 0xc9, 
};
static const unsigned char big5_chars_ban204 [] = {
    0xb3, 0xca, 0xb3, 0xc6, 0xb3, 0xcb, 0xd8, 0x51, 0xd8, 0x5c, 
    0xd8, 0x5a, 0xd8, 0x54, 
};
static const unsigned char big5_chars_ban205 [] = {
    0xb3, 0xc3, 0xd8, 0x56, 
};
static const unsigned char big5_chars_ban206 [] = {
    0xb6, 0xca, 0xb6, 0xc4, 0xdc, 0xb7, 0xb6, 0xcd, 0xdc, 0xbd, 
    0xdc, 0xc0, 0xb6, 0xc6, 0xb6, 0xc7, 0xdc, 0xba, 0xb6, 0xc5, 
    0xdc, 0xc3, 0xb6, 0xcb, 0xdc, 0xc4, 
};
static const unsigned char big5_chars_ban207 [] = {
    0xdc, 0xbf, 0xb6, 0xcc, 
};
static const unsigned char big5_chars_ban208 [] = {
    0xdc, 0xb4, 0xb6, 0xc9, 0xdc, 0xb5, 
};
static const unsigned char big5_chars_ban209 [] = {
    0xdc, 0xbe, 0xdc, 0xbc, 
};
static const unsigned char big5_chars_ban210 [] = {
    0xdc, 0xb8, 0xb6, 0xc8, 0xdc, 0xb6, 0xb6, 0xce, 0xdc, 0xbb, 
    0xdc, 0xc2, 0xdc, 0xb9, 0xdc, 0xc1, 
};
static const unsigned char big5_chars_ban211 [] = {
    0xb9, 0xb6, 0xb9, 0xb3, 
};
static const unsigned char big5_chars_ban212 [] = {
    0xb9, 0xb4, 
};
static const unsigned char big5_chars_ban213 [] = {
    0xe0, 0xf9, 0xe0, 0xf1, 0xb9, 0xb2, 0xb9, 0xaf, 0xe0, 0xf2, 
};
static const unsigned char big5_chars_ban214 [] = {
    0xb9, 0xb1, 0xe0, 0xf5, 
};
static const unsigned char big5_chars_ban215 [] = {
    0xe0, 0xf7, 
};
static const unsigned char big5_chars_ban216 [] = {
    0xe0, 0xfe, 
};
static const unsigned char big5_chars_ban217 [] = {
    0xe0, 0xfd, 0xe0, 0xf8, 0xb9, 0xae, 0xe0, 0xf0, 0xb9, 0xac, 
    0xe0, 0xf3, 0xb9, 0xb7, 0xe0, 0xf6, 
};
static const unsigned char big5_chars_ban218 [] = {
    0xe0, 0xfa, 0xb9, 0xb0, 0xb9, 0xad, 0xe0, 0xfc, 0xe0, 0xfb, 
    0xb9, 0xb5, 
};
static const unsigned char big5_chars_ban219 [] = {
    0xe0, 0xf4, 
};
static const unsigned char big5_chars_ban220 [] = {
    0xbb, 0xf8, 0xe4, 0xec, 
};
static const unsigned char big5_chars_ban221 [] = {
    0xe4, 0xe9, 0xbb, 0xf9, 
};
static const unsigned char big5_chars_ban222 [] = {
    0xbb, 0xf7, 
};
static const unsigned char big5_chars_ban223 [] = {
    0xe4, 0xf0, 0xe4, 0xed, 0xe4, 0xe6, 0xbb, 0xf6, 
};
static const unsigned char big5_chars_ban224 [] = {
    0xbb, 0xfa, 0xe4, 0xe7, 0xbb, 0xf5, 0xbb, 0xfd, 0xe4, 0xea, 
    0xe4, 0xeb, 0xbb, 0xfb, 0xbb, 0xfc, 0xe4, 0xf1, 0xe4, 0xee, 
    0xe4, 0xef, 
};
static const unsigned char big5_chars_ban225 [] = {
    0xbe, 0xaa, 0xe8, 0xf8, 0xbe, 0xa7, 0xe8, 0xf5, 0xbe, 0xa9, 
    0xbe, 0xab, 
};
static const unsigned char big5_chars_ban226 [] = {
    0xe8, 0xf6, 0xbe, 0xa8, 
};
static const unsigned char big5_chars_ban227 [] = {
    0xe8, 0xf7, 
};
static const unsigned char big5_chars_ban228 [] = {
    0xe8, 0xf4, 
};
static const unsigned char big5_chars_ban229 [] = {
    0xc0, 0x76, 0xec, 0xbd, 0xc0, 0x77, 0xec, 0xbb, 
};
static const unsigned char big5_chars_ban230 [] = {
    0xec, 0xbc, 0xec, 0xba, 0xec, 0xb9, 
};
static const unsigned char big5_chars_ban231 [] = {
    0xec, 0xbe, 0xc0, 0x75, 
};
static const unsigned char big5_chars_ban232 [] = {
    0xef, 0xb8, 0xef, 0xb9, 
};
static const unsigned char big5_chars_ban233 [] = {
    0xe4, 0xe8, 0xef, 0xb7, 0xc0, 0x78, 0xc3, 0x5f, 0xf1, 0xeb, 
    0xf1, 0xec, 
};
static const unsigned char big5_chars_ban234 [] = {
    0xc4, 0xd7, 0xc4, 0xd8, 0xf5, 0xc1, 0xf5, 0xc0, 0xc5, 0x6c, 
    0xc5, 0x6b, 0xf7, 0xd0, 
};
static const unsigned char big5_chars_ban235 [] = {
    0xa4, 0x49, 0xa4, 0x61, 0xa4, 0xb9, 
};
static const unsigned char big5_chars_ban236 [] = {
    0xa4, 0xb8, 0xa5, 0x53, 0xa5, 0x52, 0xa5, 0xfc, 0xa5, 0xfb, 
    0xa5, 0xfd, 0xa5, 0xfa, 
};
static const unsigned char big5_chars_ban237 [] = {
    0xa7, 0x4a, 0xa7, 0x49, 0xa7, 0x4b, 
};
static const unsigned char big5_chars_ban238 [] = {
    0xa8, 0xe0, 
};
static const unsigned char big5_chars_ban239 [] = {
    0xa8, 0xdf, 0xa8, 0xe1, 
};
static const unsigned char big5_chars_ban240 [] = {
    0xab, 0x5e, 
};
static const unsigned char big5_chars_ban241 [] = {
    0xa2, 0x59, 0xd0, 0xde, 0xa2, 0x5a, 0xb0, 0xc2, 0xa2, 0x5c, 
    0xa2, 0x5b, 0xd8, 0x60, 
};
static const unsigned char big5_chars_ban242 [] = {
    0xa2, 0x5d, 0xb9, 0xb8, 0xa2, 0x5e, 
};
static const unsigned char big5_chars_ban243 [] = {
    0xa4, 0x4a, 
};
static const unsigned char big5_chars_ban244 [] = {
    0xa4, 0xba, 0xa5, 0xfe, 0xa8, 0xe2, 
};
static const unsigned char big5_chars_ban245 [] = {
    0xa4, 0x4b, 0xa4, 0xbd, 0xa4, 0xbb, 0xa4, 0xbc, 
};
static const unsigned char big5_chars_ban246 [] = {
    0xa6, 0x40, 
};
static const unsigned char big5_chars_ban247 [] = {
    0xa7, 0x4c, 0xa8, 0xe4, 0xa8, 0xe3, 0xa8, 0xe5, 
};
static const unsigned char big5_chars_ban248 [] = {
    0xad, 0xdd, 
};
static const unsigned char big5_chars_ban249 [] = {
    0xbe, 0xac, 
};
static const unsigned char big5_chars_ban250 [] = {
    0xc9, 0x4e, 
};
static const unsigned char big5_chars_ban251 [] = {
    0xa5, 0x54, 0xa5, 0x55, 
};
static const unsigned char big5_chars_ban252 [] = {
    0xa6, 0x41, 
};
static const unsigned char big5_chars_ban253 [] = {
    0xca, 0x6a, 
};
static const unsigned char big5_chars_ban254 [] = {
    0xab, 0x60, 0xab, 0x5f, 0xd0, 0xe0, 0xd0, 0xdf, 0xb0, 0xc3, 
};
static const unsigned char big5_chars_ban255 [] = {
    0xa4, 0xbe, 0xc9, 0x55, 
};
static const unsigned char big5_chars_ban256 [] = {
    0xcb, 0xcd, 
};
static const unsigned char big5_chars_ban257 [] = {
    0xab, 0x61, 
};
static const unsigned char big5_chars_ban258 [] = {
    0xad, 0xe0, 
};
static const unsigned char big5_chars_ban259 [] = {
    0xad, 0xde, 0xad, 0xdf, 
};
static const unsigned char big5_chars_ban260 [] = {
    0xbe, 0xad, 
};
static const unsigned char big5_chars_ban261 [] = {
    0xa5, 0x56, 
};
static const unsigned char big5_chars_ban262 [] = {
    0xa6, 0x42, 0xc9, 0xbc, 
};
static const unsigned char big5_chars_ban263 [] = {
    0xa7, 0x4d, 0xa7, 0x4e, 
};
static const unsigned char big5_chars_ban264 [] = {
    0xca, 0x6b, 
};
static const unsigned char big5_chars_ban265 [] = {
    0xcb, 0xce, 0xa8, 0xe6, 0xcb, 0xcf, 
};
static const unsigned char big5_chars_ban266 [] = {
    0xd0, 0xe2, 0xd0, 0xe3, 0xad, 0xe3, 
};
static const unsigned char big5_chars_ban267 [] = {
    0xd0, 0xe4, 
};
static const unsigned char big5_chars_ban268 [] = {
    0xd0, 0xe1, 0xad, 0xe4, 0xad, 0xe2, 0xad, 0xe1, 0xd0, 0xe5, 
};
static const unsigned char big5_chars_ban269 [] = {
    0xd4, 0x68, 
};
static const unsigned char big5_chars_ban270 [] = {
    0xd8, 0x61, 
};
static const unsigned char big5_chars_ban271 [] = {
    0xdc, 0xc5, 0xe1, 0x40, 
};
static const unsigned char big5_chars_ban272 [] = {
    0xbb, 0xfe, 0xbe, 0xae, 0xe8, 0xf9, 
};
static const unsigned char big5_chars_ban273 [] = {
    0xa4, 0x4c, 0xa4, 0x5a, 
};
static const unsigned char big5_chars_ban274 [] = {
    0xb0, 0xc4, 0xb3, 0xcd, 
};
static const unsigned char big5_chars_ban275 [] = {
    0xb9, 0xb9, 
};
static const unsigned char big5_chars_ban276 [] = {
    0xc9, 0x42, 0xa4, 0xbf, 
};
static const unsigned char big5_chars_ban277 [] = {
    0xa5, 0x59, 0xa5, 0x57, 0xa5, 0x58, 
};
static const unsigned char big5_chars_ban278 [] = {
    0xa8, 0xe7, 
};
static const unsigned char big5_chars_ban279 [] = {
    0xa4, 0x4d, 0xa4, 0x4e, 
};
static const unsigned char big5_chars_ban280 [] = {
    0xa4, 0x62, 
};
static const unsigned char big5_chars_ban281 [] = {
    0xa4, 0xc0, 0xa4, 0xc1, 0xa4, 0xc2, 0xc9, 0xbe, 0xa5, 0x5a, 
};
static const unsigned char big5_chars_ban282 [] = {
    0xc9, 0x6b, 
};
static const unsigned char big5_chars_ban283 [] = {
    0xa6, 0x46, 
};
static const unsigned char big5_chars_ban284 [] = {
    0xc9, 0xbf, 0xa6, 0x44, 0xa6, 0x45, 0xc9, 0xbd, 
};
static const unsigned char big5_chars_ban285 [] = {
    0xa6, 0x47, 0xa6, 0x43, 
};
static const unsigned char big5_chars_ban286 [] = {
    0xca, 0x6c, 0xaa, 0xec, 0xca, 0x6d, 
};
static const unsigned char big5_chars_ban287 [] = {
    0xca, 0x6e, 
};
static const unsigned char big5_chars_ban288 [] = {
    0xa7, 0x50, 0xa7, 0x4f, 
};
static const unsigned char big5_chars_ban289 [] = {
    0xa7, 0x53, 0xa7, 0x51, 0xa7, 0x52, 
};
static const unsigned char big5_chars_ban290 [] = {
    0xa8, 0xed, 
};
static const unsigned char big5_chars_ban291 [] = {
    0xa8, 0xec, 0xcb, 0xd4, 0xcb, 0xd1, 0xcb, 0xd2, 
};
static const unsigned char big5_chars_ban292 [] = {
    0xcb, 0xd0, 0xa8, 0xee, 0xa8, 0xea, 0xa8, 0xe9, 
};
static const unsigned char big5_chars_ban293 [] = {
    0xa8, 0xeb, 0xa8, 0xe8, 
};
static const unsigned char big5_chars_ban294 [] = {
    0xa8, 0xef, 
};
static const unsigned char big5_chars_ban295 [] = {
    0xab, 0x63, 0xcd, 0xf0, 
};
static const unsigned char big5_chars_ban296 [] = {
    0xcb, 0xd3, 0xab, 0x68, 
};
static const unsigned char big5_chars_ban297 [] = {
    0xcd, 0xf1, 0xab, 0x64, 0xab, 0x67, 0xab, 0x66, 0xab, 0x65, 
    0xab, 0x62, 
};
static const unsigned char big5_chars_ban298 [] = {
    0xd0, 0xe8, 
};
static const unsigned char big5_chars_ban299 [] = {
    0xad, 0xe7, 0xd0, 0xeb, 0xad, 0xe5, 
};
static const unsigned char big5_chars_ban300 [] = {
    0xd0, 0xe7, 0xad, 0xe8, 0xad, 0xe6, 0xad, 0xe9, 0xd0, 0xe9, 
    0xd0, 0xea, 
};
static const unsigned char big5_chars_ban301 [] = {
    0xd0, 0xe6, 0xd0, 0xec, 
};
static const unsigned char big5_chars_ban302 [] = {
    0xb3, 0xd1, 0xb0, 0xc5, 0xd4, 0x69, 0xd4, 0x6b, 0xd4, 0x6a, 
    0xd4, 0x6c, 0xb0, 0xc6, 
};
static const unsigned char big5_chars_ban303 [] = {
    0xb3, 0xce, 
};
static const unsigned char big5_chars_ban304 [] = {
    0xb3, 0xcf, 0xb3, 0xd0, 
};
static const unsigned char big5_chars_ban305 [] = {
    0xb6, 0xd0, 0xdc, 0xc7, 
};
static const unsigned char big5_chars_ban306 [] = {
    0xdc, 0xc6, 0xdc, 0xc8, 0xdc, 0xc9, 0xb6, 0xd1, 
};
static const unsigned char big5_chars_ban307 [] = {
    0xb6, 0xcf, 0xe1, 0x41, 0xe1, 0x42, 0xb9, 0xbb, 0xb9, 0xba, 
    0xe3, 0x5a, 
};
static const unsigned char big5_chars_ban308 [] = {
    0xbc, 0x40, 0xbc, 0x41, 0xbc, 0x42, 0xbc, 0x44, 0xe4, 0xf2, 
    0xe4, 0xf3, 0xbc, 0x43, 
};
static const unsigned char big5_chars_ban309 [] = {
    0xbe, 0xaf, 
};
static const unsigned char big5_chars_ban310 [] = {
    0xbe, 0xb0, 
};
static const unsigned char big5_chars_ban311 [] = {
    0xf1, 0xed, 0xf5, 0xc3, 0xf5, 0xc2, 0xf7, 0xd1, 
};
static const unsigned char big5_chars_ban312 [] = {
    0xa4, 0x4f, 
};
static const unsigned char big5_chars_ban313 [] = {
    0xa5, 0x5c, 0xa5, 0x5b, 
};
static const unsigned char big5_chars_ban314 [] = {
    0xa6, 0x48, 
};
static const unsigned char big5_chars_ban315 [] = {
    0xc9, 0xc0, 
};
static const unsigned char big5_chars_ban316 [] = {
    0xa7, 0x55, 0xa7, 0x56, 0xa7, 0x54, 0xa7, 0x57, 0xca, 0x6f, 
    0xca, 0x70, 
};
static const unsigned char big5_chars_ban317 [] = {
    0xa8, 0xf1, 0xcb, 0xd5, 
};
static const unsigned char big5_chars_ban318 [] = {
    0xa8, 0xf0, 
};
static const unsigned char big5_chars_ban319 [] = {
    0xcd, 0xf2, 0xab, 0x6c, 0xcd, 0xf3, 0xab, 0x6b, 
};
static const unsigned char big5_chars_ban320 [] = {
    0xab, 0x69, 
};
static const unsigned char big5_chars_ban321 [] = {
    0xab, 0x6a, 
};
static const unsigned char big5_chars_ban322 [] = {
    0xd0, 0xed, 
};
static const unsigned char big5_chars_ban323 [] = {
    0xb0, 0xc7, 0xd4, 0x6e, 
};
static const unsigned char big5_chars_ban324 [] = {
    0xb0, 0xca, 0xd4, 0x6d, 0xb1, 0xe5, 0xb0, 0xc9, 0xb0, 0xc8, 
};
static const unsigned char big5_chars_ban325 [] = {
    0xb3, 0xd4, 
};
static const unsigned char big5_chars_ban326 [] = {
    0xb3, 0xd3, 0xb3, 0xd2, 0xb6, 0xd2, 
};
static const unsigned char big5_chars_ban327 [] = {
    0xb6, 0xd5, 0xb6, 0xd6, 0xb6, 0xd4, 
};
static const unsigned char big5_chars_ban328 [] = {
    0xb6, 0xd3, 
};
static const unsigned char big5_chars_ban329 [] = {
    0xe1, 0x43, 
};
static const unsigned char big5_chars_ban330 [] = {
    0xe1, 0x44, 
};
static const unsigned char big5_chars_ban331 [] = {
    0xe4, 0xf5, 0xbc, 0x45, 0xe4, 0xf4, 
};
static const unsigned char big5_chars_ban332 [] = {
    0xbe, 0xb1, 0xec, 0xbf, 0xc0, 0x79, 
};
static const unsigned char big5_chars_ban333 [] = {
    0xf1, 0xee, 0xc4, 0x55, 
};
static const unsigned char big5_chars_ban334 [] = {
    0xa4, 0x63, 0xa4, 0xc3, 0xc9, 0x56, 
};
static const unsigned char big5_chars_ban335 [] = {
    0xa4, 0xc4, 0xa4, 0xc5, 
};
static const unsigned char big5_chars_ban336 [] = {
    0xa5, 0x5d, 0xa5, 0x5e, 
};
static const unsigned char big5_chars_ban337 [] = {
    0xa6, 0x49, 0xca, 0x71, 0xcb, 0xd6, 0xcb, 0xd7, 
};
static const unsigned char big5_chars_ban338 [] = {
    0xab, 0x6d, 0xd0, 0xee, 0xb0, 0xcc, 0xb0, 0xcb, 0xd8, 0x63, 
    0xd8, 0x62, 
};
static const unsigned char big5_chars_ban339 [] = {
    0xa4, 0x50, 0xa4, 0xc6, 0xa5, 0x5f, 
};
static const unsigned char big5_chars_ban340 [] = {
    0xb0, 0xcd, 0xc9, 0x43, 
};
static const unsigned char big5_chars_ban341 [] = {
    0xc9, 0x6c, 0xa5, 0x60, 
};
static const unsigned char big5_chars_ban342 [] = {
    0xc9, 0xc2, 0xa6, 0x4b, 0xa6, 0x4a, 0xc9, 0xc1, 0xa7, 0x58, 
};
static const unsigned char big5_chars_ban343 [] = {
    0xad, 0xea, 
};
static const unsigned char big5_chars_ban344 [] = {
    0xd4, 0x6f, 
};
static const unsigned char big5_chars_ban345 [] = {
    0xb6, 0xd7, 0xe1, 0x45, 0xb9, 0xbc, 
};
static const unsigned char big5_chars_ban346 [] = {
    0xe8, 0xfa, 
};
static const unsigned char big5_chars_ban347 [] = {
    0xf3, 0xfd, 
};
static const unsigned char big5_chars_ban348 [] = {
    0xa4, 0xc7, 
};
static const unsigned char big5_chars_ban349 [] = {
    0xcb, 0xd8, 0xcd, 0xf4, 0xb0, 0xd0, 0xb0, 0xce, 0xb0, 0xcf, 
    0xa4, 0x51, 
};
static const unsigned char big5_chars_ban350 [] = {
    0xa4, 0x64, 0xa2, 0xcd, 0xa4, 0xca, 
};
static const unsigned char big5_chars_ban351 [] = {
    0xa4, 0xc9, 0xa4, 0xc8, 0xa5, 0x63, 0xa5, 0x62, 
};
static const unsigned char big5_chars_ban352 [] = {
    0xc9, 0x6d, 0xc9, 0xc3, 
};
static const unsigned char big5_chars_ban353 [] = {
    0xa8, 0xf5, 0xa8, 0xf2, 0xa8, 0xf4, 0xa8, 0xf3, 
};
static const unsigned char big5_chars_ban354 [] = {
    0xab, 0x6e, 
};
static const unsigned char big5_chars_ban355 [] = {
    0xb3, 0xd5, 
};
static const unsigned char big5_chars_ban356 [] = {
    0xa4, 0x52, 
};
static const unsigned char big5_chars_ban357 [] = {
    0xa4, 0xcb, 
};
static const unsigned char big5_chars_ban358 [] = {
    0xa5, 0x65, 0xa5, 0x64, 
};
static const unsigned char big5_chars_ban359 [] = {
    0xca, 0x72, 
};
static const unsigned char big5_chars_ban360 [] = {
    0xa8, 0xf6, 
};
static const unsigned char big5_chars_ban361 [] = {
    0xc9, 0x57, 
};
static const unsigned char big5_chars_ban362 [] = {
    0xa5, 0x67, 0xa5, 0x66, 0xa6, 0x4c, 0xa6, 0x4d, 0xca, 0x73, 
    0xa7, 0x59, 
};
static const unsigned char big5_chars_ban363 [] = {
    0xa7, 0x5a, 
};
static const unsigned char big5_chars_ban364 [] = {
    0xa8, 0xf7, 0xa8, 0xf8, 0xa8, 0xf9, 
};
static const unsigned char big5_chars_ban365 [] = {
    0xab, 0x6f, 0xcd, 0xf5, 
};
static const unsigned char big5_chars_ban366 [] = {
    0xad, 0xeb, 
};
static const unsigned char big5_chars_ban367 [] = {
    0xc9, 0x44, 
};
static const unsigned char big5_chars_ban368 [] = {
    0xa4, 0xcc, 
};
static const unsigned char big5_chars_ban369 [] = {
    0xc9, 0xc4, 
};
static const unsigned char big5_chars_ban370 [] = {
    0xca, 0x74, 0xca, 0x75, 
};
static const unsigned char big5_chars_ban371 [] = {
    0xcb, 0xd9, 
};
static const unsigned char big5_chars_ban372 [] = {
    0xcb, 0xda, 
};
static const unsigned char big5_chars_ban373 [] = {
    0xcd, 0xf7, 0xcd, 0xf6, 0xcd, 0xf9, 0xcd, 0xf8, 0xab, 0x70, 
};
static const unsigned char big5_chars_ban374 [] = {
    0xd4, 0x70, 0xad, 0xed, 0xd0, 0xef, 0xad, 0xec, 
};
static const unsigned char big5_chars_ban375 [] = {
    0xd8, 0x64, 0xb3, 0xd6, 
};
static const unsigned char big5_chars_ban376 [] = {
    0xd8, 0x65, 
};
static const unsigned char big5_chars_ban377 [] = {
    0xe1, 0x46, 0xb9, 0xbd, 
};
static const unsigned char big5_chars_ban378 [] = {
    0xbc, 0x46, 
};
static const unsigned char big5_chars_ban379 [] = {
    0xf1, 0xef, 
};
static const unsigned char big5_chars_ban380 [] = {
    0xc9, 0x58, 
};
static const unsigned char big5_chars_ban381 [] = {
    0xa5, 0x68, 
};
static const unsigned char big5_chars_ban382 [] = {
    0xb0, 0xd1, 
};
static const unsigned char big5_chars_ban383 [] = {
    0xa4, 0x53, 0xa4, 0x65, 0xa4, 0xce, 0xa4, 0xcd, 
};
static const unsigned char big5_chars_ban384 [] = {
    0xa4, 0xcf, 
};
static const unsigned char big5_chars_ban385 [] = {
    0xa8, 0xfb, 
};
static const unsigned char big5_chars_ban386 [] = {
    0xa8, 0xfa, 0xa8, 0xfc, 
};
static const unsigned char big5_chars_ban387 [] = {
    0xab, 0x71, 
};
static const unsigned char big5_chars_ban388 [] = {
    0xad, 0xee, 
};
static const unsigned char big5_chars_ban389 [] = {
    0xe8, 0xfb, 0xc2, 0x4f, 0xa4, 0x66, 0xa5, 0x6a, 0xa5, 0x79, 
    0xa5, 0x74, 
};
static const unsigned char big5_chars_ban390 [] = {
    0xa5, 0x6f, 0xa5, 0x6e, 0xa5, 0x75, 0xa5, 0x73, 0xa5, 0x6c, 
    0xa5, 0x7a, 0xa5, 0x6d, 0xa5, 0x69, 0xa5, 0x78, 0xa5, 0x77, 
    0xa5, 0x76, 0xa5, 0x6b, 
};
static const unsigned char big5_chars_ban391 [] = {
    0xa5, 0x72, 
};
static const unsigned char big5_chars_ban392 [] = {
    0xa5, 0x71, 
};
static const unsigned char big5_chars_ban393 [] = {
    0xa5, 0x7b, 0xa5, 0x70, 
};
static const unsigned char big5_chars_ban394 [] = {
    0xa6, 0x53, 
};
static const unsigned char big5_chars_ban395 [] = {
    0xa6, 0x59, 0xa6, 0x55, 
};
static const unsigned char big5_chars_ban396 [] = {
    0xa6, 0x5b, 0xc9, 0xc5, 0xa6, 0x58, 0xa6, 0x4e, 0xa6, 0x51, 
    0xa6, 0x54, 0xa6, 0x50, 0xa6, 0x57, 0xa6, 0x5a, 0xa6, 0x4f, 
    0xa6, 0x52, 0xa6, 0x56, 0xa6, 0x5c, 
};
static const unsigned char big5_chars_ban397 [] = {
    0xca, 0x7e, 0xca, 0x7b, 
};
static const unsigned char big5_chars_ban398 [] = {
    0xa7, 0x67, 0xca, 0x7c, 0xa7, 0x5b, 0xa7, 0x5d, 0xa7, 0x75, 
    0xa7, 0x70, 
};
static const unsigned char big5_chars_ban399 [] = {
    0xca, 0xa5, 0xca, 0x7d, 0xa7, 0x5f, 0xa7, 0x61, 0xca, 0xa4, 
    0xa7, 0x68, 0xca, 0x78, 0xa7, 0x74, 0xa7, 0x76, 0xa7, 0x5c, 
    0xa7, 0x6d, 
};
static const unsigned char big5_chars_ban400 [] = {
    0xca, 0x76, 0xa7, 0x73, 
};
static const unsigned char big5_chars_ban401 [] = {
    0xa7, 0x64, 
};
static const unsigned char big5_chars_ban402 [] = {
    0xa7, 0x6e, 0xa7, 0x6f, 0xca, 0x77, 0xa7, 0x6c, 0xa7, 0x6a, 
};
static const unsigned char big5_chars_ban403 [] = {
    0xa7, 0x6b, 0xa7, 0x71, 0xca, 0xa1, 0xa7, 0x5e, 
};
static const unsigned char big5_chars_ban404 [] = {
    0xa7, 0x72, 0xca, 0xa3, 0xa7, 0x66, 0xa7, 0x63, 
};
static const unsigned char big5_chars_ban405 [] = {
    0xca, 0x7a, 0xa7, 0x62, 0xca, 0xa6, 0xa7, 0x65, 
};
static const unsigned char big5_chars_ban406 [] = {
    0xa7, 0x69, 
};
static const unsigned char big5_chars_ban407 [] = {
    0xa7, 0x60, 0xca, 0xa2, 
};
static const unsigned char big5_chars_ban408 [] = {
    0xca, 0x79, 
};
static const unsigned char big5_chars_ban409 [] = {
    0xcb, 0xeb, 0xcb, 0xea, 0xa9, 0x4f, 0xcb, 0xed, 0xcb, 0xef, 
    0xcb, 0xe4, 0xcb, 0xe7, 0xcb, 0xee, 0xa9, 0x50, 
};
static const unsigned char big5_chars_ban410 [] = {
    0xcb, 0xe1, 0xcb, 0xe5, 
};
static const unsigned char big5_chars_ban411 [] = {
    0xcb, 0xe9, 0xce, 0x49, 0xa9, 0x4b, 0xce, 0x4d, 0xa8, 0xfd, 
    0xcb, 0xe6, 0xa8, 0xfe, 0xa9, 0x4c, 0xa9, 0x45, 0xa9, 0x41, 
};
static const unsigned char big5_chars_ban412 [] = {
    0xcb, 0xe2, 0xa9, 0x44, 0xa9, 0x49, 0xa9, 0x52, 0xcb, 0xe3, 
    0xcb, 0xdc, 0xa9, 0x43, 0xcb, 0xdd, 0xcb, 0xdf, 
};
static const unsigned char big5_chars_ban413 [] = {
    0xa9, 0x46, 
};
static const unsigned char big5_chars_ban414 [] = {
    0xa9, 0x48, 0xcb, 0xdb, 0xcb, 0xe0, 
};
static const unsigned char big5_chars_ban415 [] = {
    0xa9, 0x51, 0xa9, 0x4d, 0xcb, 0xe8, 0xa9, 0x53, 
};
static const unsigned char big5_chars_ban416 [] = {
    0xa9, 0x4a, 0xcb, 0xde, 0xa9, 0x47, 
};
static const unsigned char big5_chars_ban417 [] = {
    0xa9, 0x42, 0xa9, 0x40, 
};
static const unsigned char big5_chars_ban418 [] = {
    0xcb, 0xec, 
};
static const unsigned char big5_chars_ban419 [] = {
    0xa9, 0x4e, 
};
static const unsigned char big5_chars_ban420 [] = {
    0xce, 0x48, 0xcd, 0xfb, 0xce, 0x4b, 
};
static const unsigned char big5_chars_ban421 [] = {
    0xcd, 0xfd, 0xab, 0x78, 0xab, 0xa8, 0xab, 0x74, 0xab, 0xa7, 
    0xab, 0x7d, 0xab, 0xa4, 0xab, 0x72, 0xcd, 0xfc, 0xce, 0x43, 
    0xab, 0xa3, 0xce, 0x4f, 0xab, 0xa5, 
};
static const unsigned char big5_chars_ban422 [] = {
    0xab, 0x79, 
};
static const unsigned char big5_chars_ban423 [] = {
    0xce, 0x45, 0xce, 0x42, 0xab, 0x77, 
};
static const unsigned char big5_chars_ban424 [] = {
    0xcd, 0xfa, 0xab, 0xa6, 0xce, 0x4a, 0xab, 0x7c, 0xce, 0x4c, 
    0xab, 0xa9, 0xab, 0x73, 0xab, 0x7e, 0xab, 0x7b, 0xce, 0x40, 
    0xab, 0xa1, 0xce, 0x46, 0xce, 0x47, 0xab, 0x7a, 0xab, 0xa2, 
    0xab, 0x76, 
};
static const unsigned char big5_chars_ban425 [] = {
    0xab, 0x75, 0xcd, 0xfe, 
};
static const unsigned char big5_chars_ban426 [] = {
    0xce, 0x44, 
};
static const unsigned char big5_chars_ban427 [] = {
    0xce, 0x4e, 
};
static const unsigned char big5_chars_ban428 [] = {
    0xd1, 0x44, 0xad, 0xfb, 0xd0, 0xf1, 
};
static const unsigned char big5_chars_ban429 [] = {
    0xd0, 0xf6, 0xad, 0xf4, 0xae, 0x40, 0xd0, 0xf4, 0xad, 0xef, 
    0xad, 0xf9, 0xad, 0xfe, 0xd0, 0xfb, 
};
static const unsigned char big5_chars_ban430 [] = {
    0xad, 0xfa, 0xad, 0xfd, 
};
static const unsigned char big5_chars_ban431 [] = {
    0xd0, 0xfe, 0xad, 0xf5, 0xd0, 0xf5, 
};
static const unsigned char big5_chars_ban432 [] = {
    0xd1, 0x42, 0xd1, 0x43, 
};
static const unsigned char big5_chars_ban433 [] = {
    0xad, 0xf7, 0xd1, 0x41, 0xad, 0xf3, 0xae, 0x43, 
};
static const unsigned char big5_chars_ban434 [] = {
    0xd0, 0xf8, 
};
static const unsigned char big5_chars_ban435 [] = {
    0xad, 0xf1, 
};
static const unsigned char big5_chars_ban436 [] = {
    0xd1, 0x46, 0xd0, 0xf9, 0xd0, 0xfd, 0xad, 0xf6, 0xae, 0x42, 
    0xd0, 0xfa, 0xad, 0xfc, 0xd1, 0x40, 0xd1, 0x47, 0xd4, 0xa1, 
};
static const unsigned char big5_chars_ban437 [] = {
    0xd1, 0x45, 0xae, 0x44, 0xad, 0xf0, 0xd0, 0xfc, 0xd0, 0xf3, 
};
static const unsigned char big5_chars_ban438 [] = {
    0xad, 0xf8, 
};
static const unsigned char big5_chars_ban439 [] = {
    0xd0, 0xf2, 
};
static const unsigned char big5_chars_ban440 [] = {
    0xd0, 0xf7, 
};
static const unsigned char big5_chars_ban441 [] = {
    0xd0, 0xf0, 0xae, 0x41, 
};
static const unsigned char big5_chars_ban442 [] = {
    0xd4, 0x77, 
};
static const unsigned char big5_chars_ban443 [] = {
    0xb0, 0xe4, 0xd4, 0xa7, 0xb0, 0xe2, 0xb0, 0xdf, 0xd4, 0x7c, 
    0xb0, 0xdb, 0xd4, 0xa2, 0xb0, 0xe6, 0xd4, 0x76, 0xd4, 0x7b, 
    0xd4, 0x7a, 0xad, 0xf2, 0xb0, 0xe1, 0xd4, 0xa5, 
};
static const unsigned char big5_chars_ban444 [] = {
    0xd4, 0xa8, 0xd4, 0x73, 
};
static const unsigned char big5_chars_ban445 [] = {
    0xb3, 0xe8, 
};
static const unsigned char big5_chars_ban446 [] = {
    0xd4, 0xa9, 0xb0, 0xe7, 
};
static const unsigned char big5_chars_ban447 [] = {
    0xb0, 0xd9, 0xb0, 0xd6, 0xd4, 0x7e, 0xb0, 0xd3, 
};
static const unsigned char big5_chars_ban448 [] = {
    0xd4, 0xa6, 
};
static const unsigned char big5_chars_ban449 [] = {
    0xb0, 0xda, 0xd4, 0xaa, 
};
static const unsigned char big5_chars_ban450 [] = {
    0xd4, 0x74, 0xd4, 0xa4, 0xb0, 0xdd, 0xd4, 0x75, 0xd4, 0x78, 
    0xd4, 0x7d, 
};
static const unsigned char big5_chars_ban451 [] = {
    0xb0, 0xde, 0xb0, 0xdc, 0xb0, 0xe8, 
};
static const unsigned char big5_chars_ban452 [] = {
    0xb0, 0xe3, 
};
static const unsigned char big5_chars_ban453 [] = {
    0xb0, 0xd7, 0xb1, 0xd2, 
};
static const unsigned char big5_chars_ban454 [] = {
    0xb0, 0xd8, 0xd4, 0x79, 0xb0, 0xe5, 0xb0, 0xe0, 0xd4, 0xa3, 
    0xb0, 0xd5, 
};
static const unsigned char big5_chars_ban455 [] = {
    0xb0, 0xd4, 
};
static const unsigned char big5_chars_ban456 [] = {
    0xd4, 0x71, 0xd4, 0x72, 0xd8, 0x6a, 
};
static const unsigned char big5_chars_ban457 [] = {
    0xb3, 0xd7, 0xb3, 0xda, 0xd8, 0x75, 0xb3, 0xee, 0xd8, 0x78, 
    0xb3, 0xd8, 0xd8, 0x71, 0xb3, 0xde, 0xb3, 0xe4, 0xb5, 0xbd, 
};
static const unsigned char big5_chars_ban458 [] = {
    0xb3, 0xe2, 0xd8, 0x6e, 0xb3, 0xef, 0xb3, 0xdb, 0xb3, 0xe3, 
    0xd8, 0x76, 0xdc, 0xd7, 0xd8, 0x7b, 0xd8, 0x6f, 
};
static const unsigned char big5_chars_ban459 [] = {
    0xd8, 0x66, 0xd8, 0x73, 0xd8, 0x6d, 0xb3, 0xe1, 0xd8, 0x79, 
};
static const unsigned char big5_chars_ban460 [] = {
    0xb3, 0xdd, 0xb3, 0xf1, 0xb3, 0xea, 
};
static const unsigned char big5_chars_ban461 [] = {
    0xb3, 0xdf, 0xb3, 0xdc, 
};
static const unsigned char big5_chars_ban462 [] = {
    0xb3, 0xe7, 
};
static const unsigned char big5_chars_ban463 [] = {
    0xd8, 0x7a, 0xd8, 0x6c, 0xd8, 0x72, 0xd8, 0x74, 0xd8, 0x68, 
    0xd8, 0x77, 0xb3, 0xd9, 0xd8, 0x67, 
};
static const unsigned char big5_chars_ban464 [] = {
    0xb3, 0xe0, 0xb3, 0xf0, 0xb3, 0xec, 0xd8, 0x69, 0xb3, 0xe6, 
};
static const unsigned char big5_chars_ban465 [] = {
    0xb3, 0xed, 0xb3, 0xe9, 0xb3, 0xe5, 
};
static const unsigned char big5_chars_ban466 [] = {
    0xd8, 0x70, 
};
static const unsigned char big5_chars_ban467 [] = {
    0xb3, 0xeb, 
};
static const unsigned char big5_chars_ban468 [] = {
    0xdc, 0xd5, 0xdc, 0xd1, 
};
static const unsigned char big5_chars_ban469 [] = {
    0xdc, 0xe0, 0xdc, 0xca, 0xdc, 0xd3, 0xb6, 0xe5, 0xb6, 0xe6, 
    0xb6, 0xde, 0xdc, 0xdc, 0xb6, 0xe8, 0xdc, 0xcf, 0xdc, 0xce, 
    0xdc, 0xcc, 0xdc, 0xde, 0xb6, 0xdc, 0xdc, 0xd8, 0xdc, 0xcd, 
    0xb6, 0xdf, 0xdc, 0xd6, 0xb6, 0xda, 0xdc, 0xd2, 0xdc, 0xd9, 
    0xdc, 0xdb, 
};
static const unsigned char big5_chars_ban470 [] = {
    0xdc, 0xdf, 0xb6, 0xe3, 0xdc, 0xcb, 0xb6, 0xdd, 0xdc, 0xd0, 
};
static const unsigned char big5_chars_ban471 [] = {
    0xb6, 0xd8, 
};
static const unsigned char big5_chars_ban472 [] = {
    0xb6, 0xe4, 0xdc, 0xda, 0xb6, 0xe0, 0xb6, 0xe1, 0xb6, 0xe7, 
    0xb6, 0xdb, 0xa2, 0x5f, 0xb6, 0xd9, 0xdc, 0xd4, 
};
static const unsigned char big5_chars_ban473 [] = {
    0xb6, 0xe2, 
};
static const unsigned char big5_chars_ban474 [] = {
    0xdc, 0xdd, 
};
static const unsigned char big5_chars_ban475 [] = {
    0xb9, 0xcd, 0xb9, 0xc8, 
};
static const unsigned char big5_chars_ban476 [] = {
    0xe1, 0x55, 0xe1, 0x51, 
};
static const unsigned char big5_chars_ban477 [] = {
    0xe1, 0x4b, 0xb9, 0xc2, 0xb9, 0xbe, 0xe1, 0x54, 0xb9, 0xbf, 
    0xe1, 0x4e, 0xe1, 0x50, 
};
static const unsigned char big5_chars_ban478 [] = {
    0xe1, 0x53, 
};
static const unsigned char big5_chars_ban479 [] = {
    0xb9, 0xc4, 
};
static const unsigned char big5_chars_ban480 [] = {
    0xb9, 0xcb, 0xb9, 0xc5, 
};
static const unsigned char big5_chars_ban481 [] = {
    0xe1, 0x49, 0xb9, 0xc6, 0xb9, 0xc7, 0xe1, 0x4c, 0xb9, 0xcc, 
};
static const unsigned char big5_chars_ban482 [] = {
    0xe1, 0x4a, 0xe1, 0x4f, 0xb9, 0xc3, 0xe1, 0x48, 0xb9, 0xc9, 
    0xb9, 0xc1, 
};
static const unsigned char big5_chars_ban483 [] = {
    0xb9, 0xc0, 0xe1, 0x4d, 0xe1, 0x52, 
};
static const unsigned char big5_chars_ban484 [] = {
    0xb9, 0xca, 
};
static const unsigned char big5_chars_ban485 [] = {
    0xe1, 0x47, 
};
static const unsigned char big5_chars_ban486 [] = {
    0xbc, 0x4d, 0xe5, 0x47, 
};
static const unsigned char big5_chars_ban487 [] = {
    0xe5, 0x44, 
};
static const unsigned char big5_chars_ban488 [] = {
    0xbc, 0x47, 0xbc, 0x53, 0xbc, 0x54, 
};
static const unsigned char big5_chars_ban489 [] = {
    0xbc, 0x4a, 0xe5, 0x42, 0xbc, 0x4c, 0xe4, 0xf9, 0xbc, 0x52, 
};
static const unsigned char big5_chars_ban490 [] = {
    0xe5, 0x46, 0xbc, 0x49, 0xe5, 0x48, 0xbc, 0x48, 
};
static const unsigned char big5_chars_ban491 [] = {
    0xe5, 0x43, 0xe5, 0x45, 0xbc, 0x4b, 0xe5, 0x41, 0xe4, 0xfa, 
    0xe4, 0xf7, 
};
static const unsigned char big5_chars_ban492 [] = {
    0xd8, 0x6b, 0xe4, 0xfd, 
};
static const unsigned char big5_chars_ban493 [] = {
    0xe4, 0xf6, 0xe4, 0xfc, 0xe4, 0xfb, 
};
static const unsigned char big5_chars_ban494 [] = {
    0xe4, 0xf8, 
};
static const unsigned char big5_chars_ban495 [] = {
    0xbc, 0x4f, 
};
static const unsigned char big5_chars_ban496 [] = {
    0xbc, 0x4e, 
};
static const unsigned char big5_chars_ban497 [] = {
    0xbc, 0x50, 0xe4, 0xfe, 0xbe, 0xb2, 0xe5, 0x40, 
};
static const unsigned char big5_chars_ban498 [] = {
    0xe9, 0x45, 
};
static const unsigned char big5_chars_ban499 [] = {
    0xe8, 0xfd, 
};
static const unsigned char big5_chars_ban500 [] = {
    0xbe, 0xbe, 0xe9, 0x42, 0xbe, 0xb6, 0xbe, 0xba, 0xe9, 0x41, 
};
static const unsigned char big5_chars_ban501 [] = {
    0xbe, 0xb9, 0xbe, 0xb5, 0xbe, 0xb8, 0xbe, 0xb3, 0xbe, 0xbd, 
    0xe9, 0x43, 0xe8, 0xfe, 0xbe, 0xbc, 0xe8, 0xfc, 0xbe, 0xbb, 
    0xe9, 0x44, 0xe9, 0x40, 0xbc, 0x51, 
};
static const unsigned char big5_chars_ban502 [] = {
    0xbe, 0xbf, 0xe9, 0x46, 0xbe, 0xb7, 0xbe, 0xb4, 
};
static const unsigned char big5_chars_ban503 [] = {
    0xec, 0xc6, 0xec, 0xc8, 0xc0, 0x7b, 0xec, 0xc9, 0xec, 0xc7, 
    0xec, 0xc5, 0xec, 0xc4, 0xc0, 0x7d, 0xec, 0xc3, 0xc0, 0x7e, 
};
static const unsigned char big5_chars_ban504 [] = {
    0xec, 0xc1, 0xec, 0xc2, 0xc0, 0x7a, 0xc0, 0xa1, 0xc0, 0x7c, 
};
static const unsigned char big5_chars_ban505 [] = {
    0xec, 0xc0, 
};
static const unsigned char big5_chars_ban506 [] = {
    0xc2, 0x50, 
};
static const unsigned char big5_chars_ban507 [] = {
    0xef, 0xbc, 0xef, 0xba, 0xef, 0xbf, 0xef, 0xbd, 
};
static const unsigned char big5_chars_ban508 [] = {
    0xef, 0xbb, 0xef, 0xbe, 
};
static const unsigned char big5_chars_ban509 [] = {
    0xc3, 0x60, 0xf1, 0xf2, 0xf1, 0xf3, 0xc4, 0x56, 
};
static const unsigned char big5_chars_ban510 [] = {
    0xf1, 0xf4, 0xf1, 0xf0, 0xf1, 0xf5, 0xf1, 0xf1, 0xc2, 0x51, 
};
static const unsigned char big5_chars_ban511 [] = {
    0xf3, 0xfe, 0xf4, 0x41, 0xc4, 0x59, 0xf4, 0x40, 0xc4, 0x58, 
    0xc4, 0x57, 
};
static const unsigned char big5_chars_ban512 [] = {
    0xc4, 0x5a, 0xf5, 0xc5, 0xf5, 0xc6, 
};
static const unsigned char big5_chars_ban513 [] = {
    0xc4, 0xda, 0xc4, 0xd9, 0xc4, 0xdb, 0xf5, 0xc4, 
};
static const unsigned char big5_chars_ban514 [] = {
    0xf6, 0xd8, 0xf6, 0xd7, 
};
static const unsigned char big5_chars_ban515 [] = {
    0xc5, 0x6d, 0xc5, 0x6f, 0xc5, 0x6e, 0xf6, 0xd9, 0xc5, 0xc8, 
    0xf8, 0xa6, 
};
static const unsigned char big5_chars_ban516 [] = {
    0xc5, 0xf1, 
};
static const unsigned char big5_chars_ban517 [] = {
    0xf8, 0xa5, 0xf8, 0xee, 
};
static const unsigned char big5_chars_ban518 [] = {
    0xc9, 0x49, 
};
static const unsigned char big5_chars_ban519 [] = {
    0xa5, 0x7d, 0xa5, 0x7c, 
};
static const unsigned char big5_chars_ban520 [] = {
    0xa6, 0x5f, 0xa6, 0x5e, 0xc9, 0xc7, 0xa6, 0x5d, 0xc9, 0xc6, 
};
static const unsigned char big5_chars_ban521 [] = {
    0xa7, 0x79, 0xca, 0xa9, 
};
static const unsigned char big5_chars_ban522 [] = {
    0xca, 0xa8, 
};
static const unsigned char big5_chars_ban523 [] = {
    0xa7, 0x77, 0xa7, 0x7a, 
};
static const unsigned char big5_chars_ban524 [] = {
    0xca, 0xa7, 
};
static const unsigned char big5_chars_ban525 [] = {
    0xa7, 0x78, 
};
static const unsigned char big5_chars_ban526 [] = {
    0xcb, 0xf0, 
};
static const unsigned char big5_chars_ban527 [] = {
    0xcb, 0xf1, 0xa9, 0x54, 
};
static const unsigned char big5_chars_ban528 [] = {
    0xab, 0xaa, 
};
static const unsigned char big5_chars_ban529 [] = {
    0xd1, 0x48, 0xd1, 0x49, 0xae, 0x45, 0xae, 0x46, 
};
static const unsigned char big5_chars_ban530 [] = {
    0xd4, 0xac, 0xb0, 0xe9, 0xb0, 0xeb, 0xd4, 0xab, 0xb0, 0xea, 
    0xd8, 0x7c, 0xb3, 0xf2, 
};
static const unsigned char big5_chars_ban531 [] = {
    0xb6, 0xe9, 0xb6, 0xea, 0xdc, 0xe1, 
};
static const unsigned char big5_chars_ban532 [] = {
    0xb9, 0xcf, 
};
static const unsigned char big5_chars_ban533 [] = {
    0xb9, 0xce, 
};
static const unsigned char big5_chars_ban534 [] = {
    0xe5, 0x49, 0xe9, 0x48, 0xe9, 0x47, 
};
static const unsigned char big5_chars_ban535 [] = {
    0xf9, 0x6b, 0xa4, 0x67, 0xc9, 0x59, 
};
static const unsigned char big5_chars_ban536 [] = {
    0xc9, 0x6e, 0xc9, 0x6f, 
};
static const unsigned char big5_chars_ban537 [] = {
    0xa6, 0x62, 0xa6, 0x66, 0xc9, 0xc9, 
};
static const unsigned char big5_chars_ban538 [] = {
    0xa6, 0x64, 0xa6, 0x63, 0xc9, 0xc8, 0xa6, 0x65, 0xa6, 0x61, 
};
static const unsigned char big5_chars_ban539 [] = {
    0xa6, 0x60, 0xc9, 0xca, 
};
static const unsigned char big5_chars_ban540 [] = {
    0xa7, 0xa6, 
};
static const unsigned char big5_chars_ban541 [] = {
    0xa7, 0xa3, 
};
static const unsigned char big5_chars_ban542 [] = {
    0xa7, 0x7d, 0xca, 0xaa, 
};
static const unsigned char big5_chars_ban543 [] = {
    0xca, 0xab, 
};
static const unsigned char big5_chars_ban544 [] = {
    0xa7, 0xa1, 
};
static const unsigned char big5_chars_ban545 [] = {
    0xca, 0xad, 0xa7, 0x7b, 0xca, 0xae, 0xca, 0xac, 0xa7, 0x7e, 
    0xa7, 0xa2, 0xa7, 0xa5, 0xa7, 0xa4, 0xa7, 0x7c, 0xca, 0xaf, 
};
static const unsigned char big5_chars_ban546 [] = {
    0xa9, 0x59, 0xcb, 0xfe, 
};
static const unsigned char big5_chars_ban547 [] = {
    0xa9, 0x5b, 
};
static const unsigned char big5_chars_ban548 [] = {
    0xa9, 0x5a, 
};
static const unsigned char big5_chars_ban549 [] = {
    0xcc, 0x40, 0xa9, 0x58, 0xa9, 0x57, 0xcb, 0xf5, 
};
static const unsigned char big5_chars_ban550 [] = {
    0xcb, 0xf4, 
};
static const unsigned char big5_chars_ban551 [] = {
    0xcb, 0xf2, 0xcb, 0xf7, 0xcb, 0xf6, 0xcb, 0xf3, 0xcb, 0xfc, 
    0xcb, 0xfd, 0xcb, 0xfa, 0xcb, 0xf8, 0xa9, 0x56, 
};
static const unsigned char big5_chars_ban552 [] = {
    0xcb, 0xfb, 0xa9, 0x5c, 0xcc, 0x41, 
};
static const unsigned char big5_chars_ban553 [] = {
    0xcb, 0xf9, 
};
static const unsigned char big5_chars_ban554 [] = {
    0xab, 0xab, 0xa9, 0x55, 
};
static const unsigned char big5_chars_ban555 [] = {
    0xab, 0xac, 0xce, 0x54, 
};
static const unsigned char big5_chars_ban556 [] = {
    0xce, 0x5a, 
};
static const unsigned char big5_chars_ban557 [] = {
    0xab, 0xb2, 0xce, 0x58, 0xce, 0x5e, 
};
static const unsigned char big5_chars_ban558 [] = {
    0xce, 0x55, 0xce, 0x59, 0xce, 0x5b, 0xce, 0x5d, 0xce, 0x57, 
};
static const unsigned char big5_chars_ban559 [] = {
    0xce, 0x56, 0xce, 0x51, 0xce, 0x52, 0xab, 0xad, 
};
static const unsigned char big5_chars_ban560 [] = {
    0xab, 0xaf, 0xab, 0xae, 0xce, 0x53, 0xce, 0x5c, 
};
static const unsigned char big5_chars_ban561 [] = {
    0xab, 0xb1, 
};
static const unsigned char big5_chars_ban562 [] = {
    0xce, 0x50, 0xd1, 0x53, 
};
static const unsigned char big5_chars_ban563 [] = {
    0xd1, 0x52, 0xd1, 0x57, 0xd1, 0x4e, 
};
static const unsigned char big5_chars_ban564 [] = {
    0xd1, 0x51, 0xd1, 0x50, 
};
static const unsigned char big5_chars_ban565 [] = {
    0xd1, 0x54, 
};
static const unsigned char big5_chars_ban566 [] = {
    0xd1, 0x58, 0xae, 0x47, 0xae, 0x4a, 
};
static const unsigned char big5_chars_ban567 [] = {
    0xd1, 0x4f, 0xd1, 0x55, 
};
static const unsigned char big5_chars_ban568 [] = {
    0xae, 0x49, 0xd1, 0x4a, 
};
static const unsigned char big5_chars_ban569 [] = {
    0xab, 0xb0, 0xd4, 0xba, 0xd1, 0x56, 
};
static const unsigned char big5_chars_ban570 [] = {
    0xd1, 0x4d, 
};
static const unsigned char big5_chars_ban571 [] = {
    0xae, 0x48, 0xd1, 0x4c, 
};
static const unsigned char big5_chars_ban572 [] = {
    0xd4, 0xb1, 
};
static const unsigned char big5_chars_ban573 [] = {
    0xb0, 0xec, 0xb0, 0xf0, 0xd4, 0xc1, 0xd4, 0xaf, 0xd4, 0xbd, 
    0xb0, 0xf1, 0xd4, 0xbf, 
};
static const unsigned char big5_chars_ban574 [] = {
    0xd4, 0xc5, 
};
static const unsigned char big5_chars_ban575 [] = {
    0xd4, 0xc9, 
};
static const unsigned char big5_chars_ban576 [] = {
    0xd4, 0xc0, 0xd4, 0xb4, 0xd4, 0xbc, 
};
static const unsigned char big5_chars_ban577 [] = {
    0xd4, 0xca, 0xd4, 0xc8, 0xd4, 0xbe, 0xd4, 0xb9, 0xd4, 0xb2, 
    0xd8, 0xa6, 0xd4, 0xb0, 0xb0, 0xf5, 0xd4, 0xb7, 0xb0, 0xf6, 
    0xb0, 0xf2, 0xd4, 0xad, 0xd4, 0xc3, 0xd4, 0xb5, 
};
static const unsigned char big5_chars_ban578 [] = {
    0xd4, 0xb3, 0xd4, 0xc6, 0xb0, 0xf3, 
};
static const unsigned char big5_chars_ban579 [] = {
    0xd4, 0xcc, 0xb0, 0xed, 0xb0, 0xef, 0xd4, 0xbb, 0xd4, 0xb6, 
    0xae, 0x4b, 0xb0, 0xee, 0xd4, 0xb8, 0xd4, 0xc7, 0xd4, 0xcb, 
    0xd4, 0xc2, 
};
static const unsigned char big5_chars_ban580 [] = {
    0xd4, 0xc4, 
};
static const unsigned char big5_chars_ban581 [] = {
    0xd4, 0xae, 
};
static const unsigned char big5_chars_ban582 [] = {
    0xd8, 0xa1, 
};
static const unsigned char big5_chars_ban583 [] = {
    0xd8, 0xaa, 0xd8, 0xa9, 0xb3, 0xfa, 0xd8, 0xa2, 
};
static const unsigned char big5_chars_ban584 [] = {
    0xb3, 0xfb, 0xb3, 0xf9, 
};
static const unsigned char big5_chars_ban585 [] = {
    0xd8, 0xa4, 0xb3, 0xf6, 0xd8, 0xa8, 
};
static const unsigned char big5_chars_ban586 [] = {
    0xd8, 0xa3, 0xd8, 0xa5, 0xd8, 0x7d, 0xb3, 0xf4, 
};
static const unsigned char big5_chars_ban587 [] = {
    0xd8, 0xb2, 0xd8, 0xb1, 0xd8, 0xae, 0xb3, 0xf3, 0xb3, 0xf7, 
    0xb3, 0xf8, 0xd1, 0x4b, 0xd8, 0xab, 0xb3, 0xf5, 0xb0, 0xf4, 
    0xd8, 0xad, 0xd8, 0x7e, 0xd8, 0xb0, 0xd8, 0xaf, 
};
static const unsigned char big5_chars_ban588 [] = {
    0xd8, 0xb3, 
};
static const unsigned char big5_chars_ban589 [] = {
    0xdc, 0xef, 
};
static const unsigned char big5_chars_ban590 [] = {
    0xd8, 0xac, 
};
static const unsigned char big5_chars_ban591 [] = {
    0xd8, 0xa7, 0xdc, 0xe7, 0xb6, 0xf4, 0xb6, 0xf7, 0xb6, 0xf2, 
    0xdc, 0xe6, 0xdc, 0xea, 0xdc, 0xe5, 
};
static const unsigned char big5_chars_ban592 [] = {
    0xb6, 0xec, 0xb6, 0xf6, 0xdc, 0xe2, 0xb6, 0xf0, 0xdc, 0xe9, 
};
static const unsigned char big5_chars_ban593 [] = {
    0xb6, 0xee, 0xb6, 0xed, 0xdc, 0xec, 0xb6, 0xef, 0xdc, 0xee, 
};
static const unsigned char big5_chars_ban594 [] = {
    0xdc, 0xeb, 0xb6, 0xeb, 
};
static const unsigned char big5_chars_ban595 [] = {
    0xb6, 0xf5, 0xdc, 0xf0, 0xdc, 0xe4, 0xdc, 0xed, 
};
static const unsigned char big5_chars_ban596 [] = {
    0xdc, 0xe3, 
};
static const unsigned char big5_chars_ban597 [] = {
    0xb6, 0xf1, 
};
static const unsigned char big5_chars_ban598 [] = {
    0xb6, 0xf3, 
};
static const unsigned char big5_chars_ban599 [] = {
    0xdc, 0xe8, 
};
static const unsigned char big5_chars_ban600 [] = {
    0xdc, 0xf1, 
};
static const unsigned char big5_chars_ban601 [] = {
    0xe1, 0x5d, 0xb9, 0xd0, 0xe1, 0x63, 
};
static const unsigned char big5_chars_ban602 [] = {
    0xb9, 0xd5, 0xe1, 0x5f, 0xe1, 0x66, 0xe1, 0x57, 0xb9, 0xd7, 
    0xb9, 0xd1, 0xe1, 0x5c, 0xbc, 0x55, 0xe1, 0x5b, 0xe1, 0x64, 
    0xb9, 0xd2, 
};
static const unsigned char big5_chars_ban603 [] = {
    0xb9, 0xd6, 0xe1, 0x5a, 0xe1, 0x60, 0xe1, 0x65, 0xe1, 0x56, 
    0xb9, 0xd4, 0xe1, 0x5e, 
};
static const unsigned char big5_chars_ban604 [] = {
    0xe1, 0x62, 0xe1, 0x68, 0xe1, 0x58, 0xe1, 0x61, 
};
static const unsigned char big5_chars_ban605 [] = {
    0xb9, 0xd3, 0xe1, 0x67, 
};
static const unsigned char big5_chars_ban606 [] = {
    0xe1, 0x59, 
};
static const unsigned char big5_chars_ban607 [] = {
    0xbc, 0x59, 0xe5, 0x4b, 0xbc, 0x57, 0xbc, 0x56, 0xe5, 0x4d, 
    0xe5, 0x52, 
};
static const unsigned char big5_chars_ban608 [] = {
    0xe5, 0x4e, 
};
static const unsigned char big5_chars_ban609 [] = {
    0xe5, 0x51, 0xbc, 0x5c, 
};
static const unsigned char big5_chars_ban610 [] = {
    0xbe, 0xa5, 0xbc, 0x5b, 
};
static const unsigned char big5_chars_ban611 [] = {
    0xe5, 0x4a, 0xe5, 0x50, 
};
static const unsigned char big5_chars_ban612 [] = {
    0xbc, 0x5a, 0xe5, 0x4f, 
};
static const unsigned char big5_chars_ban613 [] = {
    0xe5, 0x4c, 
};
static const unsigned char big5_chars_ban614 [] = {
    0xbc, 0x58, 
};
static const unsigned char big5_chars_ban615 [] = {
    0xe9, 0x4d, 0xf9, 0xd9, 0xe9, 0x4f, 0xe9, 0x4a, 0xbe, 0xc1, 
    0xe9, 0x4c, 
};
static const unsigned char big5_chars_ban616 [] = {
    0xbe, 0xc0, 0xe9, 0x4e, 
};
static const unsigned char big5_chars_ban617 [] = {
    0xbe, 0xc3, 0xe9, 0x50, 0xbe, 0xc2, 0xe9, 0x49, 0xe9, 0x4b, 
};
static const unsigned char big5_chars_ban618 [] = {
    0xc0, 0xa5, 0xec, 0xcc, 
};
static const unsigned char big5_chars_ban619 [] = {
    0xc0, 0xa4, 0xec, 0xcd, 0xc0, 0xa3, 0xec, 0xcb, 0xc0, 0xa2, 
    0xec, 0xca, 
};
static const unsigned char big5_chars_ban620 [] = {
    0xc2, 0x53, 0xc2, 0x52, 0xf1, 0xf6, 0xf1, 0xf8, 
};
static const unsigned char big5_chars_ban621 [] = {
    0xf1, 0xf7, 0xc3, 0x61, 0xc3, 0x62, 
};
static const unsigned char big5_chars_ban622 [] = {
    0xc3, 0x63, 0xf4, 0x42, 0xc4, 0x5b, 
};
static const unsigned char big5_chars_ban623 [] = {
    0xf7, 0xd3, 0xf7, 0xd2, 0xc5, 0xf2, 
};
static const unsigned char big5_chars_ban624 [] = {
    0xa4, 0x68, 0xa4, 0xd0, 
};
static const unsigned char big5_chars_ban625 [] = {
    0xa7, 0xa7, 
};
static const unsigned char big5_chars_ban626 [] = {
    0xce, 0x5f, 
};
static const unsigned char big5_chars_ban627 [] = {
    0xb3, 0xfc, 0xb3, 0xfd, 
};
static const unsigned char big5_chars_ban628 [] = {
    0xdc, 0xf2, 0xb9, 0xd8, 0xe1, 0x69, 0xe5, 0x53, 
};
static const unsigned char big5_chars_ban629 [] = {
    0xc9, 0x5a, 
};
static const unsigned char big5_chars_ban630 [] = {
    0xca, 0xb0, 
};
static const unsigned char big5_chars_ban631 [] = {
    0xcc, 0x42, 0xce, 0x60, 0xd1, 0x59, 0xae, 0x4c, 
};
static const unsigned char big5_chars_ban632 [] = {
    0xf1, 0xf9, 
};
static const unsigned char big5_chars_ban633 [] = {
    0xc4, 0xdc, 0xa4, 0x69, 0xa5, 0x7e, 0xc9, 0x70, 
};
static const unsigned char big5_chars_ban634 [] = {
    0xa6, 0x67, 0xa6, 0x68, 
};
static const unsigned char big5_chars_ban635 [] = {
    0xa9, 0x5d, 
};
static const unsigned char big5_chars_ban636 [] = {
    0xb0, 0xf7, 
};
static const unsigned char big5_chars_ban637 [] = {
    0xb9, 0xda, 
};
static const unsigned char big5_chars_ban638 [] = {
    0xb9, 0xdb, 0xb9, 0xd9, 
};
static const unsigned char big5_chars_ban639 [] = {
    0xa4, 0x6a, 
};
static const unsigned char big5_chars_ban640 [] = {
    0xa4, 0xd1, 0xa4, 0xd3, 0xa4, 0xd2, 0xc9, 0x5b, 0xa4, 0xd4, 
    0xa5, 0xa1, 0xc9, 0x71, 
};
static const unsigned char big5_chars_ban641 [] = {
    0xa5, 0xa2, 
};
static const unsigned char big5_chars_ban642 [] = {
    0xa6, 0x69, 0xa6, 0x6a, 
};
static const unsigned char big5_chars_ban643 [] = {
    0xc9, 0xcb, 
};
static const unsigned char big5_chars_ban644 [] = {
    0xa7, 0xa8, 
};
static const unsigned char big5_chars_ban645 [] = {
    0xca, 0xb1, 
};
static const unsigned char big5_chars_ban646 [] = {
    0xa9, 0x61, 0xcc, 0x43, 
};
static const unsigned char big5_chars_ban647 [] = {
    0xa9, 0x5f, 0xa9, 0x60, 0xa9, 0x5e, 0xd1, 0x5a, 
};
static const unsigned char big5_chars_ban648 [] = {
    0xab, 0xb6, 0xab, 0xb5, 0xab, 0xb7, 0xab, 0xb4, 
};
static const unsigned char big5_chars_ban649 [] = {
    0xce, 0x61, 0xa9, 0x62, 0xab, 0xb3, 
};
static const unsigned char big5_chars_ban650 [] = {
    0xae, 0x4d, 0xae, 0x4e, 
};
static const unsigned char big5_chars_ban651 [] = {
    0xae, 0x4f, 
};
static const unsigned char big5_chars_ban652 [] = {
    0xd4, 0xcd, 
};
static const unsigned char big5_chars_ban653 [] = {
    0xb3, 0xfe, 0xd8, 0xb4, 0xb0, 0xf8, 
};
static const unsigned char big5_chars_ban654 [] = {
    0xb6, 0xf8, 
};
static const unsigned char big5_chars_ban655 [] = {
    0xb9, 0xdd, 0xb9, 0xdc, 0xe1, 0x6a, 
};
static const unsigned char big5_chars_ban656 [] = {
    0xbc, 0x5d, 0xbe, 0xc4, 
};
static const unsigned char big5_chars_ban657 [] = {
    0xef, 0xc0, 0xf6, 0xda, 0xf7, 0xd4, 0xa4, 0x6b, 0xa5, 0xa3, 
};
static const unsigned char big5_chars_ban658 [] = {
    0xa5, 0xa4, 0xc9, 0xd1, 0xa6, 0x6c, 0xa6, 0x6f, 
};
static const unsigned char big5_chars_ban659 [] = {
    0xc9, 0xcf, 0xc9, 0xcd, 0xa6, 0x6e, 0xc9, 0xd0, 0xc9, 0xd2, 
    0xc9, 0xcc, 0xa6, 0x71, 0xa6, 0x70, 0xa6, 0x6d, 0xa6, 0x6b, 
    0xc9, 0xce, 
};
static const unsigned char big5_chars_ban660 [] = {
    0xa7, 0xb3, 
};
static const unsigned char big5_chars_ban661 [] = {
    0xa7, 0xb0, 0xca, 0xb6, 0xca, 0xb9, 0xca, 0xb8, 
};
static const unsigned char big5_chars_ban662 [] = {
    0xa7, 0xaa, 0xa7, 0xb2, 
};
static const unsigned char big5_chars_ban663 [] = {
    0xa7, 0xaf, 0xca, 0xb5, 0xca, 0xb3, 0xa7, 0xae, 
};
static const unsigned char big5_chars_ban664 [] = {
    0xa7, 0xa9, 0xa7, 0xac, 
};
static const unsigned char big5_chars_ban665 [] = {
    0xca, 0xb4, 0xca, 0xbb, 0xca, 0xb7, 0xa7, 0xad, 0xa7, 0xb1, 
    0xa7, 0xb4, 0xca, 0xb2, 0xca, 0xba, 0xa7, 0xab, 
};
static const unsigned char big5_chars_ban666 [] = {
    0xa9, 0x67, 0xa9, 0x6f, 
};
static const unsigned char big5_chars_ban667 [] = {
    0xcc, 0x4f, 0xcc, 0x48, 0xa9, 0x70, 0xcc, 0x53, 0xcc, 0x44, 
    0xcc, 0x4b, 
};
static const unsigned char big5_chars_ban668 [] = {
    0xa9, 0x66, 0xcc, 0x45, 0xa9, 0x64, 0xcc, 0x4c, 0xcc, 0x50, 
    0xa9, 0x63, 
};
static const unsigned char big5_chars_ban669 [] = {
    0xcc, 0x51, 0xcc, 0x4a, 
};
static const unsigned char big5_chars_ban670 [] = {
    0xcc, 0x4d, 
};
static const unsigned char big5_chars_ban671 [] = {
    0xa9, 0x72, 0xa9, 0x69, 0xcc, 0x54, 0xcc, 0x52, 
};
static const unsigned char big5_chars_ban672 [] = {
    0xa9, 0x6e, 0xa9, 0x6c, 0xcc, 0x49, 0xa9, 0x6b, 0xcc, 0x47, 
    0xcc, 0x46, 0xa9, 0x6a, 0xa9, 0x68, 0xa9, 0x71, 0xa9, 0x6d, 
    0xa9, 0x65, 
};
static const unsigned char big5_chars_ban673 [] = {
    0xcc, 0x4e, 
};
static const unsigned char big5_chars_ban674 [] = {
    0xab, 0xb9, 
};
static const unsigned char big5_chars_ban675 [] = {
    0xab, 0xc0, 0xce, 0x6f, 0xab, 0xb8, 0xce, 0x67, 0xce, 0x63, 
};
static const unsigned char big5_chars_ban676 [] = {
    0xce, 0x73, 0xce, 0x62, 
};
static const unsigned char big5_chars_ban677 [] = {
    0xab, 0xbb, 0xce, 0x6c, 0xab, 0xbe, 0xab, 0xc1, 
};
static const unsigned char big5_chars_ban678 [] = {
    0xab, 0xbc, 0xce, 0x70, 0xab, 0xbf, 
};
static const unsigned char big5_chars_ban679 [] = {
    0xae, 0x56, 0xce, 0x76, 0xce, 0x64, 
};
static const unsigned char big5_chars_ban680 [] = {
    0xce, 0x66, 0xce, 0x6d, 0xce, 0x71, 0xce, 0x75, 0xce, 0x72, 
    0xce, 0x6b, 0xce, 0x6e, 
};
static const unsigned char big5_chars_ban681 [] = {
    0xce, 0x68, 0xab, 0xc3, 0xce, 0x6a, 0xce, 0x69, 0xce, 0x74, 
    0xab, 0xba, 0xce, 0x65, 0xab, 0xc2, 
};
static const unsigned char big5_chars_ban682 [] = {
    0xab, 0xbd, 
};
static const unsigned char big5_chars_ban683 [] = {
    0xae, 0x5c, 0xd1, 0x62, 
};
static const unsigned char big5_chars_ban684 [] = {
    0xae, 0x5b, 
};
static const unsigned char big5_chars_ban685 [] = {
    0xd1, 0x60, 
};
static const unsigned char big5_chars_ban686 [] = {
    0xae, 0x50, 
};
static const unsigned char big5_chars_ban687 [] = {
    0xae, 0x55, 
};
static const unsigned char big5_chars_ban688 [] = {
    0xd1, 0x5f, 0xd1, 0x5c, 0xd1, 0x61, 0xae, 0x51, 0xd1, 0x5b, 
};
static const unsigned char big5_chars_ban689 [] = {
    0xae, 0x54, 0xae, 0x52, 
};
static const unsigned char big5_chars_ban690 [] = {
    0xd1, 0x63, 0xae, 0x53, 0xae, 0x57, 
};
static const unsigned char big5_chars_ban691 [] = {
    0xae, 0x58, 
};
static const unsigned char big5_chars_ban692 [] = {
    0xae, 0x5a, 
};
static const unsigned char big5_chars_ban693 [] = {
    0xae, 0x59, 
};
static const unsigned char big5_chars_ban694 [] = {
    0xd1, 0x5d, 0xd1, 0x5e, 
};
static const unsigned char big5_chars_ban695 [] = {
    0xd1, 0x64, 
};
static const unsigned char big5_chars_ban696 [] = {
    0xd4, 0xd4, 0xb0, 0xf9, 0xd8, 0xc2, 0xd4, 0xd3, 0xd4, 0xe6, 
};
static const unsigned char big5_chars_ban697 [] = {
    0xb1, 0x40, 
};
static const unsigned char big5_chars_ban698 [] = {
    0xd4, 0xe4, 
};
static const unsigned char big5_chars_ban699 [] = {
    0xb0, 0xfe, 0xb0, 0xfa, 0xd4, 0xed, 0xd4, 0xdd, 0xd4, 0xe0, 
};
static const unsigned char big5_chars_ban700 [] = {
    0xb1, 0x43, 0xd4, 0xea, 0xd4, 0xe2, 0xb0, 0xfb, 0xb1, 0x44, 
};
static const unsigned char big5_chars_ban701 [] = {
    0xd4, 0xe7, 0xd4, 0xe5, 
};
static const unsigned char big5_chars_ban702 [] = {
    0xd4, 0xd6, 0xd4, 0xeb, 0xd4, 0xdf, 0xd4, 0xda, 
};
static const unsigned char big5_chars_ban703 [] = {
    0xd4, 0xd0, 0xd4, 0xec, 0xd4, 0xdc, 0xd4, 0xcf, 
};
static const unsigned char big5_chars_ban704 [] = {
    0xb1, 0x42, 0xd4, 0xe1, 0xd4, 0xee, 0xd4, 0xde, 0xd4, 0xd2, 
    0xd4, 0xd7, 0xd4, 0xce, 
};
static const unsigned char big5_chars_ban705 [] = {
    0xb1, 0x41, 
};
static const unsigned char big5_chars_ban706 [] = {
    0xd4, 0xdb, 0xd4, 0xd8, 0xb0, 0xfc, 0xd4, 0xd1, 
};
static const unsigned char big5_chars_ban707 [] = {
    0xd4, 0xe9, 0xb0, 0xfd, 
};
static const unsigned char big5_chars_ban708 [] = {
    0xd4, 0xd9, 0xd4, 0xd5, 
};
static const unsigned char big5_chars_ban709 [] = {
    0xd4, 0xe8, 
};
static const unsigned char big5_chars_ban710 [] = {
    0xb4, 0x40, 0xd8, 0xbb, 
};
static const unsigned char big5_chars_ban711 [] = {
    0xd8, 0xb8, 0xd8, 0xc9, 0xd8, 0xbd, 0xd8, 0xca, 
};
static const unsigned char big5_chars_ban712 [] = {
    0xb4, 0x42, 
};
static const unsigned char big5_chars_ban713 [] = {
    0xd8, 0xc6, 0xd8, 0xc3, 
};
static const unsigned char big5_chars_ban714 [] = {
    0xd8, 0xc4, 0xd8, 0xc7, 0xd8, 0xcb, 
};
static const unsigned char big5_chars_ban715 [] = {
    0xd4, 0xe3, 0xd8, 0xcd, 0xdd, 0x47, 
};
static const unsigned char big5_chars_ban716 [] = {
    0xb4, 0x43, 0xd8, 0xce, 0xd8, 0xb6, 0xd8, 0xc0, 
};
static const unsigned char big5_chars_ban717 [] = {
    0xd8, 0xc5, 
};
static const unsigned char big5_chars_ban718 [] = {
    0xb4, 0x41, 0xb4, 0x44, 0xd8, 0xcc, 0xd8, 0xcf, 0xd8, 0xba, 
    0xd8, 0xb7, 
};
static const unsigned char big5_chars_ban719 [] = {
    0xd8, 0xb9, 
};
static const unsigned char big5_chars_ban720 [] = {
    0xd8, 0xbe, 0xd8, 0xbc, 0xb4, 0x45, 
};
static const unsigned char big5_chars_ban721 [] = {
    0xd8, 0xc8, 
};
static const unsigned char big5_chars_ban722 [] = {
    0xd8, 0xbf, 
};
static const unsigned char big5_chars_ban723 [] = {
    0xd8, 0xc1, 0xd8, 0xb5, 0xdc, 0xfa, 0xdc, 0xf8, 0xb7, 0x42, 
    0xb7, 0x40, 0xdd, 0x43, 0xdc, 0xf9, 0xdd, 0x44, 0xdd, 0x40, 
    0xdc, 0xf7, 0xdd, 0x46, 0xdc, 0xf6, 0xdc, 0xfd, 0xb6, 0xfe, 
    0xb6, 0xfd, 0xb6, 0xfc, 0xdc, 0xfb, 0xdd, 0x41, 0xb6, 0xf9, 
    0xb7, 0x41, 
};
static const unsigned char big5_chars_ban724 [] = {
    0xdc, 0xf4, 
};
static const unsigned char big5_chars_ban725 [] = {
    0xdc, 0xfe, 0xdc, 0xf3, 0xdc, 0xfc, 0xb6, 0xfa, 0xdd, 0x42, 
    0xdc, 0xf5, 0xb6, 0xfb, 0xdd, 0x45, 
};
static const unsigned char big5_chars_ban726 [] = {
    0xe1, 0x6e, 0xb9, 0xe2, 0xb9, 0xe1, 0xb9, 0xe3, 0xe1, 0x7a, 
    0xe1, 0x70, 0xe1, 0x76, 0xe1, 0x6b, 0xe1, 0x79, 0xe1, 0x78, 
    0xe1, 0x7c, 0xe1, 0x75, 0xb9, 0xde, 0xe1, 0x74, 0xb9, 0xe4, 
};
static const unsigned char big5_chars_ban727 [] = {
    0xe1, 0x6d, 0xb9, 0xdf, 
};
static const unsigned char big5_chars_ban728 [] = {
    0xe1, 0x7b, 0xb9, 0xe0, 0xe1, 0x6f, 0xe1, 0x72, 0xe1, 0x77, 
    0xe1, 0x71, 0xe1, 0x6c, 
};
static const unsigned char big5_chars_ban729 [] = {
    0xe1, 0x73, 0xe5, 0x55, 0xbc, 0x61, 0xe5, 0x58, 0xe5, 0x57, 
    0xe5, 0x5a, 0xe5, 0x5c, 0xf9, 0xdc, 0xbc, 0x5f, 
};
static const unsigned char big5_chars_ban730 [] = {
    0xe5, 0x56, 
};
static const unsigned char big5_chars_ban731 [] = {
    0xe5, 0x54, 
};
static const unsigned char big5_chars_ban732 [] = {
    0xe5, 0x5d, 0xe5, 0x5b, 0xe5, 0x59, 
};
static const unsigned char big5_chars_ban733 [] = {
    0xe5, 0x5f, 
};
static const unsigned char big5_chars_ban734 [] = {
    0xe5, 0x5e, 0xbc, 0x63, 0xbc, 0x5e, 
};
static const unsigned char big5_chars_ban735 [] = {
    0xbc, 0x60, 0xbc, 0x62, 
};
static const unsigned char big5_chars_ban736 [] = {
    0xe5, 0x60, 0xe9, 0x57, 
};
static const unsigned char big5_chars_ban737 [] = {
    0xe9, 0x56, 0xe9, 0x55, 
};
static const unsigned char big5_chars_ban738 [] = {
    0xe9, 0x58, 0xe9, 0x51, 
};
static const unsigned char big5_chars_ban739 [] = {
    0xe9, 0x52, 0xe9, 0x5a, 0xe9, 0x53, 
};
static const unsigned char big5_chars_ban740 [] = {
    0xbe, 0xc5, 0xe9, 0x5c, 
};
static const unsigned char big5_chars_ban741 [] = {
    0xe9, 0x5b, 0xe9, 0x54, 
};
static const unsigned char big5_chars_ban742 [] = {
    0xec, 0xd1, 0xc0, 0xa8, 0xec, 0xcf, 0xec, 0xd4, 0xec, 0xd3, 
    0xe9, 0x59, 
};
static const unsigned char big5_chars_ban743 [] = {
    0xc0, 0xa7, 
};
static const unsigned char big5_chars_ban744 [] = {
    0xec, 0xd2, 0xec, 0xce, 0xec, 0xd6, 0xec, 0xd5, 0xc0, 0xa6, 
};
static const unsigned char big5_chars_ban745 [] = {
    0xec, 0xd0, 
};
static const unsigned char big5_chars_ban746 [] = {
    0xbe, 0xc6, 
};
static const unsigned char big5_chars_ban747 [] = {
    0xc2, 0x54, 
};
static const unsigned char big5_chars_ban748 [] = {
    0xef, 0xc1, 0xf1, 0xfa, 0xf1, 0xfb, 0xf1, 0xfc, 0xc4, 0x5c, 
};
static const unsigned char big5_chars_ban749 [] = {
    0xc4, 0x5d, 
};
static const unsigned char big5_chars_ban750 [] = {
    0xf4, 0x43, 
};
static const unsigned char big5_chars_ban751 [] = {
    0xf5, 0xc8, 0xf5, 0xc7, 
};
static const unsigned char big5_chars_ban752 [] = {
    0xf6, 0xdb, 0xf6, 0xdc, 0xf7, 0xd5, 0xf8, 0xa7, 
};
static const unsigned char big5_chars_ban753 [] = {
    0xa4, 0x6c, 0xa4, 0x6d, 
};
static const unsigned char big5_chars_ban754 [] = {
    0xa4, 0x6e, 0xa4, 0xd5, 0xa5, 0xa5, 0xc9, 0xd3, 0xa6, 0x72, 
    0xa6, 0x73, 
};
static const unsigned char big5_chars_ban755 [] = {
    0xa7, 0xb7, 0xa7, 0xb8, 0xa7, 0xb6, 0xa7, 0xb5, 
};
static const unsigned char big5_chars_ban756 [] = {
    0xa9, 0x73, 
};
static const unsigned char big5_chars_ban757 [] = {
    0xcc, 0x55, 0xa9, 0x75, 0xa9, 0x74, 0xcc, 0x56, 
};
static const unsigned char big5_chars_ban758 [] = {
    0xab, 0xc4, 
};
static const unsigned char big5_chars_ban759 [] = {
    0xae, 0x5d, 0xd1, 0x65, 
};
static const unsigned char big5_chars_ban760 [] = {
    0xd4, 0xf0, 
};
static const unsigned char big5_chars_ban761 [] = {
    0xb1, 0x45, 0xb4, 0x47, 0xd4, 0xef, 0xb4, 0x46, 
};
static const unsigned char big5_chars_ban762 [] = {
    0xb9, 0xe5, 
};
static const unsigned char big5_chars_ban763 [] = {
    0xe1, 0x7d, 0xbe, 0xc7, 
};
static const unsigned char big5_chars_ban764 [] = {
    0xc0, 0xa9, 0xec, 0xd7, 
};
static const unsigned char big5_chars_ban765 [] = {
    0xc4, 0x5e, 
};
static const unsigned char big5_chars_ban766 [] = {
    0xc5, 0x70, 
};
static const unsigned char big5_chars_ban767 [] = {
    0xc9, 0x72, 
};
static const unsigned char big5_chars_ban768 [] = {
    0xa5, 0xa6, 0xc9, 0x73, 0xa6, 0x76, 
};
static const unsigned char big5_chars_ban769 [] = {
    0xa6, 0x74, 0xa6, 0x75, 0xa6, 0x77, 
};
static const unsigned char big5_chars_ban770 [] = {
    0xa7, 0xba, 0xa7, 0xb9, 
};
static const unsigned char big5_chars_ban771 [] = {
    0xca, 0xbc, 0xa7, 0xbb, 
};
static const unsigned char big5_chars_ban772 [] = {
    0xca, 0xbd, 0xcc, 0x57, 
};
static const unsigned char big5_chars_ban773 [] = {
    0xcc, 0x58, 
};
static const unsigned char big5_chars_ban774 [] = {
    0xa9, 0x76, 0xa9, 0x78, 0xa9, 0x7a, 0xa9, 0x77, 0xa9, 0x7b, 
    0xa9, 0x79, 
};
static const unsigned char big5_chars_ban775 [] = {
    0xab, 0xc8, 0xab, 0xc5, 0xab, 0xc7, 0xab, 0xc9, 0xab, 0xc6, 
    0xd1, 0x66, 0xce, 0x77, 
};
static const unsigned char big5_chars_ban776 [] = {
    0xd1, 0x68, 0xd1, 0x67, 0xae, 0x63, 
};
static const unsigned char big5_chars_ban777 [] = {
    0xae, 0x5f, 
};
static const unsigned char big5_chars_ban778 [] = {
    0xae, 0x60, 0xae, 0x62, 0xae, 0x64, 0xae, 0x61, 
};
static const unsigned char big5_chars_ban779 [] = {
    0xae, 0x66, 0xae, 0x65, 
};
static const unsigned char big5_chars_ban780 [] = {
    0xb1, 0x4a, 0xd4, 0xf2, 0xd4, 0xf1, 0xb1, 0x49, 
};
static const unsigned char big5_chars_ban781 [] = {
    0xb1, 0x48, 0xb1, 0x47, 0xb1, 0x4b, 0xb1, 0x46, 
};
static const unsigned char big5_chars_ban782 [] = {
    0xd8, 0xd5, 0xd8, 0xd2, 0xb4, 0x49, 0xd8, 0xd1, 0xd8, 0xd6, 
};
static const unsigned char big5_chars_ban783 [] = {
    0xb4, 0x4b, 0xd8, 0xd4, 0xb4, 0x48, 0xb4, 0x4a, 0xd8, 0xd3, 
};
static const unsigned char big5_chars_ban784 [] = {
    0xdd, 0x48, 
};
static const unsigned char big5_chars_ban785 [] = {
    0xdd, 0x49, 0xdd, 0x4a, 
};
static const unsigned char big5_chars_ban786 [] = {
    0xb9, 0xe6, 0xb9, 0xee, 0xe1, 0x7e, 0xb9, 0xe8, 0xb9, 0xec, 
    0xe1, 0xa1, 0xb9, 0xed, 0xb9, 0xe9, 0xb9, 0xea, 0xb9, 0xe7, 
    0xb9, 0xeb, 0xbc, 0x66, 0xd8, 0xd0, 0xbc, 0x67, 0xbc, 0x65, 
};
static const unsigned char big5_chars_ban787 [] = {
    0xbc, 0x64, 0xe9, 0x5d, 0xbe, 0xc8, 0xec, 0xd8, 0xec, 0xd9, 
};
static const unsigned char big5_chars_ban788 [] = {
    0xc3, 0x64, 0xc4, 0x5f, 
};
static const unsigned char big5_chars_ban789 [] = {
    0xa4, 0x6f, 
};
static const unsigned char big5_chars_ban790 [] = {
    0xa6, 0x78, 
};
static const unsigned char big5_chars_ban791 [] = {
    0xab, 0xca, 
};
static const unsigned char big5_chars_ban792 [] = {
    0xd1, 0x69, 0xae, 0x67, 
};
static const unsigned char big5_chars_ban793 [] = {
    0xb1, 0x4e, 0xb1, 0x4d, 0xb1, 0x4c, 0xb4, 0x4c, 0xb4, 0x4d, 
    0xd8, 0xd7, 0xb9, 0xef, 0xbe, 0xc9, 0xa4, 0x70, 0xc9, 0x5c, 
    0xa4, 0xd6, 0xc9, 0x74, 
};
static const unsigned char big5_chars_ban794 [] = {
    0xc9, 0xd4, 0xa6, 0x79, 
};
static const unsigned char big5_chars_ban795 [] = {
    0xa9, 0x7c, 
};
static const unsigned char big5_chars_ban796 [] = {
    0xdd, 0x4b, 
};
static const unsigned char big5_chars_ban797 [] = {
    0xa4, 0x71, 
};
static const unsigned char big5_chars_ban798 [] = {
    0xa4, 0xd7, 0xc9, 0xd5, 
};
static const unsigned char big5_chars_ban799 [] = {
    0xca, 0xbe, 
};
static const unsigned char big5_chars_ban800 [] = {
    0xca, 0xbf, 
};
static const unsigned char big5_chars_ban801 [] = {
    0xa7, 0xbc, 
};
static const unsigned char big5_chars_ban802 [] = {
    0xd8, 0xd8, 0xb4, 0x4e, 
};
static const unsigned char big5_chars_ban803 [] = {
    0xdd, 0x4c, 
};
static const unsigned char big5_chars_ban804 [] = {
    0xc0, 0xaa, 0xa4, 0x72, 0xa4, 0xa8, 0xa4, 0xd8, 0xc9, 0x75, 
    0xa5, 0xa7, 
};
static const unsigned char big5_chars_ban805 [] = {
    0xa7, 0xc0, 0xa7, 0xbf, 0xa7, 0xbd, 0xa7, 0xbe, 
};
static const unsigned char big5_chars_ban806 [] = {
    0xcc, 0x59, 0xa9, 0x7e, 0xa9, 0xa1, 0xcc, 0x5a, 0xa9, 0x7d, 
};
static const unsigned char big5_chars_ban807 [] = {
    0xab, 0xce, 0xce, 0x78, 0xab, 0xcd, 0xab, 0xcb, 0xab, 0xcc, 
    0xae, 0x6a, 0xae, 0x68, 
};
static const unsigned char big5_chars_ban808 [] = {
    0xd1, 0x6b, 0xae, 0x69, 0xd1, 0x6a, 
};
static const unsigned char big5_chars_ban809 [] = {
    0xae, 0x5e, 0xd4, 0xf3, 
};
static const unsigned char big5_chars_ban810 [] = {
    0xb1, 0x50, 0xb1, 0x51, 
};
static const unsigned char big5_chars_ban811 [] = {
    0xb1, 0x4f, 
};
static const unsigned char big5_chars_ban812 [] = {
    0xb9, 0xf0, 0xe1, 0xa2, 0xbc, 0x68, 0xbc, 0x69, 
};
static const unsigned char big5_chars_ban813 [] = {
    0xe5, 0x61, 0xc0, 0xab, 0xef, 0xc2, 0xef, 0xc3, 
};
static const unsigned char big5_chars_ban814 [] = {
    0xc4, 0xdd, 0xf8, 0xa8, 0xc9, 0x4b, 0xa4, 0xd9, 
};
static const unsigned char big5_chars_ban815 [] = {
    0xa4, 0x73, 
};
static const unsigned char big5_chars_ban816 [] = {
    0xc9, 0x77, 0xc9, 0x76, 
};
static const unsigned char big5_chars_ban817 [] = {
    0xa6, 0x7a, 0xc9, 0xd7, 0xc9, 0xd8, 0xc9, 0xd6, 
};
static const unsigned char big5_chars_ban818 [] = {
    0xc9, 0xd9, 
};
static const unsigned char big5_chars_ban819 [] = {
    0xca, 0xc7, 
};
static const unsigned char big5_chars_ban820 [] = {
    0xca, 0xc2, 0xca, 0xc4, 0xca, 0xc6, 0xca, 0xc3, 0xa7, 0xc4, 
    0xca, 0xc0, 
};
static const unsigned char big5_chars_ban821 [] = {
    0xca, 0xc1, 0xa7, 0xc1, 0xa7, 0xc2, 0xca, 0xc5, 0xca, 0xc8, 
    0xa7, 0xc3, 0xca, 0xc9, 
};
static const unsigned char big5_chars_ban822 [] = {
    0xcc, 0x68, 
};
static const unsigned char big5_chars_ban823 [] = {
    0xcc, 0x62, 0xcc, 0x5d, 0xa9, 0xa3, 0xcc, 0x65, 0xcc, 0x63, 
    0xcc, 0x5c, 0xcc, 0x69, 0xcc, 0x6c, 0xcc, 0x67, 0xcc, 0x60, 
    0xa9, 0xa5, 0xcc, 0x66, 0xa9, 0xa6, 0xcc, 0x61, 0xcc, 0x64, 
    0xcc, 0x5b, 0xcc, 0x5f, 0xcc, 0x6b, 0xa9, 0xa7, 
};
static const unsigned char big5_chars_ban824 [] = {
    0xa9, 0xa8, 
};
static const unsigned char big5_chars_ban825 [] = {
    0xcc, 0x5e, 0xcc, 0x6a, 0xa9, 0xa2, 0xa9, 0xa4, 
};
static const unsigned char big5_chars_ban826 [] = {
    0xce, 0xab, 0xce, 0xa4, 0xce, 0xaa, 0xce, 0xa3, 0xce, 0xa5, 
    0xce, 0x7d, 0xce, 0x7b, 
};
static const unsigned char big5_chars_ban827 [] = {
    0xce, 0xac, 0xce, 0xa9, 0xce, 0x79, 
};
static const unsigned char big5_chars_ban828 [] = {
    0xab, 0xd0, 0xce, 0xa7, 0xce, 0xa8, 
};
static const unsigned char big5_chars_ban829 [] = {
    0xce, 0xa6, 0xce, 0x7c, 0xce, 0x7a, 0xab, 0xcf, 0xce, 0xa2, 
    0xce, 0x7e, 
};
static const unsigned char big5_chars_ban830 [] = {
    0xce, 0xa1, 0xce, 0xad, 
};
static const unsigned char big5_chars_ban831 [] = {
    0xae, 0x6f, 
};
static const unsigned char big5_chars_ban832 [] = {
    0xae, 0x6e, 
};
static const unsigned char big5_chars_ban833 [] = {
    0xd1, 0x6c, 0xae, 0x6b, 0xd1, 0x6e, 
};
static const unsigned char big5_chars_ban834 [] = {
    0xae, 0x70, 0xd1, 0x6f, 
};
static const unsigned char big5_chars_ban835 [] = {
    0xae, 0x73, 
};
static const unsigned char big5_chars_ban836 [] = {
    0xae, 0x71, 0xd1, 0x70, 0xce, 0xae, 0xd1, 0x72, 
};
static const unsigned char big5_chars_ban837 [] = {
    0xae, 0x6d, 
};
static const unsigned char big5_chars_ban838 [] = {
    0xae, 0x6c, 
};
static const unsigned char big5_chars_ban839 [] = {
    0xd1, 0x6d, 0xd1, 0x71, 0xae, 0x72, 
};
static const unsigned char big5_chars_ban840 [] = {
    0xb1, 0x53, 0xb1, 0x52, 
};
static const unsigned char big5_chars_ban841 [] = {
    0xd4, 0xf5, 0xd4, 0xf9, 0xd4, 0xfb, 0xb1, 0x54, 0xd4, 0xfe, 
};
static const unsigned char big5_chars_ban842 [] = {
    0xb1, 0x58, 0xd5, 0x41, 
};
static const unsigned char big5_chars_ban843 [] = {
    0xb1, 0x5a, 
};
static const unsigned char big5_chars_ban844 [] = {
    0xb1, 0x56, 0xb1, 0x5e, 
};
static const unsigned char big5_chars_ban845 [] = {
    0xb1, 0x5b, 0xd4, 0xf7, 0xb1, 0x55, 
};
static const unsigned char big5_chars_ban846 [] = {
    0xd4, 0xf6, 0xd4, 0xf4, 0xd5, 0x43, 0xd4, 0xf8, 
};
static const unsigned char big5_chars_ban847 [] = {
    0xb1, 0x57, 0xd5, 0x42, 0xb1, 0x5c, 0xd4, 0xfd, 0xd4, 0xfc, 
    0xb1, 0x5d, 0xd4, 0xfa, 0xb1, 0x59, 
};
static const unsigned char big5_chars_ban848 [] = {
    0xd5, 0x44, 
};
static const unsigned char big5_chars_ban849 [] = {
    0xd5, 0x40, 0xd8, 0xe7, 0xd8, 0xee, 0xd8, 0xe3, 0xb4, 0x51, 
    0xd8, 0xdf, 0xd8, 0xef, 0xd8, 0xd9, 0xd8, 0xec, 0xd8, 0xea, 
    0xd8, 0xe4, 
};
static const unsigned char big5_chars_ban850 [] = {
    0xd8, 0xed, 0xd8, 0xe6, 
};
static const unsigned char big5_chars_ban851 [] = {
    0xd8, 0xde, 0xd8, 0xf0, 0xd8, 0xdc, 0xd8, 0xe9, 0xd8, 0xda, 
};
static const unsigned char big5_chars_ban852 [] = {
    0xd8, 0xf1, 
};
static const unsigned char big5_chars_ban853 [] = {
    0xb4, 0x52, 
};
static const unsigned char big5_chars_ban854 [] = {
    0xd8, 0xeb, 0xdd, 0x4f, 0xd8, 0xdd, 0xb4, 0x4f, 
};
static const unsigned char big5_chars_ban855 [] = {
    0xd8, 0xe1, 
};
static const unsigned char big5_chars_ban856 [] = {
    0xb4, 0x50, 0xd8, 0xe0, 0xd8, 0xe5, 
};
static const unsigned char big5_chars_ban857 [] = {
    0xd8, 0xe2, 
};
static const unsigned char big5_chars_ban858 [] = {
    0xd8, 0xe8, 
};
static const unsigned char big5_chars_ban859 [] = {
    0xdd, 0x53, 
};
static const unsigned char big5_chars_ban860 [] = {
    0xdd, 0x56, 0xdd, 0x4e, 
};
static const unsigned char big5_chars_ban861 [] = {
    0xdd, 0x50, 
};
static const unsigned char big5_chars_ban862 [] = {
    0xdd, 0x55, 0xdd, 0x54, 0xb7, 0x43, 
};
static const unsigned char big5_chars_ban863 [] = {
    0xd8, 0xdb, 0xdd, 0x52, 
};
static const unsigned char big5_chars_ban864 [] = {
    0xb7, 0x44, 
};
static const unsigned char big5_chars_ban865 [] = {
    0xdd, 0x4d, 0xdd, 0x51, 
};
static const unsigned char big5_chars_ban866 [] = {
    0xe1, 0xa9, 
};
static const unsigned char big5_chars_ban867 [] = {
    0xe1, 0xb0, 0xe1, 0xa7, 
};
static const unsigned char big5_chars_ban868 [] = {
    0xe1, 0xae, 0xe1, 0xa5, 0xe1, 0xad, 0xe1, 0xb1, 0xe1, 0xa4, 
    0xe1, 0xa8, 0xe1, 0xa3, 
};
static const unsigned char big5_chars_ban869 [] = {
    0xb9, 0xf1, 
};
static const unsigned char big5_chars_ban870 [] = {
    0xe1, 0xa6, 0xb9, 0xf2, 0xe1, 0xac, 0xe1, 0xab, 0xe1, 0xaa, 
};
static const unsigned char big5_chars_ban871 [] = {
    0xe1, 0xaf, 
};
static const unsigned char big5_chars_ban872 [] = {
    0xe5, 0x65, 0xe5, 0x67, 0xbc, 0x6b, 0xe5, 0x68, 
};
static const unsigned char big5_chars_ban873 [] = {
    0xe5, 0x63, 
};
static const unsigned char big5_chars_ban874 [] = {
    0xe5, 0x62, 0xe5, 0x6c, 
};
static const unsigned char big5_chars_ban875 [] = {
    0xe5, 0x6a, 0xbc, 0x6a, 0xe5, 0x6d, 0xe5, 0x64, 0xe5, 0x69, 
    0xe5, 0x6b, 0xe5, 0x66, 
};
static const unsigned char big5_chars_ban876 [] = {
    0xe9, 0x61, 0xe9, 0x66, 0xe9, 0x60, 0xe9, 0x65, 
};
static const unsigned char big5_chars_ban877 [] = {
    0xe9, 0x5e, 0xe9, 0x68, 0xe9, 0x64, 0xe9, 0x69, 0xe9, 0x63, 
    0xe9, 0x5f, 0xe9, 0x67, 
};
static const unsigned char big5_chars_ban878 [] = {
    0xe9, 0x6a, 0xe9, 0x62, 
};
static const unsigned char big5_chars_ban879 [] = {
    0xec, 0xda, 0xc0, 0xaf, 
};
static const unsigned char big5_chars_ban880 [] = {
    0xc0, 0xad, 
};
static const unsigned char big5_chars_ban881 [] = {
    0xc0, 0xac, 0xc0, 0xae, 
};
static const unsigned char big5_chars_ban882 [] = {
    0xef, 0xc4, 
};
static const unsigned char big5_chars_ban883 [] = {
    0xf1, 0x72, 0xf1, 0xfd, 
};
static const unsigned char big5_chars_ban884 [] = {
    0xf4, 0x44, 0xf4, 0x45, 
};
static const unsigned char big5_chars_ban885 [] = {
    0xc4, 0x60, 
};
static const unsigned char big5_chars_ban886 [] = {
    0xf5, 0xc9, 
};
static const unsigned char big5_chars_ban887 [] = {
    0xc4, 0xde, 
};
static const unsigned char big5_chars_ban888 [] = {
    0xf5, 0xca, 
};
static const unsigned char big5_chars_ban889 [] = {
    0xf6, 0xde, 0xc5, 0x72, 
};
static const unsigned char big5_chars_ban890 [] = {
    0xc5, 0x71, 0xf6, 0xdd, 0xc5, 0xc9, 
};
static const unsigned char big5_chars_ban891 [] = {
    0xf7, 0xd6, 
};
static const unsigned char big5_chars_ban892 [] = {
    0xa4, 0x74, 0xa6, 0x7b, 0xc9, 0xda, 0xca, 0xca, 0xa8, 0xb5, 
    0xb1, 0x5f, 
};
static const unsigned char big5_chars_ban893 [] = {
    0xa4, 0x75, 0xa5, 0xaa, 0xa5, 0xa9, 0xa5, 0xa8, 
};
static const unsigned char big5_chars_ban894 [] = {
    0xa7, 0xc5, 
};
static const unsigned char big5_chars_ban895 [] = {
    0xae, 0x74, 
};
static const unsigned char big5_chars_ban896 [] = {
    0xdd, 0x57, 0xa4, 0x76, 0xa4, 0x77, 0xa4, 0x78, 0xa4, 0xda, 
};
static const unsigned char big5_chars_ban897 [] = {
    0xab, 0xd1, 
};
static const unsigned char big5_chars_ban898 [] = {
    0xce, 0xaf, 
};
static const unsigned char big5_chars_ban899 [] = {
    0xb4, 0x53, 0xa4, 0x79, 0xc9, 0x5d, 
};
static const unsigned char big5_chars_ban900 [] = {
    0xa5, 0xab, 0xa5, 0xac, 0xc9, 0x78, 
};
static const unsigned char big5_chars_ban901 [] = {
    0xa6, 0x7c, 
};
static const unsigned char big5_chars_ban902 [] = {
    0xca, 0xcb, 
};
static const unsigned char big5_chars_ban903 [] = {
    0xa7, 0xc6, 
};
static const unsigned char big5_chars_ban904 [] = {
    0xca, 0xcc, 
};
static const unsigned char big5_chars_ban905 [] = {
    0xa9, 0xae, 
};
static const unsigned char big5_chars_ban906 [] = {
    0xcc, 0x6e, 0xa9, 0xac, 0xa9, 0xab, 0xcc, 0x6d, 0xa9, 0xa9, 
    0xcc, 0x6f, 0xa9, 0xaa, 0xa9, 0xad, 
};
static const unsigned char big5_chars_ban907 [] = {
    0xab, 0xd2, 
};
static const unsigned char big5_chars_ban908 [] = {
    0xab, 0xd4, 0xce, 0xb3, 0xce, 0xb0, 0xce, 0xb1, 0xce, 0xb2, 
    0xce, 0xb4, 0xab, 0xd3, 
};
static const unsigned char big5_chars_ban909 [] = {
    0xd1, 0x74, 0xd1, 0x73, 
};
static const unsigned char big5_chars_ban910 [] = {
    0xae, 0x76, 
};
static const unsigned char big5_chars_ban911 [] = {
    0xae, 0x75, 
};
static const unsigned char big5_chars_ban912 [] = {
    0xb1, 0x62, 0xd5, 0x46, 
};
static const unsigned char big5_chars_ban913 [] = {
    0xb1, 0x61, 0xb1, 0x63, 0xb1, 0x60, 
};
static const unsigned char big5_chars_ban914 [] = {
    0xb4, 0x55, 0xd5, 0x45, 
};
static const unsigned char big5_chars_ban915 [] = {
    0xb4, 0x56, 0xd8, 0xf3, 
};
static const unsigned char big5_chars_ban916 [] = {
    0xb4, 0x57, 0xd8, 0xf2, 0xb4, 0x54, 
};
static const unsigned char big5_chars_ban917 [] = {
    0xdd, 0x5a, 0xdd, 0x5c, 0xb7, 0x45, 0xdd, 0x5b, 0xdd, 0x59, 
    0xdd, 0x58, 
};
static const unsigned char big5_chars_ban918 [] = {
    0xe1, 0xb4, 0xb9, 0xf7, 0xb9, 0xf5, 
};
static const unsigned char big5_chars_ban919 [] = {
    0xb9, 0xf6, 0xe1, 0xb2, 0xe1, 0xb3, 
};
static const unsigned char big5_chars_ban920 [] = {
    0xb9, 0xf3, 0xe5, 0x71, 0xe5, 0x6f, 
};
static const unsigned char big5_chars_ban921 [] = {
    0xbc, 0x6d, 0xe5, 0x70, 0xbc, 0x6e, 0xbc, 0x6c, 0xb9, 0xf4, 
};
static const unsigned char big5_chars_ban922 [] = {
    0xe9, 0x6d, 0xe9, 0x6b, 0xe9, 0x6c, 0xe5, 0x6e, 0xec, 0xdc, 
    0xc0, 0xb0, 0xec, 0xdb, 0xef, 0xc5, 0xef, 0xc6, 0xe9, 0x6e, 
    0xf1, 0xfe, 
};
static const unsigned char big5_chars_ban923 [] = {
    0xa4, 0x7a, 0xa5, 0xad, 0xa6, 0x7e, 0xc9, 0xdb, 0xa6, 0x7d, 
};
static const unsigned char big5_chars_ban924 [] = {
    0xa9, 0xaf, 0xb7, 0x46, 
};
static const unsigned char big5_chars_ban925 [] = {
    0xa4, 0xdb, 0xa5, 0xae, 0xab, 0xd5, 0xb4, 0x58, 
};
static const unsigned char big5_chars_ban926 [] = {
    0xc9, 0x79, 
};
static const unsigned char big5_chars_ban927 [] = {
    0xc9, 0x7a, 
};
static const unsigned char big5_chars_ban928 [] = {
    0xc9, 0xdc, 
};
static const unsigned char big5_chars_ban929 [] = {
    0xa7, 0xc8, 0xca, 0xd0, 0xca, 0xce, 0xa7, 0xc9, 0xca, 0xcd, 
    0xca, 0xcf, 0xca, 0xd1, 
};
static const unsigned char big5_chars_ban930 [] = {
    0xa7, 0xc7, 
};
static const unsigned char big5_chars_ban931 [] = {
    0xa9, 0xb3, 0xa9, 0xb4, 0xa9, 0xb1, 
};
static const unsigned char big5_chars_ban932 [] = {
    0xa9, 0xb0, 0xce, 0xb8, 0xa9, 0xb2, 
};
static const unsigned char big5_chars_ban933 [] = {
    0xab, 0xd6, 
};
static const unsigned char big5_chars_ban934 [] = {
    0xce, 0xb7, 0xce, 0xb9, 0xce, 0xb6, 0xce, 0xba, 0xab, 0xd7, 
    0xae, 0x79, 0xd1, 0x75, 
};
static const unsigned char big5_chars_ban935 [] = {
    0xd1, 0x77, 0xae, 0x77, 0xd1, 0x78, 0xae, 0x78, 0xd1, 0x76, 
};
static const unsigned char big5_chars_ban936 [] = {
    0xce, 0xb5, 0xd5, 0x47, 0xd5, 0x4a, 0xd5, 0x4b, 0xd5, 0x48, 
    0xb1, 0x67, 0xb1, 0x66, 0xb1, 0x64, 0xb1, 0x65, 0xd5, 0x49, 
};
static const unsigned char big5_chars_ban937 [] = {
    0xb1, 0x68, 
};
static const unsigned char big5_chars_ban938 [] = {
    0xb4, 0x5a, 0xb4, 0x5b, 
};
static const unsigned char big5_chars_ban939 [] = {
    0xb4, 0x5c, 0xdd, 0x5d, 0xdd, 0x5f, 0xdd, 0x61, 0xb7, 0x48, 
    0xb7, 0x47, 0xb4, 0x59, 0xdd, 0x60, 0xdd, 0x5e, 
};
static const unsigned char big5_chars_ban940 [] = {
    0xe1, 0xb8, 
};
static const unsigned char big5_chars_ban941 [] = {
    0xe1, 0xb6, 0xe1, 0xbc, 0xb9, 0xf8, 0xe1, 0xbd, 0xe1, 0xba, 
    0xb9, 0xf9, 0xe1, 0xb7, 0xe1, 0xb5, 0xe1, 0xbb, 0xbc, 0x70, 
    0xe5, 0x73, 0xe1, 0xb9, 0xbc, 0x72, 0xe5, 0x74, 0xbc, 0x71, 
    0xbc, 0x74, 0xe5, 0x75, 0xbc, 0x6f, 0xbc, 0x73, 
};
static const unsigned char big5_chars_ban942 [] = {
    0xe9, 0x73, 0xe9, 0x71, 0xe9, 0x70, 0xe9, 0x72, 0xe9, 0x6f, 
};
static const unsigned char big5_chars_ban943 [] = {
    0xc3, 0x66, 
};
static const unsigned char big5_chars_ban944 [] = {
    0xf4, 0x46, 0xf4, 0x47, 
};
static const unsigned char big5_chars_ban945 [] = {
    0xf5, 0xcb, 0xf6, 0xdf, 0xc6, 0x55, 
};
static const unsigned char big5_chars_ban946 [] = {
    0xa9, 0xb5, 0xa7, 0xca, 
};
static const unsigned char big5_chars_ban947 [] = {
    0xab, 0xd8, 
};
static const unsigned char big5_chars_ban948 [] = {
    0xa4, 0x7b, 0xa4, 0xdc, 
};
static const unsigned char big5_chars_ban949 [] = {
    0xa5, 0xaf, 0xc9, 0xdd, 
};
static const unsigned char big5_chars_ban950 [] = {
    0xa7, 0xcb, 0xca, 0xd2, 
};
static const unsigned char big5_chars_ban951 [] = {
    0xce, 0xbb, 0xab, 0xd9, 
};
static const unsigned char big5_chars_ban952 [] = {
    0xb9, 0xfa, 0xa4, 0x7c, 
};
static const unsigned char big5_chars_ban953 [] = {
    0xa6, 0xa1, 
};
static const unsigned char big5_chars_ban954 [] = {
    0xb7, 0x49, 0xa4, 0x7d, 0xa4, 0xdd, 0xa4, 0xde, 
};
static const unsigned char big5_chars_ban955 [] = {
    0xa5, 0xb1, 0xa5, 0xb0, 
};
static const unsigned char big5_chars_ban956 [] = {
    0xc9, 0xde, 0xa6, 0xa2, 
};
static const unsigned char big5_chars_ban957 [] = {
    0xca, 0xd3, 
};
static const unsigned char big5_chars_ban958 [] = {
    0xa7, 0xcc, 
};
static const unsigned char big5_chars_ban959 [] = {
    0xcc, 0x71, 0xcc, 0x72, 0xcc, 0x73, 
};
static const unsigned char big5_chars_ban960 [] = {
    0xa9, 0xb6, 0xa9, 0xb7, 0xcc, 0x70, 0xa9, 0xb8, 
};
static const unsigned char big5_chars_ban961 [] = {
    0xab, 0xda, 0xce, 0xbc, 
};
static const unsigned char big5_chars_ban962 [] = {
    0xd1, 0x7a, 0xae, 0x7a, 
};
static const unsigned char big5_chars_ban963 [] = {
    0xd1, 0x79, 
};
static const unsigned char big5_chars_ban964 [] = {
    0xb1, 0x69, 0xd5, 0x4c, 0xb1, 0x6a, 0xd5, 0x4d, 
};
static const unsigned char big5_chars_ban965 [] = {
    0xb4, 0x5d, 
};
static const unsigned char big5_chars_ban966 [] = {
    0xdd, 0x62, 
};
static const unsigned char big5_chars_ban967 [] = {
    0xe1, 0xbf, 0xe1, 0xbe, 
};
static const unsigned char big5_chars_ban968 [] = {
    0xb9, 0xfb, 
};
static const unsigned char big5_chars_ban969 [] = {
    0xbc, 0x75, 0xe5, 0x76, 0xbe, 0xca, 0xe9, 0x74, 0xc0, 0xb1, 
};
static const unsigned char big5_chars_ban970 [] = {
    0xc5, 0x73, 0xf7, 0xd8, 
};
static const unsigned char big5_chars_ban971 [] = {
    0xcc, 0x74, 
};
static const unsigned char big5_chars_ban972 [] = {
    0xce, 0xbd, 0xb1, 0x6b, 0xd8, 0xf4, 0xb7, 0x4a, 
};
static const unsigned char big5_chars_ban973 [] = {
    0xc2, 0x55, 
};
static const unsigned char big5_chars_ban974 [] = {
    0xa7, 0xce, 
};
static const unsigned char big5_chars_ban975 [] = {
    0xa7, 0xcd, 0xab, 0xdb, 
};
static const unsigned char big5_chars_ban976 [] = {
    0xd1, 0x7b, 
};
static const unsigned char big5_chars_ban977 [] = {
    0xb1, 0x6d, 0xb3, 0x43, 0xb1, 0x6e, 0xb1, 0x6c, 0xb4, 0x5e, 
};
static const unsigned char big5_chars_ban978 [] = {
    0xe1, 0xc0, 0xb9, 0xfc, 0xbc, 0x76, 
};
static const unsigned char big5_chars_ban979 [] = {
    0xc9, 0x4c, 0xc9, 0xdf, 
};
static const unsigned char big5_chars_ban980 [] = {
    0xca, 0xd5, 0xa7, 0xcf, 0xca, 0xd4, 0xa7, 0xd0, 
};
static const unsigned char big5_chars_ban981 [] = {
    0xa9, 0xbc, 0xcc, 0x77, 0xcc, 0x76, 0xa9, 0xbb, 0xa9, 0xb9, 
    0xa9, 0xba, 0xcc, 0x75, 
};
static const unsigned char big5_chars_ban982 [] = {
    0xab, 0xdd, 0xce, 0xbe, 0xab, 0xe0, 0xab, 0xdc, 0xab, 0xe2, 
    0xab, 0xde, 0xab, 0xdf, 0xab, 0xe1, 
};
static const unsigned char big5_chars_ban983 [] = {
    0xae, 0x7d, 0xae, 0x7c, 0xae, 0x7b, 
};
static const unsigned char big5_chars_ban984 [] = {
    0xd5, 0x4f, 0xb1, 0x6f, 0xb1, 0x72, 0xb1, 0x70, 
};
static const unsigned char big5_chars_ban985 [] = {
    0xd5, 0x4e, 0xb1, 0x75, 
};
static const unsigned char big5_chars_ban986 [] = {
    0xb1, 0x71, 0xd5, 0x50, 0xb1, 0x74, 0xb1, 0x73, 
};
static const unsigned char big5_chars_ban987 [] = {
    0xd8, 0xf6, 0xd8, 0xf5, 
};
static const unsigned char big5_chars_ban988 [] = {
    0xb4, 0x61, 0xb4, 0x5f, 0xb4, 0x60, 0xd8, 0xf7, 0xb7, 0x4b, 
    0xdd, 0x64, 0xb7, 0x4c, 0xdd, 0x63, 
};
static const unsigned char big5_chars_ban989 [] = {
    0xe5, 0x77, 
};
static const unsigned char big5_chars_ban990 [] = {
    0xbc, 0x78, 0xe1, 0xc1, 0xbc, 0x77, 
};
static const unsigned char big5_chars_ban991 [] = {
    0xb9, 0xfd, 
};
static const unsigned char big5_chars_ban992 [] = {
    0xec, 0xde, 0xe9, 0x75, 0xc0, 0xb2, 0xec, 0xdd, 0xf2, 0x40, 
    0xf4, 0x48, 0xf4, 0x49, 
};
static const unsigned char big5_chars_ban993 [] = {
    0xa4, 0xdf, 
};
static const unsigned char big5_chars_ban994 [] = {
    0xa5, 0xb2, 
};
static const unsigned char big5_chars_ban995 [] = {
    0xc9, 0x7b, 
};
static const unsigned char big5_chars_ban996 [] = {
    0xa7, 0xd2, 0xa7, 0xd4, 
};
static const unsigned char big5_chars_ban997 [] = {
    0xc9, 0xe2, 0xca, 0xd8, 0xca, 0xd7, 0xca, 0xd6, 
};
static const unsigned char big5_chars_ban998 [] = {
    0xc9, 0xe1, 0xc9, 0xe0, 0xa6, 0xa4, 0xa7, 0xd3, 0xa7, 0xd1, 
    0xa6, 0xa3, 
};
static const unsigned char big5_chars_ban999 [] = {
    0xa9, 0xbd, 0xcc, 0x78, 
};
static const unsigned char big5_chars_ban1000 [] = {
    0xa9, 0xbe, 0xca, 0xdd, 
};
static const unsigned char big5_chars_ban1001 [] = {
    0xca, 0xdf, 0xca, 0xde, 0xcc, 0x79, 
};
static const unsigned char big5_chars_ban1002 [] = {
    0xca, 0xda, 
};
static const unsigned char big5_chars_ban1003 [] = {
    0xa7, 0xd8, 0xa7, 0xd6, 
};
static const unsigned char big5_chars_ban1004 [] = {
    0xca, 0xd9, 0xca, 0xdb, 0xca, 0xe1, 
};
static const unsigned char big5_chars_ban1005 [] = {
    0xa7, 0xd5, 
};
static const unsigned char big5_chars_ban1006 [] = {
    0xca, 0xdc, 0xca, 0xe5, 0xa9, 0xc0, 
};
static const unsigned char big5_chars_ban1007 [] = {
    0xca, 0xe2, 0xa7, 0xd7, 
};
static const unsigned char big5_chars_ban1008 [] = {
    0xca, 0xe0, 0xca, 0xe3, 
};
static const unsigned char big5_chars_ban1009 [] = {
    0xa9, 0xbf, 
};
static const unsigned char big5_chars_ban1010 [] = {
    0xa9, 0xc1, 0xca, 0xe4, 
};
static const unsigned char big5_chars_ban1011 [] = {
    0xcc, 0xaf, 0xcc, 0xa2, 0xcc, 0x7e, 0xcc, 0xae, 0xcc, 0xa9, 
    0xab, 0xe7, 0xa9, 0xc2, 0xcc, 0xaa, 0xcc, 0xad, 0xab, 0xe3, 
    0xcc, 0xac, 0xa9, 0xc3, 0xa9, 0xc8, 0xa9, 0xc6, 0xcc, 0xa3, 
};
static const unsigned char big5_chars_ban1012 [] = {
    0xcc, 0x7c, 0xcc, 0xa5, 0xa9, 0xcd, 0xcc, 0xb0, 0xab, 0xe4, 
    0xcc, 0xa6, 
};
static const unsigned char big5_chars_ban1013 [] = {
    0xab, 0xe5, 0xa9, 0xc9, 0xcc, 0xa8, 
};
static const unsigned char big5_chars_ban1014 [] = {
    0xce, 0xcd, 0xab, 0xe6, 0xcc, 0x7b, 0xa9, 0xca, 0xab, 0xe8, 
    0xa9, 0xcb, 0xa9, 0xc7, 0xa9, 0xcc, 0xcc, 0xa7, 0xcc, 0x7a, 
    0xcc, 0xab, 0xa9, 0xc4, 
};
static const unsigned char big5_chars_ban1015 [] = {
    0xcc, 0x7d, 0xcc, 0xa4, 0xcc, 0xa1, 0xa9, 0xc5, 
};
static const unsigned char big5_chars_ban1016 [] = {
    0xce, 0xbf, 
};
static const unsigned char big5_chars_ban1017 [] = {
    0xce, 0xc0, 
};
static const unsigned char big5_chars_ban1018 [] = {
    0xce, 0xca, 0xd1, 0xa1, 0xce, 0xcb, 0xab, 0xee, 0xce, 0xce, 
    0xce, 0xc4, 0xab, 0xed, 0xce, 0xc6, 
};
static const unsigned char big5_chars_ban1019 [] = {
    0xce, 0xc7, 
};
static const unsigned char big5_chars_ban1020 [] = {
    0xce, 0xc9, 0xab, 0xe9, 
};
static const unsigned char big5_chars_ban1021 [] = {
    0xae, 0xa3, 
};
static const unsigned char big5_chars_ban1022 [] = {
    0xf9, 0xda, 0xce, 0xc5, 0xce, 0xc1, 0xae, 0xa4, 
};
static const unsigned char big5_chars_ban1023 [] = {
    0xce, 0xcf, 0xae, 0x7e, 0xd1, 0x7d, 0xce, 0xc8, 
};
static const unsigned char big5_chars_ban1024 [] = {
    0xd1, 0x7c, 0xce, 0xc3, 0xce, 0xcc, 
};
static const unsigned char big5_chars_ban1025 [] = {
    0xab, 0xec, 0xae, 0xa1, 0xab, 0xf2, 0xae, 0xa2, 0xce, 0xd0, 
    0xd1, 0x7e, 0xab, 0xeb, 0xae, 0xa6, 0xab, 0xf1, 0xab, 0xf0, 
    0xab, 0xef, 0xae, 0xa5, 0xce, 0xd1, 0xae, 0xa7, 0xab, 0xea, 
};
static const unsigned char big5_chars_ban1026 [] = {
    0xce, 0xc2, 
};
static const unsigned char big5_chars_ban1027 [] = {
    0xb1, 0x76, 0xd1, 0xa4, 0xd1, 0xa6, 
};
static const unsigned char big5_chars_ban1028 [] = {
    0xd1, 0xa8, 0xae, 0xa8, 0xae, 0xae, 0xd5, 0x53, 0xd1, 0xac, 
    0xd1, 0xa3, 0xb1, 0x78, 0xd5, 0x51, 
};
static const unsigned char big5_chars_ban1029 [] = {
    0xae, 0xad, 0xae, 0xab, 0xd1, 0xae, 
};
static const unsigned char big5_chars_ban1030 [] = {
    0xd5, 0x52, 
};
static const unsigned char big5_chars_ban1031 [] = {
    0xd1, 0xa5, 
};
static const unsigned char big5_chars_ban1032 [] = {
    0xae, 0xac, 0xd1, 0xa9, 0xae, 0xaf, 0xd1, 0xab, 
};
static const unsigned char big5_chars_ban1033 [] = {
    0xae, 0xaa, 0xd1, 0xaa, 0xd1, 0xad, 0xd1, 0xa7, 
};
static const unsigned char big5_chars_ban1034 [] = {
    0xae, 0xa9, 0xb1, 0x79, 
};
static const unsigned char big5_chars_ban1035 [] = {
    0xd1, 0xa2, 0xb1, 0x77, 
};
static const unsigned char big5_chars_ban1036 [] = {
    0xb1, 0x7a, 
};
static const unsigned char big5_chars_ban1037 [] = {
    0xd5, 0x55, 0xd5, 0x5e, 0xb4, 0x64, 
};
static const unsigned char big5_chars_ban1038 [] = {
    0xb1, 0x7c, 0xb1, 0xa3, 0xb4, 0x65, 0xd5, 0x60, 0xb1, 0xaa, 
    0xd8, 0xf9, 0xd5, 0x56, 0xb1, 0xa2, 0xb1, 0xa5, 0xb1, 0x7e, 
    0xd5, 0x54, 0xd5, 0x62, 0xd5, 0x65, 0xd9, 0x49, 
};
static const unsigned char big5_chars_ban1039 [] = {
    0xd5, 0x63, 0xd8, 0xfd, 0xb1, 0xa1, 0xb1, 0xa8, 0xb1, 0xac, 
    0xd5, 0x5d, 0xd8, 0xf8, 0xd5, 0x61, 0xb1, 0x7b, 0xd8, 0xfa, 
    0xd5, 0x64, 0xd8, 0xfc, 0xd5, 0x59, 
};
static const unsigned char big5_chars_ban1040 [] = {
    0xb4, 0x62, 
};
static const unsigned char big5_chars_ban1041 [] = {
    0xd5, 0x57, 0xd5, 0x58, 0xb1, 0xa7, 
};
static const unsigned char big5_chars_ban1042 [] = {
    0xb1, 0xa6, 0xd5, 0x5b, 0xb1, 0xab, 0xd5, 0x5f, 0xb1, 0xa4, 
    0xd5, 0x5c, 
};
static const unsigned char big5_chars_ban1043 [] = {
    0xb1, 0xa9, 0xb4, 0x66, 0xb4, 0x63, 0xd8, 0xfb, 
};
static const unsigned char big5_chars_ban1044 [] = {
    0xd5, 0x5a, 
};
static const unsigned char big5_chars_ban1045 [] = {
    0xb1, 0x7d, 
};
static const unsigned char big5_chars_ban1046 [] = {
    0xb4, 0x6b, 0xb4, 0x6f, 0xd9, 0x40, 0xb7, 0x51, 0xb4, 0x6d, 
    0xd9, 0x44, 0xb4, 0x71, 0xdd, 0x65, 0xd9, 0x46, 0xb7, 0x53, 
    0xb4, 0x69, 0xb4, 0x6c, 0xd9, 0x47, 
};
static const unsigned char big5_chars_ban1047 [] = {
    0xd9, 0x48, 0xd9, 0x4e, 0xb4, 0x73, 0xb7, 0x54, 
};
static const unsigned char big5_chars_ban1048 [] = {
    0xd9, 0x4a, 0xd9, 0x4f, 0xd9, 0x43, 0xb7, 0x5e, 
};
static const unsigned char big5_chars_ban1049 [] = {
    0xb7, 0x55, 0xb4, 0x72, 0xd9, 0x41, 0xd9, 0x50, 
};
static const unsigned char big5_chars_ban1050 [] = {
    0xb7, 0x5d, 0xb4, 0x70, 0xb7, 0x4e, 0xd9, 0x4d, 
};
static const unsigned char big5_chars_ban1051 [] = {
    0xb4, 0x74, 0xd9, 0x45, 0xd8, 0xfe, 0xb4, 0x6a, 0xd9, 0x42, 
};
static const unsigned char big5_chars_ban1052 [] = {
    0xd9, 0x4b, 
};
static const unsigned char big5_chars_ban1053 [] = {
    0xb7, 0x4d, 0xb7, 0x52, 0xb4, 0x67, 0xd9, 0x4c, 
};
static const unsigned char big5_chars_ban1054 [] = {
    0xb7, 0x50, 
};
static const unsigned char big5_chars_ban1055 [] = {
    0xb4, 0x68, 
};
static const unsigned char big5_chars_ban1056 [] = {
    0xb7, 0x5c, 0xe1, 0xc3, 0xdd, 0x70, 
};
static const unsigned char big5_chars_ban1057 [] = {
    0xdd, 0x68, 0xe1, 0xc2, 
};
static const unsigned char big5_chars_ban1058 [] = {
    0xdd, 0x6c, 0xdd, 0x6e, 
};
static const unsigned char big5_chars_ban1059 [] = {
    0xdd, 0x6b, 
};
static const unsigned char big5_chars_ban1060 [] = {
    0xb7, 0x5b, 
};
static const unsigned char big5_chars_ban1061 [] = {
    0xdd, 0x6a, 0xb7, 0x5f, 
};
static const unsigned char big5_chars_ban1062 [] = {
    0xe1, 0xd2, 
};
static const unsigned char big5_chars_ban1063 [] = {
    0xb7, 0x5a, 0xba, 0x40, 0xdd, 0x71, 0xe1, 0xc4, 
};
static const unsigned char big5_chars_ban1064 [] = {
    0xb7, 0x58, 0xdd, 0x69, 0xdd, 0x6d, 0xb9, 0xfe, 0xb7, 0x4f, 
    0xdd, 0x66, 0xdd, 0x67, 0xba, 0x41, 0xb7, 0x57, 0xb7, 0x59, 
    0xb7, 0x56, 0xdd, 0x6f, 
};
static const unsigned char big5_chars_ban1065 [] = {
    0xe1, 0xc8, 0xe1, 0xc9, 0xe1, 0xce, 0xbc, 0x7d, 0xe1, 0xd5, 
};
static const unsigned char big5_chars_ban1066 [] = {
    0xba, 0x47, 
};
static const unsigned char big5_chars_ban1067 [] = {
    0xba, 0x46, 0xe1, 0xd0, 
};
static const unsigned char big5_chars_ban1068 [] = {
    0xbc, 0x7c, 0xe1, 0xc5, 0xba, 0x45, 
};
static const unsigned char big5_chars_ban1069 [] = {
    0xe1, 0xd4, 0xba, 0x43, 0xba, 0x44, 
};
static const unsigned char big5_chars_ban1070 [] = {
    0xe1, 0xd1, 0xe5, 0xaa, 0xbc, 0x7a, 0xb4, 0x6e, 
};
static const unsigned char big5_chars_ban1071 [] = {
    0xe1, 0xd3, 0xbc, 0xa3, 0xe1, 0xcb, 
};
static const unsigned char big5_chars_ban1072 [] = {
    0xbc, 0x7b, 
};
static const unsigned char big5_chars_ban1073 [] = {
    0xbc, 0xa2, 0xe1, 0xc6, 0xe1, 0xca, 0xe1, 0xc7, 0xe1, 0xcd, 
    0xba, 0x48, 0xbc, 0x79, 0xba, 0x42, 
};
static const unsigned char big5_chars_ban1074 [] = {
    0xe5, 0x7a, 0xe1, 0xcf, 
};
static const unsigned char big5_chars_ban1075 [] = {
    0xbc, 0xa1, 
};
static const unsigned char big5_chars_ban1076 [] = {
    0xbc, 0xa4, 
};
static const unsigned char big5_chars_ban1077 [] = {
    0xe1, 0xcc, 
};
static const unsigned char big5_chars_ban1078 [] = {
    0xbc, 0x7e, 0xe5, 0x79, 
};
static const unsigned char big5_chars_ban1079 [] = {
    0xe5, 0x7e, 0xbe, 0xce, 0xe5, 0x78, 0xe9, 0xa3, 0xe5, 0xa9, 
    0xbc, 0xa8, 
};
static const unsigned char big5_chars_ban1080 [] = {
    0xbc, 0xa6, 0xbe, 0xcc, 0xe5, 0xa6, 0xe5, 0xa2, 0xbc, 0xac, 
};
static const unsigned char big5_chars_ban1081 [] = {
    0xe9, 0x78, 
};
static const unsigned char big5_chars_ban1082 [] = {
    0xbc, 0xaa, 0xe5, 0xa1, 
};
static const unsigned char big5_chars_ban1083 [] = {
    0xe9, 0x76, 
};
static const unsigned char big5_chars_ban1084 [] = {
    0xe5, 0xa5, 
};
static const unsigned char big5_chars_ban1085 [] = {
    0xe5, 0xa8, 0xe5, 0x7d, 
};
static const unsigned char big5_chars_ban1086 [] = {
    0xbc, 0xab, 
};
static const unsigned char big5_chars_ban1087 [] = {
    0xbc, 0xa5, 0xe9, 0x77, 0xbe, 0xcd, 0xe5, 0xa7, 0xbc, 0xa7, 
    0xbc, 0xa9, 0xe5, 0xa4, 0xbc, 0xad, 0xe5, 0xa3, 0xe5, 0x7c, 
    0xe5, 0x7b, 0xbe, 0xcb, 0xe5, 0xab, 0xe9, 0x7a, 0xec, 0xe0, 
    0xbe, 0xd0, 
};
static const unsigned char big5_chars_ban1088 [] = {
    0xe9, 0xa2, 
};
static const unsigned char big5_chars_ban1089 [] = {
    0xe9, 0x7e, 
};
static const unsigned char big5_chars_ban1090 [] = {
    0xec, 0xe1, 
};
static const unsigned char big5_chars_ban1091 [] = {
    0xbe, 0xd1, 0xe9, 0xa1, 
};
static const unsigned char big5_chars_ban1092 [] = {
    0xe9, 0x7c, 0xc0, 0xb4, 0xec, 0xdf, 
};
static const unsigned char big5_chars_ban1093 [] = {
    0xe9, 0x79, 0xe9, 0x7b, 0xc0, 0xb5, 0xbe, 0xd3, 0xc0, 0xb3, 
    0xbe, 0xd2, 0xc0, 0xb7, 0xe9, 0x7d, 0xbe, 0xcf, 
};
static const unsigned char big5_chars_ban1094 [] = {
    0xef, 0xcf, 
};
static const unsigned char big5_chars_ban1095 [] = {
    0xef, 0xc7, 
};
static const unsigned char big5_chars_ban1096 [] = {
    0xec, 0xe7, 0xef, 0xc8, 0xec, 0xe3, 
};
static const unsigned char big5_chars_ban1097 [] = {
    0xc2, 0x56, 0xec, 0xe5, 0xec, 0xe4, 0xc0, 0xb6, 0xec, 0xe2, 
    0xec, 0xe6, 0xef, 0xd0, 0xef, 0xcc, 0xef, 0xce, 
};
static const unsigned char big5_chars_ban1098 [] = {
    0xef, 0xc9, 0xef, 0xca, 
};
static const unsigned char big5_chars_ban1099 [] = {
    0xef, 0xcd, 0xef, 0xcb, 0xc3, 0x67, 
};
static const unsigned char big5_chars_ban1100 [] = {
    0xc3, 0x6a, 0xc3, 0x69, 0xc3, 0x68, 0xc4, 0x61, 0xf4, 0x4a, 
    0xc4, 0x62, 0xf2, 0x41, 0xc4, 0xdf, 0xf5, 0xcc, 0xc4, 0xe0, 
    0xc5, 0x74, 0xc5, 0xca, 0xf7, 0xd9, 
};
static const unsigned char big5_chars_ban1101 [] = {
    0xf7, 0xda, 0xf7, 0xdb, 
};
static const unsigned char big5_chars_ban1102 [] = {
    0xf9, 0xba, 0xa4, 0xe0, 0xc9, 0x7c, 0xa5, 0xb3, 
};
static const unsigned char big5_chars_ban1103 [] = {
    0xa6, 0xa6, 0xa6, 0xa7, 0xa6, 0xa5, 
};
static const unsigned char big5_chars_ban1104 [] = {
    0xa6, 0xa8, 0xa7, 0xda, 0xa7, 0xd9, 
};
static const unsigned char big5_chars_ban1105 [] = {
    0xcc, 0xb1, 0xa9, 0xcf, 0xa9, 0xce, 
};
static const unsigned char big5_chars_ban1106 [] = {
    0xd1, 0xaf, 0xb1, 0xad, 0xb1, 0xae, 
};
static const unsigned char big5_chars_ban1107 [] = {
    0xb4, 0x75, 0xdd, 0x72, 0xb7, 0x60, 0xb7, 0x61, 0xdd, 0x74, 
    0xdd, 0x76, 0xdd, 0x75, 
};
static const unsigned char big5_chars_ban1108 [] = {
    0xe1, 0xd7, 
};
static const unsigned char big5_chars_ban1109 [] = {
    0xe1, 0xd6, 0xba, 0x49, 0xe1, 0xd8, 
};
static const unsigned char big5_chars_ban1110 [] = {
    0xe5, 0xac, 0xbc, 0xae, 
};
static const unsigned char big5_chars_ban1111 [] = {
    0xbe, 0xd4, 
};
static const unsigned char big5_chars_ban1112 [] = {
    0xc0, 0xb8, 0xc2, 0x57, 0xc0, 0xb9, 
};
static const unsigned char big5_chars_ban1113 [] = {
    0xa4, 0xe1, 
};
static const unsigned char big5_chars_ban1114 [] = {
    0xca, 0xe6, 
};
static const unsigned char big5_chars_ban1115 [] = {
    0xcc, 0xb2, 0xa9, 0xd1, 0xa9, 0xd0, 0xa9, 0xd2, 0xab, 0xf3, 
    0xce, 0xd2, 0xce, 0xd3, 
};
static const unsigned char big5_chars_ban1116 [] = {
    0xd1, 0xb0, 0xae, 0xb0, 0xb1, 0xaf, 0xb4, 0x76, 0xd9, 0x51, 
    0xa4, 0xe2, 
};
static const unsigned char big5_chars_ban1117 [] = {
    0xa4, 0x7e, 0xa4, 0xe3, 
};
static const unsigned char big5_chars_ban1118 [] = {
    0xc9, 0x7d, 0xa5, 0xb7, 0xa5, 0xb6, 0xa5, 0xb4, 0xa5, 0xb5, 
};
static const unsigned char big5_chars_ban1119 [] = {
    0xa6, 0xab, 0xc9, 0xe9, 0xc9, 0xeb, 0xa6, 0xaa, 0xc9, 0xe3, 
};
static const unsigned char big5_chars_ban1120 [] = {
    0xc9, 0xe4, 
};
static const unsigned char big5_chars_ban1121 [] = {
    0xc9, 0xea, 0xc9, 0xe6, 0xc9, 0xe8, 0xa6, 0xa9, 0xc9, 0xe5, 
    0xc9, 0xec, 0xc9, 0xe7, 
};
static const unsigned char big5_chars_ban1122 [] = {
    0xa7, 0xe1, 0xa7, 0xea, 0xa7, 0xe8, 0xca, 0xf0, 0xca, 0xed, 
    0xca, 0xf5, 0xa7, 0xe6, 0xca, 0xf6, 
};
static const unsigned char big5_chars_ban1123 [] = {
    0xa7, 0xdf, 0xca, 0xf3, 
};
static const unsigned char big5_chars_ban1124 [] = {
    0xa7, 0xe5, 0xca, 0xef, 0xca, 0xee, 0xa7, 0xe3, 0xca, 0xf4, 
    0xa7, 0xe4, 0xa9, 0xd3, 0xa7, 0xde, 0xca, 0xf1, 
};
static const unsigned char big5_chars_ban1125 [] = {
    0xca, 0xe7, 0xa7, 0xdb, 
};
static const unsigned char big5_chars_ban1126 [] = {
    0xa7, 0xee, 0xca, 0xec, 0xca, 0xf2, 0xa7, 0xe0, 0xa7, 0xe2, 
};
static const unsigned char big5_chars_ban1127 [] = {
    0xca, 0xe8, 
};
static const unsigned char big5_chars_ban1128 [] = {
    0xca, 0xe9, 0xca, 0xea, 
};
static const unsigned char big5_chars_ban1129 [] = {
    0xa7, 0xed, 0xa7, 0xe7, 0xa7, 0xec, 0xca, 0xeb, 0xa7, 0xeb, 
    0xa7, 0xdd, 0xa7, 0xdc, 0xa7, 0xe9, 
};
static const unsigned char big5_chars_ban1130 [] = {
    0xa9, 0xe1, 0xcc, 0xbe, 0xcc, 0xb7, 0xa9, 0xdc, 0xa9, 0xef, 
    0xcc, 0xb3, 0xcc, 0xba, 0xcc, 0xbc, 0xcc, 0xbf, 0xa9, 0xea, 
};
static const unsigned char big5_chars_ban1131 [] = {
    0xcc, 0xbb, 0xcc, 0xb4, 0xa9, 0xe8, 0xcc, 0xb8, 
};
static const unsigned char big5_chars_ban1132 [] = {
    0xcc, 0xc0, 0xa9, 0xd9, 
};
static const unsigned char big5_chars_ban1133 [] = {
    0xcc, 0xbd, 0xa9, 0xe3, 0xa9, 0xe2, 0xcc, 0xb6, 0xa9, 0xd7, 
};
static const unsigned char big5_chars_ban1134 [] = {
    0xa9, 0xd8, 
};
static const unsigned char big5_chars_ban1135 [] = {
    0xa9, 0xd6, 
};
static const unsigned char big5_chars_ban1136 [] = {
    0xa9, 0xee, 0xa9, 0xe6, 0xa9, 0xe0, 0xa9, 0xd4, 0xcc, 0xb9, 
    0xa9, 0xdf, 0xa9, 0xd5, 0xa9, 0xe7, 0xa9, 0xf0, 0xce, 0xd4, 
    0xa9, 0xe4, 0xcc, 0xb5, 0xa9, 0xda, 0xa9, 0xdd, 0xa9, 0xde, 
};
static const unsigned char big5_chars_ban1137 [] = {
    0xa9, 0xec, 0xa9, 0xed, 0xa9, 0xeb, 0xa9, 0xe5, 0xa9, 0xe9, 
    0xa9, 0xdb, 0xab, 0xf4, 
};
static const unsigned char big5_chars_ban1138 [] = {
    0xce, 0xda, 0xac, 0x41, 0xab, 0xf8, 0xab, 0xfa, 0xac, 0x40, 
    0xce, 0xe6, 0xab, 0xfd, 0xd1, 0xb1, 0xae, 0xb1, 0xac, 0x43, 
    0xce, 0xd7, 0xce, 0xdf, 0xab, 0xfe, 0xce, 0xde, 0xce, 0xdb, 
    0xce, 0xe3, 0xce, 0xe5, 0xab, 0xf7, 0xab, 0xfb, 0xac, 0x42, 
    0xae, 0xb3, 0xce, 0xe0, 0xab, 0xf9, 0xac, 0x45, 0xce, 0xd9, 
};
static const unsigned char big5_chars_ban1139 [] = {
    0xab, 0xfc, 0xae, 0xb2, 0xab, 0xf6, 
};
static const unsigned char big5_chars_ban1140 [] = {
    0xce, 0xd6, 0xce, 0xdd, 0xce, 0xd5, 0xce, 0xd8, 0xce, 0xdc, 
    0xd1, 0xb2, 0xac, 0x44, 
};
static const unsigned char big5_chars_ban1141 [] = {
    0xce, 0xe1, 0xce, 0xe2, 0xce, 0xe4, 0xab, 0xf5, 
};
static const unsigned char big5_chars_ban1142 [] = {
    0xae, 0xc1, 0xd1, 0xbe, 0xae, 0xbf, 0xae, 0xc0, 0xd1, 0xb4, 
    0xd1, 0xc4, 
};
static const unsigned char big5_chars_ban1143 [] = {
    0xae, 0xb6, 
};
static const unsigned char big5_chars_ban1144 [] = {
    0xd5, 0x66, 0xd1, 0xc6, 0xd1, 0xc0, 
};
static const unsigned char big5_chars_ban1145 [] = {
    0xd1, 0xb7, 
};
static const unsigned char big5_chars_ban1146 [] = {
    0xd1, 0xc9, 0xd1, 0xba, 0xae, 0xbc, 0xd5, 0x7d, 0xd1, 0xbd, 
    0xae, 0xbe, 0xae, 0xb5, 
};
static const unsigned char big5_chars_ban1147 [] = {
    0xd1, 0xcb, 0xd1, 0xbf, 0xae, 0xb8, 0xd1, 0xb8, 0xd1, 0xb5, 
    0xd1, 0xb6, 0xae, 0xb9, 0xd1, 0xc5, 0xd1, 0xcc, 0xae, 0xbb, 
    0xd1, 0xbc, 0xd1, 0xbb, 0xae, 0xc3, 0xae, 0xc2, 0xae, 0xb4, 
    0xae, 0xba, 0xae, 0xbd, 0xd1, 0xc8, 
};
static const unsigned char big5_chars_ban1148 [] = {
    0xd1, 0xc2, 0xae, 0xb7, 0xd1, 0xb3, 0xd1, 0xca, 0xd1, 0xc1, 
    0xd1, 0xc3, 0xd1, 0xc7, 
};
static const unsigned char big5_chars_ban1149 [] = {
    0xd5, 0x67, 
};
static const unsigned char big5_chars_ban1150 [] = {
    0xb1, 0xb7, 0xb1, 0xcb, 0xb1, 0xca, 
};
static const unsigned char big5_chars_ban1151 [] = {
    0xb1, 0xbf, 
};
static const unsigned char big5_chars_ban1152 [] = {
    0xd5, 0x79, 0xd5, 0x75, 0xd5, 0x72, 0xd5, 0xa6, 0xb1, 0xba, 
    0xb1, 0xb2, 
};
static const unsigned char big5_chars_ban1153 [] = {
    0xd5, 0x77, 0xb4, 0xa8, 0xb1, 0xb6, 0xd5, 0xa1, 
};
static const unsigned char big5_chars_ban1154 [] = {
    0xb1, 0xcc, 0xb1, 0xc9, 0xd5, 0x7b, 0xd5, 0x6a, 
};
static const unsigned char big5_chars_ban1155 [] = {
    0xb1, 0xc8, 0xd5, 0xa3, 0xd5, 0x69, 0xb1, 0xbd, 0xb1, 0xc1, 
    0xd5, 0xa2, 
};
static const unsigned char big5_chars_ban1156 [] = {
    0xd5, 0x73, 0xb1, 0xc2, 0xb1, 0xbc, 0xd5, 0x68, 
};
static const unsigned char big5_chars_ban1157 [] = {
    0xb4, 0x78, 0xd5, 0xa5, 0xd5, 0x71, 0xb1, 0xc7, 0xd5, 0x74, 
    0xd5, 0xa4, 0xb1, 0xc6, 
};
static const unsigned char big5_chars_ban1158 [] = {
    0xd9, 0x52, 
};
static const unsigned char big5_chars_ban1159 [] = {
    0xb1, 0xb3, 0xd5, 0x6f, 0xb1, 0xb8, 0xb1, 0xc3, 
};
static const unsigned char big5_chars_ban1160 [] = {
    0xb1, 0xbe, 0xd5, 0x78, 0xd5, 0x6e, 0xd5, 0x6c, 0xd5, 0x7e, 
    0xb1, 0xb0, 0xb1, 0xc4, 0xb1, 0xb4, 0xb4, 0x77, 0xd5, 0x7c, 
    0xb1, 0xb5, 
};
static const unsigned char big5_chars_ban1161 [] = {
    0xb1, 0xb1, 0xb1, 0xc0, 0xb1, 0xbb, 0xb1, 0xb9, 0xd5, 0x70, 
    0xb1, 0xc5, 0xd5, 0x6d, 0xd5, 0x7a, 0xd5, 0x76, 0xd9, 0x54, 
    0xd9, 0x53, 
};
static const unsigned char big5_chars_ban1162 [] = {
    0xd5, 0x6b, 0xd9, 0x64, 
};
static const unsigned char big5_chars_ban1163 [] = {
    0xb4, 0x7a, 
};
static const unsigned char big5_chars_ban1164 [] = {
    0xd9, 0x6a, 0xd9, 0x59, 0xd9, 0x67, 0xdd, 0x77, 0xb4, 0x7d, 
    0xd9, 0x6b, 0xd9, 0x6e, 0xb4, 0x7c, 0xd9, 0x5c, 0xd9, 0x6d, 
    0xd9, 0x6c, 0xb4, 0x7e, 0xd9, 0x55, 0xb4, 0x79, 0xb4, 0xa3, 
};
static const unsigned char big5_chars_ban1165 [] = {
    0xb4, 0xa1, 0xd9, 0x69, 
};
static const unsigned char big5_chars_ban1166 [] = {
    0xd9, 0x5f, 0xb4, 0xa5, 0xd9, 0x70, 0xd9, 0x68, 0xd9, 0x71, 
    0xb4, 0xad, 0xb4, 0xab, 0xd9, 0x66, 0xd9, 0x65, 
};
static const unsigned char big5_chars_ban1167 [] = {
    0xd9, 0x63, 0xd9, 0x5d, 0xb4, 0xa4, 
};
static const unsigned char big5_chars_ban1168 [] = {
    0xb4, 0xa2, 0xd1, 0xb9, 0xd9, 0x56, 
};
static const unsigned char big5_chars_ban1169 [] = {
    0xdd, 0xb7, 0xd9, 0x57, 0xb4, 0x7b, 0xb4, 0xaa, 0xdd, 0x79, 
};
static const unsigned char big5_chars_ban1170 [] = {
    0xb4, 0xa6, 0xb4, 0xa7, 0xd9, 0x58, 0xd9, 0x6f, 0xdd, 0x78, 
    0xd9, 0x60, 0xd9, 0x5b, 0xb4, 0xa9, 0xd9, 0x61, 0xd9, 0x5e, 
};
static const unsigned char big5_chars_ban1171 [] = {
    0xb4, 0xae, 
};
static const unsigned char big5_chars_ban1172 [] = {
    0xb7, 0x70, 
};
static const unsigned char big5_chars_ban1173 [] = {
    0xdd, 0x7c, 0xdd, 0xb1, 0xdd, 0xb6, 0xdd, 0xaa, 0xb7, 0x6c, 
    0xdd, 0xbb, 0xb7, 0x69, 0xdd, 0x7a, 
};
static const unsigned char big5_chars_ban1174 [] = {
    0xdd, 0x7b, 0xb7, 0x62, 0xb7, 0x6b, 0xdd, 0xa4, 0xb7, 0x6e, 
    0xb7, 0x6f, 0xdd, 0xa5, 
};
static const unsigned char big5_chars_ban1175 [] = {
    0xdd, 0xb2, 0xdd, 0xb8, 0xb7, 0x6a, 
};
static const unsigned char big5_chars_ban1176 [] = {
    0xb7, 0x64, 0xdd, 0xa3, 0xdd, 0x7d, 0xdd, 0xba, 0xdd, 0xa8, 
    0xdd, 0xa9, 0xdd, 0x7e, 0xdd, 0xb4, 0xdd, 0xab, 0xdd, 0xb5, 
    0xdd, 0xad, 
};
static const unsigned char big5_chars_ban1177 [] = {
    0xb7, 0x65, 0xe1, 0xd9, 0xb7, 0x68, 0xb7, 0x66, 0xdd, 0xb9, 
    0xdd, 0xb0, 0xdd, 0xac, 
};
static const unsigned char big5_chars_ban1178 [] = {
    0xdd, 0xa1, 0xba, 0x53, 0xdd, 0xaf, 0xb7, 0x6d, 0xdd, 0xa7, 
};
static const unsigned char big5_chars_ban1179 [] = {
    0xdd, 0xa6, 
};
static const unsigned char big5_chars_ban1180 [] = {
    0xb7, 0x67, 0xb7, 0x63, 0xe1, 0xee, 0xdd, 0xb3, 0xdd, 0xae, 
};
static const unsigned char big5_chars_ban1181 [] = {
    0xdd, 0xa2, 
};
static const unsigned char big5_chars_ban1182 [] = {
    0xe1, 0xe9, 
};
static const unsigned char big5_chars_ban1183 [] = {
    0xe1, 0xda, 0xe1, 0xe5, 
};
static const unsigned char big5_chars_ban1184 [] = {
    0xe1, 0xec, 0xba, 0x51, 0xb4, 0xac, 0xe1, 0xea, 0xba, 0x4c, 
};
static const unsigned char big5_chars_ban1185 [] = {
    0xba, 0x4b, 0xe1, 0xf1, 
};
static const unsigned char big5_chars_ban1186 [] = {
    0xe1, 0xdb, 0xe1, 0xe8, 0xe1, 0xdc, 0xe1, 0xe7, 0xba, 0x4f, 
    0xe1, 0xeb, 0xd9, 0x62, 
};
static const unsigned char big5_chars_ban1187 [] = {
    0xe1, 0xf2, 0xe1, 0xe3, 0xba, 0x52, 0xe5, 0xba, 0xbc, 0xaf, 
};
static const unsigned char big5_chars_ban1188 [] = {
    0xe1, 0xf0, 0xe1, 0xef, 0xba, 0x54, 0xe5, 0xad, 0xbc, 0xb0, 
    0xe5, 0xae, 
};
static const unsigned char big5_chars_ban1189 [] = {
    0xe1, 0xdf, 0xe1, 0xe0, 0xe1, 0xdd, 0xe1, 0xe2, 0xe1, 0xde, 
    0xe1, 0xf3, 0xba, 0x4e, 0xbc, 0xb1, 0xba, 0x50, 0xba, 0x55, 
};
static const unsigned char big5_chars_ban1190 [] = {
    0xe1, 0xe1, 
};
static const unsigned char big5_chars_ban1191 [] = {
    0xe1, 0xed, 
};
static const unsigned char big5_chars_ban1192 [] = {
    0xe1, 0xe6, 
};
static const unsigned char big5_chars_ban1193 [] = {
    0xe5, 0xb1, 
};
static const unsigned char big5_chars_ban1194 [] = {
    0xba, 0x4a, 0xbc, 0xb4, 0xe9, 0xaa, 0xe5, 0xb6, 0xe5, 0xb5, 
    0xe5, 0xb7, 
};
static const unsigned char big5_chars_ban1195 [] = {
    0xe5, 0xb4, 0xbc, 0xb5, 
};
static const unsigned char big5_chars_ban1196 [] = {
    0xbc, 0xbb, 0xbc, 0xb8, 
};
static const unsigned char big5_chars_ban1197 [] = {
    0xbc, 0xb9, 0xe5, 0xaf, 0xe5, 0xb2, 0xe5, 0xbc, 0xbc, 0xc1, 
    0xbc, 0xbf, 
};
static const unsigned char big5_chars_ban1198 [] = {
    0xe5, 0xb3, 0xd9, 0x5a, 0xbc, 0xb2, 0xe5, 0xb9, 0xe5, 0xb0, 
};
static const unsigned char big5_chars_ban1199 [] = {
    0xbc, 0xc2, 0xe5, 0xb8, 0xba, 0x4d, 0xbc, 0xb7, 0xe1, 0xe4, 
};
static const unsigned char big5_chars_ban1200 [] = {
    0xbc, 0xba, 
};
static const unsigned char big5_chars_ban1201 [] = {
    0xbc, 0xbe, 0xbc, 0xc0, 0xbc, 0xbd, 0xbc, 0xbc, 
};
static const unsigned char big5_chars_ban1202 [] = {
    0xbc, 0xb6, 0xe5, 0xbb, 0xbc, 0xb3, 0xbc, 0xc3, 
};
static const unsigned char big5_chars_ban1203 [] = {
    0xbe, 0xd8, 0xbe, 0xd9, 0xe9, 0xa9, 0xbe, 0xe2, 0xbe, 0xdf, 
};
static const unsigned char big5_chars_ban1204 [] = {
    0xbe, 0xd6, 0xbe, 0xdd, 0xe9, 0xab, 0xbe, 0xdb, 0xbe, 0xd5, 
};
static const unsigned char big5_chars_ban1205 [] = {
    0xbe, 0xdc, 
};
static const unsigned char big5_chars_ban1206 [] = {
    0xe9, 0xa8, 0xc0, 0xbb, 0xbe, 0xd7, 
};
static const unsigned char big5_chars_ban1207 [] = {
    0xbe, 0xde, 0xc0, 0xba, 0xe9, 0xa7, 0xe9, 0xa6, 
};
static const unsigned char big5_chars_ban1208 [] = {
    0xbe, 0xe0, 
};
static const unsigned char big5_chars_ban1209 [] = {
    0xbe, 0xe1, 
};
static const unsigned char big5_chars_ban1210 [] = {
    0xe9, 0xa5, 0xe9, 0xa4, 0xc0, 0xbc, 0xe9, 0xae, 0xbe, 0xda, 
    0xe9, 0xac, 
};
static const unsigned char big5_chars_ban1211 [] = {
    0xc0, 0xbd, 
};
static const unsigned char big5_chars_ban1212 [] = {
    0xc0, 0xc2, 0xec, 0xea, 0xec, 0xec, 
};
static const unsigned char big5_chars_ban1213 [] = {
    0xc0, 0xbf, 
};
static const unsigned char big5_chars_ban1214 [] = {
    0xec, 0xed, 0xec, 0xe9, 
};
static const unsigned char big5_chars_ban1215 [] = {
    0xec, 0xeb, 0xc0, 0xc0, 0xc0, 0xc3, 
};
static const unsigned char big5_chars_ban1216 [] = {
    0xec, 0xe8, 0xc0, 0xbe, 0xc0, 0xc1, 0xc2, 0x59, 0xe9, 0xad, 
    0xc2, 0x58, 
};
static const unsigned char big5_chars_ban1217 [] = {
    0xc2, 0x5e, 0xef, 0xd4, 
};
static const unsigned char big5_chars_ban1218 [] = {
    0xc2, 0x5c, 0xc2, 0x5d, 0xef, 0xd7, 0xef, 0xd3, 0xc2, 0x5a, 
    0xef, 0xd1, 0xc3, 0x6b, 0xef, 0xd5, 
};
static const unsigned char big5_chars_ban1219 [] = {
    0xef, 0xd6, 0xef, 0xd2, 
};
static const unsigned char big5_chars_ban1220 [] = {
    0xc2, 0x5b, 0xf2, 0x42, 
};
static const unsigned char big5_chars_ban1221 [] = {
    0xf2, 0x45, 
};
static const unsigned char big5_chars_ban1222 [] = {
    0xf2, 0x46, 0xf2, 0x44, 0xf2, 0x47, 0xc3, 0x6c, 0xf2, 0x43, 
};
static const unsigned char big5_chars_ban1223 [] = {
    0xf4, 0x4e, 0xc4, 0x64, 0xf4, 0x4d, 0xf4, 0x4c, 0xf4, 0x4b, 
    0xc4, 0x63, 0xc4, 0x65, 
};
static const unsigned char big5_chars_ban1224 [] = {
    0xf5, 0xcd, 0xc4, 0xe2, 0xc4, 0xe1, 
};
static const unsigned char big5_chars_ban1225 [] = {
    0xf6, 0xe1, 0xf6, 0xe0, 0xf6, 0xe3, 0xc5, 0xcb, 0xc5, 0x75, 
    0xf7, 0xdd, 0xf6, 0xe2, 
};
static const unsigned char big5_chars_ban1226 [] = {
    0xf7, 0xdc, 0xc5, 0xcd, 0xc5, 0xcc, 0xc5, 0xf3, 0xf8, 0xa9, 
    0xf8, 0xef, 0xa4, 0xe4, 
};
static const unsigned char big5_chars_ban1227 [] = {
    0xd9, 0x72, 0xe9, 0xaf, 
};
static const unsigned char big5_chars_ban1228 [] = {
    0xa6, 0xac, 0xca, 0xf7, 0xa7, 0xf1, 0xa7, 0xef, 
};
static const unsigned char big5_chars_ban1229 [] = {
    0xa7, 0xf0, 
};
static const unsigned char big5_chars_ban1230 [] = {
    0xcc, 0xc1, 0xa9, 0xf1, 0xac, 0x46, 
};
static const unsigned char big5_chars_ban1231 [] = {
    0xce, 0xe7, 
};
static const unsigned char big5_chars_ban1232 [] = {
    0xce, 0xe8, 
};
static const unsigned char big5_chars_ban1233 [] = {
    0xac, 0x47, 0xd1, 0xce, 
};
static const unsigned char big5_chars_ban1234 [] = {
    0xae, 0xc4, 0xae, 0xc5, 0xd1, 0xcd, 
};
static const unsigned char big5_chars_ban1235 [] = {
    0xb1, 0xd3, 
};
static const unsigned char big5_chars_ban1236 [] = {
    0xb1, 0xcf, 
};
static const unsigned char big5_chars_ban1237 [] = {
    0xd5, 0xa7, 0xb1, 0xd6, 0xb1, 0xd5, 0xb1, 0xce, 0xb1, 0xd1, 
    0xb1, 0xd4, 0xb1, 0xd0, 
};
static const unsigned char big5_chars_ban1238 [] = {
    0xd9, 0x76, 0xb1, 0xcd, 0xb4, 0xaf, 
};
static const unsigned char big5_chars_ban1239 [] = {
    0xb4, 0xb1, 0xb4, 0xb2, 0xd9, 0x75, 0xd9, 0x78, 0xb4, 0xb0, 
    0xd9, 0x73, 0xd9, 0x77, 
};
static const unsigned char big5_chars_ban1240 [] = {
    0xd9, 0x74, 
};
static const unsigned char big5_chars_ban1241 [] = {
    0xb7, 0x71, 
};
static const unsigned char big5_chars_ban1242 [] = {
    0xdd, 0xbc, 
};
static const unsigned char big5_chars_ban1243 [] = {
    0xba, 0x56, 0xe1, 0xf4, 0xbe, 0xe3, 0xbc, 0xc4, 0xe5, 0xbd, 
    0xbc, 0xc5, 0xbc, 0xc6, 0xe5, 0xbf, 0xe5, 0xbe, 0xe5, 0xc0, 
    0xe9, 0xb1, 
};
static const unsigned char big5_chars_ban1244 [] = {
    0xe9, 0xb0, 0xec, 0xef, 0xec, 0xee, 0xc0, 0xc4, 0xc0, 0xc5, 
    0xf2, 0x48, 
};
static const unsigned char big5_chars_ban1245 [] = {
    0xa4, 0xe5, 
};
static const unsigned char big5_chars_ban1246 [] = {
    0xd9, 0x79, 
};
static const unsigned char big5_chars_ban1247 [] = {
    0xb4, 0xb4, 0xb4, 0xb3, 0xdd, 0xbd, 
};
static const unsigned char big5_chars_ban1248 [] = {
    0xef, 0xd8, 0xc4, 0xe3, 0xf7, 0xde, 0xa4, 0xe6, 
};
static const unsigned char big5_chars_ban1249 [] = {
    0xae, 0xc6, 
};
static const unsigned char big5_chars_ban1250 [] = {
    0xb1, 0xd8, 0xb1, 0xd7, 0xd9, 0x7a, 0xd9, 0x7b, 0xb7, 0x72, 
    0xe1, 0xf5, 0xba, 0x57, 0xe9, 0xb2, 
};
static const unsigned char big5_chars_ban1251 [] = {
    0xa4, 0xe7, 0xa5, 0xb8, 
};
static const unsigned char big5_chars_ban1252 [] = {
    0xa9, 0xf2, 0xcc, 0xc2, 
};
static const unsigned char big5_chars_ban1253 [] = {
    0xce, 0xe9, 0xac, 0x48, 0xb1, 0xd9, 
};
static const unsigned char big5_chars_ban1254 [] = {
    0xd9, 0x7c, 0xb4, 0xb5, 0xb7, 0x73, 
};
static const unsigned char big5_chars_ban1255 [] = {
    0xe5, 0xc1, 0xe5, 0xc2, 
};
static const unsigned char big5_chars_ban1256 [] = {
    0xec, 0xf0, 0xc2, 0x5f, 0xf8, 0xf0, 0xa4, 0xe8, 
};
static const unsigned char big5_chars_ban1257 [] = {
    0xcc, 0xc3, 0xa9, 0xf3, 0xac, 0x49, 
};
static const unsigned char big5_chars_ban1258 [] = {
    0xce, 0xea, 
};
static const unsigned char big5_chars_ban1259 [] = {
    0xae, 0xc7, 0xd1, 0xd2, 0xd1, 0xd0, 0xd1, 0xd1, 0xae, 0xc8, 
    0xd1, 0xcf, 
};
static const unsigned char big5_chars_ban1260 [] = {
    0xb1, 0xdb, 0xb1, 0xdc, 0xd5, 0xa8, 0xb1, 0xdd, 0xb1, 0xda, 
    0xd9, 0x7d, 
};
static const unsigned char big5_chars_ban1261 [] = {
    0xd9, 0x7e, 0xdd, 0xbe, 
};
static const unsigned char big5_chars_ban1262 [] = {
    0xba, 0x59, 0xba, 0x58, 
};
static const unsigned char big5_chars_ban1263 [] = {
    0xec, 0xf1, 0xef, 0xd9, 
};
static const unsigned char big5_chars_ban1264 [] = {
    0xf2, 0x4a, 0xf2, 0x49, 0xf4, 0x4f, 
};
static const unsigned char big5_chars_ban1265 [] = {
    0xc9, 0x5e, 0xac, 0x4a, 
};
static const unsigned char big5_chars_ban1266 [] = {
    0xa4, 0xe9, 0xa5, 0xb9, 
};
static const unsigned char big5_chars_ban1267 [] = {
    0xa6, 0xae, 0xa6, 0xad, 
};
static const unsigned char big5_chars_ban1268 [] = {
    0xa6, 0xaf, 0xa6, 0xb0, 0xc9, 0xee, 0xc9, 0xed, 0xca, 0xf8, 
    0xa7, 0xf2, 0xca, 0xfb, 0xca, 0xfa, 0xca, 0xf9, 0xca, 0xfc, 
};
static const unsigned char big5_chars_ban1269 [] = {
    0xa9, 0xf4, 0xcc, 0xc9, 0xcc, 0xc5, 0xcc, 0xce, 
};
static const unsigned char big5_chars_ban1270 [] = {
    0xa9, 0xfb, 
};
static const unsigned char big5_chars_ban1271 [] = {
    0xa9, 0xf9, 0xcc, 0xca, 0xcc, 0xc6, 0xcc, 0xcd, 0xa9, 0xf8, 
    0xaa, 0x40, 0xcc, 0xc8, 0xcc, 0xc4, 0xa9, 0xfe, 0xcc, 0xcb, 
    0xa9, 0xf7, 0xcc, 0xcc, 0xa9, 0xfa, 0xa9, 0xfc, 0xcc, 0xd0, 
    0xcc, 0xcf, 0xcc, 0xc7, 0xa9, 0xf6, 0xa9, 0xf5, 0xa9, 0xfd, 
};
static const unsigned char big5_chars_ban1272 [] = {
    0xce, 0xef, 0xce, 0xf5, 
};
static const unsigned char big5_chars_ban1273 [] = {
    0xac, 0x50, 0xac, 0x4d, 0xce, 0xec, 0xce, 0xf1, 
};
static const unsigned char big5_chars_ban1274 [] = {
    0xac, 0x53, 0xac, 0x4b, 0xce, 0xf0, 0xac, 0x4e, 0xac, 0x51, 
};
static const unsigned char big5_chars_ban1275 [] = {
    0xce, 0xf3, 
};
static const unsigned char big5_chars_ban1276 [] = {
    0xac, 0x4c, 0xce, 0xf8, 0xac, 0x4f, 
};
static const unsigned char big5_chars_ban1277 [] = {
    0xac, 0x52, 0xce, 0xed, 0xce, 0xf2, 0xce, 0xf6, 0xce, 0xee, 
    0xce, 0xeb, 
};
static const unsigned char big5_chars_ban1278 [] = {
    0xce, 0xf7, 0xce, 0xf4, 
};
static const unsigned char big5_chars_ban1279 [] = {
    0xae, 0xd0, 0xae, 0xc9, 0xae, 0xcc, 
};
static const unsigned char big5_chars_ban1280 [] = {
    0xae, 0xcf, 
};
static const unsigned char big5_chars_ban1281 [] = {
    0xd1, 0xd5, 
};
static const unsigned char big5_chars_ban1282 [] = {
    0xae, 0xca, 0xd1, 0xd3, 
};
static const unsigned char big5_chars_ban1283 [] = {
    0xae, 0xce, 
};
static const unsigned char big5_chars_ban1284 [] = {
    0xae, 0xcb, 
};
static const unsigned char big5_chars_ban1285 [] = {
    0xd1, 0xd6, 0xae, 0xcd, 
};
static const unsigned char big5_chars_ban1286 [] = {
    0xd5, 0xac, 0xb1, 0xdf, 0xd5, 0xab, 0xd5, 0xad, 0xb1, 0xde, 
    0xb1, 0xe3, 0xd1, 0xd4, 
};
static const unsigned char big5_chars_ban1287 [] = {
    0xd5, 0xaa, 0xd5, 0xae, 
};
static const unsigned char big5_chars_ban1288 [] = {
    0xb1, 0xe0, 0xd5, 0xa9, 0xb1, 0xe2, 
};
static const unsigned char big5_chars_ban1289 [] = {
    0xb1, 0xe1, 
};
static const unsigned char big5_chars_ban1290 [] = {
    0xd9, 0xa7, 
};
static const unsigned char big5_chars_ban1291 [] = {
    0xd9, 0xa2, 
};
static const unsigned char big5_chars_ban1292 [] = {
    0xb4, 0xb6, 0xb4, 0xba, 0xb4, 0xb7, 0xd9, 0xa5, 0xd9, 0xa8, 
};
static const unsigned char big5_chars_ban1293 [] = {
    0xb4, 0xb8, 
};
static const unsigned char big5_chars_ban1294 [] = {
    0xb4, 0xb9, 0xb4, 0xbe, 0xdd, 0xc7, 0xd9, 0xa6, 0xb4, 0xbc, 
    0xd9, 0xa3, 0xd9, 0xa1, 
};
static const unsigned char big5_chars_ban1295 [] = {
    0xb4, 0xbd, 
};
static const unsigned char big5_chars_ban1296 [] = {
    0xd9, 0xa4, 
};
static const unsigned char big5_chars_ban1297 [] = {
    0xb7, 0x79, 
};
static const unsigned char big5_chars_ban1298 [] = {
    0xdd, 0xbf, 0xb7, 0x76, 0xb7, 0x77, 0xb7, 0x75, 0xdd, 0xc4, 
    0xdd, 0xc3, 0xdd, 0xc0, 0xb7, 0x7b, 
};
static const unsigned char big5_chars_ban1299 [] = {
    0xdd, 0xc2, 0xb4, 0xbb, 
};
static const unsigned char big5_chars_ban1300 [] = {
    0xdd, 0xc6, 0xdd, 0xc1, 0xb7, 0x78, 0xb7, 0x74, 0xb7, 0x7a, 
    0xdd, 0xc5, 
};
static const unsigned char big5_chars_ban1301 [] = {
    0xba, 0x5c, 
};
static const unsigned char big5_chars_ban1302 [] = {
    0xe1, 0xf8, 0xe1, 0xf7, 0xe1, 0xf6, 0xba, 0x5a, 
};
static const unsigned char big5_chars_ban1303 [] = {
    0xba, 0x5b, 0xe5, 0xc5, 0xe5, 0xc8, 0xbc, 0xc8, 
};
static const unsigned char big5_chars_ban1304 [] = {
    0xbc, 0xc7, 0xe5, 0xc9, 0xe5, 0xc4, 0xbc, 0xca, 0xe5, 0xc6, 
};
static const unsigned char big5_chars_ban1305 [] = {
    0xbc, 0xc9, 0xe5, 0xc3, 
};
static const unsigned char big5_chars_ban1306 [] = {
    0xe5, 0xc7, 0xbe, 0xe9, 0xbe, 0xe6, 0xe9, 0xbb, 0xe9, 0xba, 
};
static const unsigned char big5_chars_ban1307 [] = {
    0xe9, 0xb9, 0xe9, 0xb4, 
};
static const unsigned char big5_chars_ban1308 [] = {
    0xe9, 0xb5, 
};
static const unsigned char big5_chars_ban1309 [] = {
    0xbe, 0xe7, 
};
static const unsigned char big5_chars_ban1310 [] = {
    0xbe, 0xe4, 0xbe, 0xe8, 0xe9, 0xb3, 0xbe, 0xe5, 0xe9, 0xb6, 
    0xe9, 0xb7, 0xe9, 0xbc, 
};
static const unsigned char big5_chars_ban1311 [] = {
    0xe9, 0xb8, 
};
static const unsigned char big5_chars_ban1312 [] = {
    0xec, 0xf2, 
};
static const unsigned char big5_chars_ban1313 [] = {
    0xc0, 0xc7, 
};
static const unsigned char big5_chars_ban1314 [] = {
    0xef, 0xdc, 0xc0, 0xc6, 0xef, 0xda, 0xef, 0xdb, 0xc2, 0x60, 
    0xc3, 0x6e, 0xf2, 0x4b, 
};
static const unsigned char big5_chars_ban1315 [] = {
    0xc3, 0x6d, 
};
static const unsigned char big5_chars_ban1316 [] = {
    0xf4, 0x51, 0xf4, 0x52, 
};
static const unsigned char big5_chars_ban1317 [] = {
    0xc4, 0x66, 
};
static const unsigned char big5_chars_ban1318 [] = {
    0xf4, 0x50, 0xc4, 0xe4, 
};
static const unsigned char big5_chars_ban1319 [] = {
    0xf7, 0xdf, 0xc5, 0xce, 0xf8, 0xaa, 0xf8, 0xab, 
};
static const unsigned char big5_chars_ban1320 [] = {
    0xa4, 0xea, 
};
static const unsigned char big5_chars_ban1321 [] = {
    0xa6, 0xb1, 0xa6, 0xb2, 0xa7, 0xf3, 
};
static const unsigned char big5_chars_ban1322 [] = {
    0xcc, 0xd1, 0xac, 0x54, 0xae, 0xd1, 0xb1, 0xe4, 
};
static const unsigned char big5_chars_ban1323 [] = {
    0xb0, 0xd2, 
};
static const unsigned char big5_chars_ban1324 [] = {
    0xb4, 0xbf, 0xb4, 0xc0, 0xb3, 0xcc, 0xd9, 0xa9, 
};
static const unsigned char big5_chars_ban1325 [] = {
    0xb7, 0x7c, 0xe1, 0xfa, 0xe1, 0xf9, 
};
static const unsigned char big5_chars_ban1326 [] = {
    0xa4, 0xeb, 0xa6, 0xb3, 0xcc, 0xd2, 0xaa, 0x42, 
};
static const unsigned char big5_chars_ban1327 [] = {
    0xaa, 0x41, 
};
static const unsigned char big5_chars_ban1328 [] = {
    0xce, 0xf9, 0xce, 0xfa, 
};
static const unsigned char big5_chars_ban1329 [] = {
    0xd1, 0xd7, 0xd1, 0xd8, 0xae, 0xd2, 0xae, 0xd3, 
};
static const unsigned char big5_chars_ban1330 [] = {
    0xae, 0xd4, 0xd5, 0xaf, 
};
static const unsigned char big5_chars_ban1331 [] = {
    0xb1, 0xe6, 
};
static const unsigned char big5_chars_ban1332 [] = {
    0xb4, 0xc2, 
};
static const unsigned char big5_chars_ban1333 [] = {
    0xb4, 0xc1, 0xdd, 0xc8, 0xdf, 0x7a, 0xe1, 0xfb, 0xe9, 0xbd, 
};
static const unsigned char big5_chars_ban1334 [] = {
    0xc2, 0x61, 0xc4, 0x67, 0xa4, 0xec, 
};
static const unsigned char big5_chars_ban1335 [] = {
    0xa5, 0xbc, 0xa5, 0xbd, 0xa5, 0xbb, 0xa5, 0xbe, 0xa5, 0xba, 
};
static const unsigned char big5_chars_ban1336 [] = {
    0xa6, 0xb6, 
};
static const unsigned char big5_chars_ban1337 [] = {
    0xc9, 0xf6, 0xa6, 0xb5, 0xa6, 0xb7, 
};
static const unsigned char big5_chars_ban1338 [] = {
    0xc9, 0xf1, 0xc9, 0xf0, 0xc9, 0xf3, 0xc9, 0xf2, 0xc9, 0xf5, 
    0xa6, 0xb4, 0xc9, 0xef, 0xc9, 0xf4, 
};
static const unsigned char big5_chars_ban1339 [] = {
    0xca, 0xfd, 0xa7, 0xfd, 0xca, 0xfe, 0xcb, 0x43, 0xa7, 0xfc, 
};
static const unsigned char big5_chars_ban1340 [] = {
    0xcb, 0x47, 0xcb, 0x42, 0xcb, 0x45, 0xa7, 0xf5, 0xa7, 0xf6, 
    0xa7, 0xf7, 0xa7, 0xf8, 
};
static const unsigned char big5_chars_ban1341 [] = {
    0xa8, 0x40, 
};
static const unsigned char big5_chars_ban1342 [] = {
    0xcb, 0x41, 0xa7, 0xfa, 0xa8, 0x41, 
};
static const unsigned char big5_chars_ban1343 [] = {
    0xcb, 0x40, 0xcb, 0x46, 
};
static const unsigned char big5_chars_ban1344 [] = {
    0xa7, 0xf9, 0xcb, 0x44, 0xa7, 0xfb, 0xa7, 0xf4, 0xa7, 0xfe, 
};
static const unsigned char big5_chars_ban1345 [] = {
    0xaa, 0x57, 
};
static const unsigned char big5_chars_ban1346 [] = {
    0xcc, 0xd4, 0xaa, 0x43, 
};
static const unsigned char big5_chars_ban1347 [] = {
    0xaa, 0x4d, 0xaa, 0x4e, 0xaa, 0x46, 0xaa, 0x58, 0xaa, 0x48, 
    0xcc, 0xdc, 0xaa, 0x53, 0xcc, 0xd7, 0xaa, 0x49, 0xcc, 0xe6, 
    0xcc, 0xe7, 0xcc, 0xdf, 0xcc, 0xd8, 0xaa, 0x56, 0xcc, 0xe4, 
    0xaa, 0x51, 0xaa, 0x4f, 
};
static const unsigned char big5_chars_ban1348 [] = {
    0xcc, 0xe5, 
};
static const unsigned char big5_chars_ban1349 [] = {
    0xcc, 0xe3, 0xcc, 0xdb, 0xcc, 0xd3, 0xcc, 0xda, 0xaa, 0x4a, 
};
static const unsigned char big5_chars_ban1350 [] = {
    0xaa, 0x50, 
};
static const unsigned char big5_chars_ban1351 [] = {
    0xaa, 0x44, 0xcc, 0xde, 0xcc, 0xdd, 0xcc, 0xd5, 
};
static const unsigned char big5_chars_ban1352 [] = {
    0xaa, 0x52, 0xcc, 0xe1, 0xcc, 0xd6, 0xaa, 0x55, 0xcc, 0xe8, 
    0xaa, 0x45, 
};
static const unsigned char big5_chars_ban1353 [] = {
    0xaa, 0x4c, 0xcc, 0xd9, 0xcc, 0xe2, 0xaa, 0x54, 
};
static const unsigned char big5_chars_ban1354 [] = {
    0xaa, 0x47, 0xaa, 0x4b, 
};
static const unsigned char big5_chars_ban1355 [] = {
    0xcc, 0xe0, 
};
static const unsigned char big5_chars_ban1356 [] = {
    0xcf, 0x5b, 0xac, 0x5c, 0xac, 0x69, 
};
static const unsigned char big5_chars_ban1357 [] = {
    0xcf, 0x56, 0xcf, 0x4c, 0xac, 0x62, 0xcf, 0x4a, 0xac, 0x5b, 
    0xcf, 0x45, 0xac, 0x65, 0xcf, 0x52, 0xce, 0xfe, 0xcf, 0x41, 
};
static const unsigned char big5_chars_ban1358 [] = {
    0xcf, 0x44, 0xce, 0xfb, 0xcf, 0x51, 0xcf, 0x61, 0xac, 0x60, 
    0xcf, 0x46, 0xcf, 0x58, 
};
static const unsigned char big5_chars_ban1359 [] = {
    0xce, 0xfd, 0xcf, 0x5f, 0xcf, 0x60, 0xcf, 0x63, 0xcf, 0x5a, 
    0xcf, 0x4b, 0xcf, 0x53, 0xac, 0x66, 0xac, 0x59, 0xac, 0x61, 
    0xac, 0x6d, 0xac, 0x56, 0xac, 0x58, 
};
static const unsigned char big5_chars_ban1360 [] = {
    0xcf, 0x43, 0xac, 0x6a, 0xac, 0x63, 0xcf, 0x5d, 0xcf, 0x40, 
    0xac, 0x6c, 0xac, 0x67, 0xcf, 0x49, 
};
static const unsigned char big5_chars_ban1361 [] = {
    0xac, 0x6b, 0xcf, 0x50, 0xcf, 0x48, 0xac, 0x64, 0xcf, 0x5c, 
    0xcf, 0x54, 
};
static const unsigned char big5_chars_ban1362 [] = {
    0xac, 0x5e, 0xcf, 0x62, 0xcf, 0x47, 0xac, 0x5a, 0xcf, 0x59, 
    0xcf, 0x4f, 0xac, 0x5f, 0xcf, 0x55, 0xac, 0x57, 0xce, 0xfc, 
    0xac, 0x68, 0xae, 0xe3, 0xac, 0x5d, 0xcf, 0x4e, 0xcf, 0x4d, 
    0xcf, 0x42, 
};
static const unsigned char big5_chars_ban1363 [] = {
    0xcf, 0x5e, 
};
static const unsigned char big5_chars_ban1364 [] = {
    0xcf, 0x57, 
};
static const unsigned char big5_chars_ban1365 [] = {
    0xac, 0x55, 
};
static const unsigned char big5_chars_ban1366 [] = {
    0xd1, 0xec, 0xae, 0xea, 0xd1, 0xed, 
};
static const unsigned char big5_chars_ban1367 [] = {
    0xd1, 0xe1, 0xae, 0xdf, 0xae, 0xeb, 
};
static const unsigned char big5_chars_ban1368 [] = {
    0xd1, 0xda, 
};
static const unsigned char big5_chars_ban1369 [] = {
    0xd1, 0xe3, 0xd1, 0xeb, 
};
static const unsigned char big5_chars_ban1370 [] = {
    0xd1, 0xd9, 0xd1, 0xf4, 0xae, 0xd5, 
};
static const unsigned char big5_chars_ban1371 [] = {
    0xd1, 0xf3, 0xd1, 0xee, 
};
static const unsigned char big5_chars_ban1372 [] = {
    0xd1, 0xef, 0xae, 0xdd, 0xae, 0xe8, 0xd1, 0xe5, 
};
static const unsigned char big5_chars_ban1373 [] = {
    0xd1, 0xe6, 0xd1, 0xf0, 0xd1, 0xe7, 
};
static const unsigned char big5_chars_ban1374 [] = {
    0xd1, 0xe2, 0xd1, 0xdc, 0xd1, 0xdd, 0xd1, 0xea, 0xd1, 0xe4, 
};
static const unsigned char big5_chars_ban1375 [] = {
    0xae, 0xd6, 0xae, 0xda, 0xd1, 0xf2, 0xd1, 0xde, 0xae, 0xe6, 
    0xae, 0xe2, 
};
static const unsigned char big5_chars_ban1376 [] = {
    0xae, 0xe5, 0xae, 0xec, 0xae, 0xdb, 0xae, 0xe7, 0xd1, 0xe9, 
    0xae, 0xe9, 0xae, 0xd8, 
};
static const unsigned char big5_chars_ban1377 [] = {
    0xae, 0xd7, 0xd1, 0xdb, 
};
static const unsigned char big5_chars_ban1378 [] = {
    0xd1, 0xdf, 0xae, 0xe0, 0xd1, 0xf1, 0xd1, 0xe8, 0xd1, 0xe0, 
    0xae, 0xe4, 0xae, 0xe1, 
};
static const unsigned char big5_chars_ban1379 [] = {
    0xae, 0xd9, 0xae, 0xdc, 
};
static const unsigned char big5_chars_ban1380 [] = {
    0xd5, 0xc4, 
};
static const unsigned char big5_chars_ban1381 [] = {
    0xd5, 0xb4, 0xd5, 0xb5, 0xd5, 0xb9, 
};
static const unsigned char big5_chars_ban1382 [] = {
    0xd5, 0xc8, 0xd5, 0xc5, 
};
static const unsigned char big5_chars_ban1383 [] = {
    0xd5, 0xbe, 0xd5, 0xbd, 0xb1, 0xed, 0xd5, 0xc1, 0xd5, 0xd0, 
    0xd5, 0xb0, 
};
static const unsigned char big5_chars_ban1384 [] = {
    0xd5, 0xd1, 0xd5, 0xc3, 0xd5, 0xd5, 0xd5, 0xc9, 0xb1, 0xec, 
    0xd5, 0xc7, 0xb1, 0xe7, 0xb1, 0xfc, 0xb1, 0xf2, 
};
static const unsigned char big5_chars_ban1385 [] = {
    0xb1, 0xf6, 0xb1, 0xf5, 0xd5, 0xb1, 
};
static const unsigned char big5_chars_ban1386 [] = {
    0xd5, 0xce, 0xd5, 0xd4, 0xd5, 0xcc, 0xd5, 0xd3, 
};
static const unsigned char big5_chars_ban1387 [] = {
    0xd5, 0xc0, 0xd5, 0xb2, 0xd5, 0xd2, 0xd5, 0xc2, 0xb1, 0xea, 
    0xb1, 0xf7, 
};
static const unsigned char big5_chars_ban1388 [] = {
    0xd5, 0xcb, 0xb1, 0xf0, 
};
static const unsigned char big5_chars_ban1389 [] = {
    0xd5, 0xca, 0xd5, 0xb3, 0xb1, 0xf8, 
};
static const unsigned char big5_chars_ban1390 [] = {
    0xb1, 0xfa, 0xd5, 0xcd, 0xb1, 0xfb, 0xb1, 0xe9, 0xd5, 0xba, 
    0xd5, 0xcf, 
};
static const unsigned char big5_chars_ban1391 [] = {
    0xb1, 0xef, 0xb1, 0xf9, 0xd5, 0xbc, 0xd5, 0xc6, 0xd5, 0xb7, 
    0xd5, 0xbb, 0xb1, 0xf4, 0xd5, 0xb6, 0xb1, 0xe8, 0xb1, 0xf1, 
    0xb1, 0xee, 0xd5, 0xbf, 0xae, 0xde, 0xd9, 0xc0, 0xb1, 0xeb, 
};
static const unsigned char big5_chars_ban1392 [] = {
    0xb1, 0xf3, 
};
static const unsigned char big5_chars_ban1393 [] = {
    0xd9, 0xc3, 0xd9, 0xd9, 0xd9, 0xce, 0xb4, 0xd6, 
};
static const unsigned char big5_chars_ban1394 [] = {
    0xb4, 0xd1, 0xd9, 0xbd, 0xb4, 0xd2, 0xd9, 0xcd, 
};
static const unsigned char big5_chars_ban1395 [] = {
    0xd9, 0xc6, 0xd9, 0xd3, 0xb4, 0xce, 0xd9, 0xab, 0xd9, 0xd5, 
    0xb4, 0xc4, 0xd9, 0xb3, 0xb4, 0xc7, 0xb4, 0xc6, 
};
static const unsigned char big5_chars_ban1396 [] = {
    0xb4, 0xd7, 
};
static const unsigned char big5_chars_ban1397 [] = {
    0xd9, 0xad, 0xd9, 0xcf, 0xd9, 0xd0, 0xb4, 0xc9, 0xb4, 0xc5, 
    0xd9, 0xbb, 
};
static const unsigned char big5_chars_ban1398 [] = {
    0xb4, 0xd0, 0xd9, 0xb6, 
};
static const unsigned char big5_chars_ban1399 [] = {
    0xd9, 0xd1, 0xb4, 0xcc, 0xd9, 0xc9, 0xd9, 0xd6, 0xd9, 0xb0, 
    0xd9, 0xb5, 0xd9, 0xaf, 
};
static const unsigned char big5_chars_ban1400 [] = {
    0xb4, 0xcb, 0xd9, 0xc2, 0xdd, 0xde, 0xd9, 0xb1, 0xb4, 0xcf, 
    0xd9, 0xba, 0xd9, 0xd2, 0xb4, 0xca, 0xd9, 0xb7, 0xd9, 0xb4, 
    0xd9, 0xc5, 0xb4, 0xcd, 0xb4, 0xc3, 0xb4, 0xd9, 0xd9, 0xc8, 
    0xd9, 0xc7, 
};
static const unsigned char big5_chars_ban1401 [] = {
    0xd9, 0xac, 0xb4, 0xc8, 0xd9, 0xd4, 0xd9, 0xbc, 0xd9, 0xbe, 
};
static const unsigned char big5_chars_ban1402 [] = {
    0xd9, 0xcb, 0xd9, 0xca, 0xd9, 0xaa, 0xb4, 0xd3, 0xb4, 0xd5, 
    0xd9, 0xb2, 0xd9, 0xb9, 0xd9, 0xc1, 0xb4, 0xd4, 0xd9, 0xb8, 
    0xd9, 0xc4, 0xd9, 0xd7, 
};
static const unsigned char big5_chars_ban1403 [] = {
    0xd9, 0xcc, 
};
static const unsigned char big5_chars_ban1404 [] = {
    0xd9, 0xd8, 
};
static const unsigned char big5_chars_ban1405 [] = {
    0xd9, 0xae, 
};
static const unsigned char big5_chars_ban1406 [] = {
    0xdd, 0xf2, 0xb7, 0xa6, 
};
static const unsigned char big5_chars_ban1407 [] = {
    0xdd, 0xf0, 0xdd, 0xdb, 0xdd, 0xe0, 0xdd, 0xd9, 
};
static const unsigned char big5_chars_ban1408 [] = {
    0xdd, 0xec, 0xdd, 0xcb, 0xdd, 0xd2, 
};
static const unsigned char big5_chars_ban1409 [] = {
    0xdd, 0xea, 0xdd, 0xf4, 0xdd, 0xdc, 
};
static const unsigned char big5_chars_ban1410 [] = {
    0xdd, 0xcf, 0xdd, 0xe2, 0xdd, 0xe7, 0xdd, 0xd3, 
};
static const unsigned char big5_chars_ban1411 [] = {
    0xdd, 0xe4, 0xdd, 0xd0, 
};
static const unsigned char big5_chars_ban1412 [] = {
    0xdd, 0xd7, 0xdd, 0xd8, 0xb7, 0xa8, 0xdd, 0xeb, 0xdd, 0xe9, 
};
static const unsigned char big5_chars_ban1413 [] = {
    0xdd, 0xcc, 0xdd, 0xee, 
};
static const unsigned char big5_chars_ban1414 [] = {
    0xdd, 0xef, 0xdd, 0xf1, 0xb7, 0xac, 0xb7, 0xa4, 
};
static const unsigned char big5_chars_ban1415 [] = {
    0xd5, 0xb8, 0xdd, 0xd4, 0xdd, 0xe6, 0xdd, 0xd5, 0xb7, 0xa1, 
    0xb7, 0xb1, 0xdd, 0xed, 0xb7, 0xaf, 0xb7, 0xab, 0xdd, 0xca, 
    0xb7, 0xa3, 
};
static const unsigned char big5_chars_ban1416 [] = {
    0xdd, 0xcd, 0xb7, 0xb0, 
};
static const unsigned char big5_chars_ban1417 [] = {
    0xdd, 0xdd, 0xdd, 0xc9, 
};
static const unsigned char big5_chars_ban1418 [] = {
    0xb7, 0xa9, 0xdd, 0xe1, 0xdd, 0xd1, 0xb7, 0xaa, 0xdd, 0xda, 
    0xb7, 0x7e, 0xb4, 0xd8, 0xdd, 0xe3, 0xd9, 0xbf, 0xdd, 0xce, 
};
static const unsigned char big5_chars_ban1419 [] = {
    0xdd, 0xe8, 0xb7, 0xa5, 0xdd, 0xe5, 0xb7, 0xa2, 0xdd, 0xdf, 
    0xb7, 0xad, 0xdd, 0xd6, 0xdd, 0xf3, 
};
static const unsigned char big5_chars_ban1420 [] = {
    0xb7, 0xa7, 0xde, 0xc6, 
};
static const unsigned char big5_chars_ban1421 [] = {
    0xb7, 0xae, 
};
static const unsigned char big5_chars_ban1422 [] = {
    0xe2, 0x4a, 0xe2, 0x48, 
};
static const unsigned char big5_chars_ban1423 [] = {
    0xe2, 0x5e, 0xe2, 0x46, 
};
static const unsigned char big5_chars_ban1424 [] = {
    0xe2, 0x58, 0xb7, 0x7d, 0xba, 0x5f, 0xe2, 0x42, 0xe2, 0x5d, 
};
static const unsigned char big5_chars_ban1425 [] = {
    0xe2, 0x47, 0xe2, 0x55, 0xba, 0x64, 0xba, 0x5d, 
};
static const unsigned char big5_chars_ban1426 [] = {
    0xe2, 0x5b, 
};
static const unsigned char big5_chars_ban1427 [] = {
    0xe2, 0x40, 0xe2, 0x5a, 
};
static const unsigned char big5_chars_ban1428 [] = {
    0xba, 0x6f, 0xe2, 0x51, 0xe2, 0x61, 0xba, 0x6d, 0xe2, 0x49, 
    0xba, 0x5e, 0xe2, 0x4b, 0xe2, 0x59, 0xba, 0x67, 0xe2, 0x44, 
    0xba, 0x6b, 0xba, 0x61, 0xe2, 0x4d, 0xe2, 0x43, 0xe1, 0xfc, 
};
static const unsigned char big5_chars_ban1429 [] = {
    0xe2, 0x57, 0xba, 0x68, 0xe2, 0x60, 0xe1, 0xfd, 0xba, 0x65, 
};
static const unsigned char big5_chars_ban1430 [] = {
    0xe2, 0x53, 
};
static const unsigned char big5_chars_ban1431 [] = {
    0xba, 0x66, 0xe2, 0x45, 0xe2, 0x50, 0xe2, 0x4c, 0xe2, 0x4e, 
};
static const unsigned char big5_chars_ban1432 [] = {
    0xba, 0x60, 0xe2, 0x5f, 0xba, 0x6e, 0xe2, 0x4f, 
};
static const unsigned char big5_chars_ban1433 [] = {
    0xe2, 0x62, 
};
static const unsigned char big5_chars_ban1434 [] = {
    0xe1, 0xfe, 0xe2, 0x54, 0xba, 0x63, 0xba, 0x6c, 0xba, 0x6a, 
    0xe2, 0x41, 0xe2, 0x56, 0xba, 0x69, 
};
static const unsigned char big5_chars_ban1435 [] = {
    0xba, 0x62, 0xe2, 0x52, 
};
static const unsigned char big5_chars_ban1436 [] = {
    0xe2, 0x5c, 
};
static const unsigned char big5_chars_ban1437 [] = {
    0xe5, 0xd5, 
};
static const unsigned char big5_chars_ban1438 [] = {
    0xe5, 0xd1, 0xe5, 0xcd, 0xe5, 0xe1, 0xe5, 0xde, 0xbc, 0xcd, 
};
static const unsigned char big5_chars_ban1439 [] = {
    0xe5, 0xe5, 0xe5, 0xd4, 0xbc, 0xd8, 0xe5, 0xdb, 
};
static const unsigned char big5_chars_ban1440 [] = {
    0xe5, 0xd0, 0xe5, 0xda, 0xbc, 0xd5, 0xe5, 0xee, 
};
static const unsigned char big5_chars_ban1441 [] = {
    0xe5, 0xeb, 0xe5, 0xdd, 0xe5, 0xce, 
};
static const unsigned char big5_chars_ban1442 [] = {
    0xe5, 0xe2, 0xe5, 0xe4, 0xbc, 0xd1, 0xe5, 0xd8, 0xe5, 0xd3, 
    0xe5, 0xca, 0xbc, 0xce, 0xbc, 0xd6, 
};
static const unsigned char big5_chars_ban1443 [] = {
    0xe5, 0xe7, 0xbc, 0xd7, 0xe5, 0xcb, 0xe5, 0xed, 0xe5, 0xe0, 
    0xe5, 0xe6, 0xbc, 0xd4, 
};
static const unsigned char big5_chars_ban1444 [] = {
    0xe5, 0xe3, 
};
static const unsigned char big5_chars_ban1445 [] = {
    0xe5, 0xea, 
};
static const unsigned char big5_chars_ban1446 [] = {
    0xbc, 0xd9, 
};
static const unsigned char big5_chars_ban1447 [] = {
    0xbc, 0xd3, 0xe5, 0xdc, 0xe5, 0xcf, 0xe5, 0xef, 0xe5, 0xcc, 
    0xe5, 0xe8, 0xbc, 0xd0, 
};
static const unsigned char big5_chars_ban1448 [] = {
    0xe5, 0xd6, 
};
static const unsigned char big5_chars_ban1449 [] = {
    0xe5, 0xd7, 0xbc, 0xcf, 0xbc, 0xcc, 0xe5, 0xd2, 0xbc, 0xd2, 
};
static const unsigned char big5_chars_ban1450 [] = {
    0xbc, 0xcb, 
};
static const unsigned char big5_chars_ban1451 [] = {
    0xe5, 0xe9, 0xe5, 0xec, 0xe5, 0xd9, 0xe9, 0xca, 
};
static const unsigned char big5_chars_ban1452 [] = {
    0xe9, 0xc2, 
};
static const unsigned char big5_chars_ban1453 [] = {
    0xe9, 0xbe, 0xbe, 0xf6, 
};
static const unsigned char big5_chars_ban1454 [] = {
    0xbe, 0xeb, 0xbe, 0xf0, 0xbe, 0xec, 0xe9, 0xcc, 0xe9, 0xd7, 
    0xbe, 0xea, 0xe9, 0xc4, 0xe9, 0xcd, 0xe5, 0xdf, 0xe9, 0xce, 
};
static const unsigned char big5_chars_ban1455 [] = {
    0xbe, 0xf1, 
};
static const unsigned char big5_chars_ban1456 [] = {
    0xe9, 0xdd, 0xbe, 0xf5, 0xbe, 0xf8, 0xe9, 0xc0, 
};
static const unsigned char big5_chars_ban1457 [] = {
    0xbe, 0xf4, 
};
static const unsigned char big5_chars_ban1458 [] = {
    0xe9, 0xdb, 0xe9, 0xdc, 0xe9, 0xd2, 0xe9, 0xd1, 0xe9, 0xc9, 
};
static const unsigned char big5_chars_ban1459 [] = {
    0xe9, 0xd3, 0xe9, 0xda, 0xe9, 0xd9, 
};
static const unsigned char big5_chars_ban1460 [] = {
    0xbe, 0xef, 0xbe, 0xed, 0xe9, 0xcb, 0xe9, 0xc8, 
};
static const unsigned char big5_chars_ban1461 [] = {
    0xe9, 0xc5, 0xe9, 0xd8, 0xbe, 0xf7, 0xe9, 0xd6, 0xbe, 0xf3, 
    0xbe, 0xf2, 
};
static const unsigned char big5_chars_ban1462 [] = {
    0xe9, 0xd0, 
};
static const unsigned char big5_chars_ban1463 [] = {
    0xe9, 0xbf, 0xe9, 0xc1, 0xe9, 0xc3, 0xe9, 0xd5, 0xe9, 0xcf, 
    0xbe, 0xee, 
};
static const unsigned char big5_chars_ban1464 [] = {
    0xe9, 0xc6, 
};
static const unsigned char big5_chars_ban1465 [] = {
    0xe9, 0xd4, 
};
static const unsigned char big5_chars_ban1466 [] = {
    0xe9, 0xc7, 
};
static const unsigned char big5_chars_ban1467 [] = {
    0xc0, 0xcf, 0xed, 0x45, 0xc0, 0xc8, 0xec, 0xf5, 
};
static const unsigned char big5_chars_ban1468 [] = {
    0xed, 0x41, 0xc0, 0xca, 0xed, 0x48, 
};
static const unsigned char big5_chars_ban1469 [] = {
    0xec, 0xfc, 
};
static const unsigned char big5_chars_ban1470 [] = {
    0xec, 0xf7, 
};
static const unsigned char big5_chars_ban1471 [] = {
    0xed, 0x49, 0xec, 0xf3, 0xec, 0xfe, 
};
static const unsigned char big5_chars_ban1472 [] = {
    0xc0, 0xd1, 0xed, 0x44, 0xed, 0x4a, 0xec, 0xfd, 0xc0, 0xc9, 
    0xed, 0x40, 0xec, 0xf4, 0xc0, 0xd0, 
};
static const unsigned char big5_chars_ban1473 [] = {
    0xed, 0x47, 0xec, 0xf9, 0xc0, 0xcc, 
};
static const unsigned char big5_chars_ban1474 [] = {
    0xec, 0xfb, 0xec, 0xf8, 0xc0, 0xd2, 0xec, 0xfa, 0xc0, 0xcb, 
    0xc0, 0xce, 0xed, 0x43, 0xec, 0xf6, 0xed, 0x46, 
};
static const unsigned char big5_chars_ban1475 [] = {
    0xed, 0x42, 
};
static const unsigned char big5_chars_ban1476 [] = {
    0xc2, 0x63, 0xef, 0xe7, 0xc2, 0x68, 0xc2, 0x69, 
};
static const unsigned char big5_chars_ban1477 [] = {
    0xc2, 0x62, 0xef, 0xe6, 
};
static const unsigned char big5_chars_ban1478 [] = {
    0xef, 0xe3, 0xef, 0xe4, 0xc2, 0x66, 0xef, 0xde, 0xef, 0xe2, 
    0xc2, 0x65, 
};
static const unsigned char big5_chars_ban1479 [] = {
    0xef, 0xdf, 
};
static const unsigned char big5_chars_ban1480 [] = {
    0xc2, 0x67, 0xc2, 0x64, 
};
static const unsigned char big5_chars_ban1481 [] = {
    0xef, 0xdd, 0xef, 0xe1, 0xef, 0xe5, 
};
static const unsigned char big5_chars_ban1482 [] = {
    0xf2, 0x51, 0xf2, 0x4e, 0xf2, 0x57, 
};
static const unsigned char big5_chars_ban1483 [] = {
    0xf2, 0x56, 0xf2, 0x54, 0xf2, 0x4f, 
};
static const unsigned char big5_chars_ban1484 [] = {
    0xc3, 0x72, 
};
static const unsigned char big5_chars_ban1485 [] = {
    0xf2, 0x50, 0xc3, 0x71, 0xc0, 0xcd, 0xf2, 0x53, 0xc3, 0x70, 
    0xf2, 0x58, 0xf2, 0x52, 0xf2, 0x4d, 0xef, 0xe0, 
};
static const unsigned char big5_chars_ban1486 [] = {
    0xc3, 0x6f, 
};
static const unsigned char big5_chars_ban1487 [] = {
    0xf2, 0x4c, 0xf4, 0x56, 
};
static const unsigned char big5_chars_ban1488 [] = {
    0xf4, 0x55, 0xf2, 0x55, 0xc4, 0x68, 
};
static const unsigned char big5_chars_ban1489 [] = {
    0xf4, 0x59, 0xf4, 0x5a, 0xf4, 0x54, 0xf4, 0x58, 
};
static const unsigned char big5_chars_ban1490 [] = {
    0xf4, 0x53, 
};
static const unsigned char big5_chars_ban1491 [] = {
    0xf5, 0xd1, 0xf4, 0x57, 0xc4, 0xe7, 0xc4, 0xe5, 0xf5, 0xcf, 
};
static const unsigned char big5_chars_ban1492 [] = {
    0xf5, 0xd2, 
};
static const unsigned char big5_chars_ban1493 [] = {
    0xf5, 0xce, 0xf5, 0xd0, 0xc4, 0xe6, 
};
static const unsigned char big5_chars_ban1494 [] = {
    0xf6, 0xe5, 0xf6, 0xe6, 0xc5, 0x76, 0xf6, 0xe4, 
};
static const unsigned char big5_chars_ban1495 [] = {
    0xf7, 0xe2, 0xc5, 0xcf, 0xf7, 0xe0, 0xf7, 0xe1, 0xf8, 0xac, 
};
static const unsigned char big5_chars_ban1496 [] = {
    0xc6, 0x56, 0xf8, 0xf3, 0xf8, 0xf1, 0xf8, 0xf2, 0xf8, 0xf4, 
};
static const unsigned char big5_chars_ban1497 [] = {
    0xf9, 0xbb, 
};
static const unsigned char big5_chars_ban1498 [] = {
    0xa4, 0xed, 0xa6, 0xb8, 
};
static const unsigned char big5_chars_ban1499 [] = {
    0xaa, 0x59, 
};
static const unsigned char big5_chars_ban1500 [] = {
    0xcc, 0xe9, 
};
static const unsigned char big5_chars_ban1501 [] = {
    0xcf, 0x64, 
};
static const unsigned char big5_chars_ban1502 [] = {
    0xd1, 0xf5, 0xd1, 0xf7, 
};
static const unsigned char big5_chars_ban1503 [] = {
    0xd1, 0xf6, 
};
static const unsigned char big5_chars_ban1504 [] = {
    0xd1, 0xf8, 0xb1, 0xfd, 0xd5, 0xd7, 0xd1, 0xf9, 
};
static const unsigned char big5_chars_ban1505 [] = {
    0xd5, 0xd6, 0xd5, 0xd8, 0xd5, 0xd9, 0xd9, 0xda, 0xb4, 0xdb, 
    0xd9, 0xdb, 0xd9, 0xdd, 0xb4, 0xdc, 0xb4, 0xda, 0xd9, 0xdc, 
};
static const unsigned char big5_chars_ban1506 [] = {
    0xdd, 0xfa, 0xdd, 0xf8, 0xdd, 0xf7, 
};
static const unsigned char big5_chars_ban1507 [] = {
    0xdd, 0xf6, 0xdd, 0xf5, 0xb7, 0xb2, 0xdd, 0xf9, 0xba, 0x70, 
    0xe2, 0x63, 0xe2, 0x65, 0xba, 0x71, 0xe2, 0x64, 0xbc, 0xdb, 
};
static const unsigned char big5_chars_ban1508 [] = {
    0xbc, 0xda, 0xe5, 0xf0, 
};
static const unsigned char big5_chars_ban1509 [] = {
    0xe9, 0xdf, 0xe9, 0xde, 0xe9, 0xe0, 
};
static const unsigned char big5_chars_ban1510 [] = {
    0xbe, 0xf9, 
};
static const unsigned char big5_chars_ban1511 [] = {
    0xed, 0x4b, 0xc0, 0xd3, 
};
static const unsigned char big5_chars_ban1512 [] = {
    0xef, 0xe8, 0xc2, 0x6a, 0xf2, 0x59, 0xc5, 0x77, 0xa4, 0xee, 
    0xa5, 0xbf, 0xa6, 0xb9, 0xa8, 0x42, 0xaa, 0x5a, 0xaa, 0x5b, 
};
static const unsigned char big5_chars_ban1513 [] = {
    0xac, 0x6e, 
};
static const unsigned char big5_chars_ban1514 [] = {
    0xd1, 0xfa, 
};
static const unsigned char big5_chars_ban1515 [] = {
    0xb7, 0xb3, 
};
static const unsigned char big5_chars_ban1516 [] = {
    0xe6, 0xd1, 0xbe, 0xfa, 0xc2, 0x6b, 0xa4, 0xef, 
};
static const unsigned char big5_chars_ban1517 [] = {
    0xa6, 0xba, 
};
static const unsigned char big5_chars_ban1518 [] = {
    0xcc, 0xeb, 0xaa, 0x5c, 0xcc, 0xea, 
};
static const unsigned char big5_chars_ban1519 [] = {
    0xcf, 0x65, 0xac, 0x6f, 0xcf, 0x66, 
};
static const unsigned char big5_chars_ban1520 [] = {
    0xac, 0x70, 
};
static const unsigned char big5_chars_ban1521 [] = {
    0xd1, 0xfc, 0xae, 0xee, 0xae, 0xed, 
};
static const unsigned char big5_chars_ban1522 [] = {
    0xd5, 0xde, 0xd5, 0xdc, 0xd5, 0xdd, 0xd5, 0xdb, 
};
static const unsigned char big5_chars_ban1523 [] = {
    0xd5, 0xda, 
};
static const unsigned char big5_chars_ban1524 [] = {
    0xd9, 0xde, 0xd9, 0xe1, 0xb4, 0xde, 0xd9, 0xdf, 0xb4, 0xdd, 
    0xd9, 0xe0, 
};
static const unsigned char big5_chars_ban1525 [] = {
    0xdd, 0xfb, 
};
static const unsigned char big5_chars_ban1526 [] = {
    0xe2, 0x66, 0xe2, 0x67, 0xe2, 0x68, 
};
static const unsigned char big5_chars_ban1527 [] = {
    0xe5, 0xf3, 0xe5, 0xf2, 0xbc, 0xdc, 0xe5, 0xf1, 0xe5, 0xf4, 
    0xe9, 0xe1, 
};
static const unsigned char big5_chars_ban1528 [] = {
    0xe9, 0xe2, 0xe9, 0xe3, 
};
static const unsigned char big5_chars_ban1529 [] = {
    0xed, 0x4c, 0xc0, 0xd4, 0xc2, 0x6c, 0xf2, 0x5a, 
};
static const unsigned char big5_chars_ban1530 [] = {
    0xc4, 0xe8, 0xc9, 0x5f, 
};
static const unsigned char big5_chars_ban1531 [] = {
    0xac, 0x71, 0xcf, 0x67, 0xae, 0xef, 
};
static const unsigned char big5_chars_ban1532 [] = {
    0xb1, 0xfe, 
};
static const unsigned char big5_chars_ban1533 [] = {
    0xb4, 0xdf, 0xd9, 0xe2, 
};
static const unsigned char big5_chars_ban1534 [] = {
    0xb7, 0xb5, 0xb7, 0xb4, 
};
static const unsigned char big5_chars_ban1535 [] = {
    0xe2, 0x69, 0xe2, 0x6a, 0xbc, 0xdd, 0xbc, 0xde, 0xe9, 0xe5, 
    0xe9, 0xe4, 0xef, 0xe9, 0xf7, 0xe3, 0xa4, 0xf0, 0xc9, 0x60, 
    0xa5, 0xc0, 
};
static const unsigned char big5_chars_ban1536 [] = {
    0xa8, 0x43, 0xcb, 0x48, 
};
static const unsigned char big5_chars_ban1537 [] = {
    0xac, 0x72, 0xb7, 0xb6, 0xa4, 0xf1, 
};
static const unsigned char big5_chars_ban1538 [] = {
    0xcf, 0x68, 0xac, 0x73, 0xcf, 0x69, 
};
static const unsigned char big5_chars_ban1539 [] = {
    0xc0, 0xd5, 0xa4, 0xf2, 
};
static const unsigned char big5_chars_ban1540 [] = {
    0xcc, 0xec, 
};
static const unsigned char big5_chars_ban1541 [] = {
    0xcf, 0x6a, 
};
static const unsigned char big5_chars_ban1542 [] = {
    0xd2, 0x42, 0xd2, 0x41, 0xd1, 0xfe, 
};
static const unsigned char big5_chars_ban1543 [] = {
    0xd1, 0xfd, 0xd2, 0x43, 0xd2, 0x40, 
};
static const unsigned char big5_chars_ban1544 [] = {
    0xb2, 0x40, 0xb2, 0x41, 
};
static const unsigned char big5_chars_ban1545 [] = {
    0xb4, 0xe0, 0xd9, 0xe3, 
};
static const unsigned char big5_chars_ban1546 [] = {
    0xd9, 0xe4, 0xd9, 0xe5, 
};
static const unsigned char big5_chars_ban1547 [] = {
    0xde, 0x41, 0xde, 0x42, 0xde, 0x40, 
};
static const unsigned char big5_chars_ban1548 [] = {
    0xdd, 0xfd, 0xdd, 0xfe, 0xb7, 0xb7, 0xe2, 0x6b, 0xe5, 0xf7, 
    0xe5, 0xf6, 0xe5, 0xf5, 0xe5, 0xf8, 0xe9, 0xe7, 0xe9, 0xe6, 
    0xbe, 0xfb, 0xe9, 0xe8, 
};
static const unsigned char big5_chars_ban1549 [] = {
    0xc0, 0xd6, 0xed, 0x4d, 
};
static const unsigned char big5_chars_ban1550 [] = {
    0xef, 0xea, 0xf2, 0x5b, 0xf6, 0xe7, 
};
static const unsigned char big5_chars_ban1551 [] = {
    0xa4, 0xf3, 0xa5, 0xc2, 0xa5, 0xc1, 
};
static const unsigned char big5_chars_ban1552 [] = {
    0xaa, 0x5d, 0xc9, 0x61, 0xc9, 0x7e, 0xa6, 0xbb, 
};
static const unsigned char big5_chars_ban1553 [] = {
    0xc9, 0xf7, 0xcb, 0x49, 0xcb, 0x4a, 0xaa, 0x5e, 
};
static const unsigned char big5_chars_ban1554 [] = {
    0xcc, 0xed, 
};
static const unsigned char big5_chars_ban1555 [] = {
    0xac, 0x74, 0xcf, 0x6b, 0xcf, 0x6c, 
};
static const unsigned char big5_chars_ban1556 [] = {
    0xae, 0xf0, 0xae, 0xf4, 0xd2, 0x44, 0xae, 0xf3, 0xae, 0xf1, 
    0xae, 0xf2, 
};
static const unsigned char big5_chars_ban1557 [] = {
    0xd5, 0xdf, 0xb2, 0x42, 0xb4, 0xe3, 
};
static const unsigned char big5_chars_ban1558 [] = {
    0xb4, 0xe1, 0xb4, 0xe2, 0xd9, 0xe6, 
};
static const unsigned char big5_chars_ban1559 [] = {
    0xba, 0x72, 0xa4, 0xf4, 
};
static const unsigned char big5_chars_ban1560 [] = {
    0xc9, 0xa1, 
};
static const unsigned char big5_chars_ban1561 [] = {
    0xa5, 0xc3, 
};
static const unsigned char big5_chars_ban1562 [] = {
    0xc9, 0xa4, 
};
static const unsigned char big5_chars_ban1563 [] = {
    0xa5, 0xc6, 0xc9, 0xa3, 0xa5, 0xc5, 0xa5, 0xc4, 0xa8, 0x44, 
    0xc9, 0xa2, 
};
static const unsigned char big5_chars_ban1564 [] = {
    0xc9, 0xf8, 
};
static const unsigned char big5_chars_ban1565 [] = {
    0xc9, 0xfc, 0xc9, 0xfe, 0xca, 0x40, 0xa6, 0xc5, 0xa6, 0xc6, 
    0xc9, 0xfb, 0xa6, 0xc1, 
};
static const unsigned char big5_chars_ban1566 [] = {
    0xc9, 0xf9, 
};
static const unsigned char big5_chars_ban1567 [] = {
    0xc9, 0xfd, 0xa6, 0xc2, 
};
static const unsigned char big5_chars_ban1568 [] = {
    0xa6, 0xbd, 
};
static const unsigned char big5_chars_ban1569 [] = {
    0xa6, 0xbe, 
};
static const unsigned char big5_chars_ban1570 [] = {
    0xa6, 0xc4, 0xc9, 0xfa, 0xa6, 0xbc, 0xa8, 0x45, 0xa6, 0xbf, 
    0xa6, 0xc0, 0xa6, 0xc3, 
};
static const unsigned char big5_chars_ban1571 [] = {
    0xcb, 0x5b, 0xcb, 0x59, 0xcb, 0x4c, 0xa8, 0x51, 0xcb, 0x53, 
    0xa8, 0x4c, 0xcb, 0x4d, 
};
static const unsigned char big5_chars_ban1572 [] = {
    0xcb, 0x55, 
};
static const unsigned char big5_chars_ban1573 [] = {
    0xcb, 0x52, 0xa8, 0x4f, 0xcb, 0x51, 0xa8, 0x56, 0xcb, 0x5a, 
    0xa8, 0x58, 
};
static const unsigned char big5_chars_ban1574 [] = {
    0xa8, 0x5a, 
};
static const unsigned char big5_chars_ban1575 [] = {
    0xcb, 0x4b, 
};
static const unsigned char big5_chars_ban1576 [] = {
    0xa8, 0x4d, 0xcb, 0x5c, 
};
static const unsigned char big5_chars_ban1577 [] = {
    0xa8, 0x54, 0xa8, 0x57, 
};
static const unsigned char big5_chars_ban1578 [] = {
    0xcd, 0x45, 0xa8, 0x47, 0xa8, 0x5e, 0xa8, 0x55, 0xcb, 0x4e, 
    0xa8, 0x4a, 0xa8, 0x59, 0xcb, 0x56, 0xa8, 0x48, 0xa8, 0x49, 
    0xcd, 0x43, 0xcb, 0x4f, 0xa8, 0x50, 0xa8, 0x5b, 0xcb, 0x5d, 
    0xcb, 0x50, 0xa8, 0x4e, 
};
static const unsigned char big5_chars_ban1579 [] = {
    0xa8, 0x53, 0xcc, 0xee, 0xa8, 0x5c, 0xcb, 0x57, 0xa8, 0x52, 
};
static const unsigned char big5_chars_ban1580 [] = {
    0xa8, 0x5d, 0xa8, 0x46, 0xcb, 0x54, 0xa8, 0x4b, 0xcb, 0x58, 
    0xcd, 0x44, 
};
static const unsigned char big5_chars_ban1581 [] = {
    0xaa, 0x6a, 0xaa, 0x7a, 0xcc, 0xf5, 0xaa, 0x71, 
};
static const unsigned char big5_chars_ban1582 [] = {
    0xcd, 0x4b, 0xaa, 0x62, 
};
static const unsigned char big5_chars_ban1583 [] = {
    0xaa, 0x65, 0xcd, 0x42, 
};
static const unsigned char big5_chars_ban1584 [] = {
    0xcc, 0xf3, 0xcc, 0xf7, 0xaa, 0x6d, 0xaa, 0x6f, 0xcc, 0xfa, 
    0xaa, 0x76, 0xaa, 0x68, 0xaa, 0x66, 0xaa, 0x67, 0xaa, 0x75, 
    0xcd, 0x47, 0xaa, 0x70, 0xcc, 0xf9, 0xcc, 0xfb, 0xaa, 0x6e, 
    0xaa, 0x73, 0xcc, 0xfc, 0xcd, 0x4a, 
};
static const unsigned char big5_chars_ban1585 [] = {
    0xac, 0x75, 0xaa, 0x79, 
};
static const unsigned char big5_chars_ban1586 [] = {
    0xaa, 0x63, 0xcd, 0x49, 
};
static const unsigned char big5_chars_ban1587 [] = {
    0xcd, 0x4d, 0xcc, 0xf8, 0xcd, 0x4f, 0xcd, 0x40, 0xaa, 0x6c, 
    0xcc, 0xf4, 0xaa, 0x6b, 0xaa, 0x7d, 0xaa, 0x72, 
};
static const unsigned char big5_chars_ban1588 [] = {
    0xcc, 0xf2, 0xcf, 0x75, 0xaa, 0x78, 0xaa, 0x7c, 0xcd, 0x41, 
    0xcd, 0x46, 
};
static const unsigned char big5_chars_ban1589 [] = {
    0xaa, 0x7e, 0xaa, 0x77, 0xaa, 0x69, 0xaa, 0x5f, 
};
static const unsigned char big5_chars_ban1590 [] = {
    0xaa, 0x64, 
};
static const unsigned char big5_chars_ban1591 [] = {
    0xcc, 0xf6, 0xaa, 0x60, 0xcd, 0x4e, 
};
static const unsigned char big5_chars_ban1592 [] = {
    0xcc, 0xf0, 0xcc, 0xef, 0xcc, 0xfd, 0xcc, 0xf1, 0xaa, 0x7b, 
    0xae, 0xf5, 0xaa, 0x74, 0xcc, 0xfe, 0xaa, 0x61, 
};
static const unsigned char big5_chars_ban1593 [] = {
    0xac, 0xa6, 
};
static const unsigned char big5_chars_ban1594 [] = {
    0xcd, 0x4c, 
};
static const unsigned char big5_chars_ban1595 [] = {
    0xcf, 0x7c, 0xcf, 0xa1, 
};
static const unsigned char big5_chars_ban1596 [] = {
    0xcf, 0xa4, 0xcf, 0x77, 
};
static const unsigned char big5_chars_ban1597 [] = {
    0xcf, 0xa7, 0xcf, 0xaa, 0xcf, 0xac, 0xcf, 0x74, 0xac, 0x76, 
    0xac, 0x7b, 0xd2, 0x49, 0xac, 0xad, 0xcf, 0xa5, 0xcf, 0xad, 
    0xcf, 0x7b, 0xcf, 0x73, 
};
static const unsigned char big5_chars_ban1598 [] = {
    0xd2, 0x64, 0xac, 0x7e, 0xcf, 0xa2, 0xcf, 0x78, 0xcf, 0x7a, 
    0xac, 0xa5, 
};
static const unsigned char big5_chars_ban1599 [] = {
    0xcf, 0x7d, 0xac, 0x7d, 0xcf, 0x70, 0xcf, 0xa8, 
};
static const unsigned char big5_chars_ban1600 [] = {
    0xcf, 0xab, 
};
static const unsigned char big5_chars_ban1601 [] = {
    0xac, 0x7a, 
};
static const unsigned char big5_chars_ban1602 [] = {
    0xac, 0xa8, 0xcf, 0x6d, 0xac, 0xaa, 0xac, 0x78, 0xac, 0xae, 
    0xcf, 0xa9, 0xcf, 0x6f, 0xac, 0xab, 0xd2, 0x5e, 0xcd, 0x48, 
    0xac, 0x7c, 0xac, 0x77, 0xcf, 0x76, 0xcf, 0x6e, 0xac, 0xac, 
    0xac, 0xa4, 0xcf, 0xa3, 0xac, 0xa9, 0xac, 0xa7, 0xcf, 0x79, 
    0xac, 0xa1, 0xcf, 0x71, 0xac, 0xa2, 0xac, 0xa3, 0xcf, 0x72, 
    0xcf, 0xa6, 0xac, 0x79, 0xcf, 0x7e, 
};
static const unsigned char big5_chars_ban1603 [] = {
    0xd2, 0x4c, 0xae, 0xfd, 0xaf, 0x43, 
};
static const unsigned char big5_chars_ban1604 [] = {
    0xd2, 0x55, 0xd2, 0x5b, 0xd2, 0x57, 0xd2, 0x4a, 0xd2, 0x4d, 
    0xd2, 0x46, 0xd2, 0x47, 0xaf, 0x4a, 0xae, 0xfa, 0xd2, 0x56, 
    0xd2, 0x5f, 0xaf, 0x45, 0xae, 0xf6, 
};
static const unsigned char big5_chars_ban1605 [] = {
    0xaf, 0x40, 0xd2, 0x4e, 0xaf, 0x42, 0xd2, 0x4f, 0xd2, 0x59, 
};
static const unsigned char big5_chars_ban1606 [] = {
    0xaf, 0x44, 0xd2, 0x68, 0xd2, 0x48, 0xae, 0xfc, 0xae, 0xfb, 
    0xaf, 0x48, 0xd2, 0x45, 0xd2, 0x66, 0xd2, 0x5a, 0xd2, 0x67, 
    0xd2, 0x61, 0xd2, 0x53, 0xd2, 0x62, 
};
static const unsigned char big5_chars_ban1607 [] = {
    0xd2, 0x5c, 0xd2, 0x65, 0xd2, 0x63, 0xaf, 0x49, 0xd2, 0x54, 
    0xae, 0xf9, 0xae, 0xf8, 0xaf, 0x41, 0xaf, 0x47, 0xd2, 0x60, 
    0xaf, 0x46, 0xd2, 0x51, 0xb2, 0x43, 
};
static const unsigned char big5_chars_ban1608 [] = {
    0xd2, 0x69, 0xd2, 0x50, 0xd2, 0x4b, 0xae, 0xfe, 0xaf, 0x4b, 
    0xae, 0xf7, 
};
static const unsigned char big5_chars_ban1609 [] = {
    0xd2, 0x58, 0xd2, 0x5d, 
};
static const unsigned char big5_chars_ban1610 [] = {
    0xb2, 0x65, 0xd5, 0xe1, 0xd5, 0xe5, 
};
static const unsigned char big5_chars_ban1611 [] = {
    0xb2, 0x52, 0xb2, 0x50, 
};
static const unsigned char big5_chars_ban1612 [] = {
    0xb2, 0x47, 0xd5, 0xe3, 0xd5, 0xe2, 0xb2, 0x5b, 
};
static const unsigned char big5_chars_ban1613 [] = {
    0xd5, 0xe8, 0xb2, 0x55, 
};
static const unsigned char big5_chars_ban1614 [] = {
    0xd5, 0xfa, 0xd6, 0x47, 0xb2, 0x44, 0xd5, 0xf7, 0xd5, 0xf0, 
    0xb2, 0x67, 0xd5, 0xe0, 
};
static const unsigned char big5_chars_ban1615 [] = {
    0xd5, 0xfc, 
};
static const unsigned char big5_chars_ban1616 [] = {
    0xb2, 0x64, 0xb2, 0x58, 0xb2, 0x63, 0xb2, 0x4e, 0xd5, 0xec, 
    0xd5, 0xfe, 0xd5, 0xf6, 0xb2, 0x4f, 0xb2, 0x49, 0xd6, 0x45, 
};
static const unsigned char big5_chars_ban1617 [] = {
    0xd5, 0xfd, 0xd6, 0x40, 0xb2, 0x51, 0xb2, 0x59, 0xd6, 0x42, 
    0xd5, 0xea, 0xd5, 0xfb, 0xd5, 0xef, 0xd6, 0x44, 0xb2, 0x5e, 
    0xb2, 0x46, 0xb2, 0x5c, 0xd5, 0xf4, 0xd5, 0xf2, 0xd5, 0xf3, 
    0xb2, 0x53, 0xd5, 0xee, 0xd5, 0xed, 0xb2, 0x48, 0xd5, 0xe7, 
    0xd6, 0x46, 0xb2, 0x4a, 0xd5, 0xf1, 0xb2, 0x68, 
};
static const unsigned char big5_chars_ban1618 [] = {
    0xb2, 0x62, 0xd5, 0xe6, 0xb2, 0x5f, 0xb2, 0x5d, 0xb2, 0x66, 
    0xd5, 0xf8, 0xb2, 0x61, 0xd2, 0x52, 0xd5, 0xf9, 0xb2, 0x60, 
    0xd6, 0x41, 0xb2, 0x45, 0xd5, 0xf5, 0xb2, 0x57, 0xd5, 0xe9, 
    0xb2, 0x56, 
};
static const unsigned char big5_chars_ban1619 [] = {
    0xb2, 0x54, 0xb2, 0x4c, 0xb2, 0x4b, 0xd9, 0xe7, 0xd6, 0x43, 
};
static const unsigned char big5_chars_ban1620 [] = {
    0xd5, 0xeb, 
};
static const unsigned char big5_chars_ban1621 [] = {
    0xd9, 0xfc, 
};
static const unsigned char big5_chars_ban1622 [] = {
    0xb2, 0x4d, 
};
static const unsigned char big5_chars_ban1623 [] = {
    0xb5, 0x41, 0xb2, 0x5a, 0xb4, 0xee, 0xd9, 0xf6, 0xb4, 0xfc, 
};
static const unsigned char big5_chars_ban1624 [] = {
    0xd9, 0xea, 0xb4, 0xeb, 0xb4, 0xe7, 0xda, 0x49, 0xb4, 0xed, 
    0xb4, 0xf1, 0xb4, 0xec, 0xb4, 0xf5, 0xda, 0x4d, 0xda, 0x44, 
};
static const unsigned char big5_chars_ban1625 [] = {
    0xd9, 0xf1, 0xb4, 0xfa, 0xb4, 0xf4, 0xd9, 0xfd, 0xb4, 0xe4, 
    0xda, 0x4a, 0xda, 0x43, 0xb4, 0xe8, 0xd9, 0xf7, 0xb4, 0xf7, 
    0xda, 0x55, 0xda, 0x56, 
};
static const unsigned char big5_chars_ban1626 [] = {
    0xb4, 0xe5, 0xda, 0x48, 0xb4, 0xf9, 0xd9, 0xfb, 0xd9, 0xed, 
    0xd9, 0xee, 0xb4, 0xfd, 0xd9, 0xf2, 0xd9, 0xf9, 0xd9, 0xf3, 
};
static const unsigned char big5_chars_ban1627 [] = {
    0xb4, 0xfb, 0xb5, 0x44, 0xd9, 0xef, 0xd9, 0xe8, 0xd9, 0xe9, 
};
static const unsigned char big5_chars_ban1628 [] = {
    0xd9, 0xeb, 0xb4, 0xea, 0xd9, 0xf8, 
};
static const unsigned char big5_chars_ban1629 [] = {
    0xb4, 0xf8, 0xb5, 0x42, 
};
static const unsigned char big5_chars_ban1630 [] = {
    0xd9, 0xfa, 0xda, 0x53, 0xda, 0x4b, 0xb4, 0xe6, 0xda, 0x51, 
    0xb4, 0xf2, 
};
static const unsigned char big5_chars_ban1631 [] = {
    0xb4, 0xf0, 
};
static const unsigned char big5_chars_ban1632 [] = {
    0xda, 0x57, 0xb4, 0xef, 0xda, 0x41, 0xd9, 0xf4, 0xd9, 0xfe, 
    0xb5, 0x47, 0xda, 0x45, 0xda, 0x42, 0xd9, 0xf0, 0xb5, 0x43, 
    0xda, 0x4f, 0xda, 0x4c, 0xda, 0x54, 0xb4, 0xe9, 0xda, 0x40, 
    0xb5, 0x46, 
};
static const unsigned char big5_chars_ban1633 [] = {
    0xda, 0x47, 
};
static const unsigned char big5_chars_ban1634 [] = {
    0xb4, 0xf3, 0xb4, 0xf6, 
};
static const unsigned char big5_chars_ban1635 [] = {
    0xda, 0x46, 0xb5, 0x45, 0xd9, 0xf5, 0xd5, 0xe4, 
};
static const unsigned char big5_chars_ban1636 [] = {
    0xda, 0x50, 0xda, 0x4e, 0xda, 0x52, 
};
static const unsigned char big5_chars_ban1637 [] = {
    0xd9, 0xec, 0xb5, 0x40, 
};
static const unsigned char big5_chars_ban1638 [] = {
    0xde, 0x61, 0xde, 0x60, 0xde, 0x46, 0xb7, 0xbd, 
};
static const unsigned char big5_chars_ban1639 [] = {
    0xde, 0x5f, 0xde, 0x49, 0xde, 0x4a, 
};
static const unsigned char big5_chars_ban1640 [] = {
    0xb7, 0xc7, 0xde, 0x68, 0xb7, 0xc2, 0xde, 0x5e, 
};
static const unsigned char big5_chars_ban1641 [] = {
    0xde, 0x43, 0xb7, 0xc8, 0xb7, 0xbe, 0xde, 0x52, 0xde, 0x48, 
    0xde, 0x4b, 0xde, 0x63, 0xb7, 0xb8, 0xde, 0x6a, 0xde, 0x62, 
    0xb7, 0xc1, 0xde, 0x57, 0xb7, 0xcc, 
};
static const unsigned char big5_chars_ban1642 [] = {
    0xb7, 0xcb, 0xb7, 0xc5, 
};
static const unsigned char big5_chars_ban1643 [] = {
    0xde, 0x69, 0xb7, 0xb9, 0xde, 0x55, 0xde, 0x4c, 0xde, 0x59, 
    0xde, 0x65, 0xb7, 0xcd, 
};
static const unsigned char big5_chars_ban1644 [] = {
    0xb7, 0xbb, 0xde, 0x54, 
};
static const unsigned char big5_chars_ban1645 [] = {
    0xde, 0x4d, 0xb7, 0xc4, 
};
static const unsigned char big5_chars_ban1646 [] = {
    0xb7, 0xc3, 0xde, 0x50, 0xde, 0x5a, 0xde, 0x64, 0xde, 0x47, 
    0xde, 0x51, 0xb7, 0xbc, 0xde, 0x5b, 0xb7, 0xc9, 0xb7, 0xc0, 
    0xde, 0x4e, 0xb7, 0xbf, 0xde, 0x45, 0xde, 0x53, 0xde, 0x67, 
    0xb4, 0xfe, 0xba, 0xb0, 0xde, 0x56, 0xe2, 0x6c, 0xde, 0x58, 
    0xde, 0x66, 0xb7, 0xc6, 0xde, 0x4f, 0xb7, 0xba, 0xb7, 0xca, 
    0xbc, 0xf0, 0xde, 0x44, 
};
static const unsigned char big5_chars_ban1647 [] = {
    0xde, 0x5d, 
};
static const unsigned char big5_chars_ban1648 [] = {
    0xde, 0x5c, 
};
static const unsigned char big5_chars_ban1649 [] = {
    0xe2, 0xaa, 0xba, 0xad, 0xe2, 0x7d, 0xe2, 0xa4, 0xba, 0xa2, 
};
static const unsigned char big5_chars_ban1650 [] = {
    0xe2, 0x6e, 0xba, 0xaf, 
};
static const unsigned char big5_chars_ban1651 [] = {
    0xba, 0x77, 0xe2, 0x6d, 0xe2, 0xb0, 0xba, 0xb1, 0xe2, 0x71, 
    0xe2, 0xa3, 
};
static const unsigned char big5_chars_ban1652 [] = {
    0xe2, 0x73, 0xe2, 0xb3, 0xe2, 0xaf, 0xba, 0x75, 0xba, 0xa1, 
    0xe6, 0x53, 0xba, 0xae, 0xba, 0x7d, 0xe2, 0x6f, 
};
static const unsigned char big5_chars_ban1653 [] = {
    0xe2, 0xae, 0xba, 0xa3, 0xe2, 0xab, 0xe2, 0xb8, 0xe2, 0x75, 
    0xe2, 0x7e, 
};
static const unsigned char big5_chars_ban1654 [] = {
    0xe2, 0xb6, 0xe2, 0xac, 0xba, 0x7c, 
};
static const unsigned char big5_chars_ban1655 [] = {
    0xe2, 0x7c, 0xba, 0x76, 0xba, 0x74, 0xba, 0xa8, 
};
static const unsigned char big5_chars_ban1656 [] = {
    0xe2, 0x7a, 0xe2, 0x77, 0xe2, 0x78, 
};
static const unsigned char big5_chars_ban1657 [] = {
    0xe2, 0xb2, 
};
static const unsigned char big5_chars_ban1658 [] = {
    0xe2, 0xb7, 0xe2, 0xb5, 0xba, 0x7a, 0xe2, 0xb9, 0xba, 0x7e, 
    0xba, 0xa7, 
};
static const unsigned char big5_chars_ban1659 [] = {
    0xe2, 0x70, 0xe5, 0xfa, 0xe2, 0x79, 
};
static const unsigned char big5_chars_ban1660 [] = {
    0xba, 0x78, 0xba, 0xac, 0xba, 0xa9, 0xba, 0x7b, 0xe2, 0xa5, 
    0xe2, 0x74, 0xba, 0xaa, 0xe2, 0xa7, 0xba, 0xa4, 0xba, 0xa6, 
    0xba, 0x73, 
};
static const unsigned char big5_chars_ban1661 [] = {
    0xe2, 0xa9, 0xe2, 0xa1, 0xe2, 0x72, 0xba, 0xa5, 0xe2, 0xb1, 
    0xe2, 0xb4, 0xe2, 0x7b, 0xe2, 0xa8, 
};
static const unsigned char big5_chars_ban1662 [] = {
    0xba, 0x79, 0xbc, 0xdf, 0xe2, 0xa6, 0xe5, 0xf9, 
};
static const unsigned char big5_chars_ban1663 [] = {
    0xe2, 0xad, 
};
static const unsigned char big5_chars_ban1664 [] = {
    0xe2, 0x76, 0xe6, 0x44, 0xe6, 0x4e, 0xbc, 0xe2, 0xe6, 0x4d, 
    0xe6, 0x59, 0xbc, 0xe4, 0xe6, 0x4b, 
};
static const unsigned char big5_chars_ban1665 [] = {
    0xe6, 0x4f, 0xbc, 0xef, 
};
static const unsigned char big5_chars_ban1666 [] = {
    0xe6, 0x46, 0xbc, 0xe7, 
};
static const unsigned char big5_chars_ban1667 [] = {
    0xe6, 0x52, 0xe9, 0xf0, 0xbc, 0xf3, 0xbc, 0xf2, 0xe6, 0x54, 
    0xe6, 0x43, 0xe6, 0x5e, 0xbc, 0xed, 
};
static const unsigned char big5_chars_ban1668 [] = {
    0xbc, 0xe3, 0xe6, 0x57, 
};
static const unsigned char big5_chars_ban1669 [] = {
    0xe6, 0x5b, 0xe6, 0x60, 0xe6, 0x55, 0xe6, 0x49, 0xbc, 0xe6, 
    0xbc, 0xe9, 0xbc, 0xf1, 0xbc, 0xec, 
};
static const unsigned char big5_chars_ban1670 [] = {
    0xe6, 0x4c, 0xe2, 0xa2, 
};
static const unsigned char big5_chars_ban1671 [] = {
    0xe6, 0x48, 0xe6, 0x5f, 0xbc, 0xe8, 
};
static const unsigned char big5_chars_ban1672 [] = {
    0xbc, 0xeb, 0xe6, 0x61, 0xbc, 0xe0, 0xe6, 0x56, 0xe5, 0xfb, 
    0xe6, 0x5c, 0xc0, 0xdf, 
};
static const unsigned char big5_chars_ban1673 [] = {
    0xe6, 0x4a, 
};
static const unsigned char big5_chars_ban1674 [] = {
    0xbc, 0xe1, 0xe6, 0x45, 0xbc, 0xe5, 0xe5, 0xfc, 0xba, 0xab, 
    0xe6, 0x41, 
};
static const unsigned char big5_chars_ban1675 [] = {
    0xe6, 0x5a, 0xe6, 0x42, 0xe6, 0x40, 0xbc, 0xea, 
};
static const unsigned char big5_chars_ban1676 [] = {
    0xe6, 0x58, 
};
static const unsigned char big5_chars_ban1677 [] = {
    0xe5, 0xfe, 0xe6, 0x51, 0xe6, 0x50, 0xe6, 0x5d, 0xe6, 0x47, 
    0xbc, 0xee, 
};
static const unsigned char big5_chars_ban1678 [] = {
    0xe9, 0xf3, 
};
static const unsigned char big5_chars_ban1679 [] = {
    0xbf, 0x49, 0xbe, 0xfe, 0xea, 0x40, 0xe9, 0xeb, 0xbf, 0x41, 
    0xe9, 0xf7, 0xbf, 0x48, 0xbf, 0x43, 0xe9, 0xf5, 0xed, 0x4f, 
    0xe9, 0xfb, 0xea, 0x42, 0xe9, 0xfa, 0xe9, 0xe9, 0xe9, 0xf8, 
    0xea, 0x44, 0xea, 0x46, 0xbe, 0xfd, 0xea, 0x45, 0xbf, 0x44, 
    0xbf, 0x4a, 
};
static const unsigned char big5_chars_ban1680 [] = {
    0xbf, 0x47, 
};
static const unsigned char big5_chars_ban1681 [] = {
    0xe9, 0xfe, 0xbf, 0x46, 0xe9, 0xf9, 
};
static const unsigned char big5_chars_ban1682 [] = {
    0xe9, 0xed, 0xe9, 0xf2, 
};
static const unsigned char big5_chars_ban1683 [] = {
    0xe9, 0xfd, 0xbf, 0x45, 0xbf, 0x42, 0xbe, 0xfc, 0xbf, 0x40, 
    0xe9, 0xf1, 
};
static const unsigned char big5_chars_ban1684 [] = {
    0xe5, 0xfd, 0xe9, 0xec, 0xe9, 0xef, 0xea, 0x41, 0xe9, 0xf4, 
    0xe9, 0xea, 0xed, 0x4e, 0xea, 0x43, 0xe9, 0xee, 0xe9, 0xfc, 
};
static const unsigned char big5_chars_ban1685 [] = {
    0xed, 0x51, 0xc0, 0xe3, 
};
static const unsigned char big5_chars_ban1686 [] = {
    0xc0, 0xd7, 
};
static const unsigned char big5_chars_ban1687 [] = {
    0xc0, 0xdb, 0xed, 0x53, 0xed, 0x59, 0xed, 0x57, 0xc0, 0xd9, 
    0xc0, 0xda, 0xc0, 0xe1, 0xed, 0x5a, 0xed, 0x52, 0xc0, 0xdc, 
};
static const unsigned char big5_chars_ban1688 [] = {
    0xed, 0x56, 0xed, 0x55, 0xed, 0x5b, 0xc0, 0xe2, 
};
static const unsigned char big5_chars_ban1689 [] = {
    0xc0, 0xdd, 0xc0, 0xe0, 0xed, 0x54, 0xc0, 0xe4, 0xc0, 0xde, 
    0xc0, 0xe5, 0xc0, 0xd8, 0xed, 0x58, 
};
static const unsigned char big5_chars_ban1690 [] = {
    0xed, 0x50, 
};
static const unsigned char big5_chars_ban1691 [] = {
    0xef, 0xf7, 
};
static const unsigned char big5_chars_ban1692 [] = {
    0xc2, 0x71, 0xef, 0xf4, 0xef, 0xf6, 
};
static const unsigned char big5_chars_ban1693 [] = {
    0xc2, 0x6f, 0xef, 0xf2, 0xef, 0xf3, 0xef, 0xee, 
};
static const unsigned char big5_chars_ban1694 [] = {
    0xe9, 0xf6, 0xef, 0xef, 0xc2, 0x70, 0xef, 0xeb, 
};
static const unsigned char big5_chars_ban1695 [] = {
    0xc2, 0x6d, 0xef, 0xf8, 0xc2, 0x6e, 0xef, 0xec, 0xef, 0xed, 
    0xef, 0xf1, 0xc2, 0x73, 
};
static const unsigned char big5_chars_ban1696 [] = {
    0xc2, 0x72, 
};
static const unsigned char big5_chars_ban1697 [] = {
    0xef, 0xf0, 0xc3, 0x78, 0xf2, 0x5f, 0xf2, 0x65, 0xc3, 0x79, 
    0xf2, 0x5c, 0xc3, 0x76, 0xc3, 0x73, 0xf2, 0x67, 0xc3, 0x77, 
};
static const unsigned char big5_chars_ban1698 [] = {
    0xc3, 0x74, 0xf2, 0x5e, 0xf2, 0x61, 0xf2, 0x62, 0xf2, 0x63, 
    0xf2, 0x66, 
};
static const unsigned char big5_chars_ban1699 [] = {
    0xef, 0xf5, 0xf2, 0x5d, 0xc3, 0x75, 0xf2, 0x64, 0xf2, 0x68, 
    0xf2, 0x60, 
};
static const unsigned char big5_chars_ban1700 [] = {
    0xf4, 0x5d, 0xc4, 0x6a, 0xf4, 0x60, 0xc4, 0x6b, 0xf4, 0x68, 
    0xf4, 0x5f, 0xf4, 0x5c, 
};
static const unsigned char big5_chars_ban1701 [] = {
    0xf4, 0x5e, 0xf4, 0x62, 0xf4, 0x65, 0xf4, 0x64, 0xf4, 0x67, 
    0xf4, 0x5b, 
};
static const unsigned char big5_chars_ban1702 [] = {
    0xc4, 0x69, 0xf4, 0x63, 0xf4, 0x66, 0xf4, 0x69, 0xf4, 0x61, 
    0xf5, 0xd3, 0xf5, 0xd4, 0xf5, 0xd8, 0xf5, 0xd9, 
};
static const unsigned char big5_chars_ban1703 [] = {
    0xf5, 0xd6, 0xf5, 0xd7, 0xf5, 0xd5, 
};
static const unsigned char big5_chars_ban1704 [] = {
    0xc4, 0xe9, 
};
static const unsigned char big5_chars_ban1705 [] = {
    0xc5, 0x78, 0xf6, 0xeb, 
};
static const unsigned char big5_chars_ban1706 [] = {
    0xf6, 0xe8, 0xf6, 0xe9, 0xf6, 0xea, 0xc5, 0x79, 
};
static const unsigned char big5_chars_ban1707 [] = {
    0xf7, 0xe5, 0xf7, 0xe4, 
};
static const unsigned char big5_chars_ban1708 [] = {
    0xf8, 0xaf, 0xc5, 0xf4, 0xf8, 0xad, 0xf8, 0xb0, 0xf8, 0xae, 
    0xf8, 0xf5, 0xc6, 0x57, 0xc6, 0x65, 0xf9, 0xa3, 0xf9, 0x6c, 
};
static const unsigned char big5_chars_ban1709 [] = {
    0xf9, 0xa2, 0xf9, 0xd0, 0xf9, 0xd1, 0xa4, 0xf5, 
};
static const unsigned char big5_chars_ban1710 [] = {
    0xa6, 0xc7, 0xca, 0x41, 
};
static const unsigned char big5_chars_ban1711 [] = {
    0xcb, 0x5e, 
};
static const unsigned char big5_chars_ban1712 [] = {
    0xa8, 0x5f, 
};
static const unsigned char big5_chars_ban1713 [] = {
    0xa8, 0x62, 
};
static const unsigned char big5_chars_ban1714 [] = {
    0xcb, 0x5f, 
};
static const unsigned char big5_chars_ban1715 [] = {
    0xa8, 0x60, 0xa8, 0x61, 
};
static const unsigned char big5_chars_ban1716 [] = {
    0xcd, 0x58, 0xcd, 0x5a, 0xcd, 0x55, 0xcd, 0x52, 0xcd, 0x54, 
};
static const unsigned char big5_chars_ban1717 [] = {
    0xaa, 0xa4, 
};
static const unsigned char big5_chars_ban1718 [] = {
    0xaa, 0xa2, 
};
static const unsigned char big5_chars_ban1719 [] = {
    0xcd, 0x56, 0xaa, 0xa3, 0xcd, 0x53, 0xcd, 0x50, 0xaa, 0xa1, 
    0xcd, 0x57, 
};
static const unsigned char big5_chars_ban1720 [] = {
    0xcd, 0x51, 0xaa, 0xa5, 0xcd, 0x59, 
};
static const unsigned char big5_chars_ban1721 [] = {
    0xcf, 0xaf, 
};
static const unsigned char big5_chars_ban1722 [] = {
    0xcf, 0xb3, 
};
static const unsigned char big5_chars_ban1723 [] = {
    0xac, 0xb7, 
};
static const unsigned char big5_chars_ban1724 [] = {
    0xcf, 0xb6, 
};
static const unsigned char big5_chars_ban1725 [] = {
    0xac, 0xaf, 0xac, 0xb2, 0xac, 0xb4, 0xac, 0xb6, 0xac, 0xb3, 
    0xcf, 0xb2, 0xcf, 0xb1, 
};
static const unsigned char big5_chars_ban1726 [] = {
    0xac, 0xb1, 0xcf, 0xb4, 0xcf, 0xb5, 
};
static const unsigned char big5_chars_ban1727 [] = {
    0xcf, 0xae, 0xac, 0xb5, 
};
static const unsigned char big5_chars_ban1728 [] = {
    0xac, 0xb0, 
};
static const unsigned char big5_chars_ban1729 [] = {
    0xcf, 0xb0, 
};
static const unsigned char big5_chars_ban1730 [] = {
    0xd2, 0x77, 0xd2, 0x78, 0xd2, 0x79, 0xaf, 0x50, 
};
static const unsigned char big5_chars_ban1731 [] = {
    0xaf, 0x4c, 0xd2, 0x6e, 
};
static const unsigned char big5_chars_ban1732 [] = {
    0xd2, 0x76, 0xd2, 0x7b, 0xaf, 0x51, 
};
static const unsigned char big5_chars_ban1733 [] = {
    0xd2, 0x6c, 0xd2, 0x72, 0xd2, 0x6b, 0xd2, 0x75, 
};
static const unsigned char big5_chars_ban1734 [] = {
    0xd2, 0x71, 0xaf, 0x4d, 0xaf, 0x4f, 0xd2, 0x7a, 
};
static const unsigned char big5_chars_ban1735 [] = {
    0xd2, 0x6a, 0xd2, 0x6d, 0xd2, 0x73, 
};
static const unsigned char big5_chars_ban1736 [] = {
    0xd2, 0x74, 0xd2, 0x7c, 0xd2, 0x70, 
};
static const unsigned char big5_chars_ban1737 [] = {
    0xaf, 0x4e, 
};
static const unsigned char big5_chars_ban1738 [] = {
    0xb2, 0x6d, 0xd6, 0x4e, 
};
static const unsigned char big5_chars_ban1739 [] = {
    0xd6, 0x50, 0xd6, 0x4c, 
};
static const unsigned char big5_chars_ban1740 [] = {
    0xd6, 0x58, 0xd6, 0x4a, 0xd6, 0x57, 0xb2, 0x69, 0xd6, 0x48, 
    0xda, 0x5b, 0xd6, 0x52, 0xb2, 0x6c, 
};
static const unsigned char big5_chars_ban1741 [] = {
    0xd6, 0x53, 0xd6, 0x56, 
};
static const unsigned char big5_chars_ban1742 [] = {
    0xd6, 0x5a, 
};
static const unsigned char big5_chars_ban1743 [] = {
    0xd6, 0x4f, 
};
static const unsigned char big5_chars_ban1744 [] = {
    0xd6, 0x54, 
};
static const unsigned char big5_chars_ban1745 [] = {
    0xb2, 0x6a, 0xb2, 0x6b, 0xd6, 0x59, 0xd6, 0x4d, 0xd6, 0x49, 
    0xd6, 0x5b, 
};
static const unsigned char big5_chars_ban1746 [] = {
    0xd6, 0x51, 
};
static const unsigned char big5_chars_ban1747 [] = {
    0xd6, 0x55, 
};
static const unsigned char big5_chars_ban1748 [] = {
    0xd6, 0x4b, 
};
static const unsigned char big5_chars_ban1749 [] = {
    0xb5, 0x48, 0xb5, 0x49, 0xda, 0x65, 0xb5, 0x4f, 
};
static const unsigned char big5_chars_ban1750 [] = {
    0xda, 0x59, 0xda, 0x62, 0xda, 0x58, 0xb5, 0x4c, 0xda, 0x60, 
    0xda, 0x5e, 
};
static const unsigned char big5_chars_ban1751 [] = {
    0xda, 0x5f, 0xb5, 0x4a, 
};
static const unsigned char big5_chars_ban1752 [] = {
    0xda, 0x63, 
};
static const unsigned char big5_chars_ban1753 [] = {
    0xda, 0x5c, 0xda, 0x5a, 0xb5, 0x4b, 0xda, 0x5d, 0xda, 0x61, 
};
static const unsigned char big5_chars_ban1754 [] = {
    0xb5, 0x4d, 
};
static const unsigned char big5_chars_ban1755 [] = {
    0xda, 0x64, 
};
static const unsigned char big5_chars_ban1756 [] = {
    0xde, 0x70, 0xde, 0x77, 0xde, 0x79, 0xde, 0xa1, 
};
static const unsigned char big5_chars_ban1757 [] = {
    0xb7, 0xda, 0xde, 0x6b, 
};
static const unsigned char big5_chars_ban1758 [] = {
    0xb7, 0xd2, 
};
static const unsigned char big5_chars_ban1759 [] = {
    0xde, 0x7a, 0xb7, 0xd7, 0xde, 0xa2, 0xb7, 0xce, 
};
static const unsigned char big5_chars_ban1760 [] = {
    0xde, 0x7d, 
};
static const unsigned char big5_chars_ban1761 [] = {
    0xde, 0x6d, 0xde, 0x7e, 0xde, 0x6c, 
};
static const unsigned char big5_chars_ban1762 [] = {
    0xb7, 0xdc, 
};
static const unsigned char big5_chars_ban1763 [] = {
    0xde, 0x78, 0xb7, 0xcf, 0xde, 0xa3, 
};
static const unsigned char big5_chars_ban1764 [] = {
    0xb7, 0xd4, 0xde, 0x71, 0xb7, 0xd9, 0xde, 0x7c, 0xde, 0x6f, 
    0xde, 0x76, 0xde, 0x72, 0xde, 0x6e, 0xb7, 0xd1, 0xb7, 0xd8, 
    0xb7, 0xd6, 0xb7, 0xd3, 0xb7, 0xdb, 0xb7, 0xd0, 0xde, 0x75, 
};
static const unsigned char big5_chars_ban1765 [] = {
    0xb7, 0xd5, 
};
static const unsigned char big5_chars_ban1766 [] = {
    0xb5, 0x4e, 
};
static const unsigned char big5_chars_ban1767 [] = {
    0xde, 0x7b, 
};
static const unsigned char big5_chars_ban1768 [] = {
    0xde, 0x73, 
};
static const unsigned char big5_chars_ban1769 [] = {
    0xde, 0x74, 
};
static const unsigned char big5_chars_ban1770 [] = {
    0xe2, 0xc1, 
};
static const unsigned char big5_chars_ban1771 [] = {
    0xba, 0xb4, 
};
static const unsigned char big5_chars_ban1772 [] = {
    0xe2, 0xbd, 0xe2, 0xc3, 0xe2, 0xbf, 
};
static const unsigned char big5_chars_ban1773 [] = {
    0xba, 0xb6, 0xe2, 0xbe, 0xe2, 0xc2, 0xe2, 0xba, 
};
static const unsigned char big5_chars_ban1774 [] = {
    0xe2, 0xbc, 0xba, 0xb5, 
};
static const unsigned char big5_chars_ban1775 [] = {
    0xe2, 0xc0, 0xe2, 0xbb, 
};
static const unsigned char big5_chars_ban1776 [] = {
    0xba, 0xb7, 
};
static const unsigned char big5_chars_ban1777 [] = {
    0xba, 0xb2, 
};
static const unsigned char big5_chars_ban1778 [] = {
    0xe2, 0xc4, 
};
static const unsigned char big5_chars_ban1779 [] = {
    0xba, 0xb3, 0xe6, 0x67, 0xe6, 0x64, 0xe6, 0x70, 0xe6, 0x6a, 
    0xe6, 0x6c, 0xbc, 0xf4, 0xe6, 0x66, 0xe6, 0x6e, 
};
static const unsigned char big5_chars_ban1780 [] = {
    0xe6, 0x6d, 0xe6, 0x6b, 
};
static const unsigned char big5_chars_ban1781 [] = {
    0xe6, 0x71, 0xbc, 0xf7, 0xe6, 0x68, 0xe6, 0x6f, 
};
static const unsigned char big5_chars_ban1782 [] = {
    0xbc, 0xf5, 
};
static const unsigned char big5_chars_ban1783 [] = {
    0xe6, 0x63, 0xe6, 0x65, 0xbc, 0xf6, 0xe6, 0x62, 0xe6, 0x72, 
};
static const unsigned char big5_chars_ban1784 [] = {
    0xe6, 0x69, 
};
static const unsigned char big5_chars_ban1785 [] = {
    0xea, 0x4a, 0xbf, 0x51, 
};
static const unsigned char big5_chars_ban1786 [] = {
    0xea, 0x55, 0xea, 0x53, 0xbf, 0x4b, 0xea, 0x49, 0xea, 0x4c, 
    0xea, 0x4d, 0xea, 0x48, 0xbf, 0x55, 0xbf, 0x56, 0xea, 0x47, 
    0xea, 0x56, 0xea, 0x51, 0xbf, 0x4f, 0xbf, 0x4c, 0xea, 0x50, 
    0xea, 0x4e, 
};
static const unsigned char big5_chars_ban1787 [] = {
    0xbf, 0x52, 0xea, 0x52, 0xbf, 0x4d, 
};
static const unsigned char big5_chars_ban1788 [] = {
    0xbf, 0x4e, 
};
static const unsigned char big5_chars_ban1789 [] = {
    0xea, 0x4f, 0xbf, 0x50, 0xea, 0x4b, 
};
static const unsigned char big5_chars_ban1790 [] = {
    0xea, 0x54, 0xbf, 0x53, 0xea, 0x57, 0xea, 0x58, 0xbf, 0x54, 
};
static const unsigned char big5_chars_ban1791 [] = {
    0xc0, 0xe7, 0xc0, 0xee, 0xed, 0x5c, 0xed, 0x62, 
};
static const unsigned char big5_chars_ban1792 [] = {
    0xed, 0x60, 0xc0, 0xea, 0xc0, 0xe9, 0xc0, 0xe6, 0xed, 0x5e, 
};
static const unsigned char big5_chars_ban1793 [] = {
    0xc0, 0xec, 0xc0, 0xeb, 0xc0, 0xe8, 
};
static const unsigned char big5_chars_ban1794 [] = {
    0xed, 0x61, 0xed, 0x5d, 0xed, 0x5f, 
};
static const unsigned char big5_chars_ban1795 [] = {
    0xc0, 0xed, 
};
static const unsigned char big5_chars_ban1796 [] = {
    0xc2, 0x77, 0xef, 0xfb, 
};
static const unsigned char big5_chars_ban1797 [] = {
    0xc2, 0x74, 0xc2, 0x75, 0xef, 0xfd, 0xc2, 0x76, 0xef, 0xfa, 
};
static const unsigned char big5_chars_ban1798 [] = {
    0xef, 0xf9, 0xf2, 0x6c, 0xef, 0xfc, 
};
static const unsigned char big5_chars_ban1799 [] = {
    0xf2, 0x6d, 0xc3, 0x7a, 0xf2, 0x6b, 
};
static const unsigned char big5_chars_ban1800 [] = {
    0xf2, 0x6a, 
};
static const unsigned char big5_chars_ban1801 [] = {
    0xf2, 0x69, 0xc3, 0x7b, 
};
static const unsigned char big5_chars_ban1802 [] = {
    0xc4, 0x6c, 
};
static const unsigned char big5_chars_ban1803 [] = {
    0xf4, 0x6a, 0xf4, 0x6b, 
};
static const unsigned char big5_chars_ban1804 [] = {
    0xf5, 0xdc, 0xf5, 0xdb, 0xc4, 0xea, 
};
static const unsigned char big5_chars_ban1805 [] = {
    0xf5, 0xda, 0xf6, 0xec, 0xf6, 0xed, 
};
static const unsigned char big5_chars_ban1806 [] = {
    0xf7, 0xe6, 0xf8, 0xb1, 
};
static const unsigned char big5_chars_ban1807 [] = {
    0xf8, 0xf6, 0xf9, 0xbc, 0xc6, 0x79, 0xf9, 0xc6, 0xa4, 0xf6, 
};
static const unsigned char big5_chars_ban1808 [] = {
    0xaa, 0xa6, 0xaa, 0xa7, 
};
static const unsigned char big5_chars_ban1809 [] = {
    0xac, 0xb8, 
};
static const unsigned char big5_chars_ban1810 [] = {
    0xc0, 0xef, 0xa4, 0xf7, 
};
static const unsigned char big5_chars_ban1811 [] = {
    0xaa, 0xa8, 0xaf, 0x52, 0xb7, 0xdd, 0xa4, 0xf8, 
};
static const unsigned char big5_chars_ban1812 [] = {
    0xb2, 0x6e, 0xba, 0xb8, 0xc9, 0x62, 
};
static const unsigned char big5_chars_ban1813 [] = {
    0xcf, 0xb7, 0xd2, 0x7d, 
};
static const unsigned char big5_chars_ban1814 [] = {
    0xe2, 0xc5, 
};
static const unsigned char big5_chars_ban1815 [] = {
    0xc0, 0xf0, 0xa4, 0xf9, 0xaa, 0xa9, 0xcf, 0xb8, 0xcf, 0xb9, 
    0xda, 0x66, 0xb5, 0x50, 
};
static const unsigned char big5_chars_ban1816 [] = {
    0xde, 0xa4, 
};
static const unsigned char big5_chars_ban1817 [] = {
    0xb7, 0xde, 0xe2, 0xc6, 
};
static const unsigned char big5_chars_ban1818 [] = {
    0xbc, 0xf8, 
};
static const unsigned char big5_chars_ban1819 [] = {
    0xc3, 0x7c, 0xa4, 0xfa, 0xda, 0x67, 0xa4, 0xfb, 
};
static const unsigned char big5_chars_ban1820 [] = {
    0xa6, 0xc9, 0xca, 0x42, 0xa6, 0xc8, 0xa8, 0x65, 0xa8, 0x64, 
    0xa8, 0x63, 0xcb, 0x60, 
};
static const unsigned char big5_chars_ban1821 [] = {
    0xaa, 0xaa, 
};
static const unsigned char big5_chars_ban1822 [] = {
    0xaa, 0xab, 0xcd, 0x5b, 
};
static const unsigned char big5_chars_ban1823 [] = {
    0xcf, 0xba, 
};
static const unsigned char big5_chars_ban1824 [] = {
    0xcf, 0xbd, 0xac, 0xba, 0xcf, 0xbb, 
};
static const unsigned char big5_chars_ban1825 [] = {
    0xac, 0xb9, 0xcf, 0xbc, 0xac, 0xbb, 
};
static const unsigned char big5_chars_ban1826 [] = {
    0xd2, 0xa2, 0xd2, 0xa1, 0xd2, 0x7e, 0xaf, 0x53, 
};
static const unsigned char big5_chars_ban1827 [] = {
    0xd6, 0x5d, 0xd6, 0x5e, 0xb2, 0x6f, 0xd6, 0x5c, 0xd6, 0x5f, 
    0xb5, 0x52, 0xb2, 0x70, 
};
static const unsigned char big5_chars_ban1828 [] = {
    0xb5, 0x51, 0xda, 0x6b, 0xda, 0x6a, 
};
static const unsigned char big5_chars_ban1829 [] = {
    0xda, 0x68, 0xda, 0x69, 
};
static const unsigned char big5_chars_ban1830 [] = {
    0xda, 0x6c, 0xde, 0xa6, 0xde, 0xa5, 0xde, 0xa9, 
};
static const unsigned char big5_chars_ban1831 [] = {
    0xde, 0xa8, 0xde, 0xa7, 0xba, 0xb9, 0xe2, 0xc9, 
};
static const unsigned char big5_chars_ban1832 [] = {
    0xe2, 0xc8, 0xba, 0xba, 0xe2, 0xc7, 0xe6, 0x73, 
};
static const unsigned char big5_chars_ban1833 [] = {
    0xe6, 0x74, 0xbc, 0xf9, 
};
static const unsigned char big5_chars_ban1834 [] = {
    0xea, 0x59, 0xea, 0x5a, 
};
static const unsigned char big5_chars_ban1835 [] = {
    0xf2, 0x72, 0xc3, 0x7d, 0xf2, 0x71, 0xf2, 0x70, 0xf2, 0x6e, 
    0xf2, 0x6f, 0xc4, 0xeb, 0xf4, 0x6c, 0xf6, 0xee, 0xf8, 0xf7, 
};
static const unsigned char big5_chars_ban1836 [] = {
    0xa4, 0xfc, 
};
static const unsigned char big5_chars_ban1837 [] = {
    0xc9, 0xa5, 0xa5, 0xc7, 0xc9, 0xa6, 
};
static const unsigned char big5_chars_ban1838 [] = {
    0xca, 0x43, 0xca, 0x44, 
};
static const unsigned char big5_chars_ban1839 [] = {
    0xcb, 0x66, 
};
static const unsigned char big5_chars_ban1840 [] = {
    0xcb, 0x62, 
};
static const unsigned char big5_chars_ban1841 [] = {
    0xcb, 0x61, 0xaa, 0xac, 0xcb, 0x65, 0xa8, 0x67, 0xcb, 0x63, 
    0xa8, 0x66, 0xcb, 0x67, 0xcb, 0x64, 
};
static const unsigned char big5_chars_ban1842 [] = {
    0xcd, 0x5f, 0xcf, 0xbe, 0xcd, 0x5d, 0xcd, 0x64, 
};
static const unsigned char big5_chars_ban1843 [] = {
    0xaa, 0xad, 
};
static const unsigned char big5_chars_ban1844 [] = {
    0xaa, 0xb0, 0xcd, 0x65, 0xcd, 0x61, 
};
static const unsigned char big5_chars_ban1845 [] = {
    0xcd, 0x62, 
};
static const unsigned char big5_chars_ban1846 [] = {
    0xcd, 0x5c, 0xaa, 0xaf, 0xcd, 0x5e, 0xaa, 0xae, 0xcd, 0x63, 
};
static const unsigned char big5_chars_ban1847 [] = {
    0xcd, 0x60, 
};
static const unsigned char big5_chars_ban1848 [] = {
    0xcf, 0xc2, 0xac, 0xbd, 0xac, 0xbe, 
};
static const unsigned char big5_chars_ban1849 [] = {
    0xcf, 0xc5, 0xcf, 0xbf, 
};
static const unsigned char big5_chars_ban1850 [] = {
    0xcf, 0xc4, 
};
static const unsigned char big5_chars_ban1851 [] = {
    0xcf, 0xc0, 0xac, 0xbc, 0xcf, 0xc3, 0xcf, 0xc1, 
};
static const unsigned char big5_chars_ban1852 [] = {
    0xd2, 0xa8, 0xd2, 0xa5, 
};
static const unsigned char big5_chars_ban1853 [] = {
    0xd2, 0xa7, 0xaf, 0x58, 0xaf, 0x57, 0xaf, 0x55, 0xd2, 0xa4, 
    0xd2, 0xa9, 0xaf, 0x54, 0xaf, 0x56, 0xd2, 0xa6, 0xd6, 0x67, 
    0xd2, 0xa3, 0xd2, 0xaa, 
};
static const unsigned char big5_chars_ban1854 [] = {
    0xd6, 0x62, 0xd6, 0x66, 
};
static const unsigned char big5_chars_ban1855 [] = {
    0xd6, 0x65, 0xda, 0x6e, 0xda, 0x79, 
};
static const unsigned char big5_chars_ban1856 [] = {
    0xd6, 0x68, 
};
static const unsigned char big5_chars_ban1857 [] = {
    0xd6, 0x63, 0xda, 0x6d, 0xb2, 0x74, 
};
static const unsigned char big5_chars_ban1858 [] = {
    0xb2, 0x73, 0xd6, 0x61, 0xd6, 0x64, 0xb2, 0x75, 
};
static const unsigned char big5_chars_ban1859 [] = {
    0xb2, 0x72, 0xb2, 0x71, 0xd6, 0x60, 0xd6, 0x69, 
};
static const unsigned char big5_chars_ban1860 [] = {
    0xda, 0x70, 0xda, 0x77, 
};
static const unsigned char big5_chars_ban1861 [] = {
    0xb5, 0x54, 0xda, 0x76, 0xda, 0x73, 
};
static const unsigned char big5_chars_ban1862 [] = {
    0xb5, 0x56, 
};
static const unsigned char big5_chars_ban1863 [] = {
    0xda, 0x75, 
};
static const unsigned char big5_chars_ban1864 [] = {
    0xda, 0x6f, 0xda, 0x71, 0xda, 0x74, 0xda, 0x72, 0xb5, 0x55, 
    0xda, 0x78, 0xb5, 0x53, 0xb7, 0xdf, 
};
static const unsigned char big5_chars_ban1865 [] = {
    0xde, 0xad, 0xde, 0xac, 0xde, 0xaa, 
};
static const unsigned char big5_chars_ban1866 [] = {
    0xb7, 0xe2, 0xb7, 0xe1, 0xde, 0xae, 
};
static const unsigned char big5_chars_ban1867 [] = {
    0xde, 0xab, 0xe2, 0xca, 0xba, 0xbb, 0xb7, 0xe0, 
};
static const unsigned char big5_chars_ban1868 [] = {
    0xde, 0xb0, 0xde, 0xaf, 
};
static const unsigned char big5_chars_ban1869 [] = {
    0xe2, 0xcd, 0xe2, 0xcb, 0xbc, 0xfa, 
};
static const unsigned char big5_chars_ban1870 [] = {
    0xba, 0xbc, 0xe2, 0xcc, 0xe6, 0x76, 
};
static const unsigned char big5_chars_ban1871 [] = {
    0xbc, 0xfb, 0xe6, 0x75, 0xe6, 0x7e, 0xe6, 0x7d, 0xe6, 0x7b, 
};
static const unsigned char big5_chars_ban1872 [] = {
    0xe6, 0x7a, 0xe6, 0x77, 0xe6, 0x78, 0xe6, 0x79, 0xe6, 0x7c, 
    0xe6, 0xa1, 
};
static const unsigned char big5_chars_ban1873 [] = {
    0xea, 0x5f, 0xea, 0x5c, 0xea, 0x5d, 0xbf, 0x57, 0xea, 0x5b, 
    0xea, 0x61, 0xea, 0x60, 0xea, 0x5e, 
};
static const unsigned char big5_chars_ban1874 [] = {
    0xed, 0x64, 0xed, 0x65, 0xc0, 0xf1, 
};
static const unsigned char big5_chars_ban1875 [] = {
    0xc0, 0xf2, 0xed, 0x63, 
};
static const unsigned char big5_chars_ban1876 [] = {
    0xc2, 0x79, 0xef, 0xfe, 0xc2, 0x78, 0xc3, 0x7e, 
};
static const unsigned char big5_chars_ban1877 [] = {
    0xc3, 0xa1, 0xc4, 0x6d, 0xf4, 0x6e, 0xf4, 0x6d, 0xf5, 0xdd, 
    0xf6, 0xef, 0xc5, 0x7a, 0xf7, 0xe8, 0xf7, 0xe7, 0xf7, 0xe9, 
    0xa5, 0xc8, 0xcf, 0xc6, 0xaf, 0x59, 0xb2, 0x76, 0xd6, 0x6a, 
    0xa5, 0xc9, 0xc9, 0xa7, 0xa4, 0xfd, 
};
static const unsigned char big5_chars_ban1878 [] = {
    0xca, 0x45, 
};
static const unsigned char big5_chars_ban1879 [] = {
    0xcb, 0x6c, 0xcb, 0x6a, 0xcb, 0x6b, 0xcb, 0x68, 0xa8, 0x68, 
    0xcb, 0x69, 
};
static const unsigned char big5_chars_ban1880 [] = {
    0xcd, 0x6d, 
};
static const unsigned char big5_chars_ban1881 [] = {
    0xaa, 0xb3, 0xcd, 0x6b, 0xcd, 0x67, 0xcd, 0x6a, 
};
static const unsigned char big5_chars_ban1882 [] = {
    0xcd, 0x66, 0xaa, 0xb5, 0xcd, 0x69, 
};
static const unsigned char big5_chars_ban1883 [] = {
    0xaa, 0xb2, 0xaa, 0xb1, 
};
static const unsigned char big5_chars_ban1884 [] = {
    0xaa, 0xb4, 0xcd, 0x6c, 0xcd, 0x68, 
};
static const unsigned char big5_chars_ban1885 [] = {
    0xac, 0xc2, 0xac, 0xc5, 0xcf, 0xce, 0xcf, 0xcd, 0xcf, 0xcc, 
    0xac, 0xbf, 0xcf, 0xd5, 0xcf, 0xcb, 
};
static const unsigned char big5_chars_ban1886 [] = {
    0xac, 0xc1, 0xd2, 0xaf, 
};
static const unsigned char big5_chars_ban1887 [] = {
    0xcf, 0xd2, 0xcf, 0xd0, 0xac, 0xc4, 
};
static const unsigned char big5_chars_ban1888 [] = {
    0xcf, 0xc8, 0xcf, 0xd3, 
};
static const unsigned char big5_chars_ban1889 [] = {
    0xcf, 0xca, 0xcf, 0xd4, 0xcf, 0xd1, 0xcf, 0xc9, 
};
static const unsigned char big5_chars_ban1890 [] = {
    0xac, 0xc0, 0xcf, 0xd6, 0xcf, 0xc7, 0xac, 0xc3, 
};
static const unsigned char big5_chars_ban1891 [] = {
    0xd2, 0xb4, 0xd2, 0xab, 0xd2, 0xb6, 
};
static const unsigned char big5_chars_ban1892 [] = {
    0xd2, 0xae, 0xd2, 0xb9, 0xd2, 0xba, 0xd2, 0xac, 0xd2, 0xb8, 
    0xd2, 0xb5, 0xd2, 0xb3, 0xd2, 0xb7, 0xaf, 0x5f, 
};
static const unsigned char big5_chars_ban1893 [] = {
    0xaf, 0x5d, 
};
static const unsigned char big5_chars_ban1894 [] = {
    0xd2, 0xb1, 
};
static const unsigned char big5_chars_ban1895 [] = {
    0xd2, 0xad, 
};
static const unsigned char big5_chars_ban1896 [] = {
    0xd2, 0xb0, 0xd2, 0xbb, 0xd2, 0xb2, 0xaf, 0x5e, 0xcf, 0xcf, 
};
static const unsigned char big5_chars_ban1897 [] = {
    0xaf, 0x5a, 0xaf, 0x5c, 
};
static const unsigned char big5_chars_ban1898 [] = {
    0xd6, 0x78, 0xd6, 0x6d, 0xd6, 0x6b, 
};
static const unsigned char big5_chars_ban1899 [] = {
    0xd6, 0x6c, 
};
static const unsigned char big5_chars_ban1900 [] = {
    0xd6, 0x73, 
};
static const unsigned char big5_chars_ban1901 [] = {
    0xd6, 0x74, 0xd6, 0x70, 0xb2, 0x7b, 0xd6, 0x75, 0xd6, 0x72, 
    0xd6, 0x6f, 
};
static const unsigned char big5_chars_ban1902 [] = {
    0xb2, 0x79, 0xd6, 0x6e, 0xb2, 0x77, 0xb2, 0x7a, 0xd6, 0x71, 
    0xd6, 0x79, 0xaf, 0x5b, 0xb2, 0x78, 0xd6, 0x77, 0xd6, 0x76, 
    0xb2, 0x7c, 
};
static const unsigned char big5_chars_ban1903 [] = {
    0xda, 0x7e, 
};
static const unsigned char big5_chars_ban1904 [] = {
    0xda, 0xa1, 0xb5, 0x60, 
};
static const unsigned char big5_chars_ban1905 [] = {
    0xda, 0xa7, 
};
static const unsigned char big5_chars_ban1906 [] = {
    0xda, 0xa9, 0xda, 0xa2, 0xb5, 0x5a, 0xda, 0xa6, 0xda, 0xa5, 
    0xb5, 0x5b, 0xb5, 0x61, 
};
static const unsigned char big5_chars_ban1907 [] = {
    0xb5, 0x62, 0xda, 0xa8, 0xb5, 0x58, 0xda, 0x7d, 0xda, 0x7b, 
    0xda, 0xa3, 0xda, 0x7a, 0xb5, 0x5f, 0xda, 0x7c, 0xda, 0xa4, 
    0xda, 0xaa, 0xb5, 0x59, 0xb5, 0x5e, 0xb5, 0x5c, 0xb5, 0x5d, 
};
static const unsigned char big5_chars_ban1908 [] = {
    0xb5, 0x57, 
};
static const unsigned char big5_chars_ban1909 [] = {
    0xb7, 0xe9, 0xde, 0xb7, 0xb7, 0xe8, 0xde, 0xbb, 
};
static const unsigned char big5_chars_ban1910 [] = {
    0xde, 0xb1, 
};
static const unsigned char big5_chars_ban1911 [] = {
    0xde, 0xbc, 
};
static const unsigned char big5_chars_ban1912 [] = {
    0xde, 0xb2, 0xde, 0xb3, 
};
static const unsigned char big5_chars_ban1913 [] = {
    0xde, 0xbd, 0xde, 0xba, 0xde, 0xb8, 0xde, 0xb9, 0xde, 0xb5, 
    0xde, 0xb4, 
};
static const unsigned char big5_chars_ban1914 [] = {
    0xde, 0xbe, 0xb7, 0xe5, 
};
static const unsigned char big5_chars_ban1915 [] = {
    0xde, 0xb6, 
};
static const unsigned char big5_chars_ban1916 [] = {
    0xb7, 0xea, 0xb7, 0xe4, 0xb7, 0xeb, 0xb7, 0xec, 
};
static const unsigned char big5_chars_ban1917 [] = {
    0xb7, 0xe7, 0xb7, 0xe6, 
};
static const unsigned char big5_chars_ban1918 [] = {
    0xe2, 0xce, 0xba, 0xbe, 0xba, 0xbd, 
};
static const unsigned char big5_chars_ban1919 [] = {
    0xe2, 0xd3, 
};
static const unsigned char big5_chars_ban1920 [] = {
    0xbc, 0xfc, 0xba, 0xbf, 
};
static const unsigned char big5_chars_ban1921 [] = {
    0xba, 0xc1, 0xe2, 0xd4, 0xb7, 0xe3, 0xba, 0xc0, 0xe2, 0xd0, 
    0xe2, 0xd2, 0xe2, 0xcf, 
};
static const unsigned char big5_chars_ban1922 [] = {
    0xe2, 0xd1, 
};
static const unsigned char big5_chars_ban1923 [] = {
    0xe6, 0xab, 
};
static const unsigned char big5_chars_ban1924 [] = {
    0xe6, 0xaa, 0xe6, 0xa7, 0xbd, 0x40, 0xea, 0x62, 0xbd, 0x41, 
    0xe6, 0xa6, 
};
static const unsigned char big5_chars_ban1925 [] = {
    0xbc, 0xfe, 
};
static const unsigned char big5_chars_ban1926 [] = {
    0xe6, 0xa8, 0xe6, 0xa5, 0xe6, 0xa2, 0xe6, 0xa9, 0xe6, 0xa3, 
    0xe6, 0xa4, 0xbc, 0xfd, 
};
static const unsigned char big5_chars_ban1927 [] = {
    0xed, 0x69, 
};
static const unsigned char big5_chars_ban1928 [] = {
    0xea, 0x66, 
};
static const unsigned char big5_chars_ban1929 [] = {
    0xea, 0x65, 0xea, 0x67, 
};
static const unsigned char big5_chars_ban1930 [] = {
    0xed, 0x66, 0xbf, 0x5a, 
};
static const unsigned char big5_chars_ban1931 [] = {
    0xea, 0x63, 
};
static const unsigned char big5_chars_ban1932 [] = {
    0xbf, 0x58, 
};
static const unsigned char big5_chars_ban1933 [] = {
    0xbf, 0x5c, 0xbf, 0x5b, 0xea, 0x64, 0xea, 0x68, 
};
static const unsigned char big5_chars_ban1934 [] = {
    0xbf, 0x59, 
};
static const unsigned char big5_chars_ban1935 [] = {
    0xed, 0x6d, 0xc0, 0xf5, 0xc2, 0x7a, 0xc0, 0xf6, 0xc0, 0xf3, 
    0xed, 0x6a, 0xed, 0x68, 
};
static const unsigned char big5_chars_ban1936 [] = {
    0xed, 0x6b, 
};
static const unsigned char big5_chars_ban1937 [] = {
    0xed, 0x6e, 0xc0, 0xf4, 0xed, 0x6c, 0xed, 0x67, 
};
static const unsigned char big5_chars_ban1938 [] = {
    0xf0, 0x42, 0xf0, 0x45, 0xf2, 0x75, 0xf0, 0x40, 
};
static const unsigned char big5_chars_ban1939 [] = {
    0xf4, 0x6f, 0xf0, 0x46, 
};
static const unsigned char big5_chars_ban1940 [] = {
    0xc3, 0xa2, 0xf0, 0x44, 0xc2, 0x7b, 0xf0, 0x41, 0xf0, 0x43, 
    0xf0, 0x47, 0xf2, 0x76, 
};
static const unsigned char big5_chars_ban1941 [] = {
    0xf2, 0x74, 
};
static const unsigned char big5_chars_ban1942 [] = {
    0xc3, 0xa3, 0xf2, 0x73, 
};
static const unsigned char big5_chars_ban1943 [] = {
    0xc4, 0x6e, 
};
static const unsigned char big5_chars_ban1944 [] = {
    0xc4, 0xed, 0xf6, 0xf1, 0xc4, 0xec, 0xf6, 0xf3, 0xf6, 0xf0, 
    0xf6, 0xf2, 0xc5, 0xd0, 0xf8, 0xb2, 0xa5, 0xca, 0xcd, 0x6e, 
    0xd2, 0xbc, 0xd2, 0xbd, 0xb2, 0x7d, 0xde, 0xbf, 0xbf, 0x5d, 
    0xc3, 0xa4, 0xc5, 0x7b, 0xf8, 0xb3, 0xa5, 0xcb, 
};
static const unsigned char big5_chars_ban1945 [] = {
    0xcd, 0x6f, 0xa2, 0x60, 
};
static const unsigned char big5_chars_ban1946 [] = {
    0xcf, 0xd7, 
};
static const unsigned char big5_chars_ban1947 [] = {
    0xcf, 0xd8, 
};
static const unsigned char big5_chars_ban1948 [] = {
    0xd2, 0xbe, 0xd2, 0xbf, 0xb2, 0x7e, 0xb2, 0xa1, 
};
static const unsigned char big5_chars_ban1949 [] = {
    0xda, 0xab, 
};
static const unsigned char big5_chars_ban1950 [] = {
    0xde, 0xc2, 0xde, 0xc1, 0xde, 0xc0, 0xe2, 0xd5, 
};
static const unsigned char big5_chars_ban1951 [] = {
    0xe2, 0xd6, 0xe2, 0xd7, 0xba, 0xc2, 
};
static const unsigned char big5_chars_ban1952 [] = {
    0xe6, 0xad, 0xe6, 0xac, 
};
static const unsigned char big5_chars_ban1953 [] = {
    0xea, 0x69, 0xbf, 0x5e, 0xbf, 0x5f, 
};
static const unsigned char big5_chars_ban1954 [] = {
    0xed, 0x72, 0xed, 0x6f, 0xed, 0x70, 0xed, 0x71, 0xf0, 0x49, 
    0xf0, 0x48, 0xc2, 0x7c, 0xf2, 0x77, 0xf5, 0xde, 0xa5, 0xcc, 
};
static const unsigned char big5_chars_ban1955 [] = {
    0xac, 0xc6, 
};
static const unsigned char big5_chars_ban1956 [] = {
    0xb2, 0xa2, 0xde, 0xc3, 
};
static const unsigned char big5_chars_ban1957 [] = {
    0xa5, 0xcd, 
};
static const unsigned char big5_chars_ban1958 [] = {
    0xd2, 0xc0, 0xb2, 0xa3, 
};
static const unsigned char big5_chars_ban1959 [] = {
    0xb5, 0x63, 0xb5, 0x64, 
};
static const unsigned char big5_chars_ban1960 [] = {
    0xa5, 0xce, 0xa5, 0xcf, 0xca, 0x46, 0xa8, 0x6a, 0xa8, 0x69, 
    0xac, 0xc7, 0xcf, 0xd9, 0xda, 0xac, 0xa5, 0xd0, 0xa5, 0xd1, 
    0xa5, 0xd2, 0xa5, 0xd3, 
};
static const unsigned char big5_chars_ban1961 [] = {
    0xa8, 0x6b, 0xa8, 0x6c, 0xcb, 0x6e, 0xcb, 0x6d, 
};
static const unsigned char big5_chars_ban1962 [] = {
    0xaa, 0xb6, 0xcd, 0x72, 0xcd, 0x70, 0xcd, 0x71, 
};
static const unsigned char big5_chars_ban1963 [] = {
    0xcf, 0xda, 0xcf, 0xdb, 
};
static const unsigned char big5_chars_ban1964 [] = {
    0xac, 0xcb, 0xac, 0xc9, 
};
static const unsigned char big5_chars_ban1965 [] = {
    0xac, 0xca, 0xac, 0xc8, 
};
static const unsigned char big5_chars_ban1966 [] = {
    0xaf, 0x60, 
};
static const unsigned char big5_chars_ban1967 [] = {
    0xaf, 0x64, 0xaf, 0x63, 0xd2, 0xc1, 0xaf, 0x62, 0xaf, 0x61, 
};
static const unsigned char big5_chars_ban1968 [] = {
    0xd2, 0xc2, 
};
static const unsigned char big5_chars_ban1969 [] = {
    0xb2, 0xa6, 0xd6, 0x7b, 0xd6, 0x7a, 0xb2, 0xa4, 0xb2, 0xa5, 
};
static const unsigned char big5_chars_ban1970 [] = {
    0xb5, 0x66, 0xb5, 0x65, 0xda, 0xae, 
};
static const unsigned char big5_chars_ban1971 [] = {
    0xda, 0xad, 0xb2, 0xa7, 
};
static const unsigned char big5_chars_ban1972 [] = {
    0xb7, 0xed, 0xde, 0xc5, 0xb7, 0xee, 0xde, 0xc4, 
};
static const unsigned char big5_chars_ban1973 [] = {
    0xe2, 0xd8, 0xe6, 0xae, 0xbd, 0x42, 0xea, 0x6a, 
};
static const unsigned char big5_chars_ban1974 [] = {
    0xed, 0x73, 
};
static const unsigned char big5_chars_ban1975 [] = {
    0xc3, 0xa6, 0xc3, 0xa5, 
};
static const unsigned char big5_chars_ban1976 [] = {
    0xc5, 0x7c, 0xa5, 0xd4, 0xcd, 0x73, 
};
static const unsigned char big5_chars_ban1977 [] = {
    0xb2, 0xa8, 0xe2, 0xd9, 0xba, 0xc3, 
};
static const unsigned char big5_chars_ban1978 [] = {
    0xcb, 0x6f, 0xcb, 0x70, 
};
static const unsigned char big5_chars_ban1979 [] = {
    0xcd, 0x74, 0xaa, 0xb8, 0xaa, 0xb9, 
};
static const unsigned char big5_chars_ban1980 [] = {
    0xaa, 0xb7, 
};
static const unsigned char big5_chars_ban1981 [] = {
    0xac, 0xcf, 0xac, 0xd0, 0xac, 0xcd, 0xac, 0xce, 
};
static const unsigned char big5_chars_ban1982 [] = {
    0xcf, 0xdc, 
};
static const unsigned char big5_chars_ban1983 [] = {
    0xcf, 0xdd, 0xac, 0xcc, 
};
static const unsigned char big5_chars_ban1984 [] = {
    0xd2, 0xc3, 
};
static const unsigned char big5_chars_ban1985 [] = {
    0xaf, 0x68, 0xaf, 0x69, 
};
static const unsigned char big5_chars_ban1986 [] = {
    0xb2, 0xab, 0xd2, 0xc9, 
};
static const unsigned char big5_chars_ban1987 [] = {
    0xaf, 0x6e, 0xaf, 0x6c, 0xd2, 0xca, 0xd2, 0xc5, 0xaf, 0x6b, 
    0xaf, 0x6a, 0xaf, 0x65, 0xd2, 0xc8, 0xd2, 0xc7, 0xd2, 0xc4, 
    0xaf, 0x6d, 
};
static const unsigned char big5_chars_ban1988 [] = {
    0xd2, 0xc6, 0xaf, 0x66, 
};
static const unsigned char big5_chars_ban1989 [] = {
    0xaf, 0x67, 
};
static const unsigned char big5_chars_ban1990 [] = {
    0xb2, 0xac, 0xd6, 0xa1, 0xd6, 0xa2, 0xb2, 0xad, 0xd6, 0x7c, 
    0xd6, 0x7e, 0xd6, 0xa4, 0xd6, 0xa3, 0xd6, 0x7d, 
};
static const unsigned char big5_chars_ban1991 [] = {
    0xb2, 0xa9, 0xb2, 0xaa, 
};
static const unsigned char big5_chars_ban1992 [] = {
    0xda, 0xb6, 0xb5, 0x6b, 0xb5, 0x6a, 0xda, 0xb0, 0xb5, 0x68, 
};
static const unsigned char big5_chars_ban1993 [] = {
    0xda, 0xb3, 0xb5, 0x6c, 0xda, 0xb4, 0xb5, 0x6d, 0xda, 0xb1, 
    0xb5, 0x67, 0xb5, 0x69, 0xda, 0xb5, 
};
static const unsigned char big5_chars_ban1994 [] = {
    0xda, 0xb2, 0xda, 0xaf, 
};
static const unsigned char big5_chars_ban1995 [] = {
    0xde, 0xd2, 
};
static const unsigned char big5_chars_ban1996 [] = {
    0xde, 0xc7, 0xb7, 0xf0, 0xb7, 0xf3, 0xb7, 0xf2, 0xb7, 0xf7, 
    0xb7, 0xf6, 0xde, 0xd3, 0xde, 0xd1, 0xde, 0xca, 0xde, 0xce, 
    0xde, 0xcd, 0xb7, 0xf4, 0xde, 0xd0, 0xde, 0xcc, 0xde, 0xd4, 
    0xde, 0xcb, 0xb7, 0xf5, 0xb7, 0xef, 0xb7, 0xf1, 
};
static const unsigned char big5_chars_ban1997 [] = {
    0xde, 0xc9, 
};
static const unsigned char big5_chars_ban1998 [] = {
    0xe2, 0xdb, 0xba, 0xc7, 0xe2, 0xdf, 0xba, 0xc6, 0xe2, 0xdc, 
    0xba, 0xc5, 
};
static const unsigned char big5_chars_ban1999 [] = {
    0xde, 0xc8, 0xde, 0xcf, 0xe2, 0xde, 
};
static const unsigned char big5_chars_ban2000 [] = {
    0xba, 0xc8, 0xe2, 0xe0, 0xe2, 0xdd, 0xe2, 0xda, 
};
static const unsigned char big5_chars_ban2001 [] = {
    0xe6, 0xb1, 0xe6, 0xb5, 0xe6, 0xb7, 0xe6, 0xb3, 0xe6, 0xb2, 
    0xe6, 0xb0, 0xbd, 0x45, 0xbd, 0x43, 0xbd, 0x48, 0xbd, 0x49, 
    0xe6, 0xb4, 0xbd, 0x46, 0xe6, 0xaf, 0xbd, 0x47, 0xba, 0xc4, 
    0xe6, 0xb6, 0xbd, 0x44, 
};
static const unsigned char big5_chars_ban2002 [] = {
    0xea, 0x6c, 
};
static const unsigned char big5_chars_ban2003 [] = {
    0xea, 0x6b, 0xea, 0x73, 0xea, 0x6d, 0xea, 0x72, 0xea, 0x6f, 
    0xbf, 0x60, 0xea, 0x71, 
};
static const unsigned char big5_chars_ban2004 [] = {
    0xbf, 0x61, 
};
static const unsigned char big5_chars_ban2005 [] = {
    0xbf, 0x62, 
};
static const unsigned char big5_chars_ban2006 [] = {
    0xea, 0x70, 0xea, 0x6e, 
};
static const unsigned char big5_chars_ban2007 [] = {
    0xc0, 0xf8, 0xed, 0x74, 
};
static const unsigned char big5_chars_ban2008 [] = {
    0xc0, 0xf7, 0xed, 0x77, 0xed, 0x75, 0xed, 0x76, 
};
static const unsigned char big5_chars_ban2009 [] = {
    0xc0, 0xf9, 
};
static const unsigned char big5_chars_ban2010 [] = {
    0xf0, 0x4d, 
};
static const unsigned char big5_chars_ban2011 [] = {
    0xc2, 0xa1, 0xf0, 0x4e, 
};
static const unsigned char big5_chars_ban2012 [] = {
    0xc2, 0x7d, 0xf0, 0x4f, 0xc2, 0x7e, 0xf0, 0x4c, 0xf0, 0x50, 
};
static const unsigned char big5_chars_ban2013 [] = {
    0xf0, 0x4a, 
};
static const unsigned char big5_chars_ban2014 [] = {
    0xc3, 0xa7, 0xf2, 0x78, 0xc3, 0xa8, 0xc4, 0x6f, 
};
static const unsigned char big5_chars_ban2015 [] = {
    0xf0, 0x4b, 0xc4, 0x70, 
};
static const unsigned char big5_chars_ban2016 [] = {
    0xc4, 0xee, 0xf5, 0xdf, 
};
static const unsigned char big5_chars_ban2017 [] = {
    0xc5, 0x7e, 0xf6, 0xf4, 0xc5, 0x7d, 
};
static const unsigned char big5_chars_ban2018 [] = {
    0xf7, 0xea, 0xc5, 0xf5, 0xc5, 0xf6, 
};
static const unsigned char big5_chars_ban2019 [] = {
    0xf9, 0xcc, 
};
static const unsigned char big5_chars_ban2020 [] = {
    0xac, 0xd1, 0xcf, 0xde, 
};
static const unsigned char big5_chars_ban2021 [] = {
    0xb5, 0x6e, 0xb5, 0x6f, 0xa5, 0xd5, 0xa6, 0xca, 0xca, 0x47, 
};
static const unsigned char big5_chars_ban2022 [] = {
    0xcb, 0x71, 0xa8, 0x6d, 
};
static const unsigned char big5_chars_ban2023 [] = {
    0xaa, 0xba, 
};
static const unsigned char big5_chars_ban2024 [] = {
    0xac, 0xd2, 0xac, 0xd3, 0xac, 0xd4, 0xd6, 0xa6, 0xd2, 0xcb, 
    0xaf, 0x6f, 
};
static const unsigned char big5_chars_ban2025 [] = {
    0xb2, 0xae, 0xd6, 0xa5, 
};
static const unsigned char big5_chars_ban2026 [] = {
    0xda, 0xb8, 0xb5, 0x71, 
};
static const unsigned char big5_chars_ban2027 [] = {
    0xda, 0xb7, 0xb5, 0x70, 
};
static const unsigned char big5_chars_ban2028 [] = {
    0xde, 0xd5, 0xbd, 0x4a, 0xe6, 0xbb, 0xe6, 0xb8, 0xe6, 0xb9, 
    0xe6, 0xba, 
};
static const unsigned char big5_chars_ban2029 [] = {
    0xed, 0x78, 
};
static const unsigned char big5_chars_ban2030 [] = {
    0xf0, 0x51, 
};
static const unsigned char big5_chars_ban2031 [] = {
    0xf4, 0x71, 0xf4, 0x70, 
};
static const unsigned char big5_chars_ban2032 [] = {
    0xf6, 0xf5, 0xa5, 0xd6, 0xcd, 0x75, 0xaf, 0x70, 
};
static const unsigned char big5_chars_ban2033 [] = {
    0xb5, 0x72, 0xde, 0xd6, 
};
static const unsigned char big5_chars_ban2034 [] = {
    0xe2, 0xe1, 
};
static const unsigned char big5_chars_ban2035 [] = {
    0xbd, 0x4b, 0xea, 0x74, 
};
static const unsigned char big5_chars_ban2036 [] = {
    0xf0, 0x52, 0xf4, 0x72, 0xa5, 0xd7, 
};
static const unsigned char big5_chars_ban2037 [] = {
    0xaa, 0xbb, 0xac, 0xd7, 0xcf, 0xdf, 0xac, 0xd8, 0xac, 0xd6, 
};
static const unsigned char big5_chars_ban2038 [] = {
    0xac, 0xd5, 0xd2, 0xcc, 0xaf, 0x71, 
};
static const unsigned char big5_chars_ban2039 [] = {
    0xaf, 0x72, 0xaf, 0x73, 
};
static const unsigned char big5_chars_ban2040 [] = {
    0xb2, 0xb0, 0xd6, 0xa7, 0xb2, 0xaf, 
};
static const unsigned char big5_chars_ban2041 [] = {
    0xda, 0xb9, 0xb2, 0xb1, 0xb5, 0x73, 0xde, 0xd7, 0xb7, 0xf8, 
    0xb7, 0xf9, 
};
static const unsigned char big5_chars_ban2042 [] = {
    0xba, 0xc9, 
};
static const unsigned char big5_chars_ban2043 [] = {
    0xba, 0xca, 0xbd, 0x4c, 0xbf, 0x64, 0xea, 0x75, 0xbf, 0x63, 
};
static const unsigned char big5_chars_ban2044 [] = {
    0xed, 0x79, 0xc0, 0xfa, 
};
static const unsigned char big5_chars_ban2045 [] = {
    0xf0, 0x53, 0xf4, 0x73, 0xa5, 0xd8, 0xa8, 0x6e, 0xcd, 0x78, 
    0xcd, 0x77, 0xaa, 0xbc, 0xcd, 0x76, 0xaa, 0xbd, 0xcd, 0x79, 
};
static const unsigned char big5_chars_ban2046 [] = {
    0xcf, 0xe5, 0xac, 0xdb, 0xac, 0xda, 0xcf, 0xe7, 0xcf, 0xe6, 
    0xac, 0xdf, 
};
static const unsigned char big5_chars_ban2047 [] = {
    0xac, 0xde, 
};
static const unsigned char big5_chars_ban2048 [] = {
    0xac, 0xd9, 
};
static const unsigned char big5_chars_ban2049 [] = {
    0xcf, 0xe1, 0xcf, 0xe2, 0xcf, 0xe3, 
};
static const unsigned char big5_chars_ban2050 [] = {
    0xac, 0xe0, 0xcf, 0xe0, 0xac, 0xdc, 0xcf, 0xe4, 0xac, 0xdd, 
};
static const unsigned char big5_chars_ban2051 [] = {
    0xd2, 0xcf, 0xd2, 0xd3, 0xd2, 0xd1, 0xd2, 0xd0, 
};
static const unsigned char big5_chars_ban2052 [] = {
    0xd2, 0xd4, 
};
static const unsigned char big5_chars_ban2053 [] = {
    0xd2, 0xd5, 0xd2, 0xd6, 0xd2, 0xce, 
};
static const unsigned char big5_chars_ban2054 [] = {
    0xd2, 0xcd, 
};
static const unsigned char big5_chars_ban2055 [] = {
    0xaf, 0x75, 0xaf, 0x76, 
};
static const unsigned char big5_chars_ban2056 [] = {
    0xd2, 0xd7, 0xd2, 0xd2, 
};
static const unsigned char big5_chars_ban2057 [] = {
    0xd6, 0xb0, 
};
static const unsigned char big5_chars_ban2058 [] = {
    0xd2, 0xd8, 0xaf, 0x77, 0xaf, 0x74, 
};
static const unsigned char big5_chars_ban2059 [] = {
    0xd6, 0xaa, 
};
static const unsigned char big5_chars_ban2060 [] = {
    0xd6, 0xa9, 
};
static const unsigned char big5_chars_ban2061 [] = {
    0xd6, 0xab, 0xd6, 0xac, 0xd6, 0xae, 0xd6, 0xad, 0xd6, 0xb2, 
    0xb2, 0xb5, 0xb2, 0xb2, 0xb2, 0xb6, 0xd6, 0xa8, 0xb2, 0xb7, 
    0xd6, 0xb1, 0xb2, 0xb4, 0xd6, 0xaf, 0xb2, 0xb3, 
};
static const unsigned char big5_chars_ban2062 [] = {
    0xda, 0xbc, 0xda, 0xbe, 0xda, 0xba, 0xda, 0xbb, 
};
static const unsigned char big5_chars_ban2063 [] = {
    0xda, 0xbf, 0xda, 0xc1, 0xda, 0xc2, 0xda, 0xbd, 0xda, 0xc0, 
    0xb5, 0x74, 
};
static const unsigned char big5_chars_ban2064 [] = {
    0xde, 0xdb, 
};
static const unsigned char big5_chars_ban2065 [] = {
    0xde, 0xe0, 0xde, 0xd8, 0xde, 0xdc, 
};
static const unsigned char big5_chars_ban2066 [] = {
    0xde, 0xe1, 0xde, 0xdd, 0xb7, 0xfa, 0xb8, 0x43, 
};
static const unsigned char big5_chars_ban2067 [] = {
    0xb7, 0xfd, 0xde, 0xd9, 0xde, 0xda, 0xba, 0xce, 0xb8, 0x46, 
    0xb7, 0xfe, 
};
static const unsigned char big5_chars_ban2068 [] = {
    0xb8, 0x44, 0xb7, 0xfc, 0xde, 0xdf, 0xb8, 0x45, 0xde, 0xde, 
    0xb8, 0x41, 0xb7, 0xfb, 0xb8, 0x42, 0xde, 0xe2, 0xe2, 0xe6, 
    0xe2, 0xe8, 
};
static const unsigned char big5_chars_ban2069 [] = {
    0xb8, 0x40, 
};
static const unsigned char big5_chars_ban2070 [] = {
    0xe2, 0xe3, 0xba, 0xcc, 0xe2, 0xe9, 0xba, 0xcd, 0xe2, 0xe7, 
    0xe2, 0xe2, 0xe2, 0xe5, 0xe2, 0xea, 0xba, 0xcb, 0xe2, 0xe4, 
};
static const unsigned char big5_chars_ban2071 [] = {
    0xbd, 0x4e, 0xe6, 0xbf, 0xe6, 0xbe, 
};
static const unsigned char big5_chars_ban2072 [] = {
    0xbd, 0x51, 0xbd, 0x4f, 0xe6, 0xbc, 0xbd, 0x4d, 0xe6, 0xbd, 
};
static const unsigned char big5_chars_ban2073 [] = {
    0xbd, 0x50, 
};
static const unsigned char big5_chars_ban2074 [] = {
    0xea, 0x7d, 
};
static const unsigned char big5_chars_ban2075 [] = {
    0xea, 0xa1, 
};
static const unsigned char big5_chars_ban2076 [] = {
    0xea, 0x7e, 0xea, 0x76, 0xea, 0x7a, 0xea, 0x79, 0xea, 0x77, 
    0xbf, 0x66, 0xbf, 0x67, 0xbf, 0x65, 0xea, 0x78, 0xea, 0x7b, 
    0xea, 0x7c, 
};
static const unsigned char big5_chars_ban2077 [] = {
    0xbf, 0x68, 
};
static const unsigned char big5_chars_ban2078 [] = {
    0xc1, 0x40, 0xed, 0xa3, 
};
static const unsigned char big5_chars_ban2079 [] = {
    0xc0, 0xfc, 0xed, 0x7b, 0xc0, 0xfe, 0xc1, 0x41, 
};
static const unsigned char big5_chars_ban2080 [] = {
    0xc0, 0xfd, 0xed, 0xa2, 0xed, 0x7c, 0xc0, 0xfb, 0xed, 0xa1, 
    0xed, 0x7a, 0xed, 0x7e, 0xed, 0x7d, 
};
static const unsigned char big5_chars_ban2081 [] = {
    0xf0, 0x55, 0xc2, 0xa4, 0xc2, 0xa5, 0xc2, 0xa2, 
};
static const unsigned char big5_chars_ban2082 [] = {
    0xc2, 0xa3, 
};
static const unsigned char big5_chars_ban2083 [] = {
    0xf0, 0x54, 
};
static const unsigned char big5_chars_ban2084 [] = {
    0xf2, 0x7b, 
};
static const unsigned char big5_chars_ban2085 [] = {
    0xc3, 0xa9, 
};
static const unsigned char big5_chars_ban2086 [] = {
    0xf2, 0x79, 0xf2, 0x7a, 
};
static const unsigned char big5_chars_ban2087 [] = {
    0xf4, 0x74, 0xf4, 0x77, 0xf4, 0x75, 0xf4, 0x76, 0xf5, 0xe0, 
};
static const unsigned char big5_chars_ban2088 [] = {
    0xc4, 0xef, 0xf7, 0xeb, 0xf8, 0xb4, 
};
static const unsigned char big5_chars_ban2089 [] = {
    0xc5, 0xf7, 0xf8, 0xf8, 0xf8, 0xf9, 0xc6, 0x66, 0xa5, 0xd9, 
    0xac, 0xe1, 
};
static const unsigned char big5_chars_ban2090 [] = {
    0xda, 0xc3, 
};
static const unsigned char big5_chars_ban2091 [] = {
    0xde, 0xe3, 
};
static const unsigned char big5_chars_ban2092 [] = {
    0xa5, 0xda, 0xa8, 0x6f, 
};
static const unsigned char big5_chars_ban2093 [] = {
    0xaa, 0xbe, 
};
static const unsigned char big5_chars_ban2094 [] = {
    0xcf, 0xe8, 0xcf, 0xe9, 0xaf, 0x78, 
};
static const unsigned char big5_chars_ban2095 [] = {
    0xda, 0xc4, 0xb5, 0x75, 0xb8, 0x47, 0xc1, 0x42, 0xed, 0xa4, 
    0xf2, 0x7c, 0xf4, 0x78, 0xa5, 0xdb, 
};
static const unsigned char big5_chars_ban2096 [] = {
    0xcd, 0xa1, 0xcd, 0x7a, 0xcd, 0x7c, 0xcd, 0x7e, 0xcd, 0x7d, 
    0xcd, 0x7b, 0xaa, 0xbf, 
};
static const unsigned char big5_chars_ban2097 [] = {
    0xac, 0xe2, 0xcf, 0xf2, 
};
static const unsigned char big5_chars_ban2098 [] = {
    0xcf, 0xed, 0xcf, 0xea, 
};
static const unsigned char big5_chars_ban2099 [] = {
    0xcf, 0xf1, 
};
static const unsigned char big5_chars_ban2100 [] = {
    0xac, 0xe4, 0xac, 0xe5, 0xcf, 0xf0, 0xcf, 0xef, 0xcf, 0xee, 
    0xcf, 0xeb, 0xcf, 0xec, 0xcf, 0xf3, 0xac, 0xe3, 
};
static const unsigned char big5_chars_ban2101 [] = {
    0xaf, 0x7c, 
};
static const unsigned char big5_chars_ban2102 [] = {
    0xaf, 0xa4, 0xaf, 0xa3, 0xd2, 0xe1, 0xd2, 0xdb, 0xd2, 0xd9, 
};
static const unsigned char big5_chars_ban2103 [] = {
    0xaf, 0xa1, 0xd6, 0xb9, 0xaf, 0x7a, 0xd2, 0xde, 0xd2, 0xe2, 
    0xd2, 0xe4, 0xd2, 0xe0, 0xd2, 0xda, 0xaf, 0xa2, 0xd2, 0xdf, 
    0xd2, 0xdd, 0xaf, 0x79, 0xd2, 0xe5, 0xaf, 0xa5, 0xd2, 0xe3, 
    0xaf, 0x7d, 0xd2, 0xdc, 
};
static const unsigned char big5_chars_ban2104 [] = {
    0xaf, 0x7e, 0xaf, 0x7b, 
};
static const unsigned char big5_chars_ban2105 [] = {
    0xb2, 0xb9, 
};
static const unsigned char big5_chars_ban2106 [] = {
    0xd6, 0xba, 
};
static const unsigned char big5_chars_ban2107 [] = {
    0xd6, 0xb3, 0xd6, 0xb5, 0xd6, 0xb7, 
};
static const unsigned char big5_chars_ban2108 [] = {
    0xd6, 0xb8, 0xd6, 0xb6, 0xb2, 0xba, 
};
static const unsigned char big5_chars_ban2109 [] = {
    0xd6, 0xbb, 
};
static const unsigned char big5_chars_ban2110 [] = {
    0xd6, 0xb4, 
};
static const unsigned char big5_chars_ban2111 [] = {
    0xda, 0xc8, 0xb5, 0x76, 0xda, 0xd0, 
};
static const unsigned char big5_chars_ban2112 [] = {
    0xda, 0xc5, 
};
static const unsigned char big5_chars_ban2113 [] = {
    0xda, 0xd1, 
};
static const unsigned char big5_chars_ban2114 [] = {
    0xda, 0xc6, 0xda, 0xc7, 
};
static const unsigned char big5_chars_ban2115 [] = {
    0xda, 0xcf, 0xda, 0xce, 0xda, 0xcb, 0xb2, 0xb8, 0xb5, 0x77, 
    0xda, 0xc9, 0xda, 0xcc, 0xb5, 0x78, 0xda, 0xcd, 0xda, 0xca, 
};
static const unsigned char big5_chars_ban2116 [] = {
    0xde, 0xee, 
};
static const unsigned char big5_chars_ban2117 [] = {
    0xde, 0xf2, 0xb8, 0x4e, 
};
static const unsigned char big5_chars_ban2118 [] = {
    0xe2, 0xf0, 0xb8, 0x51, 0xde, 0xf0, 0xf9, 0xd6, 
};
static const unsigned char big5_chars_ban2119 [] = {
    0xde, 0xed, 0xde, 0xe8, 0xde, 0xea, 0xde, 0xeb, 0xde, 0xe4, 
};
static const unsigned char big5_chars_ban2120 [] = {
    0xb8, 0x4d, 
};
static const unsigned char big5_chars_ban2121 [] = {
    0xb8, 0x4c, 
};
static const unsigned char big5_chars_ban2122 [] = {
    0xb8, 0x48, 0xde, 0xe7, 
};
static const unsigned char big5_chars_ban2123 [] = {
    0xb8, 0x4f, 
};
static const unsigned char big5_chars_ban2124 [] = {
    0xb8, 0x50, 0xde, 0xe6, 0xde, 0xe9, 0xde, 0xf1, 0xb8, 0x4a, 
    0xb8, 0x4b, 0xde, 0xef, 0xde, 0xe5, 
};
static const unsigned char big5_chars_ban2125 [] = {
    0xe2, 0xf2, 0xba, 0xd0, 0xe2, 0xf4, 0xde, 0xec, 0xe2, 0xf6, 
    0xba, 0xd4, 0xe2, 0xf7, 0xe2, 0xf3, 
};
static const unsigned char big5_chars_ban2126 [] = {
    0xba, 0xd1, 0xe2, 0xef, 0xba, 0xd3, 0xe2, 0xec, 0xe2, 0xf1, 
    0xe2, 0xf5, 0xe2, 0xee, 
};
static const unsigned char big5_chars_ban2127 [] = {
    0xb8, 0x49, 
};
static const unsigned char big5_chars_ban2128 [] = {
    0xe2, 0xeb, 0xba, 0xd2, 0xe2, 0xed, 
};
static const unsigned char big5_chars_ban2129 [] = {
    0xbd, 0x54, 0xe6, 0xc1, 0xbd, 0x58, 
};
static const unsigned char big5_chars_ban2130 [] = {
    0xbd, 0x56, 
};
static const unsigned char big5_chars_ban2131 [] = {
    0xba, 0xcf, 
};
static const unsigned char big5_chars_ban2132 [] = {
    0xe6, 0xc8, 0xe6, 0xc9, 0xbd, 0x53, 
};
static const unsigned char big5_chars_ban2133 [] = {
    0xe6, 0xc7, 0xe6, 0xca, 0xbd, 0x55, 0xbd, 0x52, 0xe6, 0xc3, 
    0xe6, 0xc0, 0xe6, 0xc5, 0xe6, 0xc2, 0xbd, 0x59, 0xe6, 0xc4, 
};
static const unsigned char big5_chars_ban2134 [] = {
    0xe6, 0xc6, 0xbd, 0x57, 
};
static const unsigned char big5_chars_ban2135 [] = {
    0xbf, 0x6a, 0xea, 0xa8, 
};
static const unsigned char big5_chars_ban2136 [] = {
    0xea, 0xa2, 0xea, 0xa6, 0xea, 0xac, 0xea, 0xad, 0xea, 0xa9, 
    0xea, 0xaa, 0xea, 0xa7, 
};
static const unsigned char big5_chars_ban2137 [] = {
    0xea, 0xa4, 
};
static const unsigned char big5_chars_ban2138 [] = {
    0xbf, 0x6c, 0xbf, 0x69, 0xea, 0xa3, 0xea, 0xa5, 
};
static const unsigned char big5_chars_ban2139 [] = {
    0xbf, 0x6b, 0xea, 0xab, 
};
static const unsigned char big5_chars_ban2140 [] = {
    0xc1, 0x46, 
};
static const unsigned char big5_chars_ban2141 [] = {
    0xed, 0xaa, 0xed, 0xa5, 0xc1, 0x45, 
};
static const unsigned char big5_chars_ban2142 [] = {
    0xc1, 0x43, 
};
static const unsigned char big5_chars_ban2143 [] = {
    0xed, 0xac, 0xc1, 0x44, 0xed, 0xa8, 0xed, 0xa9, 0xed, 0xa6, 
    0xed, 0xad, 0xf0, 0x56, 
};
static const unsigned char big5_chars_ban2144 [] = {
    0xc1, 0x47, 0xed, 0xa7, 
};
static const unsigned char big5_chars_ban2145 [] = {
    0xed, 0xae, 0xed, 0xab, 
};
static const unsigned char big5_chars_ban2146 [] = {
    0xf0, 0x5a, 
};
static const unsigned char big5_chars_ban2147 [] = {
    0xf0, 0x57, 
};
static const unsigned char big5_chars_ban2148 [] = {
    0xc2, 0xa6, 
};
static const unsigned char big5_chars_ban2149 [] = {
    0xf0, 0x5b, 0xf0, 0x5d, 0xf0, 0x5c, 0xf0, 0x58, 0xf0, 0x59, 
};
static const unsigned char big5_chars_ban2150 [] = {
    0xf2, 0xa3, 
};
static const unsigned char big5_chars_ban2151 [] = {
    0xc3, 0xaa, 
};
static const unsigned char big5_chars_ban2152 [] = {
    0xf2, 0x7e, 0xf2, 0xa2, 0xf2, 0x7d, 0xf2, 0xa4, 
};
static const unsigned char big5_chars_ban2153 [] = {
    0xf2, 0xa1, 
};
static const unsigned char big5_chars_ban2154 [] = {
    0xf4, 0x7a, 0xf4, 0x7d, 0xf4, 0x79, 0xc4, 0x71, 0xf4, 0x7b, 
    0xf4, 0x7c, 0xf4, 0x7e, 0xc4, 0x72, 0xc4, 0x74, 0xc4, 0x73, 
    0xf5, 0xe1, 
};
static const unsigned char big5_chars_ban2155 [] = {
    0xf5, 0xe3, 
};
static const unsigned char big5_chars_ban2156 [] = {
    0xf5, 0xe2, 
};
static const unsigned char big5_chars_ban2157 [] = {
    0xf6, 0xf6, 
};
static const unsigned char big5_chars_ban2158 [] = {
    0xf8, 0xb5, 0xf8, 0xfa, 0xa5, 0xdc, 
};
static const unsigned char big5_chars_ban2159 [] = {
    0xcb, 0x72, 0xaa, 0xc0, 0xcd, 0xa3, 0xaa, 0xc1, 0xaa, 0xc2, 
    0xcd, 0xa2, 
};
static const unsigned char big5_chars_ban2160 [] = {
    0xcf, 0xf8, 0xcf, 0xf7, 0xac, 0xe6, 0xac, 0xe9, 0xac, 0xe8, 
    0xac, 0xe7, 0xcf, 0xf4, 0xcf, 0xf6, 0xcf, 0xf5, 
};
static const unsigned char big5_chars_ban2161 [] = {
    0xd2, 0xe8, 0xaf, 0xa7, 0xd2, 0xec, 0xd2, 0xeb, 0xd2, 0xea, 
    0xd2, 0xe6, 0xaf, 0xa6, 0xaf, 0xaa, 0xaf, 0xad, 
};
static const unsigned char big5_chars_ban2162 [] = {
    0xaf, 0xae, 0xd2, 0xe7, 0xd2, 0xe9, 0xaf, 0xac, 0xaf, 0xab, 
    0xaf, 0xa9, 0xaf, 0xa8, 0xd6, 0xc2, 
};
static const unsigned char big5_chars_ban2163 [] = {
    0xd6, 0xc0, 0xd6, 0xbc, 0xb2, 0xbb, 
};
static const unsigned char big5_chars_ban2164 [] = {
    0xd6, 0xbd, 0xb2, 0xbc, 0xd6, 0xbe, 0xd6, 0xbf, 0xd6, 0xc1, 
};
static const unsigned char big5_chars_ban2165 [] = {
    0xb2, 0xbd, 
};
static const unsigned char big5_chars_ban2166 [] = {
    0xda, 0xd5, 
};
static const unsigned char big5_chars_ban2167 [] = {
    0xda, 0xd4, 0xda, 0xd3, 0xda, 0xd2, 
};
static const unsigned char big5_chars_ban2168 [] = {
    0xde, 0xf6, 0xb8, 0x52, 
};
static const unsigned char big5_chars_ban2169 [] = {
    0xde, 0xf3, 0xde, 0xf5, 
};
static const unsigned char big5_chars_ban2170 [] = {
    0xb8, 0x53, 
};
static const unsigned char big5_chars_ban2171 [] = {
    0xb8, 0x54, 0xde, 0xf4, 
};
static const unsigned char big5_chars_ban2172 [] = {
    0xe3, 0x41, 
};
static const unsigned char big5_chars_ban2173 [] = {
    0xe2, 0xf9, 0xe2, 0xfa, 
};
static const unsigned char big5_chars_ban2174 [] = {
    0xba, 0xd7, 0xba, 0xd5, 0xba, 0xd6, 0xe3, 0x43, 
};
static const unsigned char big5_chars_ban2175 [] = {
    0xe3, 0x42, 0xe2, 0xfe, 0xe2, 0xfd, 0xe2, 0xfc, 0xe2, 0xfb, 
    0xe3, 0x40, 0xe2, 0xf8, 
};
static const unsigned char big5_chars_ban2176 [] = {
    0xe6, 0xcb, 0xe6, 0xd0, 0xe6, 0xce, 
};
static const unsigned char big5_chars_ban2177 [] = {
    0xe6, 0xcd, 0xe6, 0xcc, 0xe6, 0xcf, 
};
static const unsigned char big5_chars_ban2178 [] = {
    0xea, 0xae, 
};
static const unsigned char big5_chars_ban2179 [] = {
    0xbf, 0x6d, 0xc1, 0x48, 0xed, 0xb0, 
};
static const unsigned char big5_chars_ban2180 [] = {
    0xc1, 0x49, 0xed, 0xaf, 0xf0, 0x5f, 0xf0, 0x5e, 0xc2, 0xa7, 
};
static const unsigned char big5_chars_ban2181 [] = {
    0xf2, 0xa5, 0xc3, 0xab, 0xf4, 0xa1, 0xc5, 0xa1, 0xf6, 0xf7, 
};
static const unsigned char big5_chars_ban2182 [] = {
    0xf8, 0xb7, 0xf8, 0xb6, 0xc9, 0xa8, 0xac, 0xea, 0xac, 0xeb, 
    0xd6, 0xc3, 
};
static const unsigned char big5_chars_ban2183 [] = {
    0xb8, 0x56, 0xa5, 0xdd, 0xa8, 0x72, 0xa8, 0x71, 0xa8, 0x70, 
};
static const unsigned char big5_chars_ban2184 [] = {
    0xcd, 0xa4, 
};
static const unsigned char big5_chars_ban2185 [] = {
    0xaa, 0xc4, 0xaa, 0xc3, 
};
static const unsigned char big5_chars_ban2186 [] = {
    0xac, 0xee, 
};
static const unsigned char big5_chars_ban2187 [] = {
    0xcf, 0xfa, 0xcf, 0xfd, 0xcf, 0xfb, 
};
static const unsigned char big5_chars_ban2188 [] = {
    0xac, 0xec, 0xac, 0xed, 
};
static const unsigned char big5_chars_ban2189 [] = {
    0xcf, 0xf9, 0xcf, 0xfc, 
};
static const unsigned char big5_chars_ban2190 [] = {
    0xaf, 0xb5, 
};
static const unsigned char big5_chars_ban2191 [] = {
    0xd2, 0xf3, 0xd2, 0xf5, 0xd2, 0xf4, 0xaf, 0xb2, 0xd2, 0xef, 
};
static const unsigned char big5_chars_ban2192 [] = {
    0xaf, 0xb0, 0xaf, 0xaf, 
};
static const unsigned char big5_chars_ban2193 [] = {
    0xaf, 0xb3, 0xaf, 0xb1, 
};
static const unsigned char big5_chars_ban2194 [] = {
    0xaf, 0xb4, 0xd2, 0xf2, 0xd2, 0xed, 0xd2, 0xee, 0xd2, 0xf1, 
    0xd2, 0xf0, 
};
static const unsigned char big5_chars_ban2195 [] = {
    0xd6, 0xc6, 0xd6, 0xc7, 0xd6, 0xc5, 
};
static const unsigned char big5_chars_ban2196 [] = {
    0xd6, 0xc4, 0xb2, 0xbe, 
};
static const unsigned char big5_chars_ban2197 [] = {
    0xb5, 0x7d, 
};
static const unsigned char big5_chars_ban2198 [] = {
    0xda, 0xd6, 0xda, 0xd8, 0xda, 0xda, 0xb5, 0x7c, 
};
static const unsigned char big5_chars_ban2199 [] = {
    0xb5, 0x7a, 
};
static const unsigned char big5_chars_ban2200 [] = {
    0xda, 0xd7, 0xb5, 0x7b, 0xda, 0xd9, 0xb5, 0x79, 
};
static const unsigned char big5_chars_ban2201 [] = {
    0xdf, 0x41, 0xde, 0xf7, 0xde, 0xfa, 0xde, 0xfe, 0xb8, 0x5a, 
    0xde, 0xfc, 
};
static const unsigned char big5_chars_ban2202 [] = {
    0xde, 0xfb, 0xde, 0xf8, 0xde, 0xf9, 0xb8, 0x58, 0xdf, 0x40, 
    0xb8, 0x57, 
};
static const unsigned char big5_chars_ban2203 [] = {
    0xb8, 0x5c, 0xb8, 0x5b, 0xb8, 0x59, 
};
static const unsigned char big5_chars_ban2204 [] = {
    0xde, 0xfd, 
};
static const unsigned char big5_chars_ban2205 [] = {
    0xe3, 0x49, 
};
static const unsigned char big5_chars_ban2206 [] = {
    0xe3, 0x48, 
};
static const unsigned char big5_chars_ban2207 [] = {
    0xe3, 0x44, 
};
static const unsigned char big5_chars_ban2208 [] = {
    0xba, 0xd8, 0xe3, 0x47, 0xe3, 0x46, 0xba, 0xd9, 
};
static const unsigned char big5_chars_ban2209 [] = {
    0xbd, 0x5e, 
};
static const unsigned char big5_chars_ban2210 [] = {
    0xe6, 0xd2, 
};
static const unsigned char big5_chars_ban2211 [] = {
    0xbd, 0x5f, 0xbd, 0x5b, 0xbd, 0x5d, 
};
static const unsigned char big5_chars_ban2212 [] = {
    0xbd, 0x5a, 0xbd, 0x5c, 
};
static const unsigned char big5_chars_ban2213 [] = {
    0xea, 0xaf, 
};
static const unsigned char big5_chars_ban2214 [] = {
    0xbf, 0x70, 0xea, 0xb1, 0xea, 0xb0, 
};
static const unsigned char big5_chars_ban2215 [] = {
    0xe3, 0x45, 0xbf, 0x72, 0xbf, 0x71, 0xbf, 0x6e, 0xbf, 0x6f, 
};
static const unsigned char big5_chars_ban2216 [] = {
    0xed, 0xb5, 
};
static const unsigned char big5_chars_ban2217 [] = {
    0xed, 0xb3, 0xc1, 0x4a, 0xed, 0xb4, 
};
static const unsigned char big5_chars_ban2218 [] = {
    0xed, 0xb6, 0xed, 0xb2, 0xed, 0xb1, 
};
static const unsigned char big5_chars_ban2219 [] = {
    0xf0, 0x60, 0xc2, 0xaa, 0xc2, 0xa8, 0xc2, 0xa9, 
};
static const unsigned char big5_chars_ban2220 [] = {
    0xf2, 0xa6, 0xf2, 0xa7, 0xc3, 0xad, 
};
static const unsigned char big5_chars_ban2221 [] = {
    0xc3, 0xac, 0xf4, 0xa3, 0xf4, 0xa4, 0xf4, 0xa2, 
};
static const unsigned char big5_chars_ban2222 [] = {
    0xf6, 0xf8, 0xf6, 0xf9, 
};
static const unsigned char big5_chars_ban2223 [] = {
    0xa5, 0xde, 0xca, 0x48, 0xa8, 0x73, 
};
static const unsigned char big5_chars_ban2224 [] = {
    0xcd, 0xa5, 0xaa, 0xc6, 0xaa, 0xc5, 0xcd, 0xa6, 
};
static const unsigned char big5_chars_ban2225 [] = {
    0xd0, 0x40, 0xac, 0xef, 0xcf, 0xfe, 0xac, 0xf0, 
};
static const unsigned char big5_chars_ban2226 [] = {
    0xaf, 0xb6, 0xd2, 0xf8, 0xd2, 0xf6, 0xd2, 0xfc, 0xaf, 0xb7, 
    0xd2, 0xf7, 0xd2, 0xfb, 0xd2, 0xf9, 0xd2, 0xfa, 
};
static const unsigned char big5_chars_ban2227 [] = {
    0xd6, 0xc8, 0xd6, 0xca, 
};
static const unsigned char big5_chars_ban2228 [] = {
    0xb2, 0xbf, 
};
static const unsigned char big5_chars_ban2229 [] = {
    0xd6, 0xc9, 0xb2, 0xc0, 0xb5, 0xa2, 0xb5, 0xa1, 0xb5, 0x7e, 
    0xda, 0xdb, 
};
static const unsigned char big5_chars_ban2230 [] = {
    0xdf, 0x44, 0xb8, 0x5d, 0xb8, 0x5e, 
};
static const unsigned char big5_chars_ban2231 [] = {
    0xdf, 0x43, 0xdf, 0x42, 
};
static const unsigned char big5_chars_ban2232 [] = {
    0xe3, 0x4a, 0xba, 0xdb, 0xba, 0xda, 0xe3, 0x4b, 0xe3, 0x4c, 
};
static const unsigned char big5_chars_ban2233 [] = {
    0xbd, 0x61, 0xbd, 0x60, 
};
static const unsigned char big5_chars_ban2234 [] = {
    0xea, 0xb5, 0xe6, 0xd3, 0xe6, 0xd5, 0xe6, 0xd4, 0xea, 0xb4, 
    0xea, 0xb2, 0xea, 0xb6, 0xea, 0xb3, 
};
static const unsigned char big5_chars_ban2235 [] = {
    0xbf, 0x73, 
};
static const unsigned char big5_chars_ban2236 [] = {
    0xed, 0xb7, 0xc1, 0x4b, 0xed, 0xb8, 0xed, 0xb9, 
};
static const unsigned char big5_chars_ban2237 [] = {
    0xc2, 0xab, 0xc2, 0xac, 
};
static const unsigned char big5_chars_ban2238 [] = {
    0xc4, 0x75, 
};
static const unsigned char big5_chars_ban2239 [] = {
    0xc5, 0xd1, 0xa5, 0xdf, 
};
static const unsigned char big5_chars_ban2240 [] = {
    0xd0, 0x41, 
};
static const unsigned char big5_chars_ban2241 [] = {
    0xd2, 0xfd, 0xaf, 0xb8, 
};
static const unsigned char big5_chars_ban2242 [] = {
    0xb3, 0xba, 0xb3, 0xb9, 
};
static const unsigned char big5_chars_ban2243 [] = {
    0xb5, 0xa4, 0xda, 0xdd, 0xb5, 0xa3, 0xda, 0xdc, 
};
static const unsigned char big5_chars_ban2244 [] = {
    0xdf, 0x45, 
};
static const unsigned char big5_chars_ban2245 [] = {
    0xba, 0xdc, 0xe3, 0x4d, 0xba, 0xdd, 
};
static const unsigned char big5_chars_ban2246 [] = {
    0xc4, 0x76, 0xf4, 0xa5, 
};
static const unsigned char big5_chars_ban2247 [] = {
    0xa6, 0xcb, 0xaa, 0xc7, 0xcd, 0xa7, 
};
static const unsigned char big5_chars_ban2248 [] = {
    0xac, 0xf2, 
};
static const unsigned char big5_chars_ban2249 [] = {
    0xac, 0xf1, 0xd0, 0x42, 0xd0, 0x43, 
};
static const unsigned char big5_chars_ban2250 [] = {
    0xd3, 0x40, 0xd3, 0x42, 0xaf, 0xb9, 
};
static const unsigned char big5_chars_ban2251 [] = {
    0xd3, 0x44, 0xd3, 0x47, 0xd3, 0x45, 
};
static const unsigned char big5_chars_ban2252 [] = {
    0xd3, 0x46, 0xd3, 0x43, 0xd2, 0xfe, 0xaf, 0xba, 0xd3, 0x48, 
    0xd3, 0x41, 
};
static const unsigned char big5_chars_ban2253 [] = {
    0xd6, 0xd3, 0xb2, 0xc6, 0xd6, 0xdc, 0xb2, 0xc3, 
};
static const unsigned char big5_chars_ban2254 [] = {
    0xd6, 0xd5, 0xb2, 0xc7, 
};
static const unsigned char big5_chars_ban2255 [] = {
    0xb2, 0xc1, 
};
static const unsigned char big5_chars_ban2256 [] = {
    0xd6, 0xd0, 0xd6, 0xdd, 0xd6, 0xd1, 0xd6, 0xce, 0xb2, 0xc5, 
};
static const unsigned char big5_chars_ban2257 [] = {
    0xb2, 0xc2, 
};
static const unsigned char big5_chars_ban2258 [] = {
    0xd6, 0xd4, 0xd6, 0xd7, 0xb2, 0xc4, 0xd6, 0xd8, 0xb2, 0xc8, 
    0xd6, 0xd9, 0xd6, 0xcf, 0xd6, 0xd6, 0xd6, 0xda, 0xd6, 0xd2, 
    0xd6, 0xcd, 0xd6, 0xcb, 
};
static const unsigned char big5_chars_ban2259 [] = {
    0xd6, 0xdb, 
};
static const unsigned char big5_chars_ban2260 [] = {
    0xda, 0xdf, 
};
static const unsigned char big5_chars_ban2261 [] = {
    0xda, 0xe4, 
};
static const unsigned char big5_chars_ban2262 [] = {
    0xda, 0xe0, 0xda, 0xe6, 0xb5, 0xa7, 0xd6, 0xcc, 0xda, 0xe1, 
    0xb5, 0xa5, 0xda, 0xde, 0xb5, 0xac, 0xda, 0xe2, 0xb5, 0xab, 
    0xda, 0xe3, 0xb5, 0xad, 0xb5, 0xa8, 0xb5, 0xae, 0xb5, 0xa9, 
};
static const unsigned char big5_chars_ban2263 [] = {
    0xb5, 0xaa, 
};
static const unsigned char big5_chars_ban2264 [] = {
    0xb5, 0xa6, 
};
static const unsigned char big5_chars_ban2265 [] = {
    0xda, 0xe5, 
};
static const unsigned char big5_chars_ban2266 [] = {
    0xb8, 0x61, 0xdf, 0x50, 
};
static const unsigned char big5_chars_ban2267 [] = {
    0xdf, 0x53, 0xdf, 0x47, 0xdf, 0x4c, 0xdf, 0x46, 0xb8, 0x63, 
};
static const unsigned char big5_chars_ban2268 [] = {
    0xdf, 0x4a, 
};
static const unsigned char big5_chars_ban2269 [] = {
    0xdf, 0x48, 0xb8, 0x62, 
};
static const unsigned char big5_chars_ban2270 [] = {
    0xdf, 0x4f, 0xdf, 0x4e, 0xdf, 0x4b, 0xdf, 0x4d, 0xdf, 0x49, 
    0xba, 0xe1, 0xdf, 0x52, 0xb8, 0x5f, 0xdf, 0x51, 
};
static const unsigned char big5_chars_ban2271 [] = {
    0xe3, 0x5d, 
};
static const unsigned char big5_chars_ban2272 [] = {
    0xba, 0xe8, 0xe3, 0x58, 
};
static const unsigned char big5_chars_ban2273 [] = {
    0xba, 0xe7, 0xe3, 0x4e, 
};
static const unsigned char big5_chars_ban2274 [] = {
    0xe3, 0x50, 0xba, 0xe0, 0xe3, 0x55, 0xe3, 0x54, 0xe3, 0x57, 
    0xba, 0xe5, 0xe3, 0x52, 0xe3, 0x51, 
};
static const unsigned char big5_chars_ban2275 [] = {
    0xba, 0xe4, 0xba, 0xdf, 0xe3, 0x53, 0xba, 0xe2, 0xe3, 0x59, 
    0xe3, 0x5b, 
};
static const unsigned char big5_chars_ban2276 [] = {
    0xe3, 0x56, 0xe3, 0x4f, 0xba, 0xe3, 
};
static const unsigned char big5_chars_ban2277 [] = {
    0xbd, 0x69, 0xba, 0xde, 
};
static const unsigned char big5_chars_ban2278 [] = {
    0xe3, 0x5c, 
};
static const unsigned char big5_chars_ban2279 [] = {
    0xe6, 0xd9, 0xbd, 0x62, 
};
static const unsigned char big5_chars_ban2280 [] = {
    0xe6, 0xdb, 
};
static const unsigned char big5_chars_ban2281 [] = {
    0xbd, 0x63, 
};
static const unsigned char big5_chars_ban2282 [] = {
    0xbd, 0x65, 0xe6, 0xde, 
};
static const unsigned char big5_chars_ban2283 [] = {
    0xe6, 0xd6, 0xba, 0xe6, 0xe6, 0xdc, 
};
static const unsigned char big5_chars_ban2284 [] = {
    0xe6, 0xd8, 
};
static const unsigned char big5_chars_ban2285 [] = {
    0xb8, 0x60, 0xbd, 0x68, 
};
static const unsigned char big5_chars_ban2286 [] = {
    0xbd, 0x64, 
};
static const unsigned char big5_chars_ban2287 [] = {
    0xbd, 0x66, 0xbd, 0x67, 
};
static const unsigned char big5_chars_ban2288 [] = {
    0xbf, 0x76, 0xe6, 0xdd, 0xe6, 0xd7, 0xbd, 0x6a, 
};
static const unsigned char big5_chars_ban2289 [] = {
    0xe6, 0xda, 
};
static const unsigned char big5_chars_ban2290 [] = {
    0xea, 0xc0, 0xea, 0xbb, 
};
static const unsigned char big5_chars_ban2291 [] = {
    0xea, 0xc5, 0xbf, 0x74, 0xea, 0xbd, 0xbf, 0x78, 0xea, 0xc3, 
    0xea, 0xba, 0xea, 0xb7, 0xea, 0xc6, 0xc1, 0x51, 0xbf, 0x79, 
    0xea, 0xc2, 0xea, 0xb8, 0xbf, 0x77, 0xea, 0xbc, 0xbf, 0x7b, 
    0xea, 0xb9, 0xea, 0xbe, 0xbf, 0x7a, 0xea, 0xc1, 0xea, 0xc4, 
};
static const unsigned char big5_chars_ban2292 [] = {
    0xed, 0xcb, 0xed, 0xcc, 0xed, 0xbc, 0xed, 0xc3, 0xed, 0xc1, 
};
static const unsigned char big5_chars_ban2293 [] = {
    0xc1, 0x4f, 0xed, 0xc8, 0xea, 0xbf, 
};
static const unsigned char big5_chars_ban2294 [] = {
    0xed, 0xbf, 
};
static const unsigned char big5_chars_ban2295 [] = {
    0xed, 0xc9, 0xc1, 0x4e, 0xed, 0xbe, 0xed, 0xbd, 0xed, 0xc7, 
    0xed, 0xc4, 0xed, 0xc6, 
};
static const unsigned char big5_chars_ban2296 [] = {
    0xed, 0xba, 0xed, 0xca, 0xc1, 0x4c, 
};
static const unsigned char big5_chars_ban2297 [] = {
    0xed, 0xc5, 0xed, 0xce, 0xed, 0xc2, 0xc1, 0x50, 0xc1, 0x4d, 
    0xed, 0xc0, 0xed, 0xbb, 0xed, 0xcd, 0xbf, 0x75, 
};
static const unsigned char big5_chars_ban2298 [] = {
    0xf0, 0x63, 
};
static const unsigned char big5_chars_ban2299 [] = {
    0xf0, 0x61, 0xf0, 0x67, 0xc2, 0xb0, 0xf0, 0x65, 0xf0, 0x64, 
    0xc2, 0xb2, 0xf0, 0x6a, 0xc2, 0xb1, 
};
static const unsigned char big5_chars_ban2300 [] = {
    0xf0, 0x6b, 0xf0, 0x68, 0xc2, 0xae, 0xf0, 0x69, 0xf0, 0x62, 
    0xc2, 0xaf, 0xc2, 0xad, 0xf2, 0xab, 0xf0, 0x66, 
};
static const unsigned char big5_chars_ban2301 [] = {
    0xf0, 0x6c, 
};
static const unsigned char big5_chars_ban2302 [] = {
    0xf2, 0xa8, 
};
static const unsigned char big5_chars_ban2303 [] = {
    0xc3, 0xb2, 0xc3, 0xb0, 0xf2, 0xaa, 
};
static const unsigned char big5_chars_ban2304 [] = {
    0xf2, 0xac, 0xf2, 0xa9, 0xc3, 0xb1, 0xc3, 0xae, 0xc3, 0xaf, 
    0xc3, 0xb3, 
};
static const unsigned char big5_chars_ban2305 [] = {
    0xc4, 0x78, 
};
static const unsigned char big5_chars_ban2306 [] = {
    0xf4, 0xaa, 
};
static const unsigned char big5_chars_ban2307 [] = {
    0xf4, 0xa9, 0xf4, 0xa7, 0xf4, 0xa6, 0xf4, 0xa8, 
};
static const unsigned char big5_chars_ban2308 [] = {
    0xc4, 0x77, 0xc4, 0x79, 
};
static const unsigned char big5_chars_ban2309 [] = {
    0xc4, 0xf0, 
};
static const unsigned char big5_chars_ban2310 [] = {
    0xf5, 0xe5, 0xf5, 0xe4, 
};
static const unsigned char big5_chars_ban2311 [] = {
    0xf6, 0xfa, 
};
static const unsigned char big5_chars_ban2312 [] = {
    0xf6, 0xfc, 0xf6, 0xfe, 0xf6, 0xfd, 0xf6, 0xfb, 
};
static const unsigned char big5_chars_ban2313 [] = {
    0xc5, 0xa3, 0xc5, 0xa2, 
};
static const unsigned char big5_chars_ban2314 [] = {
    0xc5, 0xd3, 0xc5, 0xd2, 0xc5, 0xd4, 0xf7, 0xed, 0xf7, 0xec, 
};
static const unsigned char big5_chars_ban2315 [] = {
    0xf8, 0xfb, 0xf8, 0xb8, 0xf8, 0xfc, 0xc6, 0x58, 
};
static const unsigned char big5_chars_ban2316 [] = {
    0xc6, 0x59, 0xf9, 0x6d, 
};
static const unsigned char big5_chars_ban2317 [] = {
    0xc6, 0x7e, 0xa6, 0xcc, 
};
static const unsigned char big5_chars_ban2318 [] = {
    0xcd, 0xa8, 
};
static const unsigned char big5_chars_ban2319 [] = {
    0xd0, 0x45, 0xd0, 0x46, 0xd0, 0x44, 
};
static const unsigned char big5_chars_ban2320 [] = {
    0xac, 0xf3, 
};
static const unsigned char big5_chars_ban2321 [] = {
    0xd0, 0x47, 0xd0, 0x48, 0xd0, 0x49, 
};
static const unsigned char big5_chars_ban2322 [] = {
    0xd3, 0x49, 0xd3, 0x4f, 
};
static const unsigned char big5_chars_ban2323 [] = {
    0xd3, 0x4d, 0xaf, 0xbb, 0xd3, 0x4b, 
};
static const unsigned char big5_chars_ban2324 [] = {
    0xd3, 0x4c, 0xd3, 0x4e, 
};
static const unsigned char big5_chars_ban2325 [] = {
    0xd3, 0x4a, 0xb2, 0xc9, 
};
static const unsigned char big5_chars_ban2326 [] = {
    0xd6, 0xde, 0xb2, 0xcb, 0xd6, 0xe0, 0xb2, 0xca, 0xd6, 0xdf, 
};
static const unsigned char big5_chars_ban2327 [] = {
    0xda, 0xe8, 0xb5, 0xaf, 
};
static const unsigned char big5_chars_ban2328 [] = {
    0xda, 0xea, 0xda, 0xe7, 0xd6, 0xe1, 
};
static const unsigned char big5_chars_ban2329 [] = {
    0xb5, 0xb0, 
};
static const unsigned char big5_chars_ban2330 [] = {
    0xf9, 0xdb, 0xda, 0xe9, 
};
static const unsigned char big5_chars_ban2331 [] = {
    0xdf, 0x56, 
};
static const unsigned char big5_chars_ban2332 [] = {
    0xb8, 0x64, 0xdf, 0x54, 0xb8, 0x65, 0xdf, 0x55, 0xb8, 0x66, 
};
static const unsigned char big5_chars_ban2333 [] = {
    0xba, 0xe9, 0xe3, 0x61, 0xe3, 0x5e, 0xe3, 0x60, 0xba, 0xea, 
    0xba, 0xeb, 0xe3, 0x5f, 
};
static const unsigned char big5_chars_ban2334 [] = {
    0xe6, 0xdf, 
};
static const unsigned char big5_chars_ban2335 [] = {
    0xe6, 0xe0, 
};
static const unsigned char big5_chars_ban2336 [] = {
    0xbd, 0x6b, 0xe6, 0xe2, 0xe6, 0xe1, 
};
static const unsigned char big5_chars_ban2337 [] = {
    0xa2, 0x61, 
};
static const unsigned char big5_chars_ban2338 [] = {
    0xea, 0xca, 0xea, 0xcb, 0xea, 0xc7, 
};
static const unsigned char big5_chars_ban2339 [] = {
    0xea, 0xc8, 0xbf, 0x7c, 0xbf, 0x7d, 0xea, 0xc9, 
};
static const unsigned char big5_chars_ban2340 [] = {
    0xc1, 0x57, 
};
static const unsigned char big5_chars_ban2341 [] = {
    0xc1, 0x53, 0xc1, 0x58, 0xc1, 0x54, 0xc1, 0x56, 0xc1, 0x52, 
};
static const unsigned char big5_chars_ban2342 [] = {
    0xc1, 0x55, 
};
static const unsigned char big5_chars_ban2343 [] = {
    0xc2, 0xb3, 0xed, 0xcf, 
};
static const unsigned char big5_chars_ban2344 [] = {
    0xf2, 0xae, 
};
static const unsigned char big5_chars_ban2345 [] = {
    0xf2, 0xad, 
};
static const unsigned char big5_chars_ban2346 [] = {
    0xf4, 0xab, 0xc4, 0x7a, 0xc4, 0x7b, 0xf7, 0x41, 0xf5, 0xe6, 
};
static const unsigned char big5_chars_ban2347 [] = {
    0xf7, 0x40, 
};
static const unsigned char big5_chars_ban2348 [] = {
    0xf8, 0xfd, 0xf9, 0xa4, 0xa6, 0xcd, 
};
static const unsigned char big5_chars_ban2349 [] = {
    0xa8, 0x74, 
};
static const unsigned char big5_chars_ban2350 [] = {
    0xcd, 0xa9, 0xaa, 0xc8, 
};
static const unsigned char big5_chars_ban2351 [] = {
    0xac, 0xf6, 0xd0, 0x4c, 0xac, 0xf4, 0xd0, 0x4a, 0xac, 0xf9, 
    0xac, 0xf5, 0xac, 0xfa, 0xac, 0xf8, 0xd0, 0x4b, 0xac, 0xf7, 
    0xaf, 0xbf, 0xaf, 0xbe, 0xd3, 0x5a, 0xaf, 0xc7, 0xd3, 0x53, 
    0xd3, 0x59, 0xaf, 0xc3, 0xd3, 0x52, 0xd3, 0x58, 0xd3, 0x56, 
    0xaf, 0xc2, 0xaf, 0xc4, 0xd3, 0x55, 0xaf, 0xbd, 0xd3, 0x54, 
    0xaf, 0xc8, 0xaf, 0xc5, 0xaf, 0xc9, 0xaf, 0xc6, 0xd3, 0x51, 
    0xd3, 0x50, 0xd3, 0x57, 0xaf, 0xc0, 0xaf, 0xbc, 0xaf, 0xc1, 
};
static const unsigned char big5_chars_ban2352 [] = {
    0xd6, 0xf0, 0xd6, 0xe9, 
};
static const unsigned char big5_chars_ban2353 [] = {
    0xb5, 0xb5, 0xd6, 0xe8, 
};
static const unsigned char big5_chars_ban2354 [] = {
    0xb2, 0xcf, 0xb2, 0xd6, 0xb2, 0xd3, 0xb2, 0xd9, 0xb2, 0xd8, 
    0xb2, 0xd4, 
};
static const unsigned char big5_chars_ban2355 [] = {
    0xd6, 0xe2, 0xd6, 0xe5, 
};
static const unsigned char big5_chars_ban2356 [] = {
    0xd6, 0xe4, 0xb2, 0xd0, 0xd6, 0xe6, 0xd6, 0xef, 0xb2, 0xd1, 
    0xd6, 0xe3, 0xd6, 0xec, 0xd6, 0xed, 0xb2, 0xd2, 0xd6, 0xea, 
    0xb2, 0xd7, 0xb2, 0xcd, 0xb2, 0xd5, 0xd6, 0xe7, 0xb2, 0xcc, 
    0xd6, 0xeb, 
};
static const unsigned char big5_chars_ban2357 [] = {
    0xd6, 0xee, 
};
static const unsigned char big5_chars_ban2358 [] = {
    0xda, 0xfb, 0xda, 0xf2, 0xb5, 0xb2, 0xda, 0xf9, 0xda, 0xf6, 
    0xda, 0xee, 0xda, 0xf7, 0xb5, 0xb4, 0xda, 0xef, 
};
static const unsigned char big5_chars_ban2359 [] = {
    0xda, 0xeb, 
};
static const unsigned char big5_chars_ban2360 [] = {
    0xb8, 0x6c, 0xda, 0xf4, 
};
static const unsigned char big5_chars_ban2361 [] = {
    0xb5, 0xb1, 0xda, 0xfa, 
};
static const unsigned char big5_chars_ban2362 [] = {
    0xb5, 0xb8, 0xb5, 0xba, 0xda, 0xed, 
};
static const unsigned char big5_chars_ban2363 [] = {
    0xb5, 0xb9, 0xda, 0xf0, 0xb5, 0xb3, 0xda, 0xf8, 0xda, 0xf1, 
    0xda, 0xf5, 
};
static const unsigned char big5_chars_ban2364 [] = {
    0xda, 0xf3, 0xb5, 0xb6, 0xda, 0xec, 0xb5, 0xbb, 0xb2, 0xce, 
    0xb5, 0xb7, 0xb5, 0xbc, 
};
static const unsigned char big5_chars_ban2365 [] = {
    0xb8, 0x68, 0xdf, 0x5d, 0xdf, 0x5f, 0xdf, 0x61, 0xdf, 0x65, 
};
static const unsigned char big5_chars_ban2366 [] = {
    0xdf, 0x5b, 0xdf, 0x59, 0xb8, 0x6a, 
};
static const unsigned char big5_chars_ban2367 [] = {
    0xdf, 0x60, 0xdf, 0x64, 0xdf, 0x5c, 0xdf, 0x58, 
};
static const unsigned char big5_chars_ban2368 [] = {
    0xdf, 0x57, 
};
static const unsigned char big5_chars_ban2369 [] = {
    0xdf, 0x62, 0xdf, 0x5a, 0xdf, 0x5e, 0xb8, 0x6b, 
};
static const unsigned char big5_chars_ban2370 [] = {
    0xb8, 0x69, 0xdf, 0x66, 0xb8, 0x67, 0xdf, 0x63, 
};
static const unsigned char big5_chars_ban2371 [] = {
    0xe3, 0x72, 
};
static const unsigned char big5_chars_ban2372 [] = {
    0xba, 0xee, 0xe3, 0x6a, 0xbd, 0x78, 0xe3, 0x74, 0xba, 0xf1, 
    0xe3, 0x78, 0xba, 0xf7, 0xe3, 0x65, 
};
static const unsigned char big5_chars_ban2373 [] = {
    0xe3, 0x75, 0xe3, 0x62, 
};
static const unsigned char big5_chars_ban2374 [] = {
    0xe3, 0x77, 0xe3, 0x66, 
};
static const unsigned char big5_chars_ban2375 [] = {
    0xba, 0xfe, 0xba, 0xfb, 0xe3, 0x76, 0xe3, 0x70, 0xba, 0xed, 
    0xba, 0xf5, 0xba, 0xf4, 
};
static const unsigned char big5_chars_ban2376 [] = {
    0xba, 0xf3, 0xba, 0xf9, 
};
static const unsigned char big5_chars_ban2377 [] = {
    0xe3, 0x63, 0xba, 0xfa, 0xe3, 0x71, 0xba, 0xf6, 0xba, 0xec, 
    0xe3, 0x73, 0xba, 0xef, 0xba, 0xf0, 0xba, 0xf8, 0xe3, 0x68, 
    0xe3, 0x67, 0xe3, 0x64, 
};
static const unsigned char big5_chars_ban2378 [] = {
    0xe3, 0x6c, 0xe3, 0x69, 0xe3, 0x6d, 0xba, 0xfd, 
};
static const unsigned char big5_chars_ban2379 [] = {
    0xe3, 0x79, 0xba, 0xf2, 0xe3, 0x6e, 0xe3, 0x6f, 
};
static const unsigned char big5_chars_ban2380 [] = {
    0xe3, 0x6b, 
};
static const unsigned char big5_chars_ban2381 [] = {
    0xba, 0xfc, 
};
static const unsigned char big5_chars_ban2382 [] = {
    0xe6, 0xe7, 0xbd, 0x70, 0xbd, 0x79, 0xbd, 0x75, 0xe6, 0xe4, 
};
static const unsigned char big5_chars_ban2383 [] = {
    0xbd, 0x72, 0xbd, 0x76, 0xe6, 0xf0, 0xbd, 0x6c, 0xe6, 0xe8, 
};
static const unsigned char big5_chars_ban2384 [] = {
    0xbd, 0x74, 
};
static const unsigned char big5_chars_ban2385 [] = {
    0xe6, 0xeb, 0xe6, 0xe6, 0xbd, 0x73, 0xbd, 0x77, 0xe6, 0xe5, 
};
static const unsigned char big5_chars_ban2386 [] = {
    0xbd, 0x71, 
};
static const unsigned char big5_chars_ban2387 [] = {
    0xe6, 0xef, 0xbd, 0x6e, 0xe6, 0xee, 0xe6, 0xed, 0xbd, 0x7a, 
    0xe5, 0x72, 0xbd, 0x6d, 
};
static const unsigned char big5_chars_ban2388 [] = {
    0xe6, 0xec, 0xe6, 0xe3, 
};
static const unsigned char big5_chars_ban2389 [] = {
    0xbd, 0x7b, 0xe6, 0xea, 0xbd, 0x6f, 
};
static const unsigned char big5_chars_ban2390 [] = {
    0xe6, 0xe9, 
};
static const unsigned char big5_chars_ban2391 [] = {
    0xbf, 0xa2, 0xbf, 0xa7, 0xbf, 0x7e, 0xea, 0xd8, 0xea, 0xcf, 
    0xea, 0xdb, 0xea, 0xd3, 0xea, 0xd9, 0xbf, 0xa8, 0xbf, 0xa1, 
    0xea, 0xcc, 0xea, 0xd2, 0xea, 0xdc, 0xea, 0xd5, 0xea, 0xda, 
    0xea, 0xce, 
};
static const unsigned char big5_chars_ban2392 [] = {
    0xea, 0xd6, 0xbf, 0xa3, 0xea, 0xd4, 0xbf, 0xa6, 0xbf, 0xa5, 
    0xea, 0xd0, 0xea, 0xd1, 0xea, 0xcd, 0xea, 0xd7, 0xbf, 0xa4, 
    0xea, 0xde, 0xea, 0xdd, 
};
static const unsigned char big5_chars_ban2393 [] = {
    0xed, 0xda, 0xed, 0xd6, 0xc1, 0x5f, 
};
static const unsigned char big5_chars_ban2394 [] = {
    0xed, 0xd0, 0xc1, 0x59, 0xc1, 0x69, 0xed, 0xdc, 0xc1, 0x61, 
    0xc1, 0x5d, 0xed, 0xd3, 0xc1, 0x64, 0xc1, 0x67, 0xed, 0xde, 
    0xc1, 0x5c, 0xed, 0xd5, 0xc1, 0x65, 0xed, 0xe0, 0xed, 0xdd, 
    0xed, 0xd1, 0xc1, 0x60, 0xc1, 0x5a, 0xc1, 0x68, 0xed, 0xd8, 
    0xc1, 0x63, 0xed, 0xd2, 0xc1, 0x5e, 0xed, 0xdf, 0xc1, 0x62, 
    0xc1, 0x5b, 0xed, 0xd9, 0xc1, 0x66, 0xed, 0xd7, 
};
static const unsigned char big5_chars_ban2395 [] = {
    0xed, 0xdb, 
};
static const unsigned char big5_chars_ban2396 [] = {
    0xf0, 0x6e, 0xf0, 0x74, 0xc2, 0xb9, 0xf0, 0x77, 0xc2, 0xb4, 
    0xc2, 0xb5, 0xf0, 0x6f, 0xf0, 0x76, 0xf0, 0x71, 0xc2, 0xba, 
    0xc2, 0xb7, 
};
static const unsigned char big5_chars_ban2397 [] = {
    0xf0, 0x6d, 
};
static const unsigned char big5_chars_ban2398 [] = {
    0xc2, 0xb6, 0xf0, 0x73, 0xf0, 0x75, 0xc2, 0xb8, 0xf0, 0x72, 
    0xf0, 0x70, 
};
static const unsigned char big5_chars_ban2399 [] = {
    0xf2, 0xb8, 0xc3, 0xb7, 0xc3, 0xb8, 0xc3, 0xb4, 
};
static const unsigned char big5_chars_ban2400 [] = {
    0xc3, 0xb5, 
};
static const unsigned char big5_chars_ban2401 [] = {
    0xf2, 0xb4, 0xf2, 0xb2, 
};
static const unsigned char big5_chars_ban2402 [] = {
    0xf2, 0xb6, 0xc3, 0xba, 0xf2, 0xb7, 0xf2, 0xb0, 0xf2, 0xaf, 
    0xf2, 0xb3, 0xf2, 0xb1, 0xc3, 0xb6, 0xf2, 0xb5, 0xf4, 0xac, 
    0xc4, 0x7e, 0xc4, 0x7d, 0xf4, 0xad, 
};
static const unsigned char big5_chars_ban2403 [] = {
    0xf4, 0xaf, 0xf4, 0xae, 0xc4, 0xa1, 
};
static const unsigned char big5_chars_ban2404 [] = {
    0xf5, 0xeb, 0xf5, 0xe8, 0xf5, 0xe9, 
};
static const unsigned char big5_chars_ban2405 [] = {
    0xf5, 0xe7, 0xf5, 0xea, 0xc4, 0xf2, 0xf5, 0xec, 
};
static const unsigned char big5_chars_ban2406 [] = {
    0xc4, 0xf1, 
};
static const unsigned char big5_chars_ban2407 [] = {
    0xf7, 0x42, 
};
static const unsigned char big5_chars_ban2408 [] = {
    0xc5, 0xd5, 0xc5, 0xd7, 0xf7, 0xee, 0xc5, 0xd6, 0xf8, 0xb9, 
    0xf9, 0x40, 0xf9, 0x42, 0xf8, 0xfe, 0xf9, 0x41, 0xc6, 0x6c, 
};
static const unsigned char big5_chars_ban2409 [] = {
    0xa6, 0xce, 
};
static const unsigned char big5_chars_ban2410 [] = {
    0xac, 0xfb, 0xd2, 0x6f, 0xaf, 0xca, 
};
static const unsigned char big5_chars_ban2411 [] = {
    0xb2, 0xda, 0xda, 0xfc, 0xda, 0xfd, 
};
static const unsigned char big5_chars_ban2412 [] = {
    0xea, 0xdf, 0xc1, 0x6a, 0xed, 0xe1, 
};
static const unsigned char big5_chars_ban2413 [] = {
    0xc2, 0xbb, 
};
static const unsigned char big5_chars_ban2414 [] = {
    0xf2, 0xba, 0xf2, 0xb9, 0xc4, 0xa2, 0xf5, 0xed, 
};
static const unsigned char big5_chars_ban2415 [] = {
    0xf7, 0x43, 0xc5, 0xf8, 0xca, 0x49, 
};
static const unsigned char big5_chars_ban2416 [] = {
    0xaa, 0xc9, 0xa8, 0x75, 
};
static const unsigned char big5_chars_ban2417 [] = {
    0xd0, 0x4d, 
};
static const unsigned char big5_chars_ban2418 [] = {
    0xd3, 0x60, 0xd3, 0x5b, 0xd3, 0x5f, 0xd3, 0x5d, 0xaf, 0xcb, 
    0xd3, 0x5e, 0xd3, 0x5c, 
};
static const unsigned char big5_chars_ban2419 [] = {
    0xd6, 0xf1, 
};
static const unsigned char big5_chars_ban2420 [] = {
    0xda, 0xfe, 0xdb, 0x40, 0xdf, 0x69, 0xdf, 0x6a, 0xb8, 0x6e, 
    0xb8, 0x6f, 0xdf, 0x68, 0xdf, 0x6b, 0xdf, 0x67, 0xb8, 0x6d, 
};
static const unsigned char big5_chars_ban2421 [] = {
    0xbb, 0x40, 
};
static const unsigned char big5_chars_ban2422 [] = {
    0xb8, 0x70, 0xe3, 0x7a, 
};
static const unsigned char big5_chars_ban2423 [] = {
    0xbd, 0x7c, 0xe6, 0xf1, 0xbd, 0x7d, 
};
static const unsigned char big5_chars_ban2424 [] = {
    0xbf, 0xa9, 0xea, 0xe2, 0xea, 0xe0, 0xea, 0xe1, 0xed, 0xe4, 
    0xed, 0xe3, 0xed, 0xe2, 
};
static const unsigned char big5_chars_ban2425 [] = {
    0xf2, 0xbb, 
};
static const unsigned char big5_chars_ban2426 [] = {
    0xc3, 0xb9, 0xf2, 0xbc, 0xf7, 0x44, 0xc5, 0xf9, 0xf8, 0xba, 
    0xa6, 0xcf, 0xaa, 0xcb, 0xaa, 0xca, 0xd0, 0x4f, 0xac, 0xfc, 
};
static const unsigned char big5_chars_ban2427 [] = {
    0xd0, 0x4e, 0xd3, 0x62, 
};
static const unsigned char big5_chars_ban2428 [] = {
    0xaf, 0xcc, 0xd6, 0xf2, 0xd3, 0x61, 
};
static const unsigned char big5_chars_ban2429 [] = {
    0xb2, 0xdc, 0xd6, 0xf5, 0xd6, 0xf3, 0xd6, 0xf4, 0xb2, 0xdb, 
};
static const unsigned char big5_chars_ban2430 [] = {
    0xdb, 0x42, 0xdb, 0x43, 0xdb, 0x41, 
};
static const unsigned char big5_chars_ban2431 [] = {
    0xb8, 0x73, 0xdf, 0x6d, 0xdf, 0x6c, 0xdf, 0x6e, 0xb8, 0x72, 
    0xb8, 0x71, 
};
static const unsigned char big5_chars_ban2432 [] = {
    0xe6, 0xf2, 0xe6, 0xf4, 
};
static const unsigned char big5_chars_ban2433 [] = {
    0xbd, 0x7e, 0xe6, 0xf3, 0xea, 0xe3, 0xbf, 0xaa, 0xf0, 0x79, 
};
static const unsigned char big5_chars_ban2434 [] = {
    0xf0, 0x78, 0xc3, 0xbb, 0xf2, 0xbd, 0xc3, 0xbd, 0xc3, 0xbc, 
    0xf4, 0xb0, 0xf5, 0xee, 0xc4, 0xf3, 0xa6, 0xd0, 0xd0, 0x50, 
    0xac, 0xfd, 0xd3, 0x65, 0xaf, 0xce, 0xd3, 0x64, 0xd3, 0x63, 
};
static const unsigned char big5_chars_ban2435 [] = {
    0xaf, 0xcd, 
};
static const unsigned char big5_chars_ban2436 [] = {
    0xd6, 0xfb, 
};
static const unsigned char big5_chars_ban2437 [] = {
    0xd6, 0xfd, 0xd6, 0xf6, 0xd6, 0xf7, 0xb2, 0xdd, 0xd6, 0xf8, 
    0xb2, 0xde, 0xd6, 0xfc, 0xd6, 0xf9, 0xd6, 0xfa, 0xb2, 0xdf, 
};
static const unsigned char big5_chars_ban2438 [] = {
    0xb5, 0xbe, 0xb5, 0xbf, 
};
static const unsigned char big5_chars_ban2439 [] = {
    0xdb, 0x44, 
};
static const unsigned char big5_chars_ban2440 [] = {
    0xdf, 0x6f, 0xdf, 0x70, 
};
static const unsigned char big5_chars_ban2441 [] = {
    0xe3, 0x7e, 0xbb, 0x43, 0xbb, 0x41, 0xbb, 0x42, 0xe3, 0x7b, 
    0xe3, 0x7c, 
};
static const unsigned char big5_chars_ban2442 [] = {
    0xe3, 0x7d, 0xe6, 0xf9, 
};
static const unsigned char big5_chars_ban2443 [] = {
    0xe6, 0xfa, 0xbd, 0xa1, 0xe6, 0xf7, 0xe6, 0xf6, 0xe6, 0xf8, 
    0xe6, 0xf5, 0xbf, 0xad, 0xea, 0xe4, 0xbf, 0xab, 0xbf, 0xac, 
    0xed, 0xe6, 0xc1, 0x6b, 0xed, 0xe5, 0xef, 0xa8, 
};
static const unsigned char big5_chars_ban2444 [] = {
    0xf0, 0x7a, 0xf0, 0x7b, 0xc2, 0xbc, 
};
static const unsigned char big5_chars_ban2445 [] = {
    0xc2, 0xbd, 0xc1, 0x6c, 0xf2, 0xbe, 0xf2, 0xbf, 0xf4, 0xb1, 
    0xc4, 0xa3, 0xa6, 0xd1, 
};
static const unsigned char big5_chars_ban2446 [] = {
    0xa6, 0xd2, 0xac, 0xfe, 0xaa, 0xcc, 0xaf, 0xcf, 0xd0, 0x51, 
};
static const unsigned char big5_chars_ban2447 [] = {
    0xb5, 0xc0, 0xa6, 0xd3, 0xad, 0x41, 0xd0, 0x52, 0xd0, 0x53, 
    0xad, 0x40, 0xad, 0x42, 0xa6, 0xd4, 
};
static const unsigned char big5_chars_ban2448 [] = {
    0xd0, 0x54, 0xaf, 0xd1, 0xd3, 0x66, 0xaf, 0xd3, 0xaf, 0xd0, 
    0xaf, 0xd2, 
};
static const unsigned char big5_chars_ban2449 [] = {
    0xd7, 0x41, 0xb2, 0xe0, 
};
static const unsigned char big5_chars_ban2450 [] = {
    0xd7, 0x40, 0xd6, 0xfe, 
};
static const unsigned char big5_chars_ban2451 [] = {
    0xdf, 0x71, 
};
static const unsigned char big5_chars_ban2452 [] = {
    0xe3, 0xa1, 
};
static const unsigned char big5_chars_ban2453 [] = {
    0xbd, 0xa2, 
};
static const unsigned char big5_chars_ban2454 [] = {
    0xbf, 0xae, 0xea, 0xe6, 0xea, 0xe5, 
};
static const unsigned char big5_chars_ban2455 [] = {
    0xed, 0xe7, 
};
static const unsigned char big5_chars_ban2456 [] = {
    0xf5, 0xef, 
};
static const unsigned char big5_chars_ban2457 [] = {
    0xa6, 0xd5, 0xcb, 0x73, 0xcd, 0xaa, 0xad, 0x43, 0xd0, 0x55, 
};
static const unsigned char big5_chars_ban2458 [] = {
    0xd3, 0x68, 
};
static const unsigned char big5_chars_ban2459 [] = {
    0xaf, 0xd4, 0xd3, 0x67, 0xaf, 0xd5, 
};
static const unsigned char big5_chars_ban2460 [] = {
    0xd7, 0x43, 
};
static const unsigned char big5_chars_ban2461 [] = {
    0xb2, 0xe2, 0xd7, 0x42, 0xd7, 0x44, 
};
static const unsigned char big5_chars_ban2462 [] = {
    0xb2, 0xe1, 
};
static const unsigned char big5_chars_ban2463 [] = {
    0xdb, 0x46, 0xdb, 0x47, 0xdb, 0x45, 0xb5, 0xc1, 
};
static const unsigned char big5_chars_ban2464 [] = {
    0xb8, 0x74, 
};
static const unsigned char big5_chars_ban2465 [] = {
    0xb8, 0x75, 
};
static const unsigned char big5_chars_ban2466 [] = {
    0xbb, 0x45, 
};
static const unsigned char big5_chars_ban2467 [] = {
    0xe3, 0xa3, 0xe3, 0xa2, 0xbb, 0x44, 
};
static const unsigned char big5_chars_ban2468 [] = {
    0xe6, 0xfb, 
};
static const unsigned char big5_chars_ban2469 [] = {
    0xe6, 0xfc, 
};
static const unsigned char big5_chars_ban2470 [] = {
    0xea, 0xe7, 
};
static const unsigned char big5_chars_ban2471 [] = {
    0xc1, 0x70, 0xc1, 0x6f, 0xc1, 0x6d, 0xc1, 0x6e, 0xc1, 0x71, 
};
static const unsigned char big5_chars_ban2472 [] = {
    0xf0, 0x7c, 0xc2, 0xbf, 0xc2, 0xbe, 0xf2, 0xc0, 0xf4, 0xb2, 
};
static const unsigned char big5_chars_ban2473 [] = {
    0xc5, 0xa5, 0xc5, 0xa4, 0xa6, 0xd6, 
};
static const unsigned char big5_chars_ban2474 [] = {
    0xd1, 0xfb, 
};
static const unsigned char big5_chars_ban2475 [] = {
    0xb8, 0x77, 0xb5, 0xc2, 0xb8, 0x76, 0xbb, 0x46, 
};
static const unsigned char big5_chars_ban2476 [] = {
    0xa6, 0xd7, 0xc9, 0xa9, 0xa6, 0xd8, 0xa6, 0xd9, 
};
static const unsigned char big5_chars_ban2477 [] = {
    0xcd, 0xab, 0xcb, 0x76, 
};
static const unsigned char big5_chars_ban2478 [] = {
    0xcb, 0x77, 0xa8, 0x77, 
};
static const unsigned char big5_chars_ban2479 [] = {
    0xcb, 0x74, 0xa8, 0x76, 
};
static const unsigned char big5_chars_ban2480 [] = {
    0xa8, 0x79, 0xcb, 0x75, 0xa8, 0x7b, 0xa8, 0x7a, 0xcb, 0x78, 
    0xa8, 0x78, 
};
static const unsigned char big5_chars_ban2481 [] = {
    0xaa, 0xd1, 0xaa, 0xcf, 0xcd, 0xad, 
};
static const unsigned char big5_chars_ban2482 [] = {
    0xaa, 0xce, 
};
static const unsigned char big5_chars_ban2483 [] = {
    0xaa, 0xd3, 0xaa, 0xd5, 0xaa, 0xd2, 
};
static const unsigned char big5_chars_ban2484 [] = {
    0xcd, 0xb0, 0xcd, 0xac, 0xaa, 0xd6, 
};
static const unsigned char big5_chars_ban2485 [] = {
    0xaa, 0xd0, 0xa8, 0x7c, 
};
static const unsigned char big5_chars_ban2486 [] = {
    0xaa, 0xd4, 0xcd, 0xaf, 
};
static const unsigned char big5_chars_ban2487 [] = {
    0xcd, 0xae, 
};
static const unsigned char big5_chars_ban2488 [] = {
    0xaa, 0xcd, 
};
static const unsigned char big5_chars_ban2489 [] = {
    0xd0, 0x5b, 0xad, 0x47, 0xad, 0x48, 0xd0, 0x5d, 
};
static const unsigned char big5_chars_ban2490 [] = {
    0xd0, 0x57, 0xd0, 0x5a, 0xd0, 0x63, 0xd0, 0x61, 
};
static const unsigned char big5_chars_ban2491 [] = {
    0xad, 0x49, 0xd0, 0x67, 0xad, 0x4c, 0xd0, 0x64, 0xd0, 0x5c, 
    0xd0, 0x59, 
};
static const unsigned char big5_chars_ban2492 [] = {
    0xdb, 0x49, 0xd0, 0x62, 0xad, 0x44, 0xd0, 0x65, 0xd0, 0x56, 
    0xd0, 0x5f, 0xad, 0x46, 0xad, 0x4b, 0xd0, 0x60, 0xad, 0x4f, 
    0xad, 0x4d, 
};
static const unsigned char big5_chars_ban2493 [] = {
    0xd0, 0x58, 0xad, 0x4a, 
};
static const unsigned char big5_chars_ban2494 [] = {
    0xd0, 0x5e, 0xad, 0x4e, 0xad, 0x45, 0xd0, 0x66, 
};
static const unsigned char big5_chars_ban2495 [] = {
    0xaf, 0xda, 
};
static const unsigned char big5_chars_ban2496 [] = {
    0xaf, 0xe3, 0xaf, 0xd8, 0xaf, 0xd6, 0xd3, 0x6a, 0xaf, 0xde, 
    0xaf, 0xdb, 0xd3, 0x6c, 
};
static const unsigned char big5_chars_ban2497 [] = {
    0xaf, 0xdd, 0xd3, 0x6b, 0xd3, 0x69, 0xd3, 0x6e, 0xaf, 0xe2, 
    0xaf, 0xe0, 0xdb, 0x48, 
};
static const unsigned char big5_chars_ban2498 [] = {
    0xd3, 0x6f, 0xd3, 0x6d, 0xaf, 0xd7, 
};
static const unsigned char big5_chars_ban2499 [] = {
    0xaf, 0xd9, 0xaf, 0xdc, 
};
static const unsigned char big5_chars_ban2500 [] = {
    0xaf, 0xdf, 
};
static const unsigned char big5_chars_ban2501 [] = {
    0xaf, 0xe1, 
};
static const unsigned char big5_chars_ban2502 [] = {
    0xd7, 0x4e, 0xb2, 0xe4, 
};
static const unsigned char big5_chars_ban2503 [] = {
    0xd7, 0x45, 0xd7, 0x47, 
};
static const unsigned char big5_chars_ban2504 [] = {
    0xd7, 0x48, 
};
static const unsigned char big5_chars_ban2505 [] = {
    0xd7, 0x50, 0xd7, 0x4c, 0xd7, 0x4a, 
};
static const unsigned char big5_chars_ban2506 [] = {
    0xd7, 0x4d, 0xd7, 0x51, 0xb2, 0xe5, 0xb2, 0xe9, 0xd7, 0x46, 
};
static const unsigned char big5_chars_ban2507 [] = {
    0xd7, 0x4f, 
};
static const unsigned char big5_chars_ban2508 [] = {
    0xb2, 0xe7, 
};
static const unsigned char big5_chars_ban2509 [] = {
    0xb2, 0xe6, 0xd7, 0x4b, 0xd7, 0x49, 
};
static const unsigned char big5_chars_ban2510 [] = {
    0xb2, 0xe3, 0xb2, 0xe8, 
};
static const unsigned char big5_chars_ban2511 [] = {
    0xb5, 0xc8, 0xdb, 0x51, 
};
static const unsigned char big5_chars_ban2512 [] = {
    0xdb, 0x4f, 0xb5, 0xca, 
};
static const unsigned char big5_chars_ban2513 [] = {
    0xdb, 0x4a, 0xdf, 0xa1, 
};
static const unsigned char big5_chars_ban2514 [] = {
    0xb5, 0xc9, 0xdb, 0x4e, 
};
static const unsigned char big5_chars_ban2515 [] = {
    0xdb, 0x4b, 0xb5, 0xc5, 0xb5, 0xcb, 0xdb, 0x50, 0xb5, 0xc7, 
    0xdb, 0x4d, 0xbb, 0x47, 0xb5, 0xc6, 0xdb, 0x4c, 0xb5, 0xcc, 
    0xb5, 0xc4, 0xb5, 0xc3, 
};
static const unsigned char big5_chars_ban2516 [] = {
    0xdf, 0x77, 0xdf, 0x75, 
};
static const unsigned char big5_chars_ban2517 [] = {
    0xdf, 0x7b, 
};
static const unsigned char big5_chars_ban2518 [] = {
    0xdf, 0x73, 0xdf, 0xa2, 0xdf, 0x78, 
};
static const unsigned char big5_chars_ban2519 [] = {
    0xdf, 0x72, 0xb8, 0x7b, 0xb8, 0xa3, 0xdf, 0x7d, 
};
static const unsigned char big5_chars_ban2520 [] = {
    0xdf, 0x76, 
};
static const unsigned char big5_chars_ban2521 [] = {
    0xb8, 0x7e, 
};
static const unsigned char big5_chars_ban2522 [] = {
    0xb8, 0x7c, 0xdf, 0x7e, 0xb8, 0x79, 0xb8, 0x78, 0xdf, 0x79, 
    0xb8, 0x7d, 0xb5, 0xcd, 
};
static const unsigned char big5_chars_ban2523 [] = {
    0xdf, 0x7c, 0xdf, 0x74, 0xb8, 0x7a, 0xb8, 0xa1, 0xb8, 0xa2, 
};
static const unsigned char big5_chars_ban2524 [] = {
    0xbb, 0x4c, 0xbb, 0x48, 
};
static const unsigned char big5_chars_ban2525 [] = {
    0xbb, 0x4d, 0xe3, 0xa6, 
};
static const unsigned char big5_chars_ban2526 [] = {
    0xe3, 0xa5, 0xe3, 0xa7, 0xbb, 0x4a, 0xe3, 0xa4, 0xbb, 0x4b, 
    0xe3, 0xaa, 0xe3, 0xa9, 0xe3, 0xa8, 
};
static const unsigned char big5_chars_ban2527 [] = {
    0xbb, 0x49, 
};
static const unsigned char big5_chars_ban2528 [] = {
    0xe7, 0x41, 
};
static const unsigned char big5_chars_ban2529 [] = {
    0xe7, 0x44, 0xbd, 0xa8, 0xe7, 0x43, 0xbd, 0xa7, 0xbd, 0xa3, 
    0xbd, 0xa4, 0xbd, 0xa5, 0xe7, 0x40, 0xe6, 0xfe, 0xbd, 0xa6, 
};
static const unsigned char big5_chars_ban2530 [] = {
    0xe7, 0x42, 0xe6, 0xfd, 
};
static const unsigned char big5_chars_ban2531 [] = {
    0xea, 0xe9, 0xea, 0xf3, 0xbf, 0xb1, 0xbf, 0xb0, 
};
static const unsigned char big5_chars_ban2532 [] = {
    0xea, 0xed, 0xea, 0xef, 
};
static const unsigned char big5_chars_ban2533 [] = {
    0xea, 0xea, 
};
static const unsigned char big5_chars_ban2534 [] = {
    0xea, 0xee, 0xea, 0xe8, 0xea, 0xf1, 0xbf, 0xaf, 0xea, 0xf0, 
    0xea, 0xec, 
};
static const unsigned char big5_chars_ban2535 [] = {
    0xea, 0xf2, 
};
static const unsigned char big5_chars_ban2536 [] = {
    0xea, 0xeb, 0xc1, 0x74, 0xed, 0xe8, 0xed, 0xee, 0xc1, 0x78, 
    0xc1, 0x7a, 0xc1, 0x77, 0xc1, 0x76, 
};
static const unsigned char big5_chars_ban2537 [] = {
    0xc1, 0x75, 0xc1, 0x73, 0xed, 0xe9, 0xed, 0xec, 0xc1, 0x72, 
    0xed, 0xed, 
};
static const unsigned char big5_chars_ban2538 [] = {
    0xc1, 0x79, 0xed, 0xeb, 
};
static const unsigned char big5_chars_ban2539 [] = {
    0xed, 0xea, 0xc2, 0xc0, 
};
static const unsigned char big5_chars_ban2540 [] = {
    0xc2, 0xc1, 0xf0, 0xa1, 0xf0, 0x7d, 0xf0, 0x7e, 
};
static const unsigned char big5_chars_ban2541 [] = {
    0xf2, 0xc2, 
};
static const unsigned char big5_chars_ban2542 [] = {
    0xf2, 0xc1, 0xc3, 0xbe, 0xf4, 0xb4, 0xc4, 0xa4, 0xf4, 0xb3, 
};
static const unsigned char big5_chars_ban2543 [] = {
    0xf5, 0xf0, 0xf7, 0x45, 0xc5, 0xa6, 0xf9, 0x43, 0xf9, 0x44, 
    0xc5, 0xd8, 0xa6, 0xda, 
};
static const unsigned char big5_chars_ban2544 [] = {
    0xaa, 0xd7, 0xdb, 0x52, 0xbb, 0x4e, 0xc1, 0x7b, 0xed, 0xef, 
    0xa6, 0xdb, 
};
static const unsigned char big5_chars_ban2545 [] = {
    0xaf, 0xe5, 0xaf, 0xe4, 0xdb, 0x53, 
};
static const unsigned char big5_chars_ban2546 [] = {
    0xea, 0xf4, 0xa6, 0xdc, 0xad, 0x50, 
};
static const unsigned char big5_chars_ban2547 [] = {
    0xdb, 0x54, 0xdb, 0x55, 0xdb, 0x56, 0xbb, 0x4f, 0xbf, 0xb2, 
    0xa6, 0xdd, 
};
static const unsigned char big5_chars_ban2548 [] = {
    0xaa, 0xd8, 0xd0, 0x68, 0xaf, 0xe6, 0xd3, 0x70, 0xb2, 0xea, 
};
static const unsigned char big5_chars_ban2549 [] = {
    0xdb, 0x57, 0xb8, 0xa4, 
};
static const unsigned char big5_chars_ban2550 [] = {
    0xbb, 0x50, 0xbf, 0xb3, 0xc1, 0x7c, 0xc2, 0xc2, 0xf4, 0xb5, 
    0xa6, 0xde, 0xaa, 0xd9, 
};
static const unsigned char big5_chars_ban2551 [] = {
    0xaf, 0xe7, 0xd7, 0x52, 0xb5, 0xce, 
};
static const unsigned char big5_chars_ban2552 [] = {
    0xbb, 0x51, 0xe3, 0xab, 0xe7, 0x45, 
};
static const unsigned char big5_chars_ban2553 [] = {
    0xa6, 0xdf, 0xb5, 0xcf, 0xdf, 0xa3, 0xbb, 0x52, 0xa6, 0xe0, 
    0xcd, 0xb1, 0xd0, 0x69, 0xad, 0x51, 
};
static const unsigned char big5_chars_ban2554 [] = {
    0xd3, 0x72, 
};
static const unsigned char big5_chars_ban2555 [] = {
    0xaf, 0xea, 
};
static const unsigned char big5_chars_ban2556 [] = {
    0xaf, 0xe8, 0xaf, 0xe9, 0xaf, 0xeb, 
};
static const unsigned char big5_chars_ban2557 [] = {
    0xd3, 0x71, 
};
static const unsigned char big5_chars_ban2558 [] = {
    0xd7, 0x57, 0xd7, 0x54, 0xd7, 0x56, 0xb2, 0xeb, 0xb2, 0xed, 
    0xb2, 0xec, 0xd7, 0x53, 0xb2, 0xee, 0xd7, 0x55, 
};
static const unsigned char big5_chars_ban2559 [] = {
    0xdb, 0x58, 0xdb, 0x59, 
};
static const unsigned char big5_chars_ban2560 [] = {
    0xdb, 0x5a, 0xdf, 0xa6, 
};
static const unsigned char big5_chars_ban2561 [] = {
    0xdf, 0xa7, 
};
static const unsigned char big5_chars_ban2562 [] = {
    0xdf, 0xa5, 0xdf, 0xa8, 
};
static const unsigned char big5_chars_ban2563 [] = {
    0xb8, 0xa5, 
};
static const unsigned char big5_chars_ban2564 [] = {
    0xdf, 0xa4, 
};
static const unsigned char big5_chars_ban2565 [] = {
    0xbb, 0x53, 
};
static const unsigned char big5_chars_ban2566 [] = {
    0xe7, 0x4a, 0xe7, 0x46, 0xe7, 0x49, 0xe7, 0x4b, 0xe7, 0x48, 
    0xe7, 0x47, 
};
static const unsigned char big5_chars_ban2567 [] = {
    0xea, 0xf5, 0xea, 0xf6, 0xea, 0xf7, 0xbf, 0xb4, 0xbf, 0xb5, 
    0xed, 0xf1, 0xed, 0xf0, 0xed, 0xf2, 
};
static const unsigned char big5_chars_ban2568 [] = {
    0xf0, 0xa3, 0xf0, 0xa2, 
};
static const unsigned char big5_chars_ban2569 [] = {
    0xf2, 0xc4, 
};
static const unsigned char big5_chars_ban2570 [] = {
    0xf2, 0xc5, 0xf2, 0xc3, 
};
static const unsigned char big5_chars_ban2571 [] = {
    0xc4, 0xa5, 
};
static const unsigned char big5_chars_ban2572 [] = {
    0xf4, 0xb6, 0xf4, 0xb7, 
};
static const unsigned char big5_chars_ban2573 [] = {
    0xf7, 0x46, 0xf7, 0xef, 0xf8, 0xbb, 0xa6, 0xe1, 0xa8, 0x7d, 
};
static const unsigned char big5_chars_ban2574 [] = {
    0xc1, 0x7d, 0xa6, 0xe2, 
};
static const unsigned char big5_chars_ban2575 [] = {
    0xd7, 0x58, 0xdb, 0x5b, 
};
static const unsigned char big5_chars_ban2576 [] = {
    0xc6, 0x41, 0xca, 0x4a, 
};
static const unsigned char big5_chars_ban2577 [] = {
    0xca, 0x4b, 0xca, 0x4d, 0xa6, 0xe3, 0xca, 0x4e, 0xca, 0x4c, 
};
static const unsigned char big5_chars_ban2578 [] = {
    0xcb, 0xa2, 0xcb, 0xa3, 0xcb, 0x7b, 
};
static const unsigned char big5_chars_ban2579 [] = {
    0xcb, 0xa1, 0xa8, 0xa1, 
};
static const unsigned char big5_chars_ban2580 [] = {
    0xa8, 0xa2, 0xcb, 0x7c, 0xcb, 0x7a, 0xcb, 0x79, 0xcb, 0x7d, 
    0xa8, 0x7e, 0xcb, 0x7e, 0xd0, 0x6a, 
};
static const unsigned char big5_chars_ban2581 [] = {
    0xcd, 0xb6, 0xaa, 0xdc, 0xcd, 0xb5, 0xcd, 0xb7, 
};
static const unsigned char big5_chars_ban2582 [] = {
    0xaa, 0xdb, 0xcd, 0xbc, 0xaa, 0xdf, 0xcd, 0xb2, 0xcd, 0xc0, 
    0xcd, 0xc6, 0xaa, 0xe6, 0xcd, 0xc3, 0xaa, 0xe3, 
};
static const unsigned char big5_chars_ban2583 [] = {
    0xcd, 0xb9, 0xcd, 0xbf, 0xcd, 0xc1, 
};
static const unsigned char big5_chars_ban2584 [] = {
    0xcd, 0xb4, 0xaa, 0xe2, 0xaa, 0xdd, 0xcd, 0xba, 0xaa, 0xe4, 
    0xaa, 0xe7, 0xaa, 0xe1, 
};
static const unsigned char big5_chars_ban2585 [] = {
    0xaa, 0xda, 0xcd, 0xbe, 0xcd, 0xb8, 0xcd, 0xc5, 0xaa, 0xe9, 
    0xaa, 0xe5, 0xaa, 0xe0, 0xcd, 0xbd, 0xaf, 0xec, 0xcd, 0xbb, 
    0xaa, 0xde, 0xaa, 0xe8, 
};
static const unsigned char big5_chars_ban2586 [] = {
    0xcd, 0xb3, 
};
static const unsigned char big5_chars_ban2587 [] = {
    0xcd, 0xc2, 0xcd, 0xc4, 
};
static const unsigned char big5_chars_ban2588 [] = {
    0xad, 0x62, 0xad, 0x5c, 0xad, 0x64, 0xad, 0x61, 0xd0, 0x71, 
    0xd0, 0x74, 0xad, 0x5d, 
};
static const unsigned char big5_chars_ban2589 [] = {
    0xd0, 0x6b, 
};
static const unsigned char big5_chars_ban2590 [] = {
    0xad, 0x56, 0xad, 0x60, 
};
static const unsigned char big5_chars_ban2591 [] = {
    0xad, 0x63, 0xad, 0x65, 0xd0, 0xa2, 0xd0, 0x77, 
};
static const unsigned char big5_chars_ban2592 [] = {
    0xad, 0x55, 0xd0, 0xa1, 0xad, 0x59, 0xad, 0x57, 0xad, 0x52, 
    0xd0, 0x6f, 
};
static const unsigned char big5_chars_ban2593 [] = {
    0xd0, 0x7e, 0xd0, 0x73, 0xd0, 0x76, 0xd0, 0xa5, 
};
static const unsigned char big5_chars_ban2594 [] = {
    0xad, 0x66, 0xd0, 0x7d, 0xad, 0x5e, 0xd0, 0x78, 0xd0, 0xa4, 
    0xd0, 0x75, 0xd0, 0x79, 0xd0, 0x7c, 
};
static const unsigned char big5_chars_ban2595 [] = {
    0xd0, 0x6d, 0xd0, 0xa3, 0xd0, 0x7b, 
};
static const unsigned char big5_chars_ban2596 [] = {
    0xd0, 0x6c, 
};
static const unsigned char big5_chars_ban2597 [] = {
    0xd0, 0x70, 0xad, 0x5f, 0xad, 0x5a, 0xad, 0x53, 0xad, 0x58, 
    0xad, 0x54, 0xad, 0x67, 0xd0, 0x6e, 0xd3, 0xa5, 0xad, 0x5b, 
};
static const unsigned char big5_chars_ban2598 [] = {
    0xd0, 0x7a, 0xce, 0x41, 
};
static const unsigned char big5_chars_ban2599 [] = {
    0xd3, 0xa8, 0xaf, 0xfa, 
};
static const unsigned char big5_chars_ban2600 [] = {
    0xd3, 0x76, 
};
static const unsigned char big5_chars_ban2601 [] = {
    0xd3, 0xa3, 0xd3, 0x7d, 
};
static const unsigned char big5_chars_ban2602 [] = {
    0xd3, 0xb2, 
};
static const unsigned char big5_chars_ban2603 [] = {
    0xd3, 0xaa, 
};
static const unsigned char big5_chars_ban2604 [] = {
    0xd3, 0x7e, 
};
static const unsigned char big5_chars_ban2605 [] = {
    0xd3, 0xa9, 0xd3, 0x78, 0xd3, 0x7c, 0xd3, 0xb5, 0xaf, 0xfd, 
    0xd3, 0xad, 0xd3, 0xa4, 0xaf, 0xed, 0xd3, 0xb3, 0xd3, 0x74, 
};
static const unsigned char big5_chars_ban2606 [] = {
    0xd3, 0xac, 
};
static const unsigned char big5_chars_ban2607 [] = {
    0xaf, 0xfc, 0xaf, 0xf7, 0xd3, 0x73, 0xaf, 0xf5, 0xaf, 0xf4, 
    0xaf, 0xf9, 0xd3, 0xab, 0xaf, 0xf1, 0xaf, 0xf8, 0xd0, 0x72, 
    0xdb, 0x5c, 0xd3, 0xa6, 
};
static const unsigned char big5_chars_ban2608 [] = {
    0xd3, 0x7a, 0xaf, 0xfb, 0xd3, 0x7b, 0xd3, 0xa1, 0xaf, 0xfe, 
    0xd3, 0x75, 0xd3, 0xaf, 
};
static const unsigned char big5_chars_ban2609 [] = {
    0xd3, 0xae, 0xd3, 0xb6, 0xaf, 0xf3, 0xaf, 0xf0, 0xd3, 0xb4, 
    0xd3, 0xb0, 0xd3, 0xa7, 0xd3, 0xa2, 0xaf, 0xf6, 0xaf, 0xf2, 
    0xd3, 0x77, 0xaf, 0xee, 0xd3, 0xb1, 0xaf, 0xef, 
};
static const unsigned char big5_chars_ban2610 [] = {
    0xd3, 0x79, 
};
static const unsigned char big5_chars_ban2611 [] = {
    0xd7, 0x5e, 0xd7, 0x60, 0xd7, 0x65, 0xd7, 0x79, 0xb2, 0xfc, 
    0xb2, 0xf2, 
};
static const unsigned char big5_chars_ban2612 [] = {
    0xd7, 0x5d, 0xb2, 0xfd, 0xb2, 0xfe, 0xd7, 0x68, 0xd7, 0x6f, 
    0xd7, 0x75, 
};
static const unsigned char big5_chars_ban2613 [] = {
    0xd7, 0x62, 
};
static const unsigned char big5_chars_ban2614 [] = {
    0xd7, 0x69, 
};
static const unsigned char big5_chars_ban2615 [] = {
    0xb3, 0x40, 0xd7, 0x77, 0xd7, 0x72, 0xb2, 0xfa, 0xb2, 0xf8, 
    0xd7, 0x6e, 0xd7, 0x6a, 0xd7, 0x5c, 0xb2, 0xef, 0xd7, 0x61, 
    0xd7, 0x59, 
};
static const unsigned char big5_chars_ban2616 [] = {
    0xb2, 0xf7, 0xb2, 0xf9, 0xd7, 0x66, 0xd7, 0x63, 0xb2, 0xf4, 
    0xd7, 0x73, 0xb2, 0xf1, 0xd7, 0x64, 0xd7, 0x7a, 0xd7, 0x6c, 
};
static const unsigned char big5_chars_ban2617 [] = {
    0xd7, 0x6b, 0xb2, 0xf0, 
};
static const unsigned char big5_chars_ban2618 [] = {
    0xb2, 0xfb, 
};
static const unsigned char big5_chars_ban2619 [] = {
    0xb2, 0xf3, 0xd7, 0x5a, 0xd7, 0x5f, 0xd7, 0x70, 0xd7, 0x76, 
    0xb3, 0x41, 0xd7, 0x5b, 0xd7, 0x67, 0xd7, 0x6d, 0xb2, 0xf6, 
};
static const unsigned char big5_chars_ban2620 [] = {
    0xd7, 0x78, 0xd7, 0x71, 0xd7, 0x74, 
};
static const unsigned char big5_chars_ban2621 [] = {
    0xb2, 0xf5, 
};
static const unsigned char big5_chars_ban2622 [] = {
    0xdb, 0x6c, 0xdb, 0x60, 0xb5, 0xd7, 0xdb, 0x7d, 0xdb, 0xa7, 
    0xdb, 0xaa, 0xb5, 0xd5, 0xdb, 0x68, 0xdb, 0xa3, 0xdb, 0x69, 
    0xdb, 0x77, 0xb5, 0xe2, 0xdb, 0x73, 0xb5, 0xdf, 
};
static const unsigned char big5_chars_ban2623 [] = {
    0xdb, 0x74, 0xdb, 0x5d, 
};
static const unsigned char big5_chars_ban2624 [] = {
    0xdb, 0xa4, 
};
static const unsigned char big5_chars_ban2625 [] = {
    0xb5, 0xe8, 0xdb, 0xa1, 0xdb, 0x75, 0xdb, 0xac, 0xdb, 0x70, 
    0xdf, 0xc8, 
};
static const unsigned char big5_chars_ban2626 [] = {
    0xdb, 0xaf, 0xb5, 0xe6, 0xdb, 0x6e, 0xdb, 0x7a, 0xb5, 0xe9, 
    0xb5, 0xd4, 0xdb, 0x72, 0xdb, 0xad, 0xdb, 0x6b, 0xdb, 0x64, 
    0xdb, 0x6f, 
};
static const unsigned char big5_chars_ban2627 [] = {
    0xdb, 0x63, 0xdb, 0x61, 0xb5, 0xd0, 0xdb, 0xa5, 0xdb, 0x6a, 
    0xdb, 0xa8, 
};
static const unsigned char big5_chars_ban2628 [] = {
    0xdb, 0xa9, 0xb5, 0xd8, 0xb5, 0xdd, 0xb5, 0xd9, 0xb5, 0xe1, 
    0xdb, 0x7e, 0xb5, 0xda, 0xdb, 0x76, 0xdb, 0x66, 
};
static const unsigned char big5_chars_ban2629 [] = {
    0xb5, 0xd2, 0xdb, 0x5e, 0xdb, 0xa2, 0xdb, 0xab, 0xdb, 0x65, 
    0xb5, 0xe0, 0xdb, 0xb0, 0xdb, 0x71, 
};
static const unsigned char big5_chars_ban2630 [] = {
    0xdb, 0x6d, 
};
static const unsigned char big5_chars_ban2631 [] = {
    0xb5, 0xd1, 0xb5, 0xe5, 
};
static const unsigned char big5_chars_ban2632 [] = {
    0xdb, 0x7c, 0xb5, 0xe7, 
};
static const unsigned char big5_chars_ban2633 [] = {
    0xdb, 0x78, 0xb5, 0xdc, 0xb5, 0xd6, 0xb5, 0xde, 0xb5, 0xd3, 
    0xb5, 0xe4, 0xdb, 0x79, 0xdb, 0x67, 0xdb, 0x7b, 0xdb, 0x62, 
    0xdb, 0xa6, 
};
static const unsigned char big5_chars_ban2634 [] = {
    0xdb, 0xae, 
};
static const unsigned char big5_chars_ban2635 [] = {
    0xdb, 0x5f, 
};
static const unsigned char big5_chars_ban2636 [] = {
    0xdf, 0xc7, 
};
static const unsigned char big5_chars_ban2637 [] = {
    0xdf, 0xdd, 0xb8, 0x55, 0xdf, 0xcc, 
};
static const unsigned char big5_chars_ban2638 [] = {
    0xdf, 0xca, 0xdf, 0xb5, 0xb8, 0xa9, 0xdf, 0xc5, 0xdf, 0xd9, 
    0xdf, 0xc1, 0xb8, 0xb1, 0xdf, 0xd8, 0xdf, 0xbf, 0xb5, 0xe3, 
    0xdf, 0xcf, 0xdf, 0xc0, 0xdf, 0xd6, 0xb8, 0xb0, 0xb8, 0xa8, 
};
static const unsigned char big5_chars_ban2639 [] = {
    0xdf, 0xaa, 0xdf, 0xb2, 
};
static const unsigned char big5_chars_ban2640 [] = {
    0xdf, 0xcb, 0xdf, 0xc3, 0xdf, 0xdc, 0xdf, 0xc6, 0xb8, 0xb6, 
    0xdf, 0xd7, 
};
static const unsigned char big5_chars_ban2641 [] = {
    0xb8, 0xad, 
};
static const unsigned char big5_chars_ban2642 [] = {
    0xdf, 0xc9, 0xdf, 0xd1, 0xdf, 0xb6, 0xdf, 0xd0, 
};
static const unsigned char big5_chars_ban2643 [] = {
    0xdf, 0xe1, 0xdf, 0xb1, 0xdf, 0xd2, 
};
static const unsigned char big5_chars_ban2644 [] = {
    0xdf, 0xdf, 
};
static const unsigned char big5_chars_ban2645 [] = {
    0xdf, 0xab, 0xb5, 0xdb, 
};
static const unsigned char big5_chars_ban2646 [] = {
    0xdf, 0xb9, 0xdf, 0xb8, 0xb8, 0xaf, 
};
static const unsigned char big5_chars_ban2647 [] = {
    0xdf, 0xbc, 0xdf, 0xbe, 0xdf, 0xcd, 0xdf, 0xde, 0xb8, 0xb2, 
};
static const unsigned char big5_chars_ban2648 [] = {
    0xb8, 0xb3, 
};
static const unsigned char big5_chars_ban2649 [] = {
    0xdf, 0xb0, 0xb8, 0xab, 0xdf, 0xb4, 0xdf, 0xda, 0xb8, 0xb4, 
};
static const unsigned char big5_chars_ban2650 [] = {
    0xb8, 0xac, 0xb8, 0xae, 0xb8, 0xb5, 0xdf, 0xe0, 0xdf, 0xd3, 
    0xdf, 0xce, 
};
static const unsigned char big5_chars_ban2651 [] = {
    0xdf, 0xbb, 0xdf, 0xba, 0xb8, 0xaa, 0xdf, 0xac, 0xb8, 0xa7, 
    0xdf, 0xc4, 0xdf, 0xad, 0xdf, 0xc2, 
};
static const unsigned char big5_chars_ban2652 [] = {
    0xdf, 0xb7, 0xdf, 0xdb, 
};
static const unsigned char big5_chars_ban2653 [] = {
    0xb8, 0xa6, 
};
static const unsigned char big5_chars_ban2654 [] = {
    0xdf, 0xb3, 
};
static const unsigned char big5_chars_ban2655 [] = {
    0xdf, 0xaf, 0xdf, 0xd5, 0xdf, 0xae, 0xbb, 0x60, 0xe3, 0xd3, 
};
static const unsigned char big5_chars_ban2656 [] = {
    0xe3, 0xc2, 
};
static const unsigned char big5_chars_ban2657 [] = {
    0xe3, 0xac, 0xe3, 0xca, 0xbb, 0x58, 0xe3, 0xbb, 0xe3, 0xc5, 
    0xbb, 0x5b, 0xe3, 0xbe, 0xbb, 0x59, 0xe3, 0xaf, 0xe3, 0xcd, 
    0xe3, 0xae, 0xe3, 0xc1, 
};
static const unsigned char big5_chars_ban2658 [] = {
    0xe3, 0xad, 
};
static const unsigned char big5_chars_ban2659 [] = {
    0xe3, 0xbf, 0xe3, 0xc8, 0xe3, 0xc6, 0xe3, 0xba, 0xe3, 0xb5, 
    0xe3, 0xb3, 
};
static const unsigned char big5_chars_ban2660 [] = {
    0xe3, 0xb4, 0xe3, 0xc7, 0xe3, 0xd2, 0xe3, 0xbc, 0xbb, 0x5a, 
};
static const unsigned char big5_chars_ban2661 [] = {
    0xe3, 0xb7, 
};
static const unsigned char big5_chars_ban2662 [] = {
    0xe3, 0xcb, 
};
static const unsigned char big5_chars_ban2663 [] = {
    0xbb, 0x5d, 0xe3, 0xb6, 0xe3, 0xb0, 0xe3, 0xc0, 0xbb, 0x61, 
};
static const unsigned char big5_chars_ban2664 [] = {
    0xbb, 0x55, 0xbb, 0x5e, 0xe3, 0xb8, 0xe3, 0xb2, 
};
static const unsigned char big5_chars_ban2665 [] = {
    0xbb, 0x57, 0xdf, 0xd4, 0xbb, 0x56, 0xe3, 0xc3, 
};
static const unsigned char big5_chars_ban2666 [] = {
    0xbb, 0x54, 0xbb, 0x63, 0xbb, 0x5c, 0xe3, 0xc4, 0xe3, 0xb9, 
    0xe3, 0xb1, 0xe3, 0xcc, 0xe3, 0xbd, 0xbb, 0x62, 0xe3, 0xd0, 
    0xbb, 0x5f, 0xe3, 0xcf, 
};
static const unsigned char big5_chars_ban2667 [] = {
    0xe3, 0xc9, 0xe3, 0xce, 
};
static const unsigned char big5_chars_ban2668 [] = {
    0xe3, 0xd1, 
};
static const unsigned char big5_chars_ban2669 [] = {
    0xe7, 0x73, 0xe7, 0x74, 0xe7, 0x67, 0xe7, 0x66, 0xe7, 0x62, 
    0xbd, 0xb4, 
};
static const unsigned char big5_chars_ban2670 [] = {
    0xbd, 0xac, 0xe7, 0x76, 0xe7, 0x75, 0xdf, 0xa9, 0xe7, 0x5f, 
    0xe7, 0x63, 0xe7, 0x5d, 
};
static const unsigned char big5_chars_ban2671 [] = {
    0xe7, 0x70, 0xe7, 0x61, 
};
static const unsigned char big5_chars_ban2672 [] = {
    0xe7, 0x77, 0xe7, 0x5a, 0xe7, 0x58, 0xe7, 0x64, 0xe7, 0x6e, 
    0xe7, 0x69, 0xbd, 0xb6, 0xe7, 0x4f, 
};
static const unsigned char big5_chars_ban2673 [] = {
    0xe7, 0x6d, 
};
static const unsigned char big5_chars_ban2674 [] = {
    0xbd, 0xb7, 0xdf, 0xbd, 0xe7, 0x5b, 0xe7, 0x52, 0xe7, 0x55, 
    0xe7, 0x7b, 0xe7, 0x5c, 0xe7, 0x53, 0xe7, 0x51, 0xe7, 0x4e, 
};
static const unsigned char big5_chars_ban2675 [] = {
    0xbd, 0xb0, 0xe7, 0x65, 0xbd, 0xaf, 0xbd, 0xb3, 0xe7, 0x60, 
    0xe7, 0x68, 0xbd, 0xa9, 0xe7, 0x78, 0xe7, 0x7c, 0xbd, 0xab, 
};
static const unsigned char big5_chars_ban2676 [] = {
    0xe7, 0x57, 0xe7, 0x6b, 0xe7, 0x6f, 0xe7, 0x54, 0xe7, 0x79, 
    0xbd, 0xb2, 
};
static const unsigned char big5_chars_ban2677 [] = {
    0xbd, 0xb1, 0xe7, 0x4c, 0xbd, 0xb5, 0xe7, 0x72, 0xe7, 0x56, 
    0xe7, 0x6a, 0xe7, 0x50, 0xe7, 0x5e, 0xe7, 0x59, 0xbd, 0xad, 
    0xbd, 0xae, 0xe7, 0x6c, 0xe7, 0x7d, 0xe7, 0x7a, 0xe7, 0x71, 
};
static const unsigned char big5_chars_ban2678 [] = {
    0xe7, 0x4d, 
};
static const unsigned char big5_chars_ban2679 [] = {
    0xbd, 0xaa, 0xeb, 0x49, 
};
static const unsigned char big5_chars_ban2680 [] = {
    0xeb, 0x40, 0xeb, 0x43, 
};
static const unsigned char big5_chars_ban2681 [] = {
    0xbf, 0xbb, 0xeb, 0x45, 0xea, 0xf9, 0xeb, 0x41, 0xeb, 0x47, 
    0xbf, 0xb8, 0xbf, 0xbc, 0xbf, 0xb6, 
};
static const unsigned char big5_chars_ban2682 [] = {
    0xea, 0xfb, 0xeb, 0x4c, 
};
static const unsigned char big5_chars_ban2683 [] = {
    0xeb, 0x46, 
};
static const unsigned char big5_chars_ban2684 [] = {
    0xea, 0xfc, 0xeb, 0x55, 0xeb, 0x4f, 0xea, 0xf8, 0xee, 0x46, 
    0xea, 0xfe, 0xbf, 0xb7, 
};
static const unsigned char big5_chars_ban2685 [] = {
    0xeb, 0x4a, 
};
static const unsigned char big5_chars_ban2686 [] = {
    0xeb, 0x54, 0xbf, 0xbf, 
};
static const unsigned char big5_chars_ban2687 [] = {
    0xeb, 0x51, 0xea, 0xfd, 0xeb, 0x44, 0xeb, 0x48, 0xeb, 0x42, 
    0xeb, 0x56, 0xeb, 0x53, 0xeb, 0x50, 0xbf, 0xb9, 0xbf, 0xba, 
    0xbf, 0xbe, 0xea, 0xfa, 0xeb, 0x57, 0xbf, 0xbd, 0xeb, 0x4d, 
};
static const unsigned char big5_chars_ban2688 [] = {
    0xeb, 0x4b, 
};
static const unsigned char big5_chars_ban2689 [] = {
    0xeb, 0x4e, 0xee, 0x53, 0xee, 0x40, 0xee, 0x45, 0xee, 0x52, 
    0xee, 0x44, 0xed, 0xfb, 0xee, 0x41, 
};
static const unsigned char big5_chars_ban2690 [] = {
    0xc1, 0xa2, 
};
static const unsigned char big5_chars_ban2691 [] = {
    0xed, 0xf4, 0xee, 0x4d, 0xee, 0x4f, 0xed, 0xf3, 0xc1, 0xa1, 
    0xee, 0x51, 0xee, 0x49, 0xc1, 0xa8, 0xee, 0x50, 0xee, 0x42, 
    0xc1, 0xaa, 0xed, 0xf9, 0xeb, 0x52, 0xee, 0x4a, 0xee, 0x47, 
    0xed, 0xf5, 0xee, 0x55, 0xc1, 0xa4, 
};
static const unsigned char big5_chars_ban2692 [] = {
    0xc1, 0xa5, 0xed, 0xf7, 0xee, 0x48, 
};
static const unsigned char big5_chars_ban2693 [] = {
    0xee, 0x54, 0xee, 0x4b, 0xed, 0xfd, 0xc1, 0xa7, 0xc1, 0xa3, 
    0xee, 0x4c, 0xed, 0xfe, 0xee, 0x56, 0xed, 0xf8, 0xee, 0x43, 
    0xee, 0x4e, 0xed, 0xfa, 0xed, 0xfc, 
};
static const unsigned char big5_chars_ban2694 [] = {
    0xc2, 0xcb, 0xed, 0xf6, 0xc1, 0xa9, 0xc2, 0xc4, 0xc1, 0x7e, 
};
static const unsigned char big5_chars_ban2695 [] = {
    0xc1, 0xa6, 0xc2, 0xc8, 0xf0, 0xb3, 
};
static const unsigned char big5_chars_ban2696 [] = {
    0xf0, 0xa9, 0xf0, 0xa4, 0xf0, 0xaa, 0xf0, 0xb4, 0xf0, 0xb8, 
    0xf0, 0xb7, 0xc2, 0xca, 0xc2, 0xc9, 
};
static const unsigned char big5_chars_ban2697 [] = {
    0xf0, 0xab, 0xf0, 0xb9, 0xf0, 0xae, 0xf0, 0xa6, 
};
static const unsigned char big5_chars_ban2698 [] = {
    0xf0, 0xa8, 0xf0, 0xa7, 0xf0, 0xad, 0xf0, 0xb2, 0xf0, 0xa5, 
    0xf0, 0xac, 0xf0, 0xb1, 0xc2, 0xc7, 
};
static const unsigned char big5_chars_ban2699 [] = {
    0xf0, 0xaf, 
};
static const unsigned char big5_chars_ban2700 [] = {
    0xc2, 0xc5, 0xf0, 0xb0, 0xc2, 0xc3, 0xc2, 0xc6, 0xf2, 0xd5, 
    0xf0, 0xb5, 
};
static const unsigned char big5_chars_ban2701 [] = {
    0xc3, 0xc2, 
};
static const unsigned char big5_chars_ban2702 [] = {
    0xf2, 0xcd, 0xf2, 0xd1, 0xf2, 0xc9, 0xf2, 0xcc, 
};
static const unsigned char big5_chars_ban2703 [] = {
    0xf2, 0xd4, 0xc3, 0xc0, 0xf2, 0xd9, 0xf2, 0xd2, 
};
static const unsigned char big5_chars_ban2704 [] = {
    0xf2, 0xca, 0xf2, 0xda, 0xf2, 0xd3, 0xc3, 0xc3, 0xc3, 0xc4, 
    0xf2, 0xd7, 
};
static const unsigned char big5_chars_ban2705 [] = {
    0xf2, 0xcb, 0xc3, 0xbf, 0xc3, 0xc1, 0xf2, 0xc6, 0xf2, 0xce, 
    0xf2, 0xc8, 
};
static const unsigned char big5_chars_ban2706 [] = {
    0xf2, 0xd8, 0xf2, 0xd6, 0xf2, 0xc7, 0xf2, 0xcf, 
};
static const unsigned char big5_chars_ban2707 [] = {
    0xf4, 0xbe, 0xc3, 0xc5, 0xf2, 0xd0, 0xc4, 0xa7, 0xc4, 0xa9, 
    0xc4, 0xa6, 
};
static const unsigned char big5_chars_ban2708 [] = {
    0xf4, 0xc3, 0xf4, 0xbb, 0xf4, 0xb9, 0xf4, 0xbd, 0xf4, 0xba, 
};
static const unsigned char big5_chars_ban2709 [] = {
    0xf4, 0xbf, 0xf4, 0xc1, 0xc4, 0xaa, 0xc4, 0xac, 
};
static const unsigned char big5_chars_ban2710 [] = {
    0xf4, 0xc0, 0xc4, 0xad, 0xc4, 0xab, 0xf4, 0xc2, 
};
static const unsigned char big5_chars_ban2711 [] = {
    0xc4, 0xa8, 
};
static const unsigned char big5_chars_ban2712 [] = {
    0xc4, 0xf4, 0xf5, 0xf1, 0xf5, 0xf7, 0xc4, 0xf6, 0xf4, 0xbc, 
    0xf5, 0xf6, 
};
static const unsigned char big5_chars_ban2713 [] = {
    0xf5, 0xfd, 0xf5, 0xf4, 0xf5, 0xfb, 0xf5, 0xfa, 0xf4, 0xb8, 
    0xf5, 0xf5, 0xf0, 0xb6, 0xf5, 0xfe, 0xf5, 0xf3, 0xf5, 0xf8, 
};
static const unsigned char big5_chars_ban2714 [] = {
    0xf5, 0xfc, 0xf5, 0xf2, 
};
static const unsigned char big5_chars_ban2715 [] = {
    0xf7, 0x4a, 0xc4, 0xf5, 0xf5, 0xf9, 
};
static const unsigned char big5_chars_ban2716 [] = {
    0xf7, 0xf4, 0xf7, 0x4b, 0xf7, 0x49, 0xf7, 0x47, 0xf7, 0x48, 
    0xf7, 0x4c, 
};
static const unsigned char big5_chars_ban2717 [] = {
    0xc5, 0xd9, 0xf7, 0xf2, 0xf7, 0xf0, 0xf7, 0xf5, 0xf7, 0xf3, 
};
static const unsigned char big5_chars_ban2718 [] = {
    0xf7, 0xf6, 0xc5, 0xda, 0xf7, 0xf1, 
};
static const unsigned char big5_chars_ban2719 [] = {
    0xf8, 0xbc, 
};
static const unsigned char big5_chars_ban2720 [] = {
    0xf9, 0x45, 0xf9, 0x46, 0xf9, 0x47, 
};
static const unsigned char big5_chars_ban2721 [] = {
    0xf9, 0xc7, 0xf9, 0xbd, 0xca, 0x4f, 0xaa, 0xea, 
};
static const unsigned char big5_chars_ban2722 [] = {
    0xad, 0x68, 
};
static const unsigned char big5_chars_ban2723 [] = {
    0xd3, 0xb8, 0xd3, 0xb7, 0xb0, 0x40, 0xb3, 0x42, 0xd7, 0x7c, 
};
static const unsigned char big5_chars_ban2724 [] = {
    0xd7, 0x7b, 
};
static const unsigned char big5_chars_ban2725 [] = {
    0xb5, 0xea, 0xb8, 0xb8, 
};
static const unsigned char big5_chars_ban2726 [] = {
    0xb8, 0xb7, 0xb8, 0xb9, 
};
static const unsigned char big5_chars_ban2727 [] = {
    0xe3, 0xd4, 0xe7, 0x7e, 0xeb, 0x58, 0xeb, 0x5a, 0xeb, 0x59, 
};
static const unsigned char big5_chars_ban2728 [] = {
    0xc1, 0xab, 0xee, 0x57, 0xf0, 0xba, 0xf9, 0xa5, 0xa6, 0xe4, 
};
static const unsigned char big5_chars_ban2729 [] = {
    0xcd, 0xc9, 0xcd, 0xca, 0xcd, 0xc8, 0xcd, 0xc7, 0xaa, 0xeb, 
};
static const unsigned char big5_chars_ban2730 [] = {
    0xd0, 0xa9, 0xd0, 0xa7, 
};
static const unsigned char big5_chars_ban2731 [] = {
    0xd0, 0xa6, 
};
static const unsigned char big5_chars_ban2732 [] = {
    0xad, 0x69, 0xad, 0x6b, 0xad, 0x6a, 0xd0, 0xa8, 
};
static const unsigned char big5_chars_ban2733 [] = {
    0xd3, 0xc4, 0xd3, 0xc1, 0xd3, 0xbf, 
};
static const unsigned char big5_chars_ban2734 [] = {
    0xb0, 0x41, 0xd3, 0xc2, 0xb0, 0x46, 0xd3, 0xbc, 0xd3, 0xcb, 
};
static const unsigned char big5_chars_ban2735 [] = {
    0xd3, 0xcd, 0xd3, 0xbd, 
};
static const unsigned char big5_chars_ban2736 [] = {
    0xb0, 0x43, 0xd3, 0xce, 0xd3, 0xc9, 0xd3, 0xbb, 0xd3, 0xc0, 
    0xd3, 0xca, 0xd3, 0xc6, 0xd3, 0xc3, 
};
static const unsigned char big5_chars_ban2737 [] = {
    0xb0, 0x48, 0xd3, 0xcc, 0xd3, 0xbe, 
};
static const unsigned char big5_chars_ban2738 [] = {
    0xd3, 0xc7, 0xd3, 0xb9, 0xb0, 0x47, 0xb0, 0x44, 0xd3, 0xc5, 
};
static const unsigned char big5_chars_ban2739 [] = {
    0xd3, 0xc8, 0xd3, 0xba, 0xb0, 0x45, 0xb0, 0x42, 
};
static const unsigned char big5_chars_ban2740 [] = {
    0xb3, 0x4c, 0xd7, 0xa5, 0xb3, 0x4b, 
};
static const unsigned char big5_chars_ban2741 [] = {
    0xd7, 0xa8, 0xd7, 0xab, 0xb3, 0x48, 0xb3, 0x46, 0xd7, 0x7e, 
    0xd7, 0xa9, 0xd7, 0xa7, 0xd7, 0xa4, 0xd7, 0xac, 0xd7, 0xad, 
    0xd7, 0xaf, 0xd7, 0xb0, 0xd7, 0x7d, 0xb3, 0x45, 0xd7, 0xa2, 
    0xd7, 0xa1, 0xd7, 0xae, 0xb3, 0x47, 0xd7, 0xa3, 0xb3, 0x49, 
    0xb3, 0x44, 0xd7, 0xa6, 0xb3, 0x4d, 
};
static const unsigned char big5_chars_ban2742 [] = {
    0xb3, 0x4a, 0xd7, 0xaa, 
};
static const unsigned char big5_chars_ban2743 [] = {
    0xb5, 0xf1, 0xdb, 0xbf, 
};
static const unsigned char big5_chars_ban2744 [] = {
    0xdb, 0xb4, 0xb5, 0xee, 
};
static const unsigned char big5_chars_ban2745 [] = {
    0xdf, 0xe7, 0xdb, 0xbd, 0xdb, 0xb1, 0xb5, 0xec, 0xdb, 0xb6, 
    0xb5, 0xef, 0xdb, 0xba, 0xdb, 0xb8, 0xb5, 0xf2, 0xb5, 0xeb, 
};
static const unsigned char big5_chars_ban2746 [] = {
    0xdb, 0xb2, 0xdb, 0xb5, 0xb5, 0xf0, 
};
static const unsigned char big5_chars_ban2747 [] = {
    0xdb, 0xb3, 
};
static const unsigned char big5_chars_ban2748 [] = {
    0xdb, 0xbe, 0xdb, 0xbc, 0xdb, 0xb7, 0xdb, 0xb9, 0xdb, 0xbb, 
    0xb5, 0xed, 
};
static const unsigned char big5_chars_ban2749 [] = {
    0xdf, 0xe8, 0xdf, 0xee, 0xdf, 0xe4, 0xdf, 0xea, 0xb8, 0xba, 
    0xdf, 0xe6, 0xb8, 0xc0, 
};
static const unsigned char big5_chars_ban2750 [] = {
    0xb8, 0xbf, 
};
static const unsigned char big5_chars_ban2751 [] = {
    0xb8, 0xbe, 0xdf, 0xed, 0xb8, 0xc1, 0xb8, 0xc2, 0xdf, 0xe3, 
    0xdf, 0xf0, 0xb8, 0xc3, 0xb8, 0xbd, 0xb8, 0xbc, 0xdf, 0xec, 
    0xb8, 0xc4, 0xdf, 0xe2, 0xdf, 0xe5, 0xdf, 0xef, 0xdf, 0xeb, 
};
static const unsigned char big5_chars_ban2752 [] = {
    0xe3, 0xf4, 0xe3, 0xe9, 0xb8, 0xbb, 
};
static const unsigned char big5_chars_ban2753 [] = {
    0xbb, 0x6a, 0xe3, 0xdd, 0xe3, 0xf2, 0xe3, 0xde, 0xbb, 0x65, 
};
static const unsigned char big5_chars_ban2754 [] = {
    0xe3, 0xdb, 
};
static const unsigned char big5_chars_ban2755 [] = {
    0xe3, 0xe4, 0xe3, 0xdc, 0xbb, 0x67, 0xe3, 0xd6, 0xe3, 0xf1, 
    0xbb, 0x68, 0xe3, 0xee, 0xe3, 0xef, 0xe3, 0xd7, 0xbb, 0x6d, 
    0xe3, 0xe6, 
};
static const unsigned char big5_chars_ban2756 [] = {
    0xe3, 0xe0, 0xe3, 0xe7, 0xe3, 0xda, 
};
static const unsigned char big5_chars_ban2757 [] = {
    0xe3, 0xf3, 0xe3, 0xeb, 0xe3, 0xe5, 0xe3, 0xd5, 0xbb, 0x69, 
    0xe3, 0xec, 
};
static const unsigned char big5_chars_ban2758 [] = {
    0xbb, 0x6c, 0xe3, 0xf0, 
};
static const unsigned char big5_chars_ban2759 [] = {
    0xe3, 0xea, 0xbb, 0x66, 0xe3, 0xe8, 
};
static const unsigned char big5_chars_ban2760 [] = {
    0xe3, 0xe2, 0xbb, 0x64, 0xe3, 0xd9, 0xe3, 0xe1, 0xe3, 0xed, 
    0xe3, 0xdf, 
};
static const unsigned char big5_chars_ban2761 [] = {
    0xe3, 0xe3, 
};
static const unsigned char big5_chars_ban2762 [] = {
    0xbd, 0xc1, 0xdf, 0xe9, 0xe7, 0xb2, 0xe7, 0xbb, 0xe7, 0xb1, 
    0xe7, 0xad, 0xe7, 0xaa, 0xbd, 0xc2, 0xe7, 0xa8, 0xbb, 0x6b, 
    0xe7, 0xa1, 0xbd, 0xc0, 0xe7, 0xa7, 0xbd, 0xbf, 0xe7, 0xac, 
    0xe7, 0xa9, 0xe7, 0xb9, 0xe7, 0xb4, 0xe7, 0xae, 0xe7, 0xb3, 
    0xbd, 0xbb, 0xe7, 0xab, 0xe7, 0xbe, 0xe7, 0xa2, 0xe7, 0xa3, 
    0xe7, 0xba, 0xbd, 0xbc, 0xe7, 0xbf, 0xbd, 0xbe, 0xe7, 0xc0, 
    0xe7, 0xb0, 0xe3, 0xd8, 0xe7, 0xb6, 0xe7, 0xaf, 0xe7, 0xb8, 
    0xe7, 0xb5, 
};
static const unsigned char big5_chars_ban2763 [] = {
    0xe7, 0xa6, 0xbd, 0xb9, 0xe7, 0xbd, 0xbd, 0xba, 0xe7, 0xa4, 
    0xbd, 0xbd, 0xeb, 0x64, 0xe7, 0xb7, 0xe7, 0xbc, 
};
static const unsigned char big5_chars_ban2764 [] = {
    0xeb, 0x61, 0xbd, 0xb8, 0xbf, 0xc0, 0xeb, 0x6b, 0xeb, 0x67, 
};
static const unsigned char big5_chars_ban2765 [] = {
    0xeb, 0x65, 0xeb, 0x60, 0xeb, 0x6f, 
};
static const unsigned char big5_chars_ban2766 [] = {
    0xbf, 0xc4, 
};
static const unsigned char big5_chars_ban2767 [] = {
    0xeb, 0x5c, 0xeb, 0x68, 0xeb, 0x69, 0xeb, 0x5f, 0xeb, 0x5e, 
    0xeb, 0x6c, 
};
static const unsigned char big5_chars_ban2768 [] = {
    0xeb, 0x62, 0xeb, 0x5d, 0xeb, 0x63, 
};
static const unsigned char big5_chars_ban2769 [] = {
    0xeb, 0x6e, 0xeb, 0x5b, 0xeb, 0x6d, 0xeb, 0x6a, 0xbf, 0xc2, 
    0xbf, 0xc1, 
};
static const unsigned char big5_chars_ban2770 [] = {
    0xbf, 0xc3, 0xeb, 0x66, 0xf0, 0xcb, 
};
static const unsigned char big5_chars_ban2771 [] = {
    0xee, 0x59, 0xc1, 0xb1, 0xee, 0x5d, 0xee, 0x5a, 0xee, 0x61, 
    0xee, 0x67, 0xee, 0x5c, 
};
static const unsigned char big5_chars_ban2772 [] = {
    0xee, 0x70, 0xc1, 0xae, 0xee, 0x6a, 0xee, 0x5f, 0xee, 0x6b, 
    0xee, 0x66, 0xee, 0x6d, 0xee, 0x5e, 0xc1, 0xb3, 0xc1, 0xb2, 
    0xee, 0x60, 0xee, 0x6e, 0xee, 0x58, 0xee, 0x6c, 0xc1, 0xac, 
};
static const unsigned char big5_chars_ban2773 [] = {
    0xee, 0x64, 0xee, 0x63, 0xee, 0x68, 0xee, 0x5b, 0xc1, 0xb0, 
};
static const unsigned char big5_chars_ban2774 [] = {
    0xc1, 0xb4, 0xee, 0x62, 0xee, 0x69, 0xc1, 0xb5, 0xee, 0x65, 
};
static const unsigned char big5_chars_ban2775 [] = {
    0xc1, 0xad, 0xc1, 0xaf, 0xf0, 0xc7, 0xf0, 0xc5, 
};
static const unsigned char big5_chars_ban2776 [] = {
    0xf0, 0xcc, 0xf0, 0xc9, 0xf0, 0xcd, 
};
static const unsigned char big5_chars_ban2777 [] = {
    0xf0, 0xbe, 0xf0, 0xc6, 0xf0, 0xd1, 0xee, 0x6f, 0xf0, 0xc2, 
    0xc2, 0xcf, 0xe7, 0xa5, 0xf0, 0xbd, 0xf0, 0xca, 0xf0, 0xc4, 
    0xf0, 0xc1, 0xf0, 0xbc, 0xf0, 0xbb, 0xf0, 0xd0, 
};
static const unsigned char big5_chars_ban2778 [] = {
    0xf0, 0xc0, 0xf0, 0xbf, 0xc2, 0xcd, 0xf0, 0xc8, 
};
static const unsigned char big5_chars_ban2779 [] = {
    0xc2, 0xcc, 
};
static const unsigned char big5_chars_ban2780 [] = {
    0xc2, 0xce, 0xf0, 0xc3, 0xf0, 0xcf, 
};
static const unsigned char big5_chars_ban2781 [] = {
    0xf2, 0xde, 0xf2, 0xdf, 
};
static const unsigned char big5_chars_ban2782 [] = {
    0xc3, 0xc9, 0xf2, 0xdc, 0xc3, 0xc6, 0xf2, 0xe4, 
};
static const unsigned char big5_chars_ban2783 [] = {
    0xc3, 0xca, 0xf2, 0xe6, 0xf2, 0xdb, 0xf0, 0xce, 0xf2, 0xe8, 
    0xf2, 0xdd, 
};
static const unsigned char big5_chars_ban2784 [] = {
    0xc3, 0xc7, 0xf2, 0xe3, 
};
static const unsigned char big5_chars_ban2785 [] = {
    0xf2, 0xe5, 0xf2, 0xe0, 0xf2, 0xe7, 0xf2, 0xe2, 0xf2, 0xe1, 
    0xc3, 0xc8, 
};
static const unsigned char big5_chars_ban2786 [] = {
    0xf4, 0xc5, 0xf4, 0xc6, 
};
static const unsigned char big5_chars_ban2787 [] = {
    0xf4, 0xc8, 0xc4, 0xae, 0xc4, 0xaf, 0xf4, 0xc9, 0xf4, 0xc7, 
};
static const unsigned char big5_chars_ban2788 [] = {
    0xf4, 0xc4, 
};
static const unsigned char big5_chars_ban2789 [] = {
    0xf6, 0x42, 0xf6, 0x45, 0xf6, 0x41, 
};
static const unsigned char big5_chars_ban2790 [] = {
    0xc4, 0xfa, 0xf6, 0x43, 0xc4, 0xf9, 0xc4, 0xf8, 0xc4, 0xf7, 
    0xf6, 0x44, 0xf7, 0x51, 0xf7, 0x4f, 
};
static const unsigned char big5_chars_ban2791 [] = {
    0xf7, 0x4e, 0xf6, 0x40, 0xf7, 0x50, 0xf6, 0x46, 0xf7, 0x4d, 
};
static const unsigned char big5_chars_ban2792 [] = {
    0xf7, 0xf9, 0xf7, 0xd7, 0xf7, 0xf7, 0xc5, 0xdb, 0xf7, 0xf8, 
    0xf7, 0xfa, 
};
static const unsigned char big5_chars_ban2793 [] = {
    0xf8, 0xbf, 0xc5, 0xfa, 0xf8, 0xbe, 0xf8, 0xbd, 0xc5, 0xfb, 
};
static const unsigned char big5_chars_ban2794 [] = {
    0xc6, 0x5a, 0xf9, 0x6e, 0xf9, 0xa7, 0xf9, 0xa6, 0xf9, 0xa8, 
    0xa6, 0xe5, 0xd0, 0xaa, 
};
static const unsigned char big5_chars_ban2795 [] = {
    0xd3, 0xcf, 0xd3, 0xd0, 
};
static const unsigned char big5_chars_ban2796 [] = {
    0xdb, 0xc0, 
};
static const unsigned char big5_chars_ban2797 [] = {
    0xf6, 0x47, 0xf8, 0xc0, 0xa6, 0xe6, 0xad, 0x6c, 0xd0, 0xab, 
};
static const unsigned char big5_chars_ban2798 [] = {
    0xd7, 0xb1, 0xb3, 0x4e, 
};
static const unsigned char big5_chars_ban2799 [] = {
    0xdb, 0xc2, 0xdb, 0xc1, 0xb5, 0xf3, 
};
static const unsigned char big5_chars_ban2800 [] = {
    0xb8, 0xc5, 0xe7, 0xc1, 0xbd, 0xc3, 
};
static const unsigned char big5_chars_ban2801 [] = {
    0xbd, 0xc4, 
};
static const unsigned char big5_chars_ban2802 [] = {
    0xbf, 0xc5, 0xc5, 0xfc, 0xa6, 0xe7, 
};
static const unsigned char big5_chars_ban2803 [] = {
    0xd0, 0xac, 0xaa, 0xed, 0xd0, 0xae, 0xd0, 0xad, 0xad, 0x6d, 
};
static const unsigned char big5_chars_ban2804 [] = {
    0xd3, 0xd1, 
};
static const unsigned char big5_chars_ban2805 [] = {
    0xd3, 0xd8, 0xb0, 0x49, 0xd3, 0xd6, 0xd3, 0xd4, 
};
static const unsigned char big5_chars_ban2806 [] = {
    0xd3, 0xdb, 0xd3, 0xd2, 0xd3, 0xd3, 0xb0, 0x4a, 
};
static const unsigned char big5_chars_ban2807 [] = {
    0xb0, 0x4e, 
};
static const unsigned char big5_chars_ban2808 [] = {
    0xd3, 0xdc, 0xb0, 0x4d, 0xd3, 0xda, 0xd3, 0xd7, 0xd3, 0xd5, 
    0xb0, 0x4b, 0xb0, 0x4c, 0xd3, 0xd9, 
};
static const unsigned char big5_chars_ban2809 [] = {
    0xb3, 0x50, 0xd7, 0xb2, 
};
static const unsigned char big5_chars_ban2810 [] = {
    0xb3, 0x55, 0xd7, 0xc2, 0xb3, 0x54, 0xd7, 0xc4, 
};
static const unsigned char big5_chars_ban2811 [] = {
    0xd7, 0xb8, 0xb3, 0x52, 0xd7, 0xc3, 
};
static const unsigned char big5_chars_ban2812 [] = {
    0xd7, 0xb3, 0xb3, 0x53, 0xd7, 0xbf, 0xd7, 0xbb, 0xd7, 0xbd, 
    0xd7, 0xb7, 0xd7, 0xbe, 
};
static const unsigned char big5_chars_ban2813 [] = {
    0xb3, 0x4f, 0xd7, 0xba, 
};
static const unsigned char big5_chars_ban2814 [] = {
    0xd7, 0xb9, 0xd7, 0xb5, 
};
static const unsigned char big5_chars_ban2815 [] = {
    0xd7, 0xc0, 
};
static const unsigned char big5_chars_ban2816 [] = {
    0xd7, 0xbc, 0xd7, 0xb4, 
};
static const unsigned char big5_chars_ban2817 [] = {
    0xd7, 0xb6, 0xb3, 0x51, 0xd7, 0xc1, 
};
static const unsigned char big5_chars_ban2818 [] = {
    0xb5, 0xf6, 0xdb, 0xcd, 
};
static const unsigned char big5_chars_ban2819 [] = {
    0xdb, 0xc9, 0xdb, 0xcb, 0xdb, 0xc6, 0xdb, 0xc5, 0xdb, 0xc3, 
};
static const unsigned char big5_chars_ban2820 [] = {
    0xdb, 0xca, 0xdb, 0xcc, 0xdb, 0xc8, 
};
static const unsigned char big5_chars_ban2821 [] = {
    0xdb, 0xc7, 0xb5, 0xf4, 0xb5, 0xf5, 
};
static const unsigned char big5_chars_ban2822 [] = {
    0xdb, 0xcf, 0xb8, 0xcd, 0xdf, 0xf2, 0xdf, 0xf8, 0xdf, 0xf3, 
    0xdf, 0xf4, 0xf9, 0xd8, 0xdf, 0xf9, 
};
static const unsigned char big5_chars_ban2823 [] = {
    0xb8, 0xcf, 
};
static const unsigned char big5_chars_ban2824 [] = {
    0xb8, 0xc7, 0xb8, 0xce, 0xdf, 0xf1, 0xdb, 0xc4, 0xb8, 0xca, 
    0xb8, 0xc8, 0xdf, 0xf7, 0xdf, 0xf6, 0xb8, 0xc9, 0xb8, 0xcb, 
    0xdf, 0xf5, 0xb8, 0xc6, 
};
static const unsigned char big5_chars_ban2825 [] = {
    0xb8, 0xcc, 
};
static const unsigned char big5_chars_ban2826 [] = {
    0xe3, 0xf6, 0xbb, 0x74, 
};
static const unsigned char big5_chars_ban2827 [] = {
    0xe4, 0x42, 0xe4, 0x41, 
};
static const unsigned char big5_chars_ban2828 [] = {
    0xe3, 0xfb, 0xbb, 0x76, 0xe4, 0x40, 0xe3, 0xf7, 0xe3, 0xf8, 
    0xbb, 0x6e, 0xbb, 0x70, 
};
static const unsigned char big5_chars_ban2829 [] = {
    0xe3, 0xfd, 0xe3, 0xf5, 0xbb, 0x72, 0xbb, 0x71, 0xe3, 0xf9, 
    0xe3, 0xfe, 0xe3, 0xfc, 0xbb, 0x73, 0xe3, 0xfa, 
};
static const unsigned char big5_chars_ban2830 [] = {
    0xdb, 0xce, 0xbb, 0x6f, 
};
static const unsigned char big5_chars_ban2831 [] = {
    0xe7, 0xc2, 0xe7, 0xc9, 0xbd, 0xc6, 
};
static const unsigned char big5_chars_ban2832 [] = {
    0xe7, 0xcd, 0xbd, 0xca, 0xe7, 0xc5, 0xe7, 0xc3, 
};
static const unsigned char big5_chars_ban2833 [] = {
    0xe7, 0xcc, 
};
static const unsigned char big5_chars_ban2834 [] = {
    0xbd, 0xc5, 0xe7, 0xcb, 0xbd, 0xc7, 0xbd, 0xc8, 0xe7, 0xc4, 
    0xbd, 0xc9, 0xe7, 0xca, 0xe7, 0xc6, 0xe7, 0xc7, 0xe7, 0xc8, 
    0xbb, 0x75, 
};
static const unsigned char big5_chars_ban2835 [] = {
    0xeb, 0x70, 0xeb, 0x7c, 
};
static const unsigned char big5_chars_ban2836 [] = {
    0xbf, 0xca, 0xeb, 0x77, 0xeb, 0x79, 
};
static const unsigned char big5_chars_ban2837 [] = {
    0xbf, 0xc8, 0xeb, 0x71, 0xeb, 0x75, 
};
static const unsigned char big5_chars_ban2838 [] = {
    0xeb, 0x78, 0xbf, 0xc6, 0xbf, 0xc9, 0xeb, 0x7b, 0xeb, 0x73, 
    0xeb, 0x74, 0xeb, 0x7a, 0xeb, 0x72, 0xeb, 0x76, 0xbf, 0xc7, 
    0xee, 0x72, 
};
static const unsigned char big5_chars_ban2839 [] = {
    0xee, 0x71, 0xc1, 0xb7, 0xee, 0x77, 0xc1, 0xb9, 
};
static const unsigned char big5_chars_ban2840 [] = {
    0xc1, 0xb6, 0xee, 0x73, 0xc1, 0xba, 0xee, 0x74, 
};
static const unsigned char big5_chars_ban2841 [] = {
    0xee, 0x75, 0xee, 0x78, 
};
static const unsigned char big5_chars_ban2842 [] = {
    0xc1, 0xb8, 
};
static const unsigned char big5_chars_ban2843 [] = {
    0xf0, 0xd6, 
};
static const unsigned char big5_chars_ban2844 [] = {
    0xf0, 0xd9, 
};
static const unsigned char big5_chars_ban2845 [] = {
    0xf0, 0xd3, 0xf0, 0xd5, 
};
static const unsigned char big5_chars_ban2846 [] = {
    0xf0, 0xd4, 0xf0, 0xd7, 0xf0, 0xd8, 0xee, 0x76, 0xf0, 0xd2, 
};
static const unsigned char big5_chars_ban2847 [] = {
    0xc3, 0xcd, 0xf2, 0xec, 0xf2, 0xef, 0xf2, 0xf1, 0xf2, 0xea, 
    0xf2, 0xeb, 0xf2, 0xee, 0xf2, 0xf0, 0xc3, 0xce, 0xc3, 0xcc, 
    0xc3, 0xcb, 0xf2, 0xed, 0xf2, 0xe9, 0xf4, 0xca, 0xc4, 0xb0, 
};
static const unsigned char big5_chars_ban2848 [] = {
    0xf4, 0xcb, 
};
static const unsigned char big5_chars_ban2849 [] = {
    0xf6, 0x49, 0xc4, 0xfb, 0xf6, 0x4b, 0xc4, 0xfc, 0xf6, 0x48, 
    0xf6, 0x4a, 0xc5, 0xa8, 
};
static const unsigned char big5_chars_ban2850 [] = {
    0xf7, 0x52, 0xc5, 0xa7, 0xf7, 0xfd, 0xf7, 0xfc, 
};
static const unsigned char big5_chars_ban2851 [] = {
    0xf7, 0xfb, 
};
static const unsigned char big5_chars_ban2852 [] = {
    0xf9, 0x48, 0xf9, 0x49, 0xf9, 0x4b, 0xf9, 0x4a, 
};
static const unsigned char big5_chars_ban2853 [] = {
    0xca, 0x50, 0xa6, 0xe8, 
};
static const unsigned char big5_chars_ban2854 [] = {
    0xad, 0x6e, 0xd7, 0xc5, 0xb5, 0xf7, 
};
static const unsigned char big5_chars_ban2855 [] = {
    0xdf, 0xfa, 0xc2, 0xd0, 
};
static const unsigned char big5_chars_ban2856 [] = {
    0xf2, 0xf2, 
};
static const unsigned char big5_chars_ban2857 [] = {
    0xa8, 0xa3, 
};
static const unsigned char big5_chars_ban2858 [] = {
    0xb3, 0x57, 
};
static const unsigned char big5_chars_ban2859 [] = {
    0xb3, 0x56, 
};
static const unsigned char big5_chars_ban2860 [] = {
    0xdb, 0xd0, 0xb5, 0xf8, 0xdb, 0xd2, 0xdb, 0xd1, 
};
static const unsigned char big5_chars_ban2861 [] = {
    0xdf, 0xfb, 0xb8, 0xd0, 0xe4, 0x43, 0xe4, 0x46, 0xe4, 0x45, 
};
static const unsigned char big5_chars_ban2862 [] = {
    0xe4, 0x44, 0xe7, 0xce, 0xe7, 0xd0, 0xe7, 0xcf, 
};
static const unsigned char big5_chars_ban2863 [] = {
    0xbf, 0xcc, 
};
static const unsigned char big5_chars_ban2864 [] = {
    0xbf, 0xcb, 
};
static const unsigned char big5_chars_ban2865 [] = {
    0xc1, 0xbb, 0xee, 0x79, 0xee, 0x7b, 0xee, 0x7a, 
};
static const unsigned char big5_chars_ban2866 [] = {
    0xc2, 0xd1, 
};
static const unsigned char big5_chars_ban2867 [] = {
    0xf2, 0xf4, 0xf2, 0xf3, 
};
static const unsigned char big5_chars_ban2868 [] = {
    0xf4, 0xcc, 0xc4, 0xb1, 
};
static const unsigned char big5_chars_ban2869 [] = {
    0xc4, 0xfd, 0xf7, 0x54, 0xf7, 0x53, 0xc6, 0x5b, 
};
static const unsigned char big5_chars_ban2870 [] = {
    0xa8, 0xa4, 0xd0, 0xaf, 0xad, 0x6f, 0xd7, 0xc8, 0xd7, 0xc6, 
};
static const unsigned char big5_chars_ban2871 [] = {
    0xd7, 0xc7, 0xdb, 0xd4, 0xdb, 0xd5, 0xe0, 0x43, 0xdb, 0xd3, 
};
static const unsigned char big5_chars_ban2872 [] = {
    0xdf, 0xfc, 0xe0, 0x41, 0xe0, 0x40, 0xe0, 0x42, 0xb8, 0xd1, 
    0xdf, 0xfe, 0xdf, 0xfd, 0xe0, 0x44, 
};
static const unsigned char big5_chars_ban2873 [] = {
    0xe4, 0x49, 0xe4, 0x47, 
};
static const unsigned char big5_chars_ban2874 [] = {
    0xe4, 0x48, 0xe7, 0xd3, 0xe7, 0xd1, 
};
static const unsigned char big5_chars_ban2875 [] = {
    0xe7, 0xd2, 0xeb, 0x7d, 0xee, 0x7c, 0xee, 0x7d, 0xc2, 0xd2, 
};
static const unsigned char big5_chars_ban2876 [] = {
    0xf2, 0xf5, 0xf4, 0xcd, 0xc4, 0xb2, 
};
static const unsigned char big5_chars_ban2877 [] = {
    0xf6, 0x4c, 0xf7, 0x55, 0xc5, 0xa9, 
};
static const unsigned char big5_chars_ban2878 [] = {
    0xf7, 0xfe, 0xf9, 0x4c, 0xa8, 0xa5, 
};
static const unsigned char big5_chars_ban2879 [] = {
    0xad, 0x71, 0xad, 0x72, 0xd0, 0xb0, 
};
static const unsigned char big5_chars_ban2880 [] = {
    0xd0, 0xb1, 0xad, 0x70, 
};
static const unsigned char big5_chars_ban2881 [] = {
    0xb0, 0x54, 
};
static const unsigned char big5_chars_ban2882 [] = {
    0xb0, 0x52, 
};
static const unsigned char big5_chars_ban2883 [] = {
    0xb0, 0x51, 0xb0, 0x58, 0xb0, 0x50, 0xb0, 0x59, 0xd3, 0xdd, 
    0xb0, 0x56, 
};
static const unsigned char big5_chars_ban2884 [] = {
    0xb0, 0x53, 0xb0, 0x57, 0xb0, 0x55, 0xb0, 0x4f, 
};
static const unsigned char big5_chars_ban2885 [] = {
    0xb3, 0x5f, 
};
static const unsigned char big5_chars_ban2886 [] = {
    0xb3, 0x59, 0xd7, 0xcc, 0xb3, 0x5e, 
};
static const unsigned char big5_chars_ban2887 [] = {
    0xb3, 0x60, 0xb3, 0x5a, 
};
static const unsigned char big5_chars_ban2888 [] = {
    0xb3, 0x5b, 
};
static const unsigned char big5_chars_ban2889 [] = {
    0xd7, 0xca, 
};
static const unsigned char big5_chars_ban2890 [] = {
    0xb3, 0x58, 
};
static const unsigned char big5_chars_ban2891 [] = {
    0xd7, 0xcb, 0xb3, 0x5d, 
};
static const unsigned char big5_chars_ban2892 [] = {
    0xd7, 0xc9, 0xb3, 0x5c, 
};
static const unsigned char big5_chars_ban2893 [] = {
    0xb6, 0x44, 
};
static const unsigned char big5_chars_ban2894 [] = {
    0xb6, 0x46, 
};
static const unsigned char big5_chars_ban2895 [] = {
    0xdb, 0xd8, 0xb6, 0x45, 0xb5, 0xf9, 0xb5, 0xfd, 
};
static const unsigned char big5_chars_ban2896 [] = {
    0xb8, 0xe4, 0xe0, 0x49, 0xdb, 0xda, 0xb5, 0xfe, 
};
static const unsigned char big5_chars_ban2897 [] = {
    0xdb, 0xdd, 0xdb, 0xde, 0xb6, 0x43, 
};
static const unsigned char big5_chars_ban2898 [] = {
    0xdb, 0xe0, 
};
static const unsigned char big5_chars_ban2899 [] = {
    0xdb, 0xe2, 
};
static const unsigned char big5_chars_ban2900 [] = {
    0xdb, 0xe3, 0xdb, 0xd7, 0xdb, 0xd6, 0xdb, 0xe4, 0xb6, 0x42, 
    0xdb, 0xe1, 0xdb, 0xdf, 
};
static const unsigned char big5_chars_ban2901 [] = {
    0xb6, 0x40, 0xb5, 0xfb, 0xb6, 0x47, 0xdb, 0xdb, 0xdb, 0xdc, 
    0xdb, 0xd9, 
};
static const unsigned char big5_chars_ban2902 [] = {
    0xb6, 0x41, 
};
static const unsigned char big5_chars_ban2903 [] = {
    0xb5, 0xfc, 
};
static const unsigned char big5_chars_ban2904 [] = {
    0xb5, 0xfa, 0xe0, 0x48, 0xb8, 0xdf, 0xb8, 0xda, 
};
static const unsigned char big5_chars_ban2905 [] = {
    0xb8, 0xd5, 
};
static const unsigned char big5_chars_ban2906 [] = {
    0xb8, 0xe5, 0xb8, 0xd6, 
};
static const unsigned char big5_chars_ban2907 [] = {
    0xb8, 0xd2, 0xb8, 0xe1, 0xb8, 0xde, 0xb8, 0xe0, 
};
static const unsigned char big5_chars_ban2908 [] = {
    0xb8, 0xd7, 0xb8, 0xdc, 0xb8, 0xd3, 0xb8, 0xd4, 0xe0, 0x50, 
    0xe0, 0x4d, 0xe0, 0x45, 0xe0, 0x4a, 
};
static const unsigned char big5_chars_ban2909 [] = {
    0xb8, 0xe2, 0xe0, 0x51, 0xb8, 0xe3, 0xb8, 0xd9, 
};
static const unsigned char big5_chars_ban2910 [] = {
    0xe0, 0x47, 
};
static const unsigned char big5_chars_ban2911 [] = {
    0xe0, 0x4f, 0xe0, 0x4b, 0xe0, 0x4e, 0xe0, 0x4c, 0xb8, 0xdd, 
    0xe0, 0x46, 0xb8, 0xd8, 
};
static const unsigned char big5_chars_ban2912 [] = {
    0xe4, 0x4c, 0xbb, 0x78, 0xbb, 0x7b, 
};
static const unsigned char big5_chars_ban2913 [] = {
    0xe4, 0x4e, 
};
static const unsigned char big5_chars_ban2914 [] = {
    0xbb, 0xa5, 0xe4, 0x4d, 0xbb, 0x7d, 
};
static const unsigned char big5_chars_ban2915 [] = {
    0xbd, 0xcf, 0xe4, 0x4f, 
};
static const unsigned char big5_chars_ban2916 [] = {
    0xbb, 0xa4, 0xe4, 0x4b, 0xbb, 0xa6, 
};
static const unsigned char big5_chars_ban2917 [] = {
    0xbb, 0x79, 
};
static const unsigned char big5_chars_ban2918 [] = {
    0xb8, 0xdb, 0xbb, 0x7c, 
};
static const unsigned char big5_chars_ban2919 [] = {
    0xbb, 0x7a, 0xbb, 0x7e, 0xbb, 0xa2, 0xbb, 0x77, 0xbb, 0xa7, 
    0xbb, 0xa3, 
};
static const unsigned char big5_chars_ban2920 [] = {
    0xbb, 0xa1, 0xe4, 0x4a, 
};
static const unsigned char big5_chars_ban2921 [] = {
    0xbd, 0xd6, 
};
static const unsigned char big5_chars_ban2922 [] = {
    0xbd, 0xd2, 
};
static const unsigned char big5_chars_ban2923 [] = {
    0xbd, 0xd9, 
};
static const unsigned char big5_chars_ban2924 [] = {
    0xe7, 0xd6, 0xbd, 0xda, 0xe7, 0xe2, 0xe7, 0xdb, 0xbd, 0xcb, 
    0xe7, 0xe3, 0xe7, 0xdd, 0xbd, 0xd5, 0xe7, 0xde, 
};
static const unsigned char big5_chars_ban2925 [] = {
    0xbd, 0xd4, 0xe7, 0xe1, 0xbd, 0xce, 0xe7, 0xdf, 0xe7, 0xd5, 
    0xbd, 0xcd, 0xeb, 0xaa, 0xbd, 0xd3, 
};
static const unsigned char big5_chars_ban2926 [] = {
    0xbd, 0xd0, 
};
static const unsigned char big5_chars_ban2927 [] = {
    0xbd, 0xd8, 
};
static const unsigned char big5_chars_ban2928 [] = {
    0xe7, 0xd4, 
};
static const unsigned char big5_chars_ban2929 [] = {
    0xe7, 0xd8, 0xbd, 0xcc, 0xe7, 0xd7, 0xe7, 0xd9, 0xe7, 0xda, 
    0xbd, 0xd7, 0xe7, 0xdc, 0xe7, 0xe0, 0xe7, 0xe4, 
};
static const unsigned char big5_chars_ban2930 [] = {
    0xbd, 0xdb, 0xbf, 0xd2, 0xeb, 0xa5, 0xeb, 0xab, 0xeb, 0xa8, 
    0xeb, 0x7e, 0xeb, 0xac, 0xeb, 0xa1, 
};
static const unsigned char big5_chars_ban2931 [] = {
    0xeb, 0xa7, 
};
static const unsigned char big5_chars_ban2932 [] = {
    0xbf, 0xcd, 0xbf, 0xd3, 0xeb, 0xad, 
};
static const unsigned char big5_chars_ban2933 [] = {
    0xbf, 0xcf, 
};
static const unsigned char big5_chars_ban2934 [] = {
    0xbf, 0xd9, 0xbf, 0xd4, 0xeb, 0xaf, 0xeb, 0xa9, 0xbf, 0xd0, 
    0xeb, 0xa2, 0xbf, 0xda, 0xeb, 0xa3, 0xeb, 0xa4, 0xbf, 0xdb, 
    0xbf, 0xd8, 0xbd, 0xd1, 
};
static const unsigned char big5_chars_ban2935 [] = {
    0xbf, 0xce, 0xeb, 0xb0, 0xbf, 0xdc, 
};
static const unsigned char big5_chars_ban2936 [] = {
    0xbf, 0xd5, 0xeb, 0xae, 0xbf, 0xd1, 0xbf, 0xd6, 0xbf, 0xd7, 
};
static const unsigned char big5_chars_ban2937 [] = {
    0xc1, 0xc3, 0xee, 0xa4, 0xee, 0xad, 0xee, 0xaa, 0xee, 0xac, 
};
static const unsigned char big5_chars_ban2938 [] = {
    0xc1, 0xc0, 0xee, 0xa5, 
};
static const unsigned char big5_chars_ban2939 [] = {
    0xee, 0xab, 0xc1, 0xbc, 0xee, 0xa7, 0xc1, 0xc4, 0xee, 0xa3, 
    0xee, 0xa8, 0xee, 0xaf, 0xeb, 0xa6, 0xee, 0xa9, 0xee, 0xa2, 
    0xc1, 0xbd, 0xee, 0xa1, 0xc1, 0xbe, 0xee, 0xb0, 0xc1, 0xbf, 
    0xee, 0xae, 0xc1, 0xc2, 0xee, 0x7e, 
};
static const unsigned char big5_chars_ban2940 [] = {
    0xc1, 0xc1, 
};
static const unsigned char big5_chars_ban2941 [] = {
    0xee, 0xa6, 0xf0, 0xdc, 0xf0, 0xea, 0xf0, 0xe5, 0xf0, 0xe7, 
    0xf0, 0xdb, 0xc2, 0xd3, 
};
static const unsigned char big5_chars_ban2942 [] = {
    0xf0, 0xda, 0xc2, 0xd6, 0xc2, 0xd5, 
};
static const unsigned char big5_chars_ban2943 [] = {
    0xf0, 0xe9, 0xf0, 0xe1, 0xf0, 0xde, 0xf0, 0xe4, 
};
static const unsigned char big5_chars_ban2944 [] = {
    0xf0, 0xdd, 
};
static const unsigned char big5_chars_ban2945 [] = {
    0xf0, 0xdf, 0xf0, 0xe8, 0xf0, 0xe6, 
};
static const unsigned char big5_chars_ban2946 [] = {
    0xc2, 0xd4, 0xf0, 0xed, 0xf0, 0xeb, 0xf0, 0xe2, 0xf0, 0xec, 
    0xf0, 0xe3, 
};
static const unsigned char big5_chars_ban2947 [] = {
    0xf2, 0xf9, 0xc3, 0xcf, 0xf3, 0x41, 
};
static const unsigned char big5_chars_ban2948 [] = {
    0xf6, 0x4f, 0xc3, 0xd6, 0xf0, 0xe0, 0xf2, 0xf7, 0xc3, 0xd2, 
    0xf2, 0xf8, 0xf2, 0xfd, 
};
static const unsigned char big5_chars_ban2949 [] = {
    0xc3, 0xd4, 0xc3, 0xd5, 0xf2, 0xf6, 0xf3, 0x40, 0xf3, 0x42, 
    0xf2, 0xfa, 0xf2, 0xfc, 0xf2, 0xfe, 0xf2, 0xfb, 0xf3, 0x43, 
    0xc3, 0xd1, 0xc3, 0xd7, 0xc3, 0xd3, 
};
static const unsigned char big5_chars_ban2950 [] = {
    0xc3, 0xd0, 0xf4, 0xd0, 
};
static const unsigned char big5_chars_ban2951 [] = {
    0xc4, 0xb7, 0xf4, 0xce, 
};
static const unsigned char big5_chars_ban2952 [] = {
    0xf4, 0xd2, 
};
static const unsigned char big5_chars_ban2953 [] = {
    0xf4, 0xd3, 0xc4, 0xb5, 0xf4, 0xd4, 0xf4, 0xd1, 
};
static const unsigned char big5_chars_ban2954 [] = {
    0xf4, 0xcf, 0xc4, 0xb8, 0xc4, 0xb4, 0xf4, 0xd5, 
};
static const unsigned char big5_chars_ban2955 [] = {
    0xc4, 0xb6, 0xc4, 0xb3, 
};
static const unsigned char big5_chars_ban2956 [] = {
    0xc4, 0xfe, 
};
static const unsigned char big5_chars_ban2957 [] = {
    0xc5, 0x40, 0xf6, 0x4e, 0xf6, 0x4d, 0xf6, 0x50, 0xf6, 0x51, 
};
static const unsigned char big5_chars_ban2958 [] = {
    0xc5, 0x41, 0xf7, 0x56, 0xf7, 0x5b, 0xc5, 0xaa, 
};
static const unsigned char big5_chars_ban2959 [] = {
    0xf7, 0x58, 
};
static const unsigned char big5_chars_ban2960 [] = {
    0xf7, 0x57, 0xf7, 0x5a, 0xf7, 0x59, 
};
static const unsigned char big5_chars_ban2961 [] = {
    0xf8, 0x43, 
};
static const unsigned char big5_chars_ban2962 [] = {
    0xc5, 0xdc, 0xf8, 0x42, 0xf8, 0x40, 
};
static const unsigned char big5_chars_ban2963 [] = {
    0xf8, 0x41, 
};
static const unsigned char big5_chars_ban2964 [] = {
    0xc5, 0xfe, 0xc5, 0xfd, 0xf8, 0xc1, 0xf8, 0xc2, 0xc6, 0x40, 
};
static const unsigned char big5_chars_ban2965 [] = {
    0xf9, 0x4d, 0xf9, 0x4e, 0xc6, 0x67, 
};
static const unsigned char big5_chars_ban2966 [] = {
    0xc6, 0x6d, 
};
static const unsigned char big5_chars_ban2967 [] = {
    0xf9, 0xa9, 0xf9, 0xc8, 
};
static const unsigned char big5_chars_ban2968 [] = {
    0xa8, 0xa6, 
};
static const unsigned char big5_chars_ban2969 [] = {
    0xd7, 0xcd, 
};
static const unsigned char big5_chars_ban2970 [] = {
    0xd7, 0xce, 0xe0, 0x52, 0xe4, 0x50, 0xe7, 0xe5, 0xc1, 0xc6, 
};
static const unsigned char big5_chars_ban2971 [] = {
    0xc1, 0xc5, 0xf0, 0xee, 0xf3, 0x44, 
};
static const unsigned char big5_chars_ban2972 [] = {
    0xf8, 0x44, 0xa8, 0xa7, 0xd3, 0xde, 0xb0, 0x5a, 0xb3, 0x61, 
    0xe0, 0x54, 0xe0, 0x53, 0xbd, 0xdc, 0xe7, 0xe6, 0xbd, 0xdd, 
    0xee, 0xb1, 0xc2, 0xd7, 
};
static const unsigned char big5_chars_ban2973 [] = {
    0xc6, 0x76, 0xa8, 0xa8, 0xcd, 0xcb, 0xd3, 0xdf, 
};
static const unsigned char big5_chars_ban2974 [] = {
    0xb3, 0x62, 
};
static const unsigned char big5_chars_ban2975 [] = {
    0xd7, 0xcf, 0xd7, 0xd0, 
};
static const unsigned char big5_chars_ban2976 [] = {
    0xdb, 0xe5, 
};
static const unsigned char big5_chars_ban2977 [] = {
    0xb6, 0x48, 0xb8, 0xe6, 
};
static const unsigned char big5_chars_ban2978 [] = {
    0xe0, 0x56, 0xe0, 0x55, 0xe0, 0x57, 
};
static const unsigned char big5_chars_ban2979 [] = {
    0xe4, 0x51, 0xe4, 0x52, 0xbb, 0xa8, 0xbf, 0xdd, 0xbd, 0xde, 
    0xbf, 0xde, 
};
static const unsigned char big5_chars_ban2980 [] = {
    0xee, 0xb5, 0xee, 0xb2, 0xee, 0xb4, 0xee, 0xb3, 0xc1, 0xc7, 
};
static const unsigned char big5_chars_ban2981 [] = {
    0xf0, 0xef, 0xf3, 0x46, 0xf3, 0x45, 0xcb, 0xa4, 0xb0, 0x5c, 
    0xb0, 0x5b, 0xd3, 0xe0, 
};
static const unsigned char big5_chars_ban2982 [] = {
    0xd7, 0xd1, 
};
static const unsigned char big5_chars_ban2983 [] = {
    0xdb, 0xe7, 0xdb, 0xe6, 0xb6, 0x49, 
};
static const unsigned char big5_chars_ban2984 [] = {
    0xe0, 0x59, 0xe0, 0x5a, 0xe0, 0x58, 
};
static const unsigned char big5_chars_ban2985 [] = {
    0xb8, 0xe8, 0xb8, 0xe7, 
};
static const unsigned char big5_chars_ban2986 [] = {
    0xbb, 0xaa, 0xbb, 0xa9, 
};
static const unsigned char big5_chars_ban2987 [] = {
    0xe7, 0xe7, 0xeb, 0xb3, 0xeb, 0xb1, 0xeb, 0xb2, 0xbf, 0xdf, 
    0xee, 0xb7, 0xee, 0xb6, 
};
static const unsigned char big5_chars_ban2988 [] = {
    0xf0, 0xf2, 0xf0, 0xf1, 0xf0, 0xf0, 0xf3, 0x47, 
};
static const unsigned char big5_chars_ban2989 [] = {
    0xf9, 0xaa, 0xa8, 0xa9, 0xad, 0x73, 
};
static const unsigned char big5_chars_ban2990 [] = {
    0xad, 0x74, 0xb0, 0x5d, 0xb0, 0x5e, 0xd3, 0xe2, 0xd3, 0xe1, 
    0xd7, 0xd2, 
};
static const unsigned char big5_chars_ban2991 [] = {
    0xb3, 0x68, 0xb3, 0x66, 0xb3, 0x63, 0xb3, 0x67, 0xb3, 0x65, 
    0xb3, 0x64, 
};
static const unsigned char big5_chars_ban2992 [] = {
    0xb6, 0x4a, 0xdb, 0xea, 
};
static const unsigned char big5_chars_ban2993 [] = {
    0xb8, 0xed, 0xb6, 0x4c, 0xb6, 0x51, 0xdb, 0xec, 0xb6, 0x53, 
    0xb6, 0x52, 0xb6, 0x55, 0xdb, 0xeb, 0xdb, 0xe8, 0xb6, 0x4f, 
    0xb6, 0x4b, 0xb6, 0x4d, 0xdb, 0xe9, 0xb6, 0x54, 0xb6, 0x50, 
    0xb6, 0x4e, 0xb8, 0xef, 0xb8, 0xee, 0xb8, 0xec, 0xb8, 0xf0, 
};
static const unsigned char big5_chars_ban2994 [] = {
    0xb8, 0xea, 0xb8, 0xeb, 
};
static const unsigned char big5_chars_ban2995 [] = {
    0xb8, 0xe9, 
};
static const unsigned char big5_chars_ban2996 [] = {
    0xe0, 0x5b, 
};
static const unsigned char big5_chars_ban2997 [] = {
    0xe4, 0x54, 
};
static const unsigned char big5_chars_ban2998 [] = {
    0xbb, 0xac, 0xbb, 0xad, 0xbb, 0xab, 
};
static const unsigned char big5_chars_ban2999 [] = {
    0xe4, 0x53, 
};
static const unsigned char big5_chars_ban3000 [] = {
    0xe4, 0x55, 
};
static const unsigned char big5_chars_ban3001 [] = {
    0xe7, 0xea, 0xe7, 0xec, 
};
static const unsigned char big5_chars_ban3002 [] = {
    0xbd, 0xe7, 0xe7, 0xed, 0xbd, 0xe0, 0xe7, 0xe9, 0xbd, 0xdf, 
    0xbd, 0xe9, 0xbd, 0xe5, 0xbd, 0xe6, 0xbd, 0xe2, 0xe7, 0xe8, 
    0xbd, 0xe1, 0xe7, 0xee, 0xe7, 0xeb, 
};
static const unsigned char big5_chars_ban3003 [] = {
    0xbd, 0xe8, 
};
static const unsigned char big5_chars_ban3004 [] = {
    0xbd, 0xe3, 0xbd, 0xe4, 0xeb, 0xb5, 
};
static const unsigned char big5_chars_ban3005 [] = {
    0xeb, 0xb7, 0xeb, 0xb6, 
};
static const unsigned char big5_chars_ban3006 [] = {
    0xeb, 0xb8, 0xbf, 0xe0, 0xeb, 0xb4, 
};
static const unsigned char big5_chars_ban3007 [] = {
    0xc1, 0xcb, 0xee, 0xb8, 0xc1, 0xc8, 0xc1, 0xcc, 0xc1, 0xca, 
    0xc1, 0xc9, 0xf0, 0xf3, 
};
static const unsigned char big5_chars_ban3008 [] = {
    0xf0, 0xf6, 
};
static const unsigned char big5_chars_ban3009 [] = {
    0xf0, 0xf5, 
};
static const unsigned char big5_chars_ban3010 [] = {
    0xf0, 0xf4, 0xc2, 0xd8, 0xf3, 0x48, 0xf3, 0x49, 0xc3, 0xd8, 
    0xf3, 0x4a, 0xc3, 0xd9, 
};
static const unsigned char big5_chars_ban3011 [] = {
    0xc4, 0xba, 
};
static const unsigned char big5_chars_ban3012 [] = {
    0xc4, 0xb9, 0xf6, 0x52, 
};
static const unsigned char big5_chars_ban3013 [] = {
    0xc5, 0x42, 0xf6, 0x53, 0xf7, 0x5c, 0xc5, 0xab, 0xc5, 0xac, 
};
static const unsigned char big5_chars_ban3014 [] = {
    0xf8, 0x45, 
};
static const unsigned char big5_chars_ban3015 [] = {
    0xc6, 0x42, 
};
static const unsigned char big5_chars_ban3016 [] = {
    0xa8, 0xaa, 
};
static const unsigned char big5_chars_ban3017 [] = {
    0xb3, 0x6a, 0xb3, 0x69, 0xe0, 0x5c, 0xe0, 0x5d, 
};
static const unsigned char big5_chars_ban3018 [] = {
    0xbb, 0xae, 0xeb, 0xb9, 0xbd, 0xea, 0xeb, 0xba, 0xee, 0xb9, 
    0xa8, 0xab, 
};
static const unsigned char big5_chars_ban3019 [] = {
    0xd0, 0xb2, 0xad, 0x76, 0xad, 0x75, 
};
static const unsigned char big5_chars_ban3020 [] = {
    0xd3, 0xe3, 0xb0, 0x5f, 0xd3, 0xe4, 0xd7, 0xd5, 
};
static const unsigned char big5_chars_ban3021 [] = {
    0xd7, 0xd4, 
};
static const unsigned char big5_chars_ban3022 [] = {
    0xd7, 0xd3, 
};
static const unsigned char big5_chars_ban3023 [] = {
    0xdb, 0xee, 0xb6, 0x58, 
};
static const unsigned char big5_chars_ban3024 [] = {
    0xdb, 0xed, 0xb6, 0x57, 
};
static const unsigned char big5_chars_ban3025 [] = {
    0xdb, 0xef, 0xb6, 0x56, 
};
static const unsigned char big5_chars_ban3026 [] = {
    0xe0, 0x5f, 0xe0, 0x62, 0xe0, 0x60, 0xe0, 0x61, 0xe0, 0x65, 
    0xe0, 0x5e, 0xe0, 0x66, 0xe0, 0x63, 0xe0, 0x64, 0xbb, 0xb0, 
    0xe4, 0x56, 
};
static const unsigned char big5_chars_ban3027 [] = {
    0xbb, 0xaf, 
};
static const unsigned char big5_chars_ban3028 [] = {
    0xe7, 0xf2, 0xe7, 0xf0, 
};
static const unsigned char big5_chars_ban3029 [] = {
    0xbd, 0xeb, 0xe7, 0xef, 0xe7, 0xf1, 
};
static const unsigned char big5_chars_ban3030 [] = {
    0xbd, 0xec, 
};
static const unsigned char big5_chars_ban3031 [] = {
    0xeb, 0xbb, 
};
static const unsigned char big5_chars_ban3032 [] = {
    0xeb, 0xbc, 0xc1, 0xcd, 
};
static const unsigned char big5_chars_ban3033 [] = {
    0xf3, 0x4c, 0xf3, 0x4e, 0xf3, 0x4b, 0xf3, 0x4d, 0xf4, 0xd6, 
    0xf6, 0x54, 
};
static const unsigned char big5_chars_ban3034 [] = {
    0xf9, 0x6f, 0xa8, 0xac, 0xad, 0x77, 0xd3, 0xe5, 0xd3, 0xe7, 
    0xd3, 0xe6, 
};
static const unsigned char big5_chars_ban3035 [] = {
    0xd7, 0xd8, 0xb3, 0x6c, 
};
static const unsigned char big5_chars_ban3036 [] = {
    0xd7, 0xd6, 
};
static const unsigned char big5_chars_ban3037 [] = {
    0xb3, 0x6b, 0xd7, 0xd9, 
};
static const unsigned char big5_chars_ban3038 [] = {
    0xd7, 0xda, 0xd7, 0xd7, 
};
static const unsigned char big5_chars_ban3039 [] = {
    0xdb, 0xfb, 0xb6, 0x60, 0xdb, 0xf3, 0xdb, 0xf9, 
};
static const unsigned char big5_chars_ban3040 [] = {
    0xb6, 0x5b, 0xb6, 0x5e, 0xdb, 0xf2, 0xb6, 0x59, 0xdb, 0xf6, 
    0xe0, 0x6c, 0xb6, 0x5d, 
};
static const unsigned char big5_chars_ban3041 [] = {
    0xdb, 0xf1, 
};
static const unsigned char big5_chars_ban3042 [] = {
    0xdb, 0xf7, 0xdb, 0xf4, 0xdb, 0xfa, 0xdb, 0xf0, 0xdb, 0xf8, 
    0xb6, 0x5c, 0xb6, 0x5f, 0xdb, 0xf5, 0xb6, 0x5a, 
};
static const unsigned char big5_chars_ban3043 [] = {
    0xb8, 0xf2, 0xe0, 0x68, 0xb8, 0xf1, 0xe0, 0x6f, 0xe0, 0x6e, 
    0xb8, 0xf8, 
};
static const unsigned char big5_chars_ban3044 [] = {
    0xb8, 0xf9, 0xe0, 0x70, 0xb8, 0xf3, 0xe0, 0x6d, 0xb8, 0xf7, 
    0xe0, 0x72, 0xe0, 0x69, 
};
static const unsigned char big5_chars_ban3045 [] = {
    0xe0, 0x6b, 0xb8, 0xf4, 0xe0, 0x67, 0xe0, 0x6a, 0xe0, 0x71, 
    0xb8, 0xf5, 0xe0, 0x73, 
};
static const unsigned char big5_chars_ban3046 [] = {
    0xb8, 0xf6, 
};
static const unsigned char big5_chars_ban3047 [] = {
    0xbb, 0xb1, 0xe4, 0x5b, 0xe4, 0x61, 0xe4, 0x59, 0xe4, 0x62, 
};
static const unsigned char big5_chars_ban3048 [] = {
    0xe4, 0x58, 0xe4, 0x5d, 0xe4, 0x63, 0xe4, 0x60, 0xe4, 0x5f, 
    0xe4, 0x5e, 
};
static const unsigned char big5_chars_ban3049 [] = {
    0xe4, 0x57, 0xe4, 0x5c, 
};
static const unsigned char big5_chars_ban3050 [] = {
    0xe4, 0x5a, 
};
static const unsigned char big5_chars_ban3051 [] = {
    0xbd, 0xf1, 0xbd, 0xee, 0xe7, 0xfb, 0xe8, 0x41, 0xe8, 0x43, 
    0xe8, 0x40, 0xe7, 0xf8, 0xe7, 0xfa, 0xe8, 0x45, 0xe8, 0x42, 
    0xe7, 0xfc, 0xe8, 0x46, 0xe7, 0xf9, 0xe8, 0x44, 0xbd, 0xef, 
    0xbd, 0xf5, 0xbd, 0xf3, 0xe7, 0xf3, 0xbd, 0xf4, 0xbd, 0xf0, 
    0xe7, 0xf4, 0xe7, 0xf6, 0xe7, 0xf5, 0xe7, 0xfd, 0xe7, 0xfe, 
};
static const unsigned char big5_chars_ban3052 [] = {
    0xbd, 0xf2, 
};
static const unsigned char big5_chars_ban3053 [] = {
    0xbd, 0xed, 
};
static const unsigned char big5_chars_ban3054 [] = {
    0xe7, 0xf7, 
};
static const unsigned char big5_chars_ban3055 [] = {
    0xeb, 0xc6, 0xbf, 0xe2, 
};
static const unsigned char big5_chars_ban3056 [] = {
    0xeb, 0xbd, 0xbf, 0xe3, 0xbf, 0xe6, 0xeb, 0xc2, 
};
static const unsigned char big5_chars_ban3057 [] = {
    0xeb, 0xbf, 0xbf, 0xe5, 
};
static const unsigned char big5_chars_ban3058 [] = {
    0xeb, 0xc3, 0xeb, 0xc4, 0xeb, 0xbe, 0xeb, 0xc7, 0xeb, 0xc0, 
    0xeb, 0xc5, 0xbf, 0xe4, 
};
static const unsigned char big5_chars_ban3059 [] = {
    0xbf, 0xe1, 0xeb, 0xc1, 
};
static const unsigned char big5_chars_ban3060 [] = {
    0xee, 0xbf, 0xc1, 0xd0, 0xc1, 0xce, 0xc1, 0xd1, 0xc1, 0xcf, 
    0xee, 0xbe, 0xee, 0xbb, 0xee, 0xba, 
};
static const unsigned char big5_chars_ban3061 [] = {
    0xee, 0xbd, 
};
static const unsigned char big5_chars_ban3062 [] = {
    0xee, 0xbc, 0xf1, 0x45, 0xc2, 0xde, 0xf0, 0xfb, 0xf0, 0xfa, 
};
static const unsigned char big5_chars_ban3063 [] = {
    0xc2, 0xd9, 0xf1, 0x41, 0xf1, 0x40, 0xf0, 0xf7, 0xf1, 0x43, 
    0xf0, 0xfc, 0xc2, 0xdd, 0xf0, 0xf9, 0xf1, 0x42, 0xf0, 0xf8, 
    0xc2, 0xda, 0xc2, 0xdc, 0xf0, 0xfd, 0xc2, 0xdb, 0xf0, 0xfe, 
};
static const unsigned char big5_chars_ban3064 [] = {
    0xf1, 0x44, 0xf3, 0x52, 
};
static const unsigned char big5_chars_ban3065 [] = {
    0xc3, 0xde, 0xf3, 0x4f, 
};
static const unsigned char big5_chars_ban3066 [] = {
    0xf3, 0x53, 
};
static const unsigned char big5_chars_ban3067 [] = {
    0xc3, 0xdb, 0xf3, 0x51, 0xc3, 0xe0, 
};
static const unsigned char big5_chars_ban3068 [] = {
    0xc3, 0xdd, 
};
static const unsigned char big5_chars_ban3069 [] = {
    0xf3, 0x50, 
};
static const unsigned char big5_chars_ban3070 [] = {
    0xc3, 0xdf, 0xf3, 0x54, 0xc3, 0xda, 
};
static const unsigned char big5_chars_ban3071 [] = {
    0xc4, 0xbc, 0xc4, 0xbe, 
};
static const unsigned char big5_chars_ban3072 [] = {
    0xf4, 0xd9, 0xc4, 0xbd, 0xf4, 0xd7, 0xc3, 0xdc, 0xf4, 0xd8, 
    0xc4, 0xbb, 0xc5, 0x43, 0xc5, 0x45, 0xf6, 0x56, 0xc5, 0x44, 
    0xf6, 0x55, 
};
static const unsigned char big5_chars_ban3073 [] = {
    0xf7, 0x61, 0xc5, 0xad, 0xf7, 0x60, 0xc5, 0xae, 0xf7, 0x5e, 
    0xf7, 0x5d, 0xf7, 0x62, 0xf7, 0x63, 0xf8, 0x46, 
};
static const unsigned char big5_chars_ban3074 [] = {
    0xf7, 0x5f, 
};
static const unsigned char big5_chars_ban3075 [] = {
    0xf8, 0xc6, 0xf8, 0xc3, 0xf8, 0xc4, 0xf8, 0xc5, 0xc6, 0x5c, 
};
static const unsigned char big5_chars_ban3076 [] = {
    0xf9, 0x51, 0xf9, 0x50, 0xf9, 0x4f, 0xf9, 0x70, 
};
static const unsigned char big5_chars_ban3077 [] = {
    0xf9, 0xbe, 0xf9, 0xab, 0xc6, 0x6e, 0xa8, 0xad, 0xb0, 0x60, 
};
static const unsigned char big5_chars_ban3078 [] = {
    0xb8, 0xfa, 
};
static const unsigned char big5_chars_ban3079 [] = {
    0xbd, 0xf6, 
};
static const unsigned char big5_chars_ban3080 [] = {
    0xeb, 0xc8, 
};
static const unsigned char big5_chars_ban3081 [] = {
    0xc2, 0xdf, 
};
static const unsigned char big5_chars_ban3082 [] = {
    0xf3, 0x55, 
};
static const unsigned char big5_chars_ban3083 [] = {
    0xf9, 0xac, 0xa8, 0xae, 0xaa, 0xee, 0xad, 0x79, 0xad, 0x78, 
};
static const unsigned char big5_chars_ban3084 [] = {
    0xb0, 0x63, 
};
static const unsigned char big5_chars_ban3085 [] = {
    0xd3, 0xe8, 0xb0, 0x61, 0xd3, 0xe9, 0xb0, 0x62, 
};
static const unsigned char big5_chars_ban3086 [] = {
    0xd7, 0xdf, 0xd7, 0xdb, 
};
static const unsigned char big5_chars_ban3087 [] = {
    0xb3, 0x6d, 0xd7, 0xde, 0xd7, 0xdd, 0xd7, 0xdc, 0xb3, 0x6e, 
    0xd7, 0xe0, 0xd7, 0xe1, 
};
static const unsigned char big5_chars_ban3088 [] = {
    0xdc, 0x43, 0xdc, 0x41, 0xdc, 0x45, 0xdc, 0x46, 0xdc, 0x4c, 
};
static const unsigned char big5_chars_ban3089 [] = {
    0xdc, 0x48, 0xdc, 0x4a, 
};
static const unsigned char big5_chars_ban3090 [] = {
    0xdc, 0x42, 0xdb, 0xfc, 
};
static const unsigned char big5_chars_ban3091 [] = {
    0xdc, 0x49, 
};
static const unsigned char big5_chars_ban3092 [] = {
    0xdc, 0x4b, 0xdc, 0x44, 0xdc, 0x47, 0xdb, 0xfd, 0xb6, 0x62, 
    0xdc, 0x40, 0xdb, 0xfe, 0xb6, 0x61, 0xb6, 0x63, 
};
static const unsigned char big5_chars_ban3093 [] = {
    0xb8, 0xfd, 0xe0, 0x75, 0xe0, 0x77, 0xe0, 0x76, 0xe0, 0x7b, 
    0xb8, 0xfb, 
};
static const unsigned char big5_chars_ban3094 [] = {
    0xe0, 0x78, 0xe0, 0x74, 0xe0, 0x79, 0xe0, 0x7a, 0xb8, 0xfc, 
    0xb8, 0xfe, 0xe0, 0x7c, 
};
static const unsigned char big5_chars_ban3095 [] = {
    0xe4, 0x67, 0xe4, 0x66, 
};
static const unsigned char big5_chars_ban3096 [] = {
    0xe4, 0x64, 0xe4, 0x65, 0xbb, 0xb3, 0xbb, 0xb5, 0xbb, 0xb2, 
    0xbb, 0xb4, 0xe8, 0x4d, 0xe8, 0x4e, 0xe8, 0x49, 
};
static const unsigned char big5_chars_ban3097 [] = {
    0xe8, 0x4a, 0xbd, 0xf8, 0xbd, 0xfd, 0xbd, 0xf7, 0xbd, 0xfe, 
    0xbd, 0xf9, 0xe8, 0x4b, 
};
static const unsigned char big5_chars_ban3098 [] = {
    0xe8, 0x4c, 0xe8, 0x48, 0xbe, 0x40, 0xbd, 0xfb, 
};
static const unsigned char big5_chars_ban3099 [] = {
    0xbd, 0xfa, 0xbd, 0xfc, 
};
static const unsigned char big5_chars_ban3100 [] = {
    0xe8, 0x47, 
};
static const unsigned char big5_chars_ban3101 [] = {
    0xeb, 0xca, 0xbf, 0xe8, 
};
static const unsigned char big5_chars_ban3102 [] = {
    0xeb, 0xcc, 0xbf, 0xea, 0xeb, 0xcf, 0xeb, 0xcb, 0xeb, 0xc9, 
    0xeb, 0xce, 0xbf, 0xe9, 0xeb, 0xcd, 
};
static const unsigned char big5_chars_ban3103 [] = {
    0xbf, 0xe7, 
};
static const unsigned char big5_chars_ban3104 [] = {
    0xc1, 0xd3, 0xc1, 0xd6, 0xee, 0xc1, 
};
static const unsigned char big5_chars_ban3105 [] = {
    0xc1, 0xd4, 0xee, 0xc0, 0xc1, 0xd2, 0xc1, 0xd5, 0xf1, 0x46, 
    0xf1, 0x47, 0xf1, 0x48, 0xc2, 0xe0, 
};
static const unsigned char big5_chars_ban3106 [] = {
    0xf1, 0x49, 
};
static const unsigned char big5_chars_ban3107 [] = {
    0xc2, 0xe1, 0xc3, 0xe2, 0xf3, 0x58, 0xf3, 0x59, 0xf3, 0x57, 
    0xf3, 0x56, 0xf3, 0x5a, 0xc3, 0xe1, 0xf4, 0xdd, 0xf4, 0xdb, 
    0xf4, 0xdc, 0xf4, 0xde, 0xf4, 0xda, 0xf4, 0xdf, 0xf6, 0x58, 
};
static const unsigned char big5_chars_ban3108 [] = {
    0xf6, 0x59, 0xf6, 0x57, 0xc5, 0x46, 0xf7, 0x64, 0xc5, 0xaf, 
    0xf7, 0x65, 0xf8, 0x48, 0xf8, 0x47, 
};
static const unsigned char big5_chars_ban3109 [] = {
    0xa8, 0xaf, 0xb6, 0x64, 
};
static const unsigned char big5_chars_ban3110 [] = {
    0xb9, 0x40, 
};
static const unsigned char big5_chars_ban3111 [] = {
    0xbb, 0xb6, 
};
static const unsigned char big5_chars_ban3112 [] = {
    0xbf, 0xec, 
};
static const unsigned char big5_chars_ban3113 [] = {
    0xbf, 0xeb, 
};
static const unsigned char big5_chars_ban3114 [] = {
    0xc3, 0xe3, 0xc4, 0x7c, 0xc5, 0x47, 0xa8, 0xb0, 0xb0, 0x64, 
    0xb9, 0x41, 
};
static const unsigned char big5_chars_ban3115 [] = {
    0xf3, 0x5b, 
};
static const unsigned char big5_chars_ban3116 [] = {
    0xcb, 0xa6, 
};
static const unsigned char big5_chars_ban3117 [] = {
    0xa8, 0xb1, 
};
static const unsigned char big5_chars_ban3118 [] = {
    0xa8, 0xb4, 0xa8, 0xb3, 0xa8, 0xb2, 
};
static const unsigned char big5_chars_ban3119 [] = {
    0xcb, 0xa5, 
};
static const unsigned char big5_chars_ban3120 [] = {
    0xcd, 0xcd, 
};
static const unsigned char big5_chars_ban3121 [] = {
    0xcd, 0xcf, 0xaa, 0xef, 
};
static const unsigned char big5_chars_ban3122 [] = {
    0xaa, 0xf1, 0xcd, 0xcc, 0xcd, 0xce, 0xaa, 0xf0, 0xcd, 0xd1, 
    0xcd, 0xd0, 0xcd, 0xd2, 
};
static const unsigned char big5_chars_ban3123 [] = {
    0xd0, 0xb6, 0xd0, 0xb4, 0xad, 0x7c, 0xd0, 0xb3, 0xad, 0xa3, 
    0xad, 0x7e, 0xad, 0x7b, 
};
static const unsigned char big5_chars_ban3124 [] = {
    0xad, 0xa4, 
};
static const unsigned char big5_chars_ban3125 [] = {
    0xad, 0x7d, 0xad, 0xa2, 
};
static const unsigned char big5_chars_ban3126 [] = {
    0xad, 0xa1, 0xd0, 0xb5, 
};
static const unsigned char big5_chars_ban3127 [] = {
    0xad, 0x7a, 
};
static const unsigned char big5_chars_ban3128 [] = {
    0xb0, 0x6a, 0xd3, 0xeb, 0xd3, 0xf1, 0xb0, 0x67, 0xb0, 0x6e, 
};
static const unsigned char big5_chars_ban3129 [] = {
    0xb0, 0x69, 0xd3, 0xee, 0xd3, 0xf0, 0xb0, 0x6c, 0xd3, 0xea, 
    0xd3, 0xed, 0xb0, 0x68, 0xb0, 0x65, 0xd3, 0xec, 0xb0, 0x6b, 
    0xd3, 0xef, 0xb0, 0x6d, 0xb0, 0x66, 
};
static const unsigned char big5_chars_ban3130 [] = {
    0xd7, 0xe3, 0xd7, 0xe6, 0xb3, 0x70, 
};
static const unsigned char big5_chars_ban3131 [] = {
    0xb3, 0x7a, 0xb3, 0x76, 0xd7, 0xe4, 
};
static const unsigned char big5_chars_ban3132 [] = {
    0xb3, 0x7e, 0xb3, 0x77, 0xb3, 0x7c, 0xb3, 0x72, 
};
static const unsigned char big5_chars_ban3133 [] = {
    0xb3, 0x6f, 0xb3, 0x71, 0xb3, 0x7d, 0xd7, 0xe5, 0xb3, 0x75, 
    0xb3, 0x78, 0xb3, 0x74, 0xb3, 0x79, 0xd7, 0xe7, 0xb3, 0x7b, 
    0xb3, 0x73, 0xd7, 0xe2, 
};
static const unsigned char big5_chars_ban3134 [] = {
    0xdc, 0x4d, 0xb6, 0x65, 0xdc, 0x4f, 
};
static const unsigned char big5_chars_ban3135 [] = {
    0xb6, 0x67, 0xb6, 0x69, 
};
static const unsigned char big5_chars_ban3136 [] = {
    0xdc, 0x4e, 0xb6, 0x66, 0xb6, 0x6a, 
};
static const unsigned char big5_chars_ban3137 [] = {
    0xb6, 0x68, 
};
static const unsigned char big5_chars_ban3138 [] = {
    0xb9, 0x47, 0xe0, 0xa3, 0xb9, 0x4f, 0xe0, 0x7e, 
};
static const unsigned char big5_chars_ban3139 [] = {
    0xb9, 0x50, 0xb9, 0x45, 
};
static const unsigned char big5_chars_ban3140 [] = {
    0xe0, 0xa1, 
};
static const unsigned char big5_chars_ban3141 [] = {
    0xb9, 0x4a, 
};
static const unsigned char big5_chars_ban3142 [] = {
    0xe0, 0xa2, 0xb9, 0x43, 0xb9, 0x42, 
};
static const unsigned char big5_chars_ban3143 [] = {
    0xb9, 0x4d, 0xb9, 0x4c, 0xb9, 0x4b, 0xb9, 0x49, 0xb9, 0x4e, 
    0xe0, 0x7d, 0xb9, 0x44, 0xb9, 0x46, 0xb9, 0x48, 
};
static const unsigned char big5_chars_ban3144 [] = {
    0xbb, 0xb8, 0xbb, 0xbb, 
};
static const unsigned char big5_chars_ban3145 [] = {
    0xbb, 0xbf, 0xbb, 0xb9, 0xbb, 0xbe, 0xbb, 0xbc, 
};
static const unsigned char big5_chars_ban3146 [] = {
    0xbb, 0xb7, 
};
static const unsigned char big5_chars_ban3147 [] = {
    0xbb, 0xbd, 0xbb, 0xba, 
};
static const unsigned char big5_chars_ban3148 [] = {
    0xe8, 0x52, 0xbe, 0x43, 0xbe, 0x41, 
};
static const unsigned char big5_chars_ban3149 [] = {
    0xe8, 0x53, 
};
static const unsigned char big5_chars_ban3150 [] = {
    0xbe, 0x44, 0xbe, 0x42, 0xe8, 0x51, 0xe8, 0x50, 
};
static const unsigned char big5_chars_ban3151 [] = {
    0xbf, 0xf0, 0xe8, 0x4f, 0xbf, 0xee, 0xbf, 0xed, 0xeb, 0xd0, 
    0xbe, 0x45, 0xbf, 0xef, 0xeb, 0xd1, 0xbf, 0xf2, 0xeb, 0xd2, 
    0xbf, 0xf1, 0xc1, 0xd8, 0xee, 0xc3, 0xc1, 0xd7, 0xc1, 0xdc, 
    0xc1, 0xda, 0xc1, 0xdb, 0xc2, 0xe3, 0xc1, 0xd9, 0xee, 0xc2, 
    0xeb, 0xd3, 0xc2, 0xe2, 0xc2, 0xe4, 
};
static const unsigned char big5_chars_ban3152 [] = {
    0xc3, 0xe4, 0xc3, 0xe5, 
};
static const unsigned char big5_chars_ban3153 [] = {
    0xf4, 0xe0, 
};
static const unsigned char big5_chars_ban3154 [] = {
    0xc5, 0xde, 0xc5, 0xdd, 0xa8, 0xb6, 
};
static const unsigned char big5_chars_ban3155 [] = {
    0xca, 0x55, 0xb0, 0x6f, 
};
static const unsigned char big5_chars_ban3156 [] = {
    0xca, 0x52, 0xca, 0x53, 0xca, 0x51, 
};
static const unsigned char big5_chars_ban3157 [] = {
    0xca, 0x54, 
};
static const unsigned char big5_chars_ban3158 [] = {
    0xcb, 0xaa, 0xcb, 0xa7, 0xcb, 0xac, 0xcb, 0xa8, 0xa8, 0xb7, 
    0xa8, 0xba, 
};
static const unsigned char big5_chars_ban3159 [] = {
    0xcb, 0xa9, 0xa8, 0xb9, 0xcb, 0xab, 
};
static const unsigned char big5_chars_ban3160 [] = {
    0xa8, 0xb8, 
};
static const unsigned char big5_chars_ban3161 [] = {
    0xcd, 0xd5, 0xcd, 0xd7, 0xaa, 0xf4, 0xcd, 0xd3, 0xcd, 0xd6, 
    0xcd, 0xd4, 0xaa, 0xf2, 0xaa, 0xf5, 
};
static const unsigned char big5_chars_ban3162 [] = {
    0xaa, 0xf3, 
};
static const unsigned char big5_chars_ban3163 [] = {
    0xd0, 0xb8, 0xd0, 0xbc, 0xd0, 0xb9, 
};
static const unsigned char big5_chars_ban3164 [] = {
    0xad, 0xa7, 
};
static const unsigned char big5_chars_ban3165 [] = {
    0xad, 0xa8, 
};
static const unsigned char big5_chars_ban3166 [] = {
    0xd0, 0xbb, 
};
static const unsigned char big5_chars_ban3167 [] = {
    0xd0, 0xbd, 0xd0, 0xbf, 
};
static const unsigned char big5_chars_ban3168 [] = {
    0xad, 0xa5, 0xd0, 0xbe, 
};
static const unsigned char big5_chars_ban3169 [] = {
    0xad, 0xa6, 
};
static const unsigned char big5_chars_ban3170 [] = {
    0xd7, 0xee, 0xd0, 0xba, 0xd3, 0xf2, 0xd3, 0xfb, 0xd3, 0xf9, 
    0xd3, 0xf4, 0xd3, 0xf5, 0xd3, 0xfa, 0xd3, 0xfc, 0xb0, 0x71, 
};
static const unsigned char big5_chars_ban3171 [] = {
    0xd3, 0xf7, 0xd3, 0xf3, 0xb0, 0x70, 0xb0, 0x72, 0xd3, 0xf6, 
    0xd3, 0xfd, 0xd3, 0xf8, 
};
static const unsigned char big5_chars_ban3172 [] = {
    0xb3, 0xa1, 0xd7, 0xf1, 0xd7, 0xe9, 0xd7, 0xef, 0xd7, 0xf0, 
    0xb3, 0xa2, 
};
static const unsigned char big5_chars_ban3173 [] = {
    0xd7, 0xe8, 0xd7, 0xea, 0xd0, 0xb7, 0xd7, 0xec, 0xd7, 0xed, 
    0xd7, 0xeb, 0xb6, 0x6c, 
};
static const unsigned char big5_chars_ban3174 [] = {
    0xdc, 0x56, 0xeb, 0xd4, 0xdc, 0x57, 0xdc, 0x54, 0xb3, 0xa3, 
    0xb6, 0x6e, 0xdc, 0x53, 0xdc, 0x59, 0xdc, 0x58, 0xb6, 0x6b, 
    0xdc, 0x5c, 0xdc, 0x52, 0xdc, 0x5b, 0xdc, 0x50, 0xdc, 0x5a, 
    0xdc, 0x55, 0xb6, 0x6d, 
};
static const unsigned char big5_chars_ban3175 [] = {
    0xe0, 0xaa, 
};
static const unsigned char big5_chars_ban3176 [] = {
    0xe0, 0xa5, 0xe0, 0xab, 0xe0, 0xa6, 0xe0, 0xa4, 0xe0, 0xa7, 
    0xb9, 0x51, 
};
static const unsigned char big5_chars_ban3177 [] = {
    0xe0, 0xa9, 
};
static const unsigned char big5_chars_ban3178 [] = {
    0xe0, 0xa8, 0xb9, 0x52, 0xbb, 0xc1, 0xbb, 0xc0, 0xe4, 0x6e, 
    0xe4, 0x71, 0xe4, 0x69, 0xe4, 0x6d, 0xbb, 0xc2, 0xe4, 0x6c, 
    0xe4, 0x6a, 0xe4, 0x70, 0xe4, 0x6b, 0xe4, 0x68, 0xe4, 0x6f, 
};
static const unsigned char big5_chars_ban3179 [] = {
    0xe8, 0x59, 0xbe, 0x48, 0xf1, 0x4a, 0xe8, 0x56, 0xe8, 0x57, 
    0xe8, 0x55, 0xdc, 0x51, 0xbe, 0x47, 0xe8, 0x5a, 0xe8, 0x54, 
    0xbe, 0x46, 0xbe, 0x49, 0xe8, 0x58, 0xeb, 0xd5, 0xbf, 0xf3, 
    0xeb, 0xd6, 0xeb, 0xd7, 
};
static const unsigned char big5_chars_ban3180 [] = {
    0xee, 0xc4, 0xc1, 0xdd, 0xf1, 0x4b, 0xf1, 0x4c, 
};
static const unsigned char big5_chars_ban3181 [] = {
    0xf1, 0x4d, 0xf3, 0x5d, 0xf3, 0x5c, 0xf4, 0xe2, 
};
static const unsigned char big5_chars_ban3182 [] = {
    0xf4, 0xe1, 0xf6, 0x5b, 0xf6, 0x5c, 0xf6, 0x5a, 0xf7, 0x66, 
    0xc5, 0xb0, 0xa8, 0xbb, 0xad, 0xaa, 0xad, 0xa9, 0xb0, 0x75, 
    0xb0, 0x74, 0xd4, 0x40, 0xd4, 0x41, 0xd3, 0xfe, 
};
static const unsigned char big5_chars_ban3183 [] = {
    0xb0, 0x73, 0xd7, 0xf5, 
};
static const unsigned char big5_chars_ban3184 [] = {
    0xd7, 0xf6, 0xd7, 0xf2, 0xb3, 0xa4, 0xd7, 0xf3, 
};
static const unsigned char big5_chars_ban3185 [] = {
    0xd7, 0xf4, 
};
static const unsigned char big5_chars_ban3186 [] = {
    0xdc, 0x5f, 0xdc, 0x61, 0xdc, 0x5d, 0xdc, 0x60, 0xb6, 0x6f, 
    0xdc, 0x5e, 0xb6, 0x70, 
};
static const unsigned char big5_chars_ban3187 [] = {
    0xdd, 0x73, 0xb9, 0x55, 0xb9, 0x54, 
};
static const unsigned char big5_chars_ban3188 [] = {
    0xb9, 0x53, 
};
static const unsigned char big5_chars_ban3189 [] = {
    0xe0, 0xac, 0xe0, 0xad, 
};
static const unsigned char big5_chars_ban3190 [] = {
    0xe4, 0x73, 0xe4, 0x75, 0xbb, 0xc6, 0xbb, 0xc3, 
};
static const unsigned char big5_chars_ban3191 [] = {
    0xbb, 0xc5, 0xbb, 0xc4, 0xe4, 0x74, 0xe4, 0x72, 
};
static const unsigned char big5_chars_ban3192 [] = {
    0xe8, 0x61, 0xe8, 0x5e, 0xe8, 0x5f, 0xbe, 0x4d, 0xe8, 0x60, 
    0xe8, 0x5b, 0xe8, 0x5c, 0xbe, 0x4a, 
};
static const unsigned char big5_chars_ban3193 [] = {
    0xbe, 0x4b, 0xe8, 0x5d, 0xbe, 0x4c, 
};
static const unsigned char big5_chars_ban3194 [] = {
    0xeb, 0xdb, 
};
static const unsigned char big5_chars_ban3195 [] = {
    0xeb, 0xdc, 0xeb, 0xd9, 0xeb, 0xda, 0xbf, 0xf4, 0xeb, 0xd8, 
};
static const unsigned char big5_chars_ban3196 [] = {
    0xee, 0xc8, 0xee, 0xc5, 0xee, 0xc7, 0xc1, 0xe0, 0xee, 0xcb, 
    0xc1, 0xdf, 0xee, 0xc9, 0xee, 0xcc, 0xee, 0xca, 0xee, 0xc6, 
    0xc1, 0xde, 
};
static const unsigned char big5_chars_ban3197 [] = {
    0xf1, 0x4f, 
};
static const unsigned char big5_chars_ban3198 [] = {
    0xf1, 0x50, 0xf1, 0x4e, 
};
static const unsigned char big5_chars_ban3199 [] = {
    0xf1, 0x52, 0xc2, 0xe5, 0xc2, 0xe6, 0xf3, 0x5f, 0xc3, 0xe7, 
    0xf1, 0x51, 0xf3, 0x5e, 0xc3, 0xe6, 0xf4, 0xe5, 0xf4, 0xe6, 
    0xc4, 0xbf, 0xf4, 0xe4, 
};
static const unsigned char big5_chars_ban3200 [] = {
    0xf4, 0xe3, 
};
static const unsigned char big5_chars_ban3201 [] = {
    0xf6, 0x5d, 0xc5, 0x48, 
};
static const unsigned char big5_chars_ban3202 [] = {
    0xf8, 0x49, 0xf8, 0xc8, 0xf8, 0xc7, 
};
static const unsigned char big5_chars_ban3203 [] = {
    0xc6, 0x43, 0xc6, 0x5d, 0xf8, 0xc9, 0xf9, 0x71, 
};
static const unsigned char big5_chars_ban3204 [] = {
    0xc6, 0x6f, 0xa8, 0xbc, 0xaa, 0xf6, 
};
static const unsigned char big5_chars_ban3205 [] = {
    0xb9, 0x56, 
};
static const unsigned char big5_chars_ban3206 [] = {
    0xc4, 0xc0, 0xa8, 0xbd, 0xad, 0xab, 0xb3, 0xa5, 0xb6, 0x71, 
    0xc2, 0xe7, 0xaa, 0xf7, 
};
static const unsigned char big5_chars_ban3207 [] = {
    0xd0, 0xc1, 0xd0, 0xc0, 0xd4, 0x42, 
};
static const unsigned char big5_chars_ban3208 [] = {
    0xb0, 0x78, 0xb0, 0x76, 0xb0, 0x7a, 0xd4, 0x44, 
};
static const unsigned char big5_chars_ban3209 [] = {
    0xb0, 0x79, 0xb0, 0x77, 
};
static const unsigned char big5_chars_ban3210 [] = {
    0xd4, 0x43, 0xb3, 0xa8, 0xd7, 0xfc, 
};
static const unsigned char big5_chars_ban3211 [] = {
    0xb3, 0xa7, 0xb3, 0xa9, 0xd8, 0x42, 0xb3, 0xab, 0xd7, 0xfe, 
    0xd8, 0x40, 0xd7, 0xf7, 0xb3, 0xaa, 0xd8, 0x43, 
};
static const unsigned char big5_chars_ban3212 [] = {
    0xd7, 0xf9, 
};
static const unsigned char big5_chars_ban3213 [] = {
    0xd7, 0xfa, 0xd7, 0xf8, 0xb3, 0xa6, 
};
static const unsigned char big5_chars_ban3214 [] = {
    0xd8, 0x41, 0xd7, 0xfb, 0xd7, 0xfd, 
};
static const unsigned char big5_chars_ban3215 [] = {
    0xdc, 0x6d, 
};
static const unsigned char big5_chars_ban3216 [] = {
    0xdc, 0x6c, 0xdc, 0x6a, 0xdc, 0x62, 0xdc, 0x71, 0xdc, 0x65, 
    0xdc, 0x6f, 0xdc, 0x76, 0xdc, 0x6e, 0xb6, 0x79, 
};
static const unsigned char big5_chars_ban3217 [] = {
    0xb6, 0x75, 0xdc, 0x63, 
};
static const unsigned char big5_chars_ban3218 [] = {
    0xdc, 0x69, 0xb6, 0x77, 
};
static const unsigned char big5_chars_ban3219 [] = {
    0xdc, 0x68, 0xb6, 0x78, 0xb6, 0x7a, 0xdc, 0x6b, 
};
static const unsigned char big5_chars_ban3220 [] = {
    0xb6, 0x72, 0xb6, 0x73, 0xdc, 0x77, 0xdc, 0x75, 
};
static const unsigned char big5_chars_ban3221 [] = {
    0xdc, 0x74, 0xdc, 0x66, 
};
static const unsigned char big5_chars_ban3222 [] = {
    0xdc, 0x72, 
};
static const unsigned char big5_chars_ban3223 [] = {
    0xb6, 0x76, 
};
static const unsigned char big5_chars_ban3224 [] = {
    0xb6, 0x74, 0xdc, 0x73, 0xdc, 0x64, 0xdc, 0x67, 0xdc, 0x70, 
};
static const unsigned char big5_chars_ban3225 [] = {
    0xe4, 0xba, 0xe0, 0xb7, 
};
static const unsigned char big5_chars_ban3226 [] = {
    0xe0, 0xb0, 0xe0, 0xc3, 0xe0, 0xcc, 0xe0, 0xb3, 0xb9, 0x61, 
};
static const unsigned char big5_chars_ban3227 [] = {
    0xe0, 0xc0, 0xb9, 0x57, 0xb9, 0x59, 0xb9, 0x65, 0xe0, 0xb1, 
};
static const unsigned char big5_chars_ban3228 [] = {
    0xb9, 0x5a, 0xb9, 0x5c, 0xb9, 0x66, 0xb9, 0x5b, 
};
static const unsigned char big5_chars_ban3229 [] = {
    0xb9, 0x64, 0xe0, 0xb9, 
};
static const unsigned char big5_chars_ban3230 [] = {
    0xe0, 0xae, 0xb9, 0x62, 0xe0, 0xb8, 0xb9, 0x5e, 0xe0, 0xca, 
    0xb9, 0x63, 0xe0, 0xc8, 0xe0, 0xbc, 0xe0, 0xc6, 0xb9, 0x60, 
    0xe0, 0xaf, 0xe0, 0xc9, 0xe0, 0xc4, 
};
static const unsigned char big5_chars_ban3231 [] = {
    0xe0, 0xcb, 0xb9, 0x58, 
};
static const unsigned char big5_chars_ban3232 [] = {
    0xb9, 0x67, 0xb9, 0x5d, 
};
static const unsigned char big5_chars_ban3233 [] = {
    0xe0, 0xb5, 
};
static const unsigned char big5_chars_ban3234 [] = {
    0xe0, 0xbd, 0xe0, 0xc1, 
};
static const unsigned char big5_chars_ban3235 [] = {
    0xe0, 0xc5, 0xb9, 0x5f, 0xe0, 0xb4, 0xe0, 0xb2, 0xe0, 0xbe, 
};
static const unsigned char big5_chars_ban3236 [] = {
    0xe0, 0xbb, 0xe0, 0xba, 
};
static const unsigned char big5_chars_ban3237 [] = {
    0xe0, 0xbf, 0xe0, 0xc2, 
};
static const unsigned char big5_chars_ban3238 [] = {
    0xe0, 0xc7, 
};
static const unsigned char big5_chars_ban3239 [] = {
    0xe4, 0x78, 
};
static const unsigned char big5_chars_ban3240 [] = {
    0xbb, 0xc7, 0xe4, 0xa4, 0xe4, 0x7a, 0xbb, 0xcc, 0xbb, 0xd0, 
    0xe4, 0xad, 0xe4, 0xb5, 0xe4, 0xa6, 0xbb, 0xc8, 
};
static const unsigned char big5_chars_ban3241 [] = {
    0xe4, 0xaa, 0xe0, 0xb6, 
};
static const unsigned char big5_chars_ban3242 [] = {
    0xbb, 0xc9, 0xe4, 0xb1, 0xe4, 0xb6, 0xe4, 0xae, 
};
static const unsigned char big5_chars_ban3243 [] = {
    0xe4, 0xb0, 0xe4, 0xb9, 0xe4, 0xb2, 0xe4, 0x7e, 0xe4, 0xa9, 
};
static const unsigned char big5_chars_ban3244 [] = {
    0xbb, 0xd1, 
};
static const unsigned char big5_chars_ban3245 [] = {
    0xbb, 0xcd, 0xe4, 0x7c, 0xe4, 0xab, 0xbb, 0xcb, 0xe4, 0xa5, 
    0xbb, 0xca, 0xe4, 0xb3, 0xe4, 0xa2, 0xe4, 0x79, 0xbb, 0xce, 
    0xe4, 0xb8, 
};
static const unsigned char big5_chars_ban3246 [] = {
    0xe4, 0x7b, 0xe4, 0xaf, 0xe4, 0xac, 0xe4, 0xa7, 0xe4, 0x77, 
    0xe4, 0x76, 0xe4, 0xa1, 0xe4, 0xb4, 0xbb, 0xcf, 0xe4, 0xb7, 
    0xe4, 0x7d, 0xe4, 0xa3, 0xbe, 0x52, 
};
static const unsigned char big5_chars_ban3247 [] = {
    0xbe, 0x5a, 0xbe, 0x55, 0xe8, 0xa4, 0xe8, 0xa1, 0xe8, 0x67, 
    0xbe, 0x50, 
};
static const unsigned char big5_chars_ban3248 [] = {
    0xf9, 0xd7, 
};
static const unsigned char big5_chars_ban3249 [] = {
    0xbe, 0x4f, 0xbe, 0x56, 
};
static const unsigned char big5_chars_ban3250 [] = {
    0xe8, 0x65, 0xbe, 0x54, 0xe8, 0x71, 0xe8, 0x63, 0xe8, 0x64, 
    0xbe, 0x4e, 0xe8, 0xa3, 0xbe, 0x58, 0xe8, 0x74, 0xe8, 0x79, 
    0xe8, 0x73, 0xeb, 0xee, 0xe8, 0x6f, 0xe8, 0x77, 0xe8, 0x75, 
    0xe8, 0x68, 0xe8, 0x62, 0xe8, 0x7d, 0xbe, 0x57, 0xe8, 0x7e, 
};
static const unsigned char big5_chars_ban3251 [] = {
    0xe8, 0x78, 
};
static const unsigned char big5_chars_ban3252 [] = {
    0xe8, 0x6d, 0xe8, 0x6b, 0xe8, 0x66, 
};
static const unsigned char big5_chars_ban3253 [] = {
    0xe8, 0x6e, 0xe8, 0x7b, 0xe8, 0x6a, 0xe8, 0x7a, 0xe8, 0xa2, 
};
static const unsigned char big5_chars_ban3254 [] = {
    0xbe, 0x53, 
};
static const unsigned char big5_chars_ban3255 [] = {
    0xe8, 0x76, 0xe8, 0x7c, 0xe8, 0x72, 0xe8, 0x6c, 0xbe, 0x51, 
};
static const unsigned char big5_chars_ban3256 [] = {
    0xe4, 0xa8, 0xe8, 0x70, 0xbe, 0x59, 0xe8, 0x69, 
};
static const unsigned char big5_chars_ban3257 [] = {
    0xeb, 0xf4, 0xbf, 0xf7, 0xeb, 0xf3, 0xeb, 0xf0, 0xec, 0x44, 
    0xbf, 0xfb, 
};
static const unsigned char big5_chars_ban3258 [] = {
    0xec, 0x41, 0xeb, 0xf8, 0xec, 0x43, 0xeb, 0xe9, 0xeb, 0xf6, 
};
static const unsigned char big5_chars_ban3259 [] = {
    0xbf, 0xfd, 
};
static const unsigned char big5_chars_ban3260 [] = {
    0xeb, 0xe1, 
};
static const unsigned char big5_chars_ban3261 [] = {
    0xeb, 0xdf, 0xec, 0x42, 
};
static const unsigned char big5_chars_ban3262 [] = {
    0xec, 0x40, 0xeb, 0xfe, 0xeb, 0xed, 0xeb, 0xec, 0xeb, 0xe2, 
    0xc0, 0x40, 
};
static const unsigned char big5_chars_ban3263 [] = {
    0xeb, 0xe8, 0xeb, 0xf2, 0xeb, 0xfd, 0xc0, 0x43, 0xec, 0x45, 
};
static const unsigned char big5_chars_ban3264 [] = {
    0xc1, 0xe8, 0xc0, 0x45, 0xbf, 0xfe, 0xeb, 0xe6, 
};
static const unsigned char big5_chars_ban3265 [] = {
    0xeb, 0xef, 0xeb, 0xde, 0xeb, 0xe0, 0xbf, 0xf5, 0xc0, 0x42, 
    0xbf, 0xfa, 0xeb, 0xe7, 0xeb, 0xf7, 0xeb, 0xf1, 0xc0, 0x41, 
    0xeb, 0xdd, 0xc1, 0xe3, 0xeb, 0xf9, 0xeb, 0xfc, 0xbf, 0xfc, 
};
static const unsigned char big5_chars_ban3266 [] = {
    0xeb, 0xeb, 0xc0, 0x44, 0xbf, 0xf9, 
};
static const unsigned char big5_chars_ban3267 [] = {
    0xbf, 0xf8, 0xeb, 0xf5, 0xeb, 0xfb, 0xbf, 0xf6, 
};
static const unsigned char big5_chars_ban3268 [] = {
    0xeb, 0xe4, 0xeb, 0xfa, 
};
static const unsigned char big5_chars_ban3269 [] = {
    0xeb, 0xe5, 
};
static const unsigned char big5_chars_ban3270 [] = {
    0xeb, 0xea, 0xee, 0xd2, 
};
static const unsigned char big5_chars_ban3271 [] = {
    0xee, 0xd7, 0xc1, 0xe5, 0xc1, 0xe7, 0xee, 0xdd, 0xc1, 0xe1, 
    0xee, 0xec, 0xee, 0xe3, 0xee, 0xd8, 0xee, 0xd9, 0xee, 0xe2, 
};
static const unsigned char big5_chars_ban3272 [] = {
    0xc1, 0xee, 0xee, 0xe1, 0xee, 0xd1, 0xee, 0xe0, 0xee, 0xd4, 
    0xee, 0xed, 0xc1, 0xed, 0xc1, 0xeb, 0xee, 0xd5, 
};
static const unsigned char big5_chars_ban3273 [] = {
    0xee, 0xe8, 
};
static const unsigned char big5_chars_ban3274 [] = {
    0xee, 0xda, 0xee, 0xe7, 
};
static const unsigned char big5_chars_ban3275 [] = {
    0xee, 0xe9, 0xee, 0xd0, 0xc1, 0xe6, 
};
static const unsigned char big5_chars_ban3276 [] = {
    0xee, 0xea, 
};
static const unsigned char big5_chars_ban3277 [] = {
    0xee, 0xde, 
};
static const unsigned char big5_chars_ban3278 [] = {
    0xc1, 0xea, 0xee, 0xdb, 
};
static const unsigned char big5_chars_ban3279 [] = {
    0xc1, 0xec, 0xee, 0xe4, 
};
static const unsigned char big5_chars_ban3280 [] = {
    0xc1, 0xe4, 0xee, 0xd6, 0xee, 0xe5, 
};
static const unsigned char big5_chars_ban3281 [] = {
    0xee, 0xdf, 0xeb, 0xe3, 0xee, 0xe6, 0xee, 0xd3, 
};
static const unsigned char big5_chars_ban3282 [] = {
    0xc1, 0xe9, 
};
static const unsigned char big5_chars_ban3283 [] = {
    0xee, 0xeb, 
};
static const unsigned char big5_chars_ban3284 [] = {
    0xc1, 0xe2, 0xee, 0xce, 
};
static const unsigned char big5_chars_ban3285 [] = {
    0xf1, 0x60, 0xf1, 0x59, 0xc2, 0xe9, 
};
static const unsigned char big5_chars_ban3286 [] = {
    0xf1, 0x54, 0xf1, 0x63, 0xf1, 0x5b, 0xee, 0xdc, 
};
static const unsigned char big5_chars_ban3287 [] = {
    0xf1, 0x65, 0xf1, 0x55, 
};
static const unsigned char big5_chars_ban3288 [] = {
    0xc2, 0xe8, 0xf1, 0x5f, 0xc2, 0xea, 0xc2, 0xf2, 0xc2, 0xf0, 
    0xf1, 0x61, 0xc2, 0xf1, 0xf1, 0x57, 
};
static const unsigned char big5_chars_ban3289 [] = {
    0xf1, 0x58, 0xf1, 0x5d, 0xf1, 0x62, 
};
static const unsigned char big5_chars_ban3290 [] = {
    0xee, 0xcd, 0xc2, 0xeb, 0xf1, 0x6a, 0xf1, 0x67, 0xf1, 0x6b, 
    0xf1, 0x5e, 0xf1, 0x5a, 0xf1, 0x68, 0xf3, 0x6a, 0xf1, 0x5c, 
};
static const unsigned char big5_chars_ban3291 [] = {
    0xc2, 0xee, 
};
static const unsigned char big5_chars_ban3292 [] = {
    0xc2, 0xed, 0xee, 0xcf, 0xc2, 0xef, 0xf1, 0x64, 0xf1, 0x66, 
    0xc2, 0xec, 0xf1, 0x69, 0xf1, 0x53, 
};
static const unsigned char big5_chars_ban3293 [] = {
    0xf1, 0x56, 
};
static const unsigned char big5_chars_ban3294 [] = {
    0xf3, 0x73, 
};
static const unsigned char big5_chars_ban3295 [] = {
    0xf3, 0x63, 0xc3, 0xeb, 0xf3, 0x71, 
};
static const unsigned char big5_chars_ban3296 [] = {
    0xf3, 0x61, 0xc3, 0xec, 
};
static const unsigned char big5_chars_ban3297 [] = {
    0xf3, 0x6c, 
};
static const unsigned char big5_chars_ban3298 [] = {
    0xf3, 0x68, 0xc3, 0xf1, 0xf3, 0x72, 0xf3, 0x62, 0xf3, 0x65, 
    0xc3, 0xe9, 0xf3, 0x74, 
};
static const unsigned char big5_chars_ban3299 [] = {
    0xf3, 0x6d, 0xf3, 0x70, 0xc3, 0xef, 0xc3, 0xf4, 0xc3, 0xf2, 
    0xf3, 0x69, 0xf3, 0x64, 
};
static const unsigned char big5_chars_ban3300 [] = {
    0xc3, 0xed, 0xc3, 0xee, 0xf3, 0x60, 0xc3, 0xea, 
};
static const unsigned char big5_chars_ban3301 [] = {
    0xc3, 0xe8, 0xc3, 0xf0, 0xf3, 0x6f, 0xc3, 0xf3, 
};
static const unsigned char big5_chars_ban3302 [] = {
    0xf3, 0x6b, 0xf3, 0x75, 0xc3, 0xf5, 
};
static const unsigned char big5_chars_ban3303 [] = {
    0xf3, 0x67, 
};
static const unsigned char big5_chars_ban3304 [] = {
    0xf3, 0x6e, 
};
static const unsigned char big5_chars_ban3305 [] = {
    0xf4, 0xf3, 0xf5, 0x42, 0xf4, 0xf5, 0xf4, 0xfc, 0xf3, 0x66, 
    0xf4, 0xfa, 0xf4, 0xe9, 0xf5, 0x40, 0xc4, 0xc3, 0xf4, 0xed, 
    0xf4, 0xfe, 0xf4, 0xf4, 
};
static const unsigned char big5_chars_ban3306 [] = {
    0xc4, 0xc2, 
};
static const unsigned char big5_chars_ban3307 [] = {
    0xf5, 0x44, 0xf4, 0xf6, 
};
static const unsigned char big5_chars_ban3308 [] = {
    0xf4, 0xfb, 0xf4, 0xfd, 0xf4, 0xe7, 0xf5, 0x41, 0xf4, 0xf2, 
    0xf4, 0xf7, 0xf4, 0xeb, 0xf4, 0xef, 0xf5, 0x43, 0xf4, 0xf9, 
    0xf4, 0xe8, 0xf4, 0xec, 0xf4, 0xee, 0xf4, 0xf8, 
};
static const unsigned char big5_chars_ban3309 [] = {
    0xc4, 0xc1, 0xf4, 0xf1, 
};
static const unsigned char big5_chars_ban3310 [] = {
    0xf4, 0xea, 
};
static const unsigned char big5_chars_ban3311 [] = {
    0xf4, 0xf0, 0xf6, 0x61, 0xf6, 0x66, 0xc5, 0x4f, 0xf6, 0x68, 
};
static const unsigned char big5_chars_ban3312 [] = {
    0xc5, 0x49, 
};
static const unsigned char big5_chars_ban3313 [] = {
    0xf6, 0x64, 0xf6, 0x6a, 0xc5, 0x4e, 0xc5, 0x4a, 
};
static const unsigned char big5_chars_ban3314 [] = {
    0xc5, 0x4b, 0xf6, 0x60, 0xf6, 0x67, 0xc5, 0x4d, 0xf6, 0x65, 
    0xc5, 0x4c, 0xf6, 0x5f, 0xf6, 0x63, 0xf6, 0x62, 
};
static const unsigned char big5_chars_ban3315 [] = {
    0xf6, 0x5e, 0xf6, 0x69, 
};
static const unsigned char big5_chars_ban3316 [] = {
    0xc5, 0xb1, 0xf7, 0x6d, 0xf7, 0x70, 0xf7, 0x6c, 0xf7, 0x6e, 
    0xf7, 0x6f, 0xf7, 0x69, 0xf7, 0x6a, 0xf7, 0x67, 
};
static const unsigned char big5_chars_ban3317 [] = {
    0xf7, 0x6b, 0xf7, 0x68, 0xc5, 0xb2, 0xc5, 0xb3, 
};
static const unsigned char big5_chars_ban3318 [] = {
    0xf8, 0x4b, 
};
static const unsigned char big5_chars_ban3319 [] = {
    0xf8, 0x4d, 
};
static const unsigned char big5_chars_ban3320 [] = {
    0xf8, 0x4c, 0xf8, 0x4e, 
};
static const unsigned char big5_chars_ban3321 [] = {
    0xc5, 0xe0, 
};
static const unsigned char big5_chars_ban3322 [] = {
    0xf8, 0x4a, 0xc5, 0xdf, 0xc5, 0xe1, 
};
static const unsigned char big5_chars_ban3323 [] = {
    0xf8, 0xcb, 0xf8, 0xcc, 0xc6, 0x44, 0xf8, 0xca, 
};
static const unsigned char big5_chars_ban3324 [] = {
    0xf9, 0x53, 0xf9, 0x52, 0xf9, 0x54, 0xc6, 0x5f, 0xf9, 0x55, 
    0xc6, 0x5e, 0xf9, 0x56, 0xf9, 0x72, 0xf9, 0x75, 0xf9, 0x74, 
    0xc6, 0x68, 0xf9, 0x73, 
};
static const unsigned char big5_chars_ban3325 [] = {
    0xc6, 0x72, 0xc6, 0x70, 0xc6, 0x71, 0xc6, 0x77, 0xf9, 0xc0, 
    0xf9, 0xc1, 0xf9, 0xbf, 0xf9, 0xc9, 
};
static const unsigned char big5_chars_ban3326 [] = {
    0xaa, 0xf8, 
};
static const unsigned char big5_chars_ban3327 [] = {
    0xd8, 0x44, 0xdc, 0x78, 0xe8, 0xa5, 0xf3, 0x76, 
};
static const unsigned char big5_chars_ban3328 [] = {
    0xaa, 0xf9, 
};
static const unsigned char big5_chars_ban3329 [] = {
    0xad, 0xac, 0xb0, 0x7b, 
};
static const unsigned char big5_chars_ban3330 [] = {
    0xd8, 0x45, 
};
static const unsigned char big5_chars_ban3331 [] = {
    0xd8, 0x46, 0xb3, 0xac, 
};
static const unsigned char big5_chars_ban3332 [] = {
    0xb6, 0x7d, 0xdc, 0x7a, 0xdc, 0x79, 0xb6, 0xa3, 0xb6, 0x7c, 
    0xdc, 0x7b, 0xb6, 0x7e, 0xb6, 0xa2, 0xb6, 0xa1, 0xb6, 0x7b, 
};
static const unsigned char big5_chars_ban3333 [] = {
    0xb9, 0x68, 
};
static const unsigned char big5_chars_ban3334 [] = {
    0xe0, 0xd0, 0xe0, 0xce, 
};
static const unsigned char big5_chars_ban3335 [] = {
    0xe0, 0xcf, 0xe0, 0xcd, 
};
static const unsigned char big5_chars_ban3336 [] = {
    0xbb, 0xd2, 
};
static const unsigned char big5_chars_ban3337 [] = {
    0xbb, 0xd5, 0xbb, 0xd7, 0xbb, 0xd6, 
};
static const unsigned char big5_chars_ban3338 [] = {
    0xbb, 0xd3, 0xbb, 0xd4, 
};
static const unsigned char big5_chars_ban3339 [] = {
    0xe8, 0xa7, 0xe8, 0xa6, 0xbe, 0x5b, 0xe8, 0xa8, 
};
static const unsigned char big5_chars_ban3340 [] = {
    0xe8, 0xa9, 0xbe, 0x5c, 
};
static const unsigned char big5_chars_ban3341 [] = {
    0xec, 0x4d, 0xec, 0x4b, 0xee, 0xf3, 
};
static const unsigned char big5_chars_ban3342 [] = {
    0xec, 0x49, 0xec, 0x4a, 0xc0, 0x46, 0xec, 0x46, 0xec, 0x4e, 
    0xec, 0x48, 0xec, 0x4c, 0xee, 0xef, 
};
static const unsigned char big5_chars_ban3343 [] = {
    0xee, 0xf1, 
};
static const unsigned char big5_chars_ban3344 [] = {
    0xee, 0xf2, 0xc1, 0xf3, 0xee, 0xee, 0xc1, 0xf2, 0xee, 0xf0, 
    0xc1, 0xef, 0xc1, 0xf0, 0xc1, 0xf1, 0xec, 0x47, 
};
static const unsigned char big5_chars_ban3345 [] = {
    0xc2, 0xf5, 0xf1, 0x6e, 0xf1, 0x6c, 0xf1, 0x6d, 0xc2, 0xf3, 
    0xc2, 0xf6, 0xc2, 0xf4, 
};
static const unsigned char big5_chars_ban3346 [] = {
    0xf3, 0x77, 0xf3, 0x78, 0xc3, 0xf6, 
};
static const unsigned char big5_chars_ban3347 [] = {
    0xf5, 0x45, 0xf5, 0x47, 0xf5, 0x46, 0xc4, 0xc4, 0xc5, 0x50, 
    0xf6, 0x6d, 0xf6, 0x6c, 0xf6, 0x6b, 
};
static const unsigned char big5_chars_ban3348 [] = {
    0xaa, 0xfa, 
};
static const unsigned char big5_chars_ban3349 [] = {
    0xc9, 0xaa, 
};
static const unsigned char big5_chars_ban3350 [] = {
    0xca, 0x58, 0xa6, 0xe9, 0xca, 0x56, 0xca, 0x59, 0xca, 0x57, 
};
static const unsigned char big5_chars_ban3351 [] = {
    0xcb, 0xae, 
};
static const unsigned char big5_chars_ban3352 [] = {
    0xa8, 0xc1, 
};
static const unsigned char big5_chars_ban3353 [] = {
    0xa8, 0xc2, 0xcb, 0xb0, 0xa8, 0xbf, 0xcb, 0xaf, 0xcb, 0xad, 
    0xa8, 0xc0, 0xa8, 0xbe, 
};
static const unsigned char big5_chars_ban3354 [] = {
    0xcd, 0xd8, 0xcd, 0xdb, 0xaa, 0xfd, 0xcd, 0xda, 0xcd, 0xd9, 
};
static const unsigned char big5_chars_ban3355 [] = {
    0xaa, 0xfc, 0xaa, 0xfb, 
};
static const unsigned char big5_chars_ban3356 [] = {
    0xab, 0x40, 0xcd, 0xdc, 0xaa, 0xfe, 
};
static const unsigned char big5_chars_ban3357 [] = {
    0xd0, 0xc6, 0xad, 0xae, 0xad, 0xaf, 0xad, 0xb0, 0xd0, 0xc7, 
    0xd0, 0xc3, 0xad, 0xad, 0xd0, 0xc4, 
};
static const unsigned char big5_chars_ban3358 [] = {
    0xd0, 0xc5, 0xd0, 0xc2, 
};
static const unsigned char big5_chars_ban3359 [] = {
    0xb0, 0xa4, 
};
static const unsigned char big5_chars_ban3360 [] = {
    0xb0, 0xa1, 0xd4, 0x45, 0xb0, 0xa2, 0xb0, 0xa5, 0xd4, 0x46, 
};
static const unsigned char big5_chars_ban3361 [] = {
    0xb0, 0x7e, 0xb0, 0x7c, 0xb0, 0x7d, 0xb0, 0xa3, 
};
static const unsigned char big5_chars_ban3362 [] = {
    0xb3, 0xad, 0xd8, 0x49, 0xb3, 0xb5, 0xd8, 0x48, 
};
static const unsigned char big5_chars_ban3363 [] = {
    0xd8, 0x4b, 0xb3, 0xb1, 0xd8, 0x4a, 0xb6, 0xab, 0xb3, 0xaf, 
    0xb3, 0xb2, 0xb3, 0xae, 0xb3, 0xb3, 0xb3, 0xb4, 0xb3, 0xb0, 
};
static const unsigned char big5_chars_ban3364 [] = {
    0xd8, 0x47, 0xb6, 0xa7, 0xdc, 0x7d, 
};
static const unsigned char big5_chars_ban3365 [] = {
    0xdc, 0xa3, 
};
static const unsigned char big5_chars_ban3366 [] = {
    0xdc, 0xa2, 0xb6, 0xac, 0xb6, 0xa8, 0xb6, 0xa9, 0xdc, 0x7c, 
    0xdc, 0x7e, 0xdc, 0xa1, 0xb6, 0xa4, 0xb6, 0xa6, 
};
static const unsigned char big5_chars_ban3367 [] = {
    0xb6, 0xaa, 0xb6, 0xa5, 
};
static const unsigned char big5_chars_ban3368 [] = {
    0xe0, 0xd3, 0xe0, 0xd1, 0xe0, 0xd2, 0xb9, 0x6a, 0xb9, 0x6b, 
};
static const unsigned char big5_chars_ban3369 [] = {
    0xe0, 0xd4, 0xb9, 0x69, 0xbb, 0xd8, 
};
static const unsigned char big5_chars_ban3370 [] = {
    0xbb, 0xda, 0xbb, 0xd9, 
};
static const unsigned char big5_chars_ban3371 [] = {
    0xe4, 0xbb, 
};
static const unsigned char big5_chars_ban3372 [] = {
    0xe4, 0xbc, 0xe8, 0xab, 
};
static const unsigned char big5_chars_ban3373 [] = {
    0xe8, 0xaa, 
};
static const unsigned char big5_chars_ban3374 [] = {
    0xc0, 0x47, 0xc0, 0x48, 0xec, 0x4f, 0xc0, 0x49, 
};
static const unsigned char big5_chars_ban3375 [] = {
    0xee, 0xf6, 
};
static const unsigned char big5_chars_ban3376 [] = {
    0xee, 0xf4, 
};
static const unsigned char big5_chars_ban3377 [] = {
    0xee, 0xf5, 0xc1, 0xf4, 
};
static const unsigned char big5_chars_ban3378 [] = {
    0xf1, 0x6f, 0xc3, 0xf7, 
};
static const unsigned char big5_chars_ban3379 [] = {
    0xc1, 0xf5, 0xab, 0x41, 
};
static const unsigned char big5_chars_ban3380 [] = {
    0xb0, 0xa6, 0xd4, 0x47, 
};
static const unsigned char big5_chars_ban3381 [] = {
    0xd8, 0x4c, 0xb3, 0xb6, 0xb6, 0xad, 0xdc, 0xa4, 0xdc, 0xa6, 
    0xb6, 0xaf, 0xb6, 0xae, 0xb6, 0xb0, 0xb6, 0xb1, 0xdc, 0xa5, 
    0xb9, 0x6e, 0xb9, 0x6f, 0xb9, 0x6d, 0xbb, 0xdb, 0xb9, 0x6c, 
    0xe0, 0xd5, 
};
static const unsigned char big5_chars_ban3382 [] = {
    0xbb, 0xdc, 0xe8, 0xac, 0xec, 0x50, 0xc0, 0x4a, 0xc1, 0xf6, 
    0xf1, 0x70, 0xf1, 0x74, 0xc2, 0xf9, 0xf1, 0x71, 0xc2, 0xfa, 
    0xc2, 0xf8, 0xf1, 0x75, 0xc2, 0xfb, 0xf1, 0x73, 
};
static const unsigned char big5_chars_ban3383 [] = {
    0xf3, 0x79, 0xc2, 0xf7, 0xc3, 0xf8, 
};
static const unsigned char big5_chars_ban3384 [] = {
    0xf8, 0xcd, 
};
static const unsigned char big5_chars_ban3385 [] = {
    0xab, 0x42, 0xb3, 0xb8, 0xb3, 0xb7, 
};
static const unsigned char big5_chars_ban3386 [] = {
    0xb6, 0xb2, 0xdc, 0xa8, 0xdc, 0xa7, 0xb6, 0xb3, 
};
static const unsigned char big5_chars_ban3387 [] = {
    0xe0, 0xd9, 0xb9, 0x73, 0xb9, 0x70, 0xe0, 0xd8, 0xb9, 0x72, 
    0xe0, 0xd6, 0xb9, 0x71, 
};
static const unsigned char big5_chars_ban3388 [] = {
    0xe0, 0xd7, 
};
static const unsigned char big5_chars_ban3389 [] = {
    0xe4, 0xbd, 0xbb, 0xdd, 
};
static const unsigned char big5_chars_ban3390 [] = {
    0xe8, 0xaf, 
};
static const unsigned char big5_chars_ban3391 [] = {
    0xbe, 0x5d, 0xe8, 0xad, 0xbe, 0x5e, 0xbe, 0x5f, 0xe8, 0xae, 
    0xbe, 0x60, 
};
static const unsigned char big5_chars_ban3392 [] = {
    0xec, 0x51, 
};
static const unsigned char big5_chars_ban3393 [] = {
    0xc0, 0x4e, 0xc0, 0x4b, 0xc0, 0x50, 0xec, 0x53, 0xc0, 0x4c, 
    0xec, 0x52, 0xc0, 0x4f, 
};
static const unsigned char big5_chars_ban3394 [] = {
    0xc0, 0x4d, 
};
static const unsigned char big5_chars_ban3395 [] = {
    0xee, 0xf9, 0xee, 0xfb, 
};
static const unsigned char big5_chars_ban3396 [] = {
    0xc1, 0xf7, 0xee, 0xfa, 0xc1, 0xf8, 0xee, 0xf8, 0xee, 0xf7, 
};
static const unsigned char big5_chars_ban3397 [] = {
    0xf1, 0x77, 0xf1, 0x76, 0xc2, 0xfc, 0xf1, 0x78, 0xf3, 0x7e, 
    0xc3, 0xfa, 0xf3, 0x7d, 0xf3, 0x7a, 0xc3, 0xf9, 0xf3, 0x7b, 
    0xf3, 0x7c, 
};
static const unsigned char big5_chars_ban3398 [] = {
    0xf5, 0x48, 0xf5, 0x49, 0xc4, 0xc5, 
};
static const unsigned char big5_chars_ban3399 [] = {
    0xc5, 0x53, 
};
static const unsigned char big5_chars_ban3400 [] = {
    0xf6, 0x6e, 
};
static const unsigned char big5_chars_ban3401 [] = {
    0xc5, 0x51, 0xc5, 0x52, 0xf6, 0x6f, 
};
static const unsigned char big5_chars_ban3402 [] = {
    0xc5, 0xb4, 0xc5, 0xb5, 0xf7, 0x71, 
};
static const unsigned char big5_chars_ban3403 [] = {
    0xc6, 0x45, 0xf8, 0xcf, 0xc6, 0x47, 
};
static const unsigned char big5_chars_ban3404 [] = {
    0xf8, 0xce, 0xf8, 0xd0, 0xc6, 0x46, 0xf9, 0x57, 
};
static const unsigned char big5_chars_ban3405 [] = {
    0xf9, 0xad, 
};
static const unsigned char big5_chars_ban3406 [] = {
    0xab, 0x43, 
};
static const unsigned char big5_chars_ban3407 [] = {
    0xb9, 0x74, 
};
static const unsigned char big5_chars_ban3408 [] = {
    0xe4, 0xbe, 
};
static const unsigned char big5_chars_ban3409 [] = {
    0xe8, 0xb0, 0xc0, 0x51, 0xc0, 0x52, 
};
static const unsigned char big5_chars_ban3410 [] = {
    0xab, 0x44, 
};
static const unsigned char big5_chars_ban3411 [] = {
    0xbe, 0x61, 0xc3, 0xfb, 0xad, 0xb1, 
};
static const unsigned char big5_chars_ban3412 [] = {
    0xc0, 0x53, 
};
static const unsigned char big5_chars_ban3413 [] = {
    0xc5, 0xe2, 0xad, 0xb2, 0xd8, 0x4d, 
};
static const unsigned char big5_chars_ban3414 [] = {
    0xdc, 0xa9, 
};
static const unsigned char big5_chars_ban3415 [] = {
    0xdc, 0xab, 
};
static const unsigned char big5_chars_ban3416 [] = {
    0xdc, 0xaa, 
};
static const unsigned char big5_chars_ban3417 [] = {
    0xe0, 0xdd, 0xe0, 0xda, 0xb9, 0x75, 
};
static const unsigned char big5_chars_ban3418 [] = {
    0xb9, 0x76, 0xe0, 0xdb, 0xe0, 0xdc, 
};
static const unsigned char big5_chars_ban3419 [] = {
    0xe4, 0xc0, 0xe4, 0xc5, 0xbb, 0xde, 0xe4, 0xbf, 0xe4, 0xc1, 
    0xe4, 0xc8, 0xe4, 0xc3, 0xe4, 0xc7, 0xe4, 0xc4, 0xe4, 0xc2, 
    0xe4, 0xc6, 0xbb, 0xdf, 
};
static const unsigned char big5_chars_ban3420 [] = {
    0xe8, 0xb3, 
};
static const unsigned char big5_chars_ban3421 [] = {
    0xe8, 0xb1, 0xbe, 0x63, 
};
static const unsigned char big5_chars_ban3422 [] = {
    0xbe, 0x62, 0xe8, 0xb2, 0xbe, 0x64, 
};
static const unsigned char big5_chars_ban3423 [] = {
    0xec, 0x56, 
};
static const unsigned char big5_chars_ban3424 [] = {
    0xec, 0x55, 0xc0, 0x54, 0xec, 0x54, 0xee, 0xfc, 
};
static const unsigned char big5_chars_ban3425 [] = {
    0xee, 0xfe, 0xef, 0x41, 0xef, 0x40, 
};
static const unsigned char big5_chars_ban3426 [] = {
    0xc1, 0xf9, 0xee, 0xfd, 0xf1, 0xa1, 0xc2, 0xfd, 0xf1, 0x7d, 
    0xf1, 0xa2, 0xc2, 0xfe, 
};
static const unsigned char big5_chars_ban3427 [] = {
    0xf1, 0x7b, 
};
static const unsigned char big5_chars_ban3428 [] = {
    0xf1, 0x7e, 0xf1, 0x7c, 0xf1, 0x79, 0xc3, 0x40, 0xf1, 0x7a, 
};
static const unsigned char big5_chars_ban3429 [] = {
    0xf3, 0xa1, 
};
static const unsigned char big5_chars_ban3430 [] = {
    0xf3, 0xa3, 0xf3, 0xa2, 
};
static const unsigned char big5_chars_ban3431 [] = {
    0xf5, 0x4a, 
};
static const unsigned char big5_chars_ban3432 [] = {
    0xf5, 0x4b, 
};
static const unsigned char big5_chars_ban3433 [] = {
    0xf6, 0x70, 
};
static const unsigned char big5_chars_ban3434 [] = {
    0xc5, 0xb7, 
};
static const unsigned char big5_chars_ban3435 [] = {
    0xc5, 0xb6, 0xf8, 0x4f, 0xf8, 0x50, 0xc6, 0x48, 0xf8, 0xd1, 
};
static const unsigned char big5_chars_ban3436 [] = {
    0xc6, 0x69, 
};
static const unsigned char big5_chars_ban3437 [] = {
    0xad, 0xb3, 0xb6, 0xb4, 0xe4, 0xca, 0xe4, 0xc9, 0xe8, 0xb5, 
    0xe8, 0xb4, 
};
static const unsigned char big5_chars_ban3438 [] = {
    0xc1, 0xfa, 0xef, 0x43, 0xef, 0x42, 0xf1, 0xa5, 0xf1, 0xa3, 
    0xf1, 0xa6, 0xf1, 0xa4, 
};
static const unsigned char big5_chars_ban3439 [] = {
    0xc3, 0xfc, 0xf3, 0xa4, 0xf3, 0xa5, 0xf3, 0xa6, 
};
static const unsigned char big5_chars_ban3440 [] = {
    0xf6, 0x71, 
};
static const unsigned char big5_chars_ban3441 [] = {
    0xf7, 0x72, 
};
static const unsigned char big5_chars_ban3442 [] = {
    0xf8, 0xd2, 
};
static const unsigned char big5_chars_ban3443 [] = {
    0xad, 0xb4, 
};
static const unsigned char big5_chars_ban3444 [] = {
    0xec, 0x57, 0xef, 0x44, 
};
static const unsigned char big5_chars_ban3445 [] = {
    0xad, 0xb5, 
};
static const unsigned char big5_chars_ban3446 [] = {
    0xbb, 0xe0, 
};
static const unsigned char big5_chars_ban3447 [] = {
    0xec, 0x58, 0xc3, 0x41, 0xf1, 0xa7, 0xc3, 0xfd, 
};
static const unsigned char big5_chars_ban3448 [] = {
    0xf5, 0x4c, 0xf5, 0x4d, 0xc5, 0x54, 0xf8, 0x51, 0xad, 0xb6, 
    0xb3, 0xbb, 0xb3, 0xbc, 0xd8, 0x4e, 0xb6, 0xb5, 0xb6, 0xb6, 
    0xdc, 0xac, 0xb6, 0xb7, 
};
static const unsigned char big5_chars_ban3449 [] = {
    0xb9, 0x7a, 
};
static const unsigned char big5_chars_ban3450 [] = {
    0xb9, 0x7c, 0xe0, 0xdf, 0xe0, 0xe0, 0xe0, 0xde, 0xb9, 0x77, 
    0xb9, 0x78, 0xb9, 0x7b, 0xb9, 0x79, 
};
static const unsigned char big5_chars_ban3451 [] = {
    0xe4, 0xcb, 0xbb, 0xe1, 0xbb, 0xe2, 
};
static const unsigned char big5_chars_ban3452 [] = {
    0xe8, 0xbc, 0xbe, 0x67, 0xe8, 0xb7, 0xe8, 0xb6, 
};
static const unsigned char big5_chars_ban3453 [] = {
    0xe8, 0xbb, 0xbe, 0x65, 
};
static const unsigned char big5_chars_ban3454 [] = {
    0xc0, 0x5b, 
};
static const unsigned char big5_chars_ban3455 [] = {
    0xe8, 0xb8, 0xe8, 0xbd, 0xe8, 0xba, 0xe8, 0xb9, 
};
static const unsigned char big5_chars_ban3456 [] = {
    0xbe, 0x66, 
};
static const unsigned char big5_chars_ban3457 [] = {
    0xc0, 0x59, 
};
static const unsigned char big5_chars_ban3458 [] = {
    0xec, 0x5a, 0xc0, 0x55, 
};
static const unsigned char big5_chars_ban3459 [] = {
    0xec, 0x5b, 
};
static const unsigned char big5_chars_ban3460 [] = {
    0xec, 0x59, 
};
static const unsigned char big5_chars_ban3461 [] = {
    0xc0, 0x58, 0xc0, 0x56, 0xc0, 0x5a, 
};
static const unsigned char big5_chars_ban3462 [] = {
    0xc0, 0x57, 
};
static const unsigned char big5_chars_ban3463 [] = {
    0xef, 0x45, 
};
static const unsigned char big5_chars_ban3464 [] = {
    0xef, 0x4a, 0xef, 0x46, 0xef, 0x49, 0xc1, 0xfb, 
};
static const unsigned char big5_chars_ban3465 [] = {
    0xed, 0xd4, 0xef, 0x48, 0xef, 0x47, 
};
static const unsigned char big5_chars_ban3466 [] = {
    0xc3, 0x44, 0xc3, 0x42, 0xc3, 0x45, 0xc3, 0x43, 0xf1, 0xa8, 
    0xf1, 0xa9, 0xf1, 0xaa, 0xc3, 0x46, 
};
static const unsigned char big5_chars_ban3467 [] = {
    0xf3, 0xaa, 0xc4, 0x40, 0xf3, 0xa8, 
};
static const unsigned char big5_chars_ban3468 [] = {
    0xc4, 0x41, 0xf3, 0xa7, 0xf3, 0xa9, 0xc3, 0xfe, 0xf5, 0x51, 
    0xf5, 0x4e, 
};
static const unsigned char big5_chars_ban3469 [] = {
    0xf5, 0x4f, 0xf5, 0x50, 0xf6, 0x72, 0xc5, 0x56, 
};
static const unsigned char big5_chars_ban3470 [] = {
    0xc5, 0x55, 
};
static const unsigned char big5_chars_ban3471 [] = {
    0xf7, 0x74, 0xf7, 0x73, 0xc5, 0xb8, 
};
static const unsigned char big5_chars_ban3472 [] = {
    0xc5, 0xe3, 0xc6, 0x49, 0xc6, 0x60, 0xf9, 0x58, 0xf9, 0xae, 
    0xf9, 0xaf, 
};
static const unsigned char big5_chars_ban3473 [] = {
    0xad, 0xb7, 0xdc, 0xad, 
};
static const unsigned char big5_chars_ban3474 [] = {
    0xe0, 0xe1, 0xe4, 0xcc, 0xe4, 0xcd, 0xbb, 0xe3, 
};
static const unsigned char big5_chars_ban3475 [] = {
    0xbb, 0xe4, 0xe8, 0xbe, 0xbe, 0x68, 
};
static const unsigned char big5_chars_ban3476 [] = {
    0xc1, 0xfc, 
};
static const unsigned char big5_chars_ban3477 [] = {
    0xf1, 0xab, 
};
static const unsigned char big5_chars_ban3478 [] = {
    0xc3, 0x47, 0xf3, 0xad, 0xc4, 0x42, 0xf3, 0xac, 0xf3, 0xae, 
    0xf3, 0xab, 0xf6, 0x75, 0xf5, 0x52, 0xf5, 0x53, 
};
static const unsigned char big5_chars_ban3479 [] = {
    0xc4, 0xc6, 
};
static const unsigned char big5_chars_ban3480 [] = {
    0xf6, 0x74, 
};
static const unsigned char big5_chars_ban3481 [] = {
    0xf6, 0x73, 
};
static const unsigned char big5_chars_ban3482 [] = {
    0xf7, 0x75, 0xf9, 0xb0, 
};
static const unsigned char big5_chars_ban3483 [] = {
    0xad, 0xb8, 
};
static const unsigned char big5_chars_ban3484 [] = {
    0xad, 0xb9, 
};
static const unsigned char big5_chars_ban3485 [] = {
    0xb0, 0xa7, 0xd4, 0x48, 
};
static const unsigned char big5_chars_ban3486 [] = {
    0xd8, 0x4f, 
};
static const unsigned char big5_chars_ban3487 [] = {
    0xb6, 0xb8, 
};
static const unsigned char big5_chars_ban3488 [] = {
    0xb6, 0xbb, 0xb6, 0xb9, 0xdc, 0xae, 
};
static const unsigned char big5_chars_ban3489 [] = {
    0xb6, 0xbd, 
};
static const unsigned char big5_chars_ban3490 [] = {
    0xb6, 0xba, 
};
static const unsigned char big5_chars_ban3491 [] = {
    0xb6, 0xbc, 
};
static const unsigned char big5_chars_ban3492 [] = {
    0xb9, 0x7e, 
};
static const unsigned char big5_chars_ban3493 [] = {
    0xe0, 0xe2, 
};
static const unsigned char big5_chars_ban3494 [] = {
    0xe0, 0xe3, 0xe8, 0xc0, 
};
static const unsigned char big5_chars_ban3495 [] = {
    0xb9, 0x7d, 0xb9, 0xa1, 0xb9, 0xa2, 
};
static const unsigned char big5_chars_ban3496 [] = {
    0xe4, 0xcf, 
};
static const unsigned char big5_chars_ban3497 [] = {
    0xe4, 0xce, 0xbb, 0xe5, 
};
static const unsigned char big5_chars_ban3498 [] = {
    0xbb, 0xe6, 
};
static const unsigned char big5_chars_ban3499 [] = {
    0xe4, 0xd0, 0xe8, 0xbf, 0xbb, 0xe8, 0xbe, 0x69, 
};
static const unsigned char big5_chars_ban3500 [] = {
    0xbb, 0xe7, 
};
static const unsigned char big5_chars_ban3501 [] = {
    0xc0, 0x5c, 0xe8, 0xc1, 0xbe, 0x6b, 0xbe, 0x6a, 0xe8, 0xc2, 
    0xe8, 0xc5, 0xe8, 0xc3, 0xe8, 0xc4, 0xbe, 0x6c, 
};
static const unsigned char big5_chars_ban3502 [] = {
    0xc0, 0x61, 0xc0, 0x5f, 
};
static const unsigned char big5_chars_ban3503 [] = {
    0xc0, 0x5e, 0xec, 0x5d, 
};
static const unsigned char big5_chars_ban3504 [] = {
    0xc0, 0x60, 
};
static const unsigned char big5_chars_ban3505 [] = {
    0xec, 0x5c, 0xef, 0x4b, 
};
static const unsigned char big5_chars_ban3506 [] = {
    0xec, 0x5e, 0xc0, 0x5d, 0xec, 0x5f, 0xef, 0x4e, 0xef, 0x4c, 
    0xef, 0x4d, 0xef, 0x52, 0xc3, 0x4b, 0xef, 0x51, 0xef, 0x54, 
    0xef, 0x53, 0xef, 0x50, 0xef, 0x4f, 
};
static const unsigned char big5_chars_ban3507 [] = {
    0xc1, 0xfd, 
};
static const unsigned char big5_chars_ban3508 [] = {
    0xf1, 0xae, 
};
static const unsigned char big5_chars_ban3509 [] = {
    0xf1, 0xad, 0xc3, 0x4a, 0xc3, 0x48, 0xc3, 0x49, 
};
static const unsigned char big5_chars_ban3510 [] = {
    0xf1, 0xac, 
};
static const unsigned char big5_chars_ban3511 [] = {
    0xf3, 0xb1, 
};
static const unsigned char big5_chars_ban3512 [] = {
    0xc4, 0x43, 
};
static const unsigned char big5_chars_ban3513 [] = {
    0xf3, 0xb0, 0xf3, 0xaf, 0xc4, 0x44, 
};
static const unsigned char big5_chars_ban3514 [] = {
    0xf5, 0x58, 0xf5, 0x57, 
};
static const unsigned char big5_chars_ban3515 [] = {
    0xf5, 0x55, 
};
static const unsigned char big5_chars_ban3516 [] = {
    0xf5, 0x54, 0xc4, 0xc8, 0xc4, 0xc7, 0xf5, 0x59, 0xf7, 0x76, 
    0xc5, 0xb9, 0xf6, 0x77, 0xc5, 0x57, 0xf6, 0x76, 0xf5, 0x56, 
};
static const unsigned char big5_chars_ban3517 [] = {
    0xf7, 0x77, 0xc5, 0xe4, 
};
static const unsigned char big5_chars_ban3518 [] = {
    0xc6, 0x61, 0xf9, 0x59, 
};
static const unsigned char big5_chars_ban3519 [] = {
    0xf9, 0xb1, 
};
static const unsigned char big5_chars_ban3520 [] = {
    0xad, 0xba, 0xd8, 0x50, 0xef, 0x55, 0xad, 0xbb, 
};
static const unsigned char big5_chars_ban3521 [] = {
    0xe4, 0xd2, 0xe4, 0xd1, 0xec, 0x60, 
};
static const unsigned char big5_chars_ban3522 [] = {
    0xef, 0x57, 
};
static const unsigned char big5_chars_ban3523 [] = {
    0xef, 0x56, 
};
static const unsigned char big5_chars_ban3524 [] = {
    0xc3, 0x4c, 0xf3, 0xb2, 0xf3, 0xb3, 0xc4, 0xc9, 
};
static const unsigned char big5_chars_ban3525 [] = {
    0xf9, 0xb2, 0xb0, 0xa8, 0xb6, 0xbf, 0xb6, 0xbe, 0xe0, 0xe4, 
    0xe0, 0xe6, 0xb9, 0xa4, 0xe0, 0xe5, 0xb9, 0xa3, 0xb9, 0xa5, 
    0xe0, 0xe7, 
};
static const unsigned char big5_chars_ban3526 [] = {
    0xe4, 0xd4, 0xe4, 0xd6, 0xe4, 0xd5, 
};
static const unsigned char big5_chars_ban3527 [] = {
    0xe4, 0xd8, 
};
static const unsigned char big5_chars_ban3528 [] = {
    0xbb, 0xe9, 0xe4, 0xd7, 0xe4, 0xd3, 
};
static const unsigned char big5_chars_ban3529 [] = {
    0xe4, 0xd9, 
};
static const unsigned char big5_chars_ban3530 [] = {
    0xe8, 0xcc, 
};
static const unsigned char big5_chars_ban3531 [] = {
    0xe8, 0xcf, 0xe8, 0xd1, 0xe8, 0xc7, 0xe8, 0xcb, 0xe8, 0xc8, 
    0xbe, 0x6e, 0xbe, 0x71, 0xbe, 0x73, 0xe8, 0xc9, 0xe8, 0xca, 
    0xbe, 0x72, 0xe8, 0xcd, 0xe8, 0xd0, 0xe8, 0xce, 0xbe, 0x74, 
};
static const unsigned char big5_chars_ban3532 [] = {
    0xbe, 0x70, 0xe8, 0xc6, 0xbe, 0x6d, 
};
static const unsigned char big5_chars_ban3533 [] = {
    0xbe, 0x6f, 
};
static const unsigned char big5_chars_ban3534 [] = {
    0xc0, 0x63, 0xec, 0x66, 0xec, 0x64, 0xec, 0x63, 
};
static const unsigned char big5_chars_ban3535 [] = {
    0xec, 0x69, 
};
static const unsigned char big5_chars_ban3536 [] = {
    0xec, 0x68, 0xec, 0x67, 
};
static const unsigned char big5_chars_ban3537 [] = {
    0xec, 0x62, 0xc0, 0x62, 0xec, 0x61, 
};
static const unsigned char big5_chars_ban3538 [] = {
    0xec, 0x65, 0xc0, 0x64, 
};
static const unsigned char big5_chars_ban3539 [] = {
    0xef, 0x5a, 
};
static const unsigned char big5_chars_ban3540 [] = {
    0xef, 0x5e, 0xef, 0x5b, 0xef, 0x5d, 0xef, 0x5c, 0xef, 0x59, 
    0xef, 0x5f, 0xef, 0x62, 0xef, 0x60, 0xef, 0x61, 0xc2, 0x40, 
};
static const unsigned char big5_chars_ban3541 [] = {
    0xc1, 0xfe, 0xef, 0x58, 0xef, 0x63, 0xf1, 0xb3, 0xf1, 0xb6, 
    0xf1, 0xb8, 0xf1, 0xb7, 
};
static const unsigned char big5_chars_ban3542 [] = {
    0xf1, 0xb1, 0xf1, 0xb5, 0xf1, 0xb0, 
};
static const unsigned char big5_chars_ban3543 [] = {
    0xf1, 0xb2, 0xc3, 0x4d, 0xf1, 0xaf, 
};
static const unsigned char big5_chars_ban3544 [] = {
    0xf1, 0xb4, 
};
static const unsigned char big5_chars_ban3545 [] = {
    0xf3, 0xc0, 0xf3, 0xb5, 0xc4, 0x45, 
};
static const unsigned char big5_chars_ban3546 [] = {
    0xc4, 0x46, 0xf3, 0xb4, 0xf3, 0xb9, 0xf3, 0xbf, 0xf3, 0xb7, 
    0xf3, 0xbe, 
};
static const unsigned char big5_chars_ban3547 [] = {
    0xf3, 0xbb, 
};
static const unsigned char big5_chars_ban3548 [] = {
    0xf3, 0xba, 0xf3, 0xbd, 0xf3, 0xb8, 0xf3, 0xb6, 
};
static const unsigned char big5_chars_ban3549 [] = {
    0xf3, 0xbc, 
};
static const unsigned char big5_chars_ban3550 [] = {
    0xf5, 0x60, 0xf5, 0x5e, 0xc4, 0xca, 0xf5, 0x5d, 0xf5, 0x63, 
    0xf5, 0x61, 
};
static const unsigned char big5_chars_ban3551 [] = {
    0xc4, 0xcb, 0xf5, 0x5c, 0xf5, 0x5a, 
};
static const unsigned char big5_chars_ban3552 [] = {
    0xf5, 0x5b, 0xc4, 0xcd, 0xf5, 0x5f, 0xc4, 0xcc, 0xf5, 0x62, 
    0xf6, 0x78, 0xf6, 0x7e, 
};
static const unsigned char big5_chars_ban3553 [] = {
    0xf6, 0x79, 0xc5, 0x5b, 0xf6, 0xa1, 0xc5, 0x5a, 0xf6, 0x7d, 
    0xf6, 0x7c, 0xc5, 0x59, 0xf6, 0x7b, 0xc5, 0x58, 0xf6, 0x7a, 
};
static const unsigned char big5_chars_ban3554 [] = {
    0xf7, 0x7d, 0xf7, 0xa1, 0xf7, 0x7e, 
};
static const unsigned char big5_chars_ban3555 [] = {
    0xf7, 0x7b, 0xc5, 0xbb, 0xf7, 0x78, 0xf7, 0x7c, 0xf7, 0xa3, 
};
static const unsigned char big5_chars_ban3556 [] = {
    0xf7, 0xa2, 0xf7, 0x79, 0xf7, 0x7a, 0xc5, 0xba, 0xf8, 0x52, 
    0xc5, 0xe7, 
};
static const unsigned char big5_chars_ban3557 [] = {
    0xf8, 0x53, 0xc5, 0xe5, 0xc5, 0xe6, 
};
static const unsigned char big5_chars_ban3558 [] = {
    0xf8, 0xd3, 0xc6, 0x4a, 0xf9, 0x76, 
};
static const unsigned char big5_chars_ban3559 [] = {
    0xc6, 0x6a, 
};
static const unsigned char big5_chars_ban3560 [] = {
    0xf9, 0xb3, 0xc6, 0x6b, 0xf9, 0xb4, 0xf9, 0xb5, 0xf9, 0xc3, 
    0xf9, 0xc2, 0xc6, 0x7a, 0xf9, 0xcd, 
};
static const unsigned char big5_chars_ban3561 [] = {
    0xb0, 0xa9, 
};
static const unsigned char big5_chars_ban3562 [] = {
    0xe0, 0xe9, 
};
static const unsigned char big5_chars_ban3563 [] = {
    0xe0, 0xe8, 
};
static const unsigned char big5_chars_ban3564 [] = {
    0xbb, 0xea, 0xbb, 0xeb, 0xe4, 0xda, 
};
static const unsigned char big5_chars_ban3565 [] = {
    0xe8, 0xd2, 0xec, 0x6c, 
};
static const unsigned char big5_chars_ban3566 [] = {
    0xbe, 0x75, 0xc0, 0x65, 0xec, 0x6a, 
};
static const unsigned char big5_chars_ban3567 [] = {
    0xec, 0x6d, 0xc0, 0x66, 
};
static const unsigned char big5_chars_ban3568 [] = {
    0xef, 0x64, 0xec, 0x6b, 0xf1, 0xb9, 0xc3, 0x4e, 0xf3, 0xc1, 
};
static const unsigned char big5_chars_ban3569 [] = {
    0xf5, 0x66, 0xf5, 0x64, 
};
static const unsigned char big5_chars_ban3570 [] = {
    0xf5, 0x65, 
};
static const unsigned char big5_chars_ban3571 [] = {
    0xf6, 0xa2, 
};
static const unsigned char big5_chars_ban3572 [] = {
    0xc5, 0x5c, 0xf7, 0xa4, 0xc5, 0xea, 0xc5, 0xbc, 0xc5, 0xe8, 
    0xc5, 0xe9, 0xf8, 0xd4, 0xc6, 0x62, 
};
static const unsigned char big5_chars_ban3573 [] = {
    0xb0, 0xaa, 
};
static const unsigned char big5_chars_ban3574 [] = {
    0xf1, 0xba, 
};
static const unsigned char big5_chars_ban3575 [] = {
    0xd4, 0x49, 
};
static const unsigned char big5_chars_ban3576 [] = {
    0xb9, 0xa6, 
};
static const unsigned char big5_chars_ban3577 [] = {
    0xe4, 0xdb, 
};
static const unsigned char big5_chars_ban3578 [] = {
    0xbb, 0xec, 0xe4, 0xdc, 
};
static const unsigned char big5_chars_ban3579 [] = {
    0xe8, 0xd4, 0xe8, 0xd3, 0xc0, 0x68, 0xbe, 0x76, 0xbe, 0x77, 
};
static const unsigned char big5_chars_ban3580 [] = {
    0xe8, 0xd7, 0xe8, 0xd6, 0xe8, 0xd5, 
};
static const unsigned char big5_chars_ban3581 [] = {
    0xec, 0x6e, 0xec, 0x71, 
};
static const unsigned char big5_chars_ban3582 [] = {
    0xec, 0x70, 0xec, 0x6f, 0xc0, 0x67, 0xef, 0x68, 0xef, 0x66, 
    0xef, 0x65, 
};
static const unsigned char big5_chars_ban3583 [] = {
    0xef, 0x67, 
};
static const unsigned char big5_chars_ban3584 [] = {
    0xc3, 0x4f, 0xf1, 0xbc, 0xf1, 0xbd, 0xc3, 0x50, 
};
static const unsigned char big5_chars_ban3585 [] = {
    0xf1, 0xbb, 
};
static const unsigned char big5_chars_ban3586 [] = {
    0xf3, 0xc3, 0xf3, 0xc2, 0xf3, 0xc5, 0xc4, 0x47, 0xf3, 0xc4, 
};
static const unsigned char big5_chars_ban3587 [] = {
    0xf5, 0x67, 0xf5, 0x69, 0xf5, 0x68, 
};
static const unsigned char big5_chars_ban3588 [] = {
    0xf6, 0xa3, 0xf6, 0xa6, 0xf6, 0xa4, 0xf6, 0xa5, 0xf7, 0xa5, 
    0xc5, 0xbd, 
};
static const unsigned char big5_chars_ban3589 [] = {
    0xf8, 0x54, 0xf8, 0x55, 0xf8, 0x56, 
};
static const unsigned char big5_chars_ban3590 [] = {
    0xc6, 0x4b, 0xc6, 0x63, 0xf9, 0xb6, 0xb0, 0xab, 
};
static const unsigned char big5_chars_ban3591 [] = {
    0xbe, 0x78, 0xc0, 0x69, 0xf1, 0xbe, 
};
static const unsigned char big5_chars_ban3592 [] = {
    0xf7, 0xa6, 
};
static const unsigned char big5_chars_ban3593 [] = {
    0xf9, 0xc4, 0xd4, 0x4a, 
};
static const unsigned char big5_chars_ban3594 [] = {
    0xc6, 0x7b, 0xb0, 0xac, 0xec, 0x72, 
};
static const unsigned char big5_chars_ban3595 [] = {
    0xf1, 0xbf, 
};
static const unsigned char big5_chars_ban3596 [] = {
    0xf3, 0xc6, 
};
static const unsigned char big5_chars_ban3597 [] = {
    0xf6, 0xa7, 0xf7, 0xa7, 0xb0, 0xad, 
};
static const unsigned char big5_chars_ban3598 [] = {
    0xe4, 0xdd, 0xe4, 0xde, 
};
static const unsigned char big5_chars_ban3599 [] = {
    0xbb, 0xed, 0xbb, 0xee, 0xe8, 0xd9, 0xbe, 0x7a, 0xbe, 0x79, 
    0xe8, 0xd8, 
};
static const unsigned char big5_chars_ban3600 [] = {
    0xef, 0x69, 
};
static const unsigned char big5_chars_ban3601 [] = {
    0xf1, 0xc0, 0xf1, 0xc2, 0xf1, 0xc1, 0xc3, 0x53, 0xc3, 0x52, 
    0xc3, 0x51, 
};
static const unsigned char big5_chars_ban3602 [] = {
    0xc5, 0x5e, 0xf6, 0xa8, 
};
static const unsigned char big5_chars_ban3603 [] = {
    0xc5, 0x5d, 0xf7, 0xa9, 0xf7, 0xa8, 
};
static const unsigned char big5_chars_ban3604 [] = {
    0xc6, 0x4c, 0xf8, 0xd5, 0xb3, 0xbd, 0xe0, 0xea, 
};
static const unsigned char big5_chars_ban3605 [] = {
    0xe4, 0xe1, 0xe4, 0xdf, 0xe4, 0xe0, 
};
static const unsigned char big5_chars_ban3606 [] = {
    0xe8, 0xe2, 
};
static const unsigned char big5_chars_ban3607 [] = {
    0xe8, 0xdd, 0xe8, 0xda, 0xe8, 0xe1, 
};
static const unsigned char big5_chars_ban3608 [] = {
    0xe8, 0xe3, 
};
static const unsigned char big5_chars_ban3609 [] = {
    0xbe, 0x7c, 0xe8, 0xe0, 0xe8, 0xdc, 
};
static const unsigned char big5_chars_ban3610 [] = {
    0xe8, 0xdb, 0xe8, 0xdf, 0xe8, 0xde, 0xbe, 0x7b, 
};
static const unsigned char big5_chars_ban3611 [] = {
    0xec, 0x7d, 0xec, 0x78, 0xec, 0x76, 0xec, 0xa1, 0xec, 0x77, 
};
static const unsigned char big5_chars_ban3612 [] = {
    0xec, 0x73, 
};
static const unsigned char big5_chars_ban3613 [] = {
    0xec, 0x79, 
};
static const unsigned char big5_chars_ban3614 [] = {
    0xec, 0x74, 0xef, 0x72, 0xec, 0x75, 0xec, 0xa2, 
};
static const unsigned char big5_chars_ban3615 [] = {
    0xec, 0x7c, 0xc0, 0x6a, 0xec, 0x7b, 0xec, 0x7a, 
};
static const unsigned char big5_chars_ban3616 [] = {
    0xec, 0x7e, 
};
static const unsigned char big5_chars_ban3617 [] = {
    0xef, 0x6a, 0xef, 0x6d, 
};
static const unsigned char big5_chars_ban3618 [] = {
    0xef, 0x6c, 
};
static const unsigned char big5_chars_ban3619 [] = {
    0xef, 0x74, 0xef, 0x6f, 0xef, 0x73, 
};
static const unsigned char big5_chars_ban3620 [] = {
    0xef, 0x71, 0xef, 0x70, 0xef, 0x6e, 
};
static const unsigned char big5_chars_ban3621 [] = {
    0xef, 0x6b, 
};
static const unsigned char big5_chars_ban3622 [] = {
    0xc2, 0x43, 0xc2, 0x42, 
};
static const unsigned char big5_chars_ban3623 [] = {
    0xc2, 0x44, 0xc2, 0x41, 0xef, 0x75, 
};
static const unsigned char big5_chars_ban3624 [] = {
    0xf1, 0xc8, 0xf1, 0xcb, 
};
static const unsigned char big5_chars_ban3625 [] = {
    0xf1, 0xc9, 0xf1, 0xcd, 
};
static const unsigned char big5_chars_ban3626 [] = {
    0xf1, 0xce, 
};
static const unsigned char big5_chars_ban3627 [] = {
    0xf1, 0xc6, 0xc3, 0x58, 0xf1, 0xc7, 
};
static const unsigned char big5_chars_ban3628 [] = {
    0xf1, 0xc5, 0xf1, 0xcc, 
};
static const unsigned char big5_chars_ban3629 [] = {
    0xf1, 0xc4, 0xf1, 0xc3, 0xc3, 0x57, 0xc3, 0x55, 0xc3, 0x54, 
};
static const unsigned char big5_chars_ban3630 [] = {
    0xf1, 0xca, 0xf3, 0xcf, 0xf3, 0xd5, 0xc4, 0x4a, 0xf3, 0xd0, 
};
static const unsigned char big5_chars_ban3631 [] = {
    0xf3, 0xd3, 0xf3, 0xd7, 0xc4, 0x4b, 0xf3, 0xd2, 
};
static const unsigned char big5_chars_ban3632 [] = {
    0xf3, 0xca, 
};
static const unsigned char big5_chars_ban3633 [] = {
    0xf3, 0xc9, 0xf3, 0xd6, 0xf3, 0xcd, 
};
static const unsigned char big5_chars_ban3634 [] = {
    0xf3, 0xcb, 0xf3, 0xd4, 0xf3, 0xcc, 0xc4, 0x49, 0xc4, 0x48, 
};
static const unsigned char big5_chars_ban3635 [] = {
    0xf3, 0xc7, 0xf3, 0xc8, 0xf3, 0xd1, 
};
static const unsigned char big5_chars_ban3636 [] = {
    0xf3, 0xce, 
};
static const unsigned char big5_chars_ban3637 [] = {
    0xf5, 0x6c, 0xf5, 0x6f, 
};
static const unsigned char big5_chars_ban3638 [] = {
    0xc3, 0x56, 
};
static const unsigned char big5_chars_ban3639 [] = {
    0xf5, 0x6d, 0xf5, 0x73, 0xf5, 0x71, 0xf5, 0x6b, 0xf5, 0x76, 
};
static const unsigned char big5_chars_ban3640 [] = {
    0xf5, 0x6a, 
};
static const unsigned char big5_chars_ban3641 [] = {
    0xc4, 0xcf, 0xf5, 0x72, 
};
static const unsigned char big5_chars_ban3642 [] = {
    0xf5, 0x6e, 0xc4, 0xce, 0xf5, 0x75, 
};
static const unsigned char big5_chars_ban3643 [] = {
    0xf5, 0x74, 
};
static const unsigned char big5_chars_ban3644 [] = {
    0xf6, 0xab, 0xf6, 0xaa, 
};
static const unsigned char big5_chars_ban3645 [] = {
    0xf6, 0xb1, 
};
static const unsigned char big5_chars_ban3646 [] = {
    0xf6, 0xad, 0xf6, 0xb0, 0xc5, 0x60, 
};
static const unsigned char big5_chars_ban3647 [] = {
    0xf6, 0xae, 0xf6, 0xaf, 
};
static const unsigned char big5_chars_ban3648 [] = {
    0xf6, 0xa9, 0xf6, 0xac, 0xc5, 0x5f, 
};
static const unsigned char big5_chars_ban3649 [] = {
    0xc5, 0xbf, 0xf7, 0xb4, 0xf7, 0xaf, 0xf7, 0xb3, 
};
static const unsigned char big5_chars_ban3650 [] = {
    0xf7, 0xb6, 0xf7, 0xb2, 
};
static const unsigned char big5_chars_ban3651 [] = {
    0xf7, 0xae, 
};
static const unsigned char big5_chars_ban3652 [] = {
    0xc5, 0xc1, 0xf7, 0xb1, 0xf7, 0xb5, 0xc5, 0xc0, 0xf7, 0xac, 
    0xf5, 0x70, 0xf7, 0xb0, 
};
static const unsigned char big5_chars_ban3653 [] = {
    0xf7, 0xad, 
};
static const unsigned char big5_chars_ban3654 [] = {
    0xf7, 0xaa, 
};
static const unsigned char big5_chars_ban3655 [] = {
    0xf7, 0xab, 0xc5, 0xbe, 0xf8, 0x5a, 0xf8, 0x5c, 0xf8, 0x5f, 
    0xf8, 0x5b, 0xf8, 0x60, 
};
static const unsigned char big5_chars_ban3656 [] = {
    0xf8, 0x59, 
};
static const unsigned char big5_chars_ban3657 [] = {
    0xf8, 0x57, 
};
static const unsigned char big5_chars_ban3658 [] = {
    0xc5, 0xeb, 0xf8, 0x5d, 0xc5, 0xed, 0xc5, 0xec, 0xf8, 0x58, 
    0xf8, 0x5e, 
};
static const unsigned char big5_chars_ban3659 [] = {
    0xf8, 0xda, 0xc6, 0x4d, 0xf8, 0xdb, 
};
static const unsigned char big5_chars_ban3660 [] = {
    0xf8, 0xd9, 0xf8, 0xd6, 
};
static const unsigned char big5_chars_ban3661 [] = {
    0xf8, 0xd8, 0xf8, 0xd7, 0xf9, 0x5a, 
};
static const unsigned char big5_chars_ban3662 [] = {
    0xf9, 0x5c, 0xf9, 0x5b, 
};
static const unsigned char big5_chars_ban3663 [] = {
    0xf9, 0x79, 
};
static const unsigned char big5_chars_ban3664 [] = {
    0xf9, 0x78, 0xf9, 0x77, 0xf9, 0x7a, 
};
static const unsigned char big5_chars_ban3665 [] = {
    0xc6, 0x73, 0xc6, 0x74, 0xf9, 0xca, 0xf9, 0xce, 
};
static const unsigned char big5_chars_ban3666 [] = {
    0xb3, 0xbe, 0xdc, 0xaf, 0xe0, 0xed, 
};
static const unsigned char big5_chars_ban3667 [] = {
    0xb9, 0xa7, 0xe0, 0xeb, 
};
static const unsigned char big5_chars_ban3668 [] = {
    0xe0, 0xec, 
};
static const unsigned char big5_chars_ban3669 [] = {
    0xe4, 0xe2, 0xe4, 0xe3, 0xbb, 0xf1, 0xbb, 0xef, 0xe4, 0xe4, 
    0xbb, 0xf0, 0xe8, 0xe8, 
};
static const unsigned char big5_chars_ban3670 [] = {
    0xe8, 0xeb, 0xe8, 0xe5, 0xe8, 0xec, 0xe8, 0xe4, 0xe8, 0xe6, 
};
static const unsigned char big5_chars_ban3671 [] = {
    0xe8, 0xe7, 0xe8, 0xea, 
};
static const unsigned char big5_chars_ban3672 [] = {
    0xbe, 0xa1, 0xe8, 0xef, 0xe8, 0xee, 0xbe, 0x7d, 0xe8, 0xe9, 
    0xe8, 0xed, 0xbe, 0x7e, 
};
static const unsigned char big5_chars_ban3673 [] = {
    0xec, 0xac, 
};
static const unsigned char big5_chars_ban3674 [] = {
    0xc0, 0x6f, 
};
static const unsigned char big5_chars_ban3675 [] = {
    0xec, 0xa7, 0xc0, 0x6b, 
};
static const unsigned char big5_chars_ban3676 [] = {
    0xec, 0xa4, 0xec, 0xaa, 0xec, 0xad, 
};
static const unsigned char big5_chars_ban3677 [] = {
    0xc0, 0x70, 
};
static const unsigned char big5_chars_ban3678 [] = {
    0xec, 0xa9, 0xec, 0xa6, 0xec, 0xae, 0xec, 0xa5, 
};
static const unsigned char big5_chars_ban3679 [] = {
    0xec, 0xab, 0xc0, 0x6c, 
};
static const unsigned char big5_chars_ban3680 [] = {
    0xec, 0xa3, 0xc0, 0x6d, 
};
static const unsigned char big5_chars_ban3681 [] = {
    0xc0, 0x6e, 0xec, 0xa8, 
};
static const unsigned char big5_chars_ban3682 [] = {
    0xef, 0xa9, 0xef, 0x7a, 0xef, 0x7b, 0xef, 0x7e, 0xef, 0x7c, 
};
static const unsigned char big5_chars_ban3683 [] = {
    0xef, 0x76, 
};
static const unsigned char big5_chars_ban3684 [] = {
    0xef, 0x79, 0xef, 0xa5, 0xef, 0x7d, 
};
static const unsigned char big5_chars_ban3685 [] = {
    0xc2, 0x45, 
};
static const unsigned char big5_chars_ban3686 [] = {
    0xef, 0xa7, 0xef, 0xa4, 0xc2, 0x46, 0xef, 0xa6, 0xef, 0x77, 
    0xef, 0xa2, 0xef, 0xa3, 
};
static const unsigned char big5_chars_ban3687 [] = {
    0xef, 0xa1, 
};
static const unsigned char big5_chars_ban3688 [] = {
    0xf1, 0xd2, 0xf1, 0xd4, 0xf1, 0xd7, 
};
static const unsigned char big5_chars_ban3689 [] = {
    0xf1, 0xd1, 
};
static const unsigned char big5_chars_ban3690 [] = {
    0xc3, 0x59, 0xf1, 0xd9, 0xf1, 0xd0, 0xf1, 0xda, 
};
static const unsigned char big5_chars_ban3691 [] = {
    0xf1, 0xd6, 0xf1, 0xd8, 0xf1, 0xdc, 0xf1, 0xd5, 0xf1, 0xdd, 
    0xf1, 0xd3, 0xf1, 0xcf, 0xc3, 0x5a, 
};
static const unsigned char big5_chars_ban3692 [] = {
    0xf1, 0xdb, 0xc3, 0x5b, 0xc4, 0x4d, 
};
static const unsigned char big5_chars_ban3693 [] = {
    0xef, 0x78, 0xf3, 0xf1, 0xf3, 0xe8, 0xc4, 0x4f, 0xf3, 0xe4, 
    0xc4, 0x50, 
};
static const unsigned char big5_chars_ban3694 [] = {
    0xf3, 0xed, 0xf3, 0xe7, 0xf3, 0xdd, 0xc4, 0x4e, 0xf3, 0xea, 
    0xf3, 0xe5, 0xf3, 0xe6, 
};
static const unsigned char big5_chars_ban3695 [] = {
    0xf3, 0xd8, 0xf3, 0xdf, 0xf3, 0xee, 
};
static const unsigned char big5_chars_ban3696 [] = {
    0xf3, 0xeb, 
};
static const unsigned char big5_chars_ban3697 [] = {
    0xf3, 0xe3, 
};
static const unsigned char big5_chars_ban3698 [] = {
    0xf3, 0xef, 0xf3, 0xde, 0xf3, 0xd9, 0xf3, 0xec, 
};
static const unsigned char big5_chars_ban3699 [] = {
    0xf3, 0xdb, 0xf3, 0xe9, 0xf3, 0xe0, 0xf3, 0xf0, 0xf3, 0xdc, 
    0xc4, 0x4c, 0xf3, 0xda, 0xf3, 0xe1, 0xf3, 0xe2, 
};
static const unsigned char big5_chars_ban3700 [] = {
    0xf5, 0x7d, 
};
static const unsigned char big5_chars_ban3701 [] = {
    0xf5, 0x7b, 
};
static const unsigned char big5_chars_ban3702 [] = {
    0xf5, 0xa2, 
};
static const unsigned char big5_chars_ban3703 [] = {
    0xf5, 0xae, 0xf5, 0xa5, 0xf5, 0x7c, 0xf5, 0x78, 0xf5, 0xa7, 
    0xf5, 0x7e, 0xf5, 0xa3, 0xf5, 0x7a, 0xf5, 0xaa, 0xf5, 0x77, 
    0xf5, 0xa1, 0xf5, 0xa6, 0xf5, 0xa8, 0xf5, 0xab, 0xf5, 0x79, 
};
static const unsigned char big5_chars_ban3704 [] = {
    0xf5, 0xaf, 0xf5, 0xb0, 0xf5, 0xa9, 0xf5, 0xad, 0xf5, 0xa4, 
};
static const unsigned char big5_chars_ban3705 [] = {
    0xf6, 0xc1, 0xf6, 0xc4, 
};
static const unsigned char big5_chars_ban3706 [] = {
    0xc5, 0x61, 
};
static const unsigned char big5_chars_ban3707 [] = {
    0xf6, 0xc3, 0xf6, 0xc8, 0xf6, 0xc6, 0xc5, 0x62, 0xf6, 0xbd, 
    0xf6, 0xb3, 0xf6, 0xb2, 0xc5, 0x64, 0xf6, 0xbf, 0xf6, 0xc0, 
    0xf6, 0xbc, 0xf6, 0xb4, 
};
static const unsigned char big5_chars_ban3708 [] = {
    0xf6, 0xb9, 0xf5, 0xac, 
};
static const unsigned char big5_chars_ban3709 [] = {
    0xf6, 0xb5, 0xc5, 0x63, 0xf6, 0xbb, 
};
static const unsigned char big5_chars_ban3710 [] = {
    0xf6, 0xba, 
};
static const unsigned char big5_chars_ban3711 [] = {
    0xf6, 0xb6, 0xf6, 0xc2, 
};
static const unsigned char big5_chars_ban3712 [] = {
    0xf6, 0xb7, 0xf7, 0xbb, 0xf6, 0xc5, 0xf6, 0xc7, 0xf6, 0xbe, 
    0xf6, 0xb8, 0xf7, 0xbc, 0xf7, 0xbe, 0xf7, 0xb8, 0xc5, 0xc2, 
};
static const unsigned char big5_chars_ban3713 [] = {
    0xf7, 0xc5, 0xf7, 0xc3, 0xc5, 0xc3, 0xf7, 0xc2, 0xf7, 0xc1, 
    0xf7, 0xba, 0xf7, 0xb7, 0xf7, 0xbd, 0xf7, 0xc6, 0xf7, 0xb9, 
    0xf7, 0xbf, 
};
static const unsigned char big5_chars_ban3714 [] = {
    0xf8, 0x69, 0xf8, 0x6e, 0xf8, 0x64, 0xf8, 0x67, 0xc5, 0xee, 
    0xf8, 0x6b, 
};
static const unsigned char big5_chars_ban3715 [] = {
    0xf8, 0x72, 0xf7, 0xc0, 
};
static const unsigned char big5_chars_ban3716 [] = {
    0xf8, 0x65, 0xf8, 0x6f, 0xf8, 0x73, 0xf8, 0x6a, 0xf8, 0x63, 
    0xf8, 0x6d, 
};
static const unsigned char big5_chars_ban3717 [] = {
    0xf8, 0x6c, 0xf8, 0x71, 0xf8, 0x70, 0xf7, 0xc4, 0xf8, 0x68, 
    0xf8, 0x62, 0xf8, 0x66, 0xc6, 0x4e, 0xc6, 0x4f, 0xf8, 0x61, 
};
static const unsigned char big5_chars_ban3718 [] = {
    0xf8, 0xe6, 0xf8, 0xdd, 0xf8, 0xe5, 0xf8, 0xe2, 0xf8, 0xe3, 
    0xf8, 0xdc, 0xf8, 0xdf, 0xf8, 0xe7, 0xf8, 0xe1, 0xf8, 0xe0, 
    0xf8, 0xde, 
};
static const unsigned char big5_chars_ban3719 [] = {
    0xf8, 0xe4, 
};
static const unsigned char big5_chars_ban3720 [] = {
    0xf9, 0x5d, 
};
static const unsigned char big5_chars_ban3721 [] = {
    0xf9, 0x5e, 
};
static const unsigned char big5_chars_ban3722 [] = {
    0xf9, 0x60, 0xf9, 0x5f, 0xf9, 0x62, 0xf9, 0x61, 0xf9, 0x7c, 
    0xf9, 0x7b, 0xf9, 0xb7, 
};
static const unsigned char big5_chars_ban3723 [] = {
    0xf9, 0xb8, 
};
static const unsigned char big5_chars_ban3724 [] = {
    0xf9, 0xc5, 0xc6, 0x78, 0xc6, 0x7c, 
};
static const unsigned char big5_chars_ban3725 [] = {
    0xf9, 0xcf, 0xc6, 0x7d, 
};
static const unsigned char big5_chars_ban3726 [] = {
    0xb3, 0xbf, 
};
static const unsigned char big5_chars_ban3727 [] = {
    0xc4, 0xd0, 0xf6, 0xc9, 
};
static const unsigned char big5_chars_ban3728 [] = {
    0xc6, 0x50, 0xc6, 0x51, 
};
static const unsigned char big5_chars_ban3729 [] = {
    0xb3, 0xc0, 0xe0, 0xee, 
};
static const unsigned char big5_chars_ban3730 [] = {
    0xb9, 0xa8, 0xe8, 0xf0, 
};
static const unsigned char big5_chars_ban3731 [] = {
    0xec, 0xb0, 0xec, 0xb1, 0xec, 0xaf, 0xef, 0xab, 0xef, 0xaa, 
    0xc2, 0x47, 0xf1, 0xdf, 0xef, 0xac, 0xf1, 0xde, 
};
static const unsigned char big5_chars_ban3732 [] = {
    0xf3, 0xf3, 0xc4, 0x51, 0xc4, 0x53, 0xf3, 0xf2, 
};
static const unsigned char big5_chars_ban3733 [] = {
    0xc4, 0x52, 
};
static const unsigned char big5_chars_ban3734 [] = {
    0xf5, 0xb1, 0xf5, 0xb3, 0xf5, 0xb2, 0xf6, 0xca, 0xc5, 0x65, 
};
static const unsigned char big5_chars_ban3735 [] = {
    0xc5, 0xef, 0xf8, 0xe8, 0xf9, 0x63, 
};
static const unsigned char big5_chars_ban3736 [] = {
    0xf9, 0xd2, 0xb3, 0xc1, 
};
static const unsigned char big5_chars_ban3737 [] = {
    0xe4, 0xe5, 
};
static const unsigned char big5_chars_ban3738 [] = {
    0xbe, 0xa2, 
};
static const unsigned char big5_chars_ban3739 [] = {
    0xec, 0xb3, 0xec, 0xb2, 
};
static const unsigned char big5_chars_ban3740 [] = {
    0xef, 0xad, 
};
static const unsigned char big5_chars_ban3741 [] = {
    0xc4, 0x54, 0xc4, 0xd1, 0xf7, 0xc7, 0xf9, 0xcb, 
};
static const unsigned char big5_chars_ban3742 [] = {
    0xb3, 0xc2, 0xbb, 0xf2, 
};
static const unsigned char big5_chars_ban3743 [] = {
    0xbe, 0xa3, 
};
static const unsigned char big5_chars_ban3744 [] = {
    0xf3, 0xf4, 
};
static const unsigned char big5_chars_ban3745 [] = {
    0xf8, 0x74, 0xb6, 0xc0, 
};
static const unsigned char big5_chars_ban3746 [] = {
    0xef, 0xae, 
};
static const unsigned char big5_chars_ban3747 [] = {
    0xc6, 0x64, 0xb6, 0xc1, 0xbe, 0xa4, 0xc2, 0x48, 0xf8, 0x75, 
    0xb6, 0xc2, 
};
static const unsigned char big5_chars_ban3748 [] = {
    0xe8, 0xf1, 0xc0, 0x72, 0xec, 0xb4, 0xec, 0xb5, 
};
static const unsigned char big5_chars_ban3749 [] = {
    0xc0, 0x71, 
};
static const unsigned char big5_chars_ban3750 [] = {
    0xef, 0xaf, 0xc2, 0x4c, 0xc2, 0x4a, 0xc2, 0x4b, 0xc2, 0x49, 
    0xf1, 0xe0, 0xc3, 0x5c, 
};
static const unsigned char big5_chars_ban3751 [] = {
    0xf5, 0xb5, 0xf5, 0xb4, 0xf5, 0xb7, 0xf5, 0xb6, 0xc4, 0xd2, 
};
static const unsigned char big5_chars_ban3752 [] = {
    0xf6, 0xcb, 
};
static const unsigned char big5_chars_ban3753 [] = {
    0xf6, 0xcd, 0xf6, 0xcc, 0xc5, 0x66, 0xf7, 0xc8, 
};
static const unsigned char big5_chars_ban3754 [] = {
    0xf8, 0x76, 0xf8, 0x77, 0xc5, 0xf0, 0xf9, 0x64, 0xf9, 0x7d, 
    0xc6, 0x75, 
};
static const unsigned char big5_chars_ban3755 [] = {
    0xdc, 0xb0, 0xec, 0xb6, 0xef, 0xb0, 0xf3, 0xf5, 0xe0, 0xef, 
};
static const unsigned char big5_chars_ban3756 [] = {
    0xef, 0xb1, 0xf1, 0xe2, 0xf1, 0xe1, 
};
static const unsigned char big5_chars_ban3757 [] = {
    0xf8, 0x78, 0xc6, 0x52, 
};
static const unsigned char big5_chars_ban3758 [] = {
    0xf9, 0x65, 0xf9, 0x7e, 
};
static const unsigned char big5_chars_ban3759 [] = {
    0xb9, 0xa9, 0xe8, 0xf2, 0xe8, 0xf3, 
};
static const unsigned char big5_chars_ban3760 [] = {
    0xec, 0xb7, 0xb9, 0xaa, 
};
static const unsigned char big5_chars_ban3761 [] = {
    0xc3, 0x5d, 0xf1, 0xe3, 
};
static const unsigned char big5_chars_ban3762 [] = {
    0xf6, 0xcf, 0xc5, 0x67, 0xf6, 0xd0, 0xf6, 0xce, 0xf8, 0x79, 
};
static const unsigned char big5_chars_ban3763 [] = {
    0xf8, 0xe9, 
};
static const unsigned char big5_chars_ban3764 [] = {
    0xb9, 0xab, 
};
static const unsigned char big5_chars_ban3765 [] = {
    0xef, 0xb4, 0xef, 0xb3, 0xef, 0xb2, 0xf1, 0xe4, 
};
static const unsigned char big5_chars_ban3766 [] = {
    0xf1, 0xe8, 0xf1, 0xe7, 0xf1, 0xe6, 0xf1, 0xe5, 0xc3, 0x5e, 
    0xf3, 0xf6, 0xf5, 0xb9, 0xc4, 0xd3, 0xf5, 0xb8, 0xf6, 0xd1, 
    0xf7, 0xcb, 0xf7, 0xca, 0xc5, 0xc4, 0xf7, 0xc9, 0xf8, 0x7c, 
    0xf8, 0x7b, 0xf8, 0x7a, 
};
static const unsigned char big5_chars_ban3767 [] = {
    0xbb, 0xf3, 
};
static const unsigned char big5_chars_ban3768 [] = {
    0xec, 0xb8, 0xc2, 0x4d, 
};
static const unsigned char big5_chars_ban3769 [] = {
    0xf3, 0xf7, 0xf3, 0xf8, 0xf7, 0xcc, 0xf8, 0x7d, 
};
static const unsigned char big5_chars_ban3770 [] = {
    0xf8, 0xea, 0xf9, 0x66, 0xf9, 0xb9, 0xf9, 0xd4, 0xbb, 0xf4, 
    0xc2, 0x4e, 0xf1, 0xe9, 0xf3, 0xf9, 0xf6, 0xd2, 0xf8, 0x7e, 
};
static const unsigned char big5_chars_ban3771 [] = {
    0xbe, 0xa6, 
};
static const unsigned char big5_chars_ban3772 [] = {
    0xef, 0xb5, 0xf1, 0xea, 0xf3, 0xfa, 0xf3, 0xfb, 0xf3, 0xfc, 
    0xf5, 0xbe, 
};
static const unsigned char big5_chars_ban3773 [] = {
    0xf5, 0xba, 0xc5, 0x68, 0xf5, 0xbd, 0xf5, 0xbc, 0xc4, 0xd4, 
    0xf5, 0xbb, 0xc4, 0xd6, 
};
static const unsigned char big5_chars_ban3774 [] = {
    0xc4, 0xd5, 0xf6, 0xd4, 0xf6, 0xd3, 0xc5, 0x69, 0xc5, 0x6a, 
};
static const unsigned char big5_chars_ban3775 [] = {
    0xc5, 0xc6, 0xf7, 0xcd, 0xc5, 0xc5, 
};
static const unsigned char big5_chars_ban3776 [] = {
    0xf8, 0xa3, 0xf8, 0xa4, 0xf8, 0xa2, 0xf8, 0xa1, 0xc6, 0x54, 
};
static const unsigned char big5_chars_ban3777 [] = {
    0xf8, 0xeb, 0xf8, 0xec, 0xf8, 0xed, 0xc6, 0x53, 0xf9, 0x67, 
    0xf9, 0x6a, 0xf9, 0x69, 0xf9, 0x68, 
};
static const unsigned char big5_chars_ban3778 [] = {
    0xf9, 0xd3, 
};
static const unsigned char big5_chars_ban3779 [] = {
    0xc0, 0x73, 
};
static const unsigned char big5_chars_ban3780 [] = {
    0xc3, 0x65, 0xf5, 0xbf, 0xf6, 0xd5, 
};
static const unsigned char big5_chars_ban3781 [] = {
    0xc5, 0xc7, 0xf7, 0xce, 
};
static const unsigned char big5_chars_ban3782 [] = {
    0xf9, 0xd5, 
};
static const unsigned char big5_chars_ban3783 [] = {
    0xc0, 0x74, 
};
static const unsigned char big5_chars_ban3784 [] = {
    0xef, 0xb6, 
};
static const unsigned char big5_chars_ban3785 [] = {
    0xf7, 0xcf, 
};
static const unsigned char big5_chars_ban3786 [] = {
    0xf9, 0xa1, 
};
static const unsigned char big5_chars_ban3787 [] = {
    0xc9, 0x4a, 0xdd, 0xfc, 
};
static const unsigned char big5_chars_ban3788 [] = {
    0xa1, 0x4a, 0xa1, 0x57, 
};
static const unsigned char big5_chars_ban3789 [] = {
    0xa1, 0x59, 0xa1, 0x5b, 0xa1, 0x5f, 0xa1, 0x60, 0xa1, 0x63, 
    0xa1, 0x64, 0xa1, 0x67, 0xa1, 0x68, 0xa1, 0x6b, 0xa1, 0x6c, 
    0xa1, 0x6f, 0xa1, 0x70, 0xa1, 0x73, 0xa1, 0x74, 0xa1, 0x77, 
    0xa1, 0x78, 0xa1, 0x7b, 0xa1, 0x7c, 
};
static const unsigned char big5_chars_ban3790 [] = {
    0xa1, 0xc6, 0xa1, 0xc7, 0xa1, 0xca, 0xa1, 0xcb, 0xa1, 0xc8, 
    0xa1, 0xc9, 0xa1, 0x5c, 0xa1, 0x4d, 0xa1, 0x4e, 0xa1, 0x4f, 
};
static const unsigned char big5_chars_ban3791 [] = {
    0xa1, 0x51, 0xa1, 0x52, 0xa1, 0x53, 0xa1, 0x54, 
};
static const unsigned char big5_chars_ban3792 [] = {
    0xa1, 0x7d, 0xa1, 0x7e, 0xa1, 0xa1, 0xa1, 0xa2, 0xa1, 0xa3, 
    0xa1, 0xa4, 0xa1, 0xcc, 0xa1, 0xcd, 0xa1, 0xce, 0xa1, 0xde, 
    0xa1, 0xdf, 0xa1, 0xe0, 0xa1, 0xe1, 0xa1, 0xe2, 
};
static const unsigned char big5_chars_ban3793 [] = {
    0xa2, 0x42, 0xa2, 0x4c, 0xa2, 0x4d, 0xa2, 0x4e, 
};
static const unsigned char big5_chars_ban3794 [] = {
    0xa1, 0x49, 
};
static const unsigned char big5_chars_ban3795 [] = {
    0xa1, 0xad, 0xa2, 0x43, 0xa2, 0x48, 0xa1, 0xae, 
};
static const unsigned char big5_chars_ban3796 [] = {
    0xa1, 0x5d, 0xa1, 0x5e, 0xa1, 0xaf, 0xa1, 0xcf, 0xa1, 0x41, 
    0xa1, 0xd0, 0xa1, 0x44, 0xa1, 0xfe, 0xa2, 0xaf, 0xa2, 0xb0, 
    0xa2, 0xb1, 0xa2, 0xb2, 0xa2, 0xb3, 0xa2, 0xb4, 0xa2, 0xb5, 
    0xa2, 0xb6, 0xa2, 0xb7, 0xa2, 0xb8, 0xa1, 0x47, 0xa1, 0x46, 
    0xa1, 0xd5, 0xa1, 0xd7, 0xa1, 0xd6, 0xa1, 0x48, 0xa2, 0x49, 
    0xa2, 0xcf, 0xa2, 0xd0, 0xa2, 0xd1, 0xa2, 0xd2, 0xa2, 0xd3, 
    0xa2, 0xd4, 0xa2, 0xd5, 0xa2, 0xd6, 0xa2, 0xd7, 0xa2, 0xd8, 
    0xa2, 0xd9, 0xa2, 0xda, 0xa2, 0xdb, 0xa2, 0xdc, 0xa2, 0xdd, 
    0xa2, 0xde, 0xa2, 0xdf, 0xa2, 0xe0, 0xa2, 0xe1, 0xa2, 0xe2, 
    0xa2, 0xe3, 0xa2, 0xe4, 0xa2, 0xe5, 0xa2, 0xe6, 0xa2, 0xe7, 
    0xa2, 0xe8, 
};
static const unsigned char big5_chars_ban3797 [] = {
    0xa2, 0x40, 
};
static const unsigned char big5_chars_ban3798 [] = {
    0xa1, 0xc4, 
};
static const unsigned char big5_chars_ban3799 [] = {
    0xa2, 0xe9, 0xa2, 0xea, 0xa2, 0xeb, 0xa2, 0xec, 0xa2, 0xed, 
    0xa2, 0xee, 0xa2, 0xef, 0xa2, 0xf0, 0xa2, 0xf1, 0xa2, 0xf2, 
    0xa2, 0xf3, 0xa2, 0xf4, 0xa2, 0xf5, 0xa2, 0xf6, 0xa2, 0xf7, 
    0xa2, 0xf8, 0xa2, 0xf9, 0xa2, 0xfa, 0xa2, 0xfb, 0xa2, 0xfc, 
    0xa2, 0xfd, 0xa2, 0xfe, 0xa3, 0x40, 0xa3, 0x41, 0xa3, 0x42, 
    0xa3, 0x43, 0xa1, 0x61, 0xa1, 0x55, 0xa1, 0x62, 0xa1, 0xe3, 
};
static const unsigned char big5_chars_ban3800 [] = {
    0xa2, 0x46, 0xa2, 0x47, 
};
static const unsigned char big5_chars_ban3801 [] = {
    0xa1, 0xc3, 
};
static const unsigned char big5_chars_ban3802 [] = {
    0xa2, 0x44, 
};

static struct _uc16_bans {
    unsigned short start, end;
    const unsigned char* big5_chars;
} uc16_bans [] = {
    {0x00A7, 0x00A7, big5_chars_ban0}, 
    {0x00AF, 0x00B1, big5_chars_ban1}, 
    {0x00B7, 0x00B7, big5_chars_ban2}, 
    {0x00D7, 0x00D7, big5_chars_ban3}, 
    {0x00F7, 0x00F7, big5_chars_ban4}, 
    {0x02C7, 0x02C7, big5_chars_ban5}, 
    {0x02C9, 0x02CB, big5_chars_ban6}, 
    {0x02CD, 0x02CD, big5_chars_ban7}, 
    {0x02D9, 0x02D9, big5_chars_ban8}, 
    {0x0391, 0x03A1, big5_chars_ban9}, 
    {0x03A3, 0x03A9, big5_chars_ban10}, 
    {0x03B1, 0x03C1, big5_chars_ban11}, 
    {0x03C3, 0x03C9, big5_chars_ban12}, 
    {0x2013, 0x2014, big5_chars_ban13}, 
    {0x2018, 0x2019, big5_chars_ban14}, 
    {0x201C, 0x201D, big5_chars_ban15}, 
    {0x2025, 0x2027, big5_chars_ban16}, 
    {0x2032, 0x2032, big5_chars_ban17}, 
    {0x2035, 0x2035, big5_chars_ban18}, 
    {0x203B, 0x203B, big5_chars_ban19}, 
    {0x20AC, 0x20AC, big5_chars_ban20}, 
    {0x2103, 0x2103, big5_chars_ban21}, 
    {0x2105, 0x2105, big5_chars_ban22}, 
    {0x2109, 0x2109, big5_chars_ban23}, 
    {0x2160, 0x2169, big5_chars_ban24}, 
    {0x2190, 0x2193, big5_chars_ban25}, 
    {0x2196, 0x2199, big5_chars_ban26}, 
    {0x2215, 0x2215, big5_chars_ban27}, 
    {0x221A, 0x221A, big5_chars_ban28}, 
    {0x221E, 0x2220, big5_chars_ban29}, 
    {0x2223, 0x2223, big5_chars_ban30}, 
    {0x2225, 0x2225, big5_chars_ban31}, 
    {0x2229, 0x222B, big5_chars_ban32}, 
    {0x222E, 0x222E, big5_chars_ban33}, 
    {0x2234, 0x2235, big5_chars_ban34}, 
    {0x2252, 0x2252, big5_chars_ban35}, 
    {0x2260, 0x2261, big5_chars_ban36}, 
    {0x2266, 0x2267, big5_chars_ban37}, 
    {0x2295, 0x2295, big5_chars_ban38}, 
    {0x2299, 0x2299, big5_chars_ban39}, 
    {0x22A5, 0x22A5, big5_chars_ban40}, 
    {0x22BF, 0x22BF, big5_chars_ban41}, 
    {0x2500, 0x2500, big5_chars_ban42}, 
    {0x2502, 0x2502, big5_chars_ban43}, 
    {0x250C, 0x250C, big5_chars_ban44}, 
    {0x2510, 0x2510, big5_chars_ban45}, 
    {0x2514, 0x2514, big5_chars_ban46}, 
    {0x2518, 0x2518, big5_chars_ban47}, 
    {0x251C, 0x251C, big5_chars_ban48}, 
    {0x2524, 0x2524, big5_chars_ban49}, 
    {0x252C, 0x252C, big5_chars_ban50}, 
    {0x2534, 0x2534, big5_chars_ban51}, 
    {0x253C, 0x253C, big5_chars_ban52}, 
    {0x2550, 0x2574, big5_chars_ban53}, 
    {0x2581, 0x258F, big5_chars_ban54}, 
    {0x2593, 0x2595, big5_chars_ban55}, 
    {0x25A0, 0x25A1, big5_chars_ban56}, 
    {0x25B2, 0x25B3, big5_chars_ban57}, 
    {0x25BC, 0x25BD, big5_chars_ban58}, 
    {0x25C6, 0x25C7, big5_chars_ban59}, 
    {0x25CB, 0x25CB, big5_chars_ban60}, 
    {0x25CE, 0x25CF, big5_chars_ban61}, 
    {0x25E2, 0x25E5, big5_chars_ban62}, 
    {0x2605, 0x2606, big5_chars_ban63}, 
    {0x2640, 0x2640, big5_chars_ban64}, 
    {0x2642, 0x2642, big5_chars_ban65}, 
    {0x3000, 0x3003, big5_chars_ban66}, 
    {0x3008, 0x3012, big5_chars_ban67}, 
    {0x3014, 0x3015, big5_chars_ban68}, 
    {0x301D, 0x301E, big5_chars_ban69}, 
    {0x3021, 0x3029, big5_chars_ban70}, 
    {0x3105, 0x3129, big5_chars_ban71}, 
    {0x32A3, 0x32A3, big5_chars_ban72}, 
    {0x338E, 0x338F, big5_chars_ban73}, 
    {0x339C, 0x339E, big5_chars_ban74}, 
    {0x33A1, 0x33A1, big5_chars_ban75}, 
    {0x33C4, 0x33C4, big5_chars_ban76}, 
    {0x33CE, 0x33CE, big5_chars_ban77}, 
    {0x33D1, 0x33D2, big5_chars_ban78}, 
    {0x33D5, 0x33D5, big5_chars_ban79}, 
    {0x4E00, 0x4E01, big5_chars_ban80}, 
    {0x4E03, 0x4E03, big5_chars_ban81}, 
    {0x4E07, 0x4E11, big5_chars_ban82}, 
    {0x4E14, 0x4E16, big5_chars_ban83}, 
    {0x4E18, 0x4E19, big5_chars_ban84}, 
    {0x4E1E, 0x4E1F, big5_chars_ban85}, 
    {0x4E26, 0x4E26, big5_chars_ban86}, 
    {0x4E2B, 0x4E2B, big5_chars_ban87}, 
    {0x4E2D, 0x4E2E, big5_chars_ban88}, 
    {0x4E30, 0x4E33, big5_chars_ban89}, 
    {0x4E38, 0x4E39, big5_chars_ban90}, 
    {0x4E3B, 0x4E3C, big5_chars_ban91}, 
    {0x4E42, 0x4E43, big5_chars_ban92}, 
    {0x4E45, 0x4E45, big5_chars_ban93}, 
    {0x4E47, 0x4E48, big5_chars_ban94}, 
    {0x4E4B, 0x4E4B, big5_chars_ban95}, 
    {0x4E4D, 0x4E4F, big5_chars_ban96}, 
    {0x4E52, 0x4E53, big5_chars_ban97}, 
    {0x4E56, 0x4E56, big5_chars_ban98}, 
    {0x4E58, 0x4E59, big5_chars_ban99}, 
    {0x4E5C, 0x4E5F, big5_chars_ban100}, 
    {0x4E69, 0x4E69, big5_chars_ban101}, 
    {0x4E73, 0x4E73, big5_chars_ban102}, 
    {0x4E7E, 0x4E7F, big5_chars_ban103}, 
    {0x4E82, 0x4E84, big5_chars_ban104}, 
    {0x4E86, 0x4E86, big5_chars_ban105}, 
    {0x4E88, 0x4E88, big5_chars_ban106}, 
    {0x4E8B, 0x4E8E, big5_chars_ban107}, 
    {0x4E91, 0x4E95, big5_chars_ban108}, 
    {0x4E99, 0x4E99, big5_chars_ban109}, 
    {0x4E9B, 0x4E9B, big5_chars_ban110}, 
    {0x4E9E, 0x4E9F, big5_chars_ban111}, 
    {0x4EA1, 0x4EA2, big5_chars_ban112}, 
    {0x4EA4, 0x4EA6, big5_chars_ban113}, 
    {0x4EA8, 0x4EA8, big5_chars_ban114}, 
    {0x4EAB, 0x4EAE, big5_chars_ban115}, 
    {0x4EB3, 0x4EB3, big5_chars_ban116}, 
    {0x4EB6, 0x4EB6, big5_chars_ban117}, 
    {0x4EB9, 0x4EBA, big5_chars_ban118}, 
    {0x4EC0, 0x4EC4, big5_chars_ban119}, 
    {0x4EC6, 0x4ECB, big5_chars_ban120}, 
    {0x4ECD, 0x4ECD, big5_chars_ban121}, 
    {0x4ED4, 0x4EDA, big5_chars_ban122}, 
    {0x4EDC, 0x4EDF, big5_chars_ban123}, 
    {0x4EE1, 0x4EE1, big5_chars_ban124}, 
    {0x4EE3, 0x4EE5, big5_chars_ban125}, 
    {0x4EE8, 0x4EE9, big5_chars_ban126}, 
    {0x4EF0, 0x4EF7, big5_chars_ban127}, 
    {0x4EFB, 0x4EFB, big5_chars_ban128}, 
    {0x4EFD, 0x4EFD, big5_chars_ban129}, 
    {0x4EFF, 0x4F02, big5_chars_ban130}, 
    {0x4F04, 0x4F05, big5_chars_ban131}, 
    {0x4F08, 0x4F0B, big5_chars_ban132}, 
    {0x4F0D, 0x4F15, big5_chars_ban133}, 
    {0x4F18, 0x4F19, big5_chars_ban134}, 
    {0x4F1D, 0x4F1D, big5_chars_ban135}, 
    {0x4F22, 0x4F22, big5_chars_ban136}, 
    {0x4F2C, 0x4F2D, big5_chars_ban137}, 
    {0x4F2F, 0x4F30, big5_chars_ban138}, 
    {0x4F33, 0x4F34, big5_chars_ban139}, 
    {0x4F36, 0x4F36, big5_chars_ban140}, 
    {0x4F38, 0x4F38, big5_chars_ban141}, 
    {0x4F3A, 0x4F3F, big5_chars_ban142}, 
    {0x4F41, 0x4F41, big5_chars_ban143}, 
    {0x4F43, 0x4F43, big5_chars_ban144}, 
    {0x4F46, 0x4F49, big5_chars_ban145}, 
    {0x4F4C, 0x4F64, big5_chars_ban146}, 
    {0x4F67, 0x4F67, big5_chars_ban147}, 
    {0x4F69, 0x4F6C, big5_chars_ban148}, 
    {0x4F6E, 0x4F70, big5_chars_ban149}, 
    {0x4F73, 0x4F89, big5_chars_ban150}, 
    {0x4F8B, 0x4F8B, big5_chars_ban151}, 
    {0x4F8D, 0x4F8D, big5_chars_ban152}, 
    {0x4F8F, 0x4F92, big5_chars_ban153}, 
    {0x4F94, 0x4F98, big5_chars_ban154}, 
    {0x4F9A, 0x4F9E, big5_chars_ban155}, 
    {0x4FAE, 0x4FAF, big5_chars_ban156}, 
    {0x4FB2, 0x4FB3, big5_chars_ban157}, 
    {0x4FB5, 0x4FB7, big5_chars_ban158}, 
    {0x4FB9, 0x4FBB, big5_chars_ban159}, 
    {0x4FBF, 0x4FC5, big5_chars_ban160}, 
    {0x4FC7, 0x4FC7, big5_chars_ban161}, 
    {0x4FC9, 0x4FCB, big5_chars_ban162}, 
    {0x4FCD, 0x4FD1, big5_chars_ban163}, 
    {0x4FD3, 0x4FD4, big5_chars_ban164}, 
    {0x4FD6, 0x4FE1, big5_chars_ban165}, 
    {0x4FEC, 0x4FEC, big5_chars_ban166}, 
    {0x4FEE, 0x4FEF, big5_chars_ban167}, 
    {0x4FF1, 0x4FF1, big5_chars_ban168}, 
    {0x4FF3, 0x4FF8, big5_chars_ban169}, 
    {0x4FFA, 0x4FFA, big5_chars_ban170}, 
    {0x4FFE, 0x4FFE, big5_chars_ban171}, 
    {0x5000, 0x5000, big5_chars_ban172}, 
    {0x5005, 0x5007, big5_chars_ban173}, 
    {0x5009, 0x5009, big5_chars_ban174}, 
    {0x500B, 0x500F, big5_chars_ban175}, 
    {0x5011, 0x501C, big5_chars_ban176}, 
    {0x501E, 0x5023, big5_chars_ban177}, 
    {0x5025, 0x502D, big5_chars_ban178}, 
    {0x502F, 0x5031, big5_chars_ban179}, 
    {0x5033, 0x5033, big5_chars_ban180}, 
    {0x5035, 0x5035, big5_chars_ban181}, 
    {0x5037, 0x5037, big5_chars_ban182}, 
    {0x503C, 0x503C, big5_chars_ban183}, 
    {0x5040, 0x5041, big5_chars_ban184}, 
    {0x5043, 0x5043, big5_chars_ban185}, 
    {0x5045, 0x504F, big5_chars_ban186}, 
    {0x5051, 0x5051, big5_chars_ban187}, 
    {0x5053, 0x5053, big5_chars_ban188}, 
    {0x5055, 0x5055, big5_chars_ban189}, 
    {0x5057, 0x5057, big5_chars_ban190}, 
    {0x505A, 0x5065, big5_chars_ban191}, 
    {0x5068, 0x506B, big5_chars_ban192}, 
    {0x506D, 0x5070, big5_chars_ban193}, 
    {0x5072, 0x5077, big5_chars_ban194}, 
    {0x507A, 0x507A, big5_chars_ban195}, 
    {0x507D, 0x507D, big5_chars_ban196}, 
    {0x5080, 0x5080, big5_chars_ban197}, 
    {0x5082, 0x5083, big5_chars_ban198}, 
    {0x5085, 0x5085, big5_chars_ban199}, 
    {0x5087, 0x5087, big5_chars_ban200}, 
    {0x508B, 0x508E, big5_chars_ban201}, 
    {0x5091, 0x5092, big5_chars_ban202}, 
    {0x5094, 0x5096, big5_chars_ban203}, 
    {0x5098, 0x509E, big5_chars_ban204}, 
    {0x50A2, 0x50A3, big5_chars_ban205}, 
    {0x50AC, 0x50B8, big5_chars_ban206}, 
    {0x50BA, 0x50BB, big5_chars_ban207}, 
    {0x50BD, 0x50BF, big5_chars_ban208}, 
    {0x50C1, 0x50C2, big5_chars_ban209}, 
    {0x50C4, 0x50CB, big5_chars_ban210}, 
    {0x50CE, 0x50CF, big5_chars_ban211}, 
    {0x50D1, 0x50D1, big5_chars_ban212}, 
    {0x50D3, 0x50D7, big5_chars_ban213}, 
    {0x50DA, 0x50DB, big5_chars_ban214}, 
    {0x50DD, 0x50DD, big5_chars_ban215}, 
    {0x50E0, 0x50E0, big5_chars_ban216}, 
    {0x50E3, 0x50EA, big5_chars_ban217}, 
    {0x50EC, 0x50F1, big5_chars_ban218}, 
    {0x50F3, 0x50F3, big5_chars_ban219}, 
    {0x50F5, 0x50F6, big5_chars_ban220}, 
    {0x50F8, 0x50F9, big5_chars_ban221}, 
    {0x50FB, 0x50FB, big5_chars_ban222}, 
    {0x50FD, 0x5100, big5_chars_ban223}, 
    {0x5102, 0x510C, big5_chars_ban224}, 
    {0x5110, 0x5115, big5_chars_ban225}, 
    {0x5117, 0x5118, big5_chars_ban226}, 
    {0x511A, 0x511A, big5_chars_ban227}, 
    {0x511C, 0x511C, big5_chars_ban228}, 
    {0x511F, 0x5122, big5_chars_ban229}, 
    {0x5124, 0x5126, big5_chars_ban230}, 
    {0x5129, 0x512A, big5_chars_ban231}, 
    {0x512D, 0x512E, big5_chars_ban232}, 
    {0x5130, 0x5135, big5_chars_ban233}, 
    {0x5137, 0x513D, big5_chars_ban234}, 
    {0x513F, 0x5141, big5_chars_ban235}, 
    {0x5143, 0x5149, big5_chars_ban236}, 
    {0x514B, 0x514D, big5_chars_ban237}, 
    {0x5152, 0x5152, big5_chars_ban238}, 
    {0x5154, 0x5155, big5_chars_ban239}, 
    {0x5157, 0x5157, big5_chars_ban240}, 
    {0x5159, 0x515F, big5_chars_ban241}, 
    {0x5161, 0x5163, big5_chars_ban242}, 
    {0x5165, 0x5165, big5_chars_ban243}, 
    {0x5167, 0x5169, big5_chars_ban244}, 
    {0x516B, 0x516E, big5_chars_ban245}, 
    {0x5171, 0x5171, big5_chars_ban246}, 
    {0x5175, 0x5178, big5_chars_ban247}, 
    {0x517C, 0x517C, big5_chars_ban248}, 
    {0x5180, 0x5180, big5_chars_ban249}, 
    {0x5187, 0x5187, big5_chars_ban250}, 
    {0x5189, 0x518A, big5_chars_ban251}, 
    {0x518D, 0x518D, big5_chars_ban252}, 
    {0x518F, 0x518F, big5_chars_ban253}, 
    {0x5191, 0x5195, big5_chars_ban254}, 
    {0x5197, 0x5198, big5_chars_ban255}, 
    {0x519E, 0x519E, big5_chars_ban256}, 
    {0x51A0, 0x51A0, big5_chars_ban257}, 
    {0x51A2, 0x51A2, big5_chars_ban258}, 
    {0x51A4, 0x51A5, big5_chars_ban259}, 
    {0x51AA, 0x51AA, big5_chars_ban260}, 
    {0x51AC, 0x51AC, big5_chars_ban261}, 
    {0x51B0, 0x51B1, big5_chars_ban262}, 
    {0x51B6, 0x51B7, big5_chars_ban263}, 
    {0x51B9, 0x51B9, big5_chars_ban264}, 
    {0x51BC, 0x51BE, big5_chars_ban265}, 
    {0x51C4, 0x51C6, big5_chars_ban266}, 
    {0x51C8, 0x51C8, big5_chars_ban267}, 
    {0x51CA, 0x51CE, big5_chars_ban268}, 
    {0x51D0, 0x51D0, big5_chars_ban269}, 
    {0x51D4, 0x51D4, big5_chars_ban270}, 
    {0x51D7, 0x51D8, big5_chars_ban271}, 
    {0x51DC, 0x51DE, big5_chars_ban272}, 
    {0x51E0, 0x51E1, big5_chars_ban273}, 
    {0x51F0, 0x51F1, big5_chars_ban274}, 
    {0x51F3, 0x51F3, big5_chars_ban275}, 
    {0x51F5, 0x51F6, big5_chars_ban276}, 
    {0x51F8, 0x51FA, big5_chars_ban277}, 
    {0x51FD, 0x51FD, big5_chars_ban278}, 
    {0x5200, 0x5201, big5_chars_ban279}, 
    {0x5203, 0x5203, big5_chars_ban280}, 
    {0x5206, 0x520A, big5_chars_ban281}, 
    {0x520C, 0x520C, big5_chars_ban282}, 
    {0x520E, 0x520E, big5_chars_ban283}, 
    {0x5210, 0x5213, big5_chars_ban284}, 
    {0x5216, 0x5217, big5_chars_ban285}, 
    {0x521C, 0x521E, big5_chars_ban286}, 
    {0x5221, 0x5221, big5_chars_ban287}, 
    {0x5224, 0x5225, big5_chars_ban288}, 
    {0x5228, 0x522A, big5_chars_ban289}, 
    {0x522E, 0x522E, big5_chars_ban290}, 
    {0x5230, 0x5233, big5_chars_ban291}, 
    {0x5235, 0x5238, big5_chars_ban292}, 
    {0x523A, 0x523B, big5_chars_ban293}, 
    {0x5241, 0x5241, big5_chars_ban294}, 
    {0x5243, 0x5244, big5_chars_ban295}, 
    {0x5246, 0x5247, big5_chars_ban296}, 
    {0x5249, 0x524E, big5_chars_ban297}, 
    {0x5252, 0x5252, big5_chars_ban298}, 
    {0x5254, 0x5256, big5_chars_ban299}, 
    {0x525A, 0x525F, big5_chars_ban300}, 
    {0x5261, 0x5262, big5_chars_ban301}, 
    {0x5269, 0x526F, big5_chars_ban302}, 
    {0x5272, 0x5272, big5_chars_ban303}, 
    {0x5274, 0x5275, big5_chars_ban304}, 
    {0x5277, 0x5278, big5_chars_ban305}, 
    {0x527A, 0x527D, big5_chars_ban306}, 
    {0x527F, 0x5284, big5_chars_ban307}, 
    {0x5287, 0x528D, big5_chars_ban308}, 
    {0x5291, 0x5291, big5_chars_ban309}, 
    {0x5293, 0x5293, big5_chars_ban310}, 
    {0x5296, 0x5299, big5_chars_ban311}, 
    {0x529B, 0x529B, big5_chars_ban312}, 
    {0x529F, 0x52A0, big5_chars_ban313}, 
    {0x52A3, 0x52A3, big5_chars_ban314}, 
    {0x52A6, 0x52A6, big5_chars_ban315}, 
    {0x52A9, 0x52AE, big5_chars_ban316}, 
    {0x52BB, 0x52BC, big5_chars_ban317}, 
    {0x52BE, 0x52BE, big5_chars_ban318}, 
    {0x52C0, 0x52C3, big5_chars_ban319}, 
    {0x52C7, 0x52C7, big5_chars_ban320}, 
    {0x52C9, 0x52C9, big5_chars_ban321}, 
    {0x52CD, 0x52CD, big5_chars_ban322}, 
    {0x52D2, 0x52D3, big5_chars_ban323}, 
    {0x52D5, 0x52D9, big5_chars_ban324}, 
    {0x52DB, 0x52DB, big5_chars_ban325}, 
    {0x52DD, 0x52DF, big5_chars_ban326}, 
    {0x52E2, 0x52E4, big5_chars_ban327}, 
    {0x52E6, 0x52E6, big5_chars_ban328}, 
    {0x52E9, 0x52E9, big5_chars_ban329}, 
    {0x52EB, 0x52EB, big5_chars_ban330}, 
    {0x52EF, 0x52F1, big5_chars_ban331}, 
    {0x52F3, 0x52F5, big5_chars_ban332}, 
    {0x52F7, 0x52F8, big5_chars_ban333}, 
    {0x52FA, 0x52FC, big5_chars_ban334}, 
    {0x52FE, 0x52FF, big5_chars_ban335}, 
    {0x5305, 0x5306, big5_chars_ban336}, 
    {0x5308, 0x530B, big5_chars_ban337}, 
    {0x530D, 0x5312, big5_chars_ban338}, 
    {0x5315, 0x5317, big5_chars_ban339}, 
    {0x5319, 0x531A, big5_chars_ban340}, 
    {0x531C, 0x531D, big5_chars_ban341}, 
    {0x531F, 0x5323, big5_chars_ban342}, 
    {0x532A, 0x532A, big5_chars_ban343}, 
    {0x532D, 0x532D, big5_chars_ban344}, 
    {0x532F, 0x5331, big5_chars_ban345}, 
    {0x5334, 0x5334, big5_chars_ban346}, 
    {0x5337, 0x5337, big5_chars_ban347}, 
    {0x5339, 0x5339, big5_chars_ban348}, 
    {0x533C, 0x5341, big5_chars_ban349}, 
    {0x5343, 0x5345, big5_chars_ban350}, 
    {0x5347, 0x534A, big5_chars_ban351}, 
    {0x534C, 0x534D, big5_chars_ban352}, 
    {0x5351, 0x5354, big5_chars_ban353}, 
    {0x5357, 0x5357, big5_chars_ban354}, 
    {0x535A, 0x535A, big5_chars_ban355}, 
    {0x535C, 0x535C, big5_chars_ban356}, 
    {0x535E, 0x535E, big5_chars_ban357}, 
    {0x5360, 0x5361, big5_chars_ban358}, 
    {0x5363, 0x5363, big5_chars_ban359}, 
    {0x5366, 0x5366, big5_chars_ban360}, 
    {0x536C, 0x536C, big5_chars_ban361}, 
    {0x536E, 0x5373, big5_chars_ban362}, 
    {0x5375, 0x5375, big5_chars_ban363}, 
    {0x5377, 0x5379, big5_chars_ban364}, 
    {0x537B, 0x537C, big5_chars_ban365}, 
    {0x537F, 0x537F, big5_chars_ban366}, 
    {0x5382, 0x5382, big5_chars_ban367}, 
    {0x5384, 0x5384, big5_chars_ban368}, 
    {0x538A, 0x538A, big5_chars_ban369}, 
    {0x538E, 0x538F, big5_chars_ban370}, 
    {0x5392, 0x5392, big5_chars_ban371}, 
    {0x5394, 0x5394, big5_chars_ban372}, 
    {0x5396, 0x539A, big5_chars_ban373}, 
    {0x539C, 0x539F, big5_chars_ban374}, 
    {0x53A4, 0x53A5, big5_chars_ban375}, 
    {0x53A7, 0x53A7, big5_chars_ban376}, 
    {0x53AC, 0x53AD, big5_chars_ban377}, 
    {0x53B2, 0x53B2, big5_chars_ban378}, 
    {0x53B4, 0x53B4, big5_chars_ban379}, 
    {0x53B9, 0x53B9, big5_chars_ban380}, 
    {0x53BB, 0x53BB, big5_chars_ban381}, 
    {0x53C3, 0x53C3, big5_chars_ban382}, 
    {0x53C8, 0x53CB, big5_chars_ban383}, 
    {0x53CD, 0x53CD, big5_chars_ban384}, 
    {0x53D4, 0x53D4, big5_chars_ban385}, 
    {0x53D6, 0x53D7, big5_chars_ban386}, 
    {0x53DB, 0x53DB, big5_chars_ban387}, 
    {0x53DF, 0x53DF, big5_chars_ban388}, 
    {0x53E1, 0x53E6, big5_chars_ban389}, 
    {0x53E8, 0x53F3, big5_chars_ban390}, 
    {0x53F5, 0x53F5, big5_chars_ban391}, 
    {0x53F8, 0x53F8, big5_chars_ban392}, 
    {0x53FB, 0x53FC, big5_chars_ban393}, 
    {0x5401, 0x5401, big5_chars_ban394}, 
    {0x5403, 0x5404, big5_chars_ban395}, 
    {0x5406, 0x5412, big5_chars_ban396}, 
    {0x5418, 0x5419, big5_chars_ban397}, 
    {0x541B, 0x5420, big5_chars_ban398}, 
    {0x5424, 0x542E, big5_chars_ban399}, 
    {0x5430, 0x5431, big5_chars_ban400}, 
    {0x5433, 0x5433, big5_chars_ban401}, 
    {0x5435, 0x5439, big5_chars_ban402}, 
    {0x543B, 0x543E, big5_chars_ban403}, 
    {0x5440, 0x5443, big5_chars_ban404}, 
    {0x5445, 0x5448, big5_chars_ban405}, 
    {0x544A, 0x544A, big5_chars_ban406}, 
    {0x544E, 0x544F, big5_chars_ban407}, 
    {0x5454, 0x5454, big5_chars_ban408}, 
    {0x5460, 0x5468, big5_chars_ban409}, 
    {0x546B, 0x546C, big5_chars_ban410}, 
    {0x546F, 0x5478, big5_chars_ban411}, 
    {0x547A, 0x5482, big5_chars_ban412}, 
    {0x5484, 0x5484, big5_chars_ban413}, 
    {0x5486, 0x5488, big5_chars_ban414}, 
    {0x548B, 0x548E, big5_chars_ban415}, 
    {0x5490, 0x5492, big5_chars_ban416}, 
    {0x5495, 0x5496, big5_chars_ban417}, 
    {0x5498, 0x5498, big5_chars_ban418}, 
    {0x549A, 0x549A, big5_chars_ban419}, 
    {0x54A0, 0x54A2, big5_chars_ban420}, 
    {0x54A5, 0x54B1, big5_chars_ban421}, 
    {0x54B3, 0x54B3, big5_chars_ban422}, 
    {0x54B6, 0x54B8, big5_chars_ban423}, 
    {0x54BA, 0x54C9, big5_chars_ban424}, 
    {0x54CE, 0x54CF, big5_chars_ban425}, 
    {0x54D6, 0x54D6, big5_chars_ban426}, 
    {0x54DE, 0x54DE, big5_chars_ban427}, 
    {0x54E0, 0x54E2, big5_chars_ban428}, 
    {0x54E4, 0x54EB, big5_chars_ban429}, 
    {0x54ED, 0x54EE, big5_chars_ban430}, 
    {0x54F1, 0x54F3, big5_chars_ban431}, 
    {0x54F7, 0x54F8, big5_chars_ban432}, 
    {0x54FA, 0x54FD, big5_chars_ban433}, 
    {0x54FF, 0x54FF, big5_chars_ban434}, 
    {0x5501, 0x5501, big5_chars_ban435}, 
    {0x5503, 0x550C, big5_chars_ban436}, 
    {0x550E, 0x5512, big5_chars_ban437}, 
    {0x5514, 0x5514, big5_chars_ban438}, 
    {0x5517, 0x5517, big5_chars_ban439}, 
    {0x551A, 0x551A, big5_chars_ban440}, 
    {0x5526, 0x5527, big5_chars_ban441}, 
    {0x552A, 0x552A, big5_chars_ban442}, 
    {0x552C, 0x5539, big5_chars_ban443}, 
    {0x553B, 0x553C, big5_chars_ban444}, 
    {0x553E, 0x553E, big5_chars_ban445}, 
    {0x5540, 0x5541, big5_chars_ban446}, 
    {0x5543, 0x5546, big5_chars_ban447}, 
    {0x5548, 0x5548, big5_chars_ban448}, 
    {0x554A, 0x554B, big5_chars_ban449}, 
    {0x554D, 0x5552, big5_chars_ban450}, 
    {0x5555, 0x5557, big5_chars_ban451}, 
    {0x555C, 0x555C, big5_chars_ban452}, 
    {0x555E, 0x555F, big5_chars_ban453}, 
    {0x5561, 0x5566, big5_chars_ban454}, 
    {0x556A, 0x556A, big5_chars_ban455}, 
    {0x5575, 0x5577, big5_chars_ban456}, 
    {0x557B, 0x5584, big5_chars_ban457}, 
    {0x5587, 0x558F, big5_chars_ban458}, 
    {0x5591, 0x5595, big5_chars_ban459}, 
    {0x5598, 0x559A, big5_chars_ban460}, 
    {0x559C, 0x559D, big5_chars_ban461}, 
    {0x559F, 0x559F, big5_chars_ban462}, 
    {0x55A1, 0x55A8, big5_chars_ban463}, 
    {0x55AA, 0x55AE, big5_chars_ban464}, 
    {0x55B1, 0x55B3, big5_chars_ban465}, 
    {0x55B5, 0x55B5, big5_chars_ban466}, 
    {0x55BB, 0x55BB, big5_chars_ban467}, 
    {0x55BF, 0x55C0, big5_chars_ban468}, 
    {0x55C2, 0x55D6, big5_chars_ban469}, 
    {0x55D9, 0x55DD, big5_chars_ban470}, 
    {0x55DF, 0x55DF, big5_chars_ban471}, 
    {0x55E1, 0x55E9, big5_chars_ban472}, 
    {0x55EF, 0x55EF, big5_chars_ban473}, 
    {0x55F2, 0x55F2, big5_chars_ban474}, 
    {0x55F6, 0x55F7, big5_chars_ban475}, 
    {0x55F9, 0x55FA, big5_chars_ban476}, 
    {0x55FC, 0x5602, big5_chars_ban477}, 
    {0x5604, 0x5604, big5_chars_ban478}, 
    {0x5606, 0x5606, big5_chars_ban479}, 
    {0x5608, 0x5609, big5_chars_ban480}, 
    {0x560C, 0x5610, big5_chars_ban481}, 
    {0x5612, 0x5617, big5_chars_ban482}, 
    {0x561B, 0x561D, big5_chars_ban483}, 
    {0x561F, 0x561F, big5_chars_ban484}, 
    {0x5627, 0x5627, big5_chars_ban485}, 
    {0x5629, 0x562A, big5_chars_ban486}, 
    {0x562C, 0x562C, big5_chars_ban487}, 
    {0x562E, 0x5630, big5_chars_ban488}, 
    {0x5632, 0x5636, big5_chars_ban489}, 
    {0x5638, 0x563B, big5_chars_ban490}, 
    {0x563D, 0x5642, big5_chars_ban491}, 
    {0x5645, 0x5646, big5_chars_ban492}, 
    {0x5648, 0x564A, big5_chars_ban493}, 
    {0x564C, 0x564C, big5_chars_ban494}, 
    {0x564E, 0x564E, big5_chars_ban495}, 
    {0x5653, 0x5653, big5_chars_ban496}, 
    {0x5657, 0x565A, big5_chars_ban497}, 
    {0x565E, 0x565E, big5_chars_ban498}, 
    {0x5660, 0x5660, big5_chars_ban499}, 
    {0x5662, 0x5666, big5_chars_ban500}, 
    {0x5668, 0x5674, big5_chars_ban501}, 
    {0x5676, 0x5679, big5_chars_ban502}, 
    {0x567E, 0x5687, big5_chars_ban503}, 
    {0x568C, 0x5690, big5_chars_ban504}, 
    {0x5693, 0x5693, big5_chars_ban505}, 
    {0x5695, 0x5695, big5_chars_ban506}, 
    {0x5697, 0x569A, big5_chars_ban507}, 
    {0x569C, 0x569D, big5_chars_ban508}, 
    {0x56A5, 0x56A8, big5_chars_ban509}, 
    {0x56AA, 0x56AE, big5_chars_ban510}, 
    {0x56B2, 0x56B7, big5_chars_ban511}, 
    {0x56BC, 0x56BE, big5_chars_ban512}, 
    {0x56C0, 0x56C3, big5_chars_ban513}, 
    {0x56C5, 0x56C6, big5_chars_ban514}, 
    {0x56C8, 0x56CD, big5_chars_ban515}, 
    {0x56D1, 0x56D1, big5_chars_ban516}, 
    {0x56D3, 0x56D4, big5_chars_ban517}, 
    {0x56D7, 0x56D7, big5_chars_ban518}, 
    {0x56DA, 0x56DB, big5_chars_ban519}, 
    {0x56DD, 0x56E1, big5_chars_ban520}, 
    {0x56E4, 0x56E5, big5_chars_ban521}, 
    {0x56E7, 0x56E7, big5_chars_ban522}, 
    {0x56EA, 0x56EB, big5_chars_ban523}, 
    {0x56EE, 0x56EE, big5_chars_ban524}, 
    {0x56F0, 0x56F0, big5_chars_ban525}, 
    {0x56F7, 0x56F7, big5_chars_ban526}, 
    {0x56F9, 0x56FA, big5_chars_ban527}, 
    {0x56FF, 0x56FF, big5_chars_ban528}, 
    {0x5701, 0x5704, big5_chars_ban529}, 
    {0x5707, 0x570D, big5_chars_ban530}, 
    {0x5712, 0x5714, big5_chars_ban531}, 
    {0x5716, 0x5716, big5_chars_ban532}, 
    {0x5718, 0x5718, big5_chars_ban533}, 
    {0x571A, 0x571C, big5_chars_ban534}, 
    {0x571E, 0x5720, big5_chars_ban535}, 
    {0x5722, 0x5723, big5_chars_ban536}, 
    {0x5728, 0x572A, big5_chars_ban537}, 
    {0x572C, 0x5730, big5_chars_ban538}, 
    {0x5733, 0x5734, big5_chars_ban539}, 
    {0x573B, 0x573B, big5_chars_ban540}, 
    {0x573E, 0x573E, big5_chars_ban541}, 
    {0x5740, 0x5741, big5_chars_ban542}, 
    {0x5745, 0x5745, big5_chars_ban543}, 
    {0x5747, 0x5747, big5_chars_ban544}, 
    {0x5749, 0x5752, big5_chars_ban545}, 
    {0x5761, 0x5762, big5_chars_ban546}, 
    {0x5764, 0x5764, big5_chars_ban547}, 
    {0x5766, 0x5766, big5_chars_ban548}, 
    {0x5768, 0x576B, big5_chars_ban549}, 
    {0x576D, 0x576D, big5_chars_ban550}, 
    {0x576F, 0x5777, big5_chars_ban551}, 
    {0x577B, 0x577D, big5_chars_ban552}, 
    {0x5780, 0x5780, big5_chars_ban553}, 
    {0x5782, 0x5783, big5_chars_ban554}, 
    {0x578B, 0x578C, big5_chars_ban555}, 
    {0x578F, 0x578F, big5_chars_ban556}, 
    {0x5793, 0x5795, big5_chars_ban557}, 
    {0x5797, 0x579B, big5_chars_ban558}, 
    {0x579D, 0x57A0, big5_chars_ban559}, 
    {0x57A2, 0x57A5, big5_chars_ban560}, 
    {0x57AE, 0x57AE, big5_chars_ban561}, 
    {0x57B5, 0x57B6, big5_chars_ban562}, 
    {0x57B8, 0x57BA, big5_chars_ban563}, 
    {0x57BC, 0x57BD, big5_chars_ban564}, 
    {0x57BF, 0x57BF, big5_chars_ban565}, 
    {0x57C1, 0x57C3, big5_chars_ban566}, 
    {0x57C6, 0x57C7, big5_chars_ban567}, 
    {0x57CB, 0x57CC, big5_chars_ban568}, 
    {0x57CE, 0x57D0, big5_chars_ban569}, 
    {0x57D2, 0x57D2, big5_chars_ban570}, 
    {0x57D4, 0x57D5, big5_chars_ban571}, 
    {0x57DC, 0x57DC, big5_chars_ban572}, 
    {0x57DF, 0x57E5, big5_chars_ban573}, 
    {0x57E7, 0x57E7, big5_chars_ban574}, 
    {0x57E9, 0x57E9, big5_chars_ban575}, 
    {0x57EC, 0x57EE, big5_chars_ban576}, 
    {0x57F0, 0x57FD, big5_chars_ban577}, 
    {0x5800, 0x5802, big5_chars_ban578}, 
    {0x5804, 0x580E, big5_chars_ban579}, 
    {0x5810, 0x5810, big5_chars_ban580}, 
    {0x5814, 0x5814, big5_chars_ban581}, 
    {0x5819, 0x5819, big5_chars_ban582}, 
    {0x581B, 0x581E, big5_chars_ban583}, 
    {0x5820, 0x5821, big5_chars_ban584}, 
    {0x5823, 0x5825, big5_chars_ban585}, 
    {0x5827, 0x582A, big5_chars_ban586}, 
    {0x582C, 0x5839, big5_chars_ban587}, 
    {0x583B, 0x583B, big5_chars_ban588}, 
    {0x583D, 0x583D, big5_chars_ban589}, 
    {0x583F, 0x583F, big5_chars_ban590}, 
    {0x5848, 0x584F, big5_chars_ban591}, 
    {0x5851, 0x5855, big5_chars_ban592}, 
    {0x5857, 0x585B, big5_chars_ban593}, 
    {0x585D, 0x585E, big5_chars_ban594}, 
    {0x5862, 0x5865, big5_chars_ban595}, 
    {0x5868, 0x5868, big5_chars_ban596}, 
    {0x586B, 0x586B, big5_chars_ban597}, 
    {0x586D, 0x586D, big5_chars_ban598}, 
    {0x586F, 0x586F, big5_chars_ban599}, 
    {0x5871, 0x5871, big5_chars_ban600}, 
    {0x5874, 0x5876, big5_chars_ban601}, 
    {0x5879, 0x5883, big5_chars_ban602}, 
    {0x5885, 0x588B, big5_chars_ban603}, 
    {0x588E, 0x5891, big5_chars_ban604}, 
    {0x5893, 0x5894, big5_chars_ban605}, 
    {0x5898, 0x5898, big5_chars_ban606}, 
    {0x589C, 0x58A1, big5_chars_ban607}, 
    {0x58A3, 0x58A3, big5_chars_ban608}, 
    {0x58A5, 0x58A6, big5_chars_ban609}, 
    {0x58A8, 0x58A9, big5_chars_ban610}, 
    {0x58AB, 0x58AC, big5_chars_ban611}, 
    {0x58AE, 0x58AF, big5_chars_ban612}, 
    {0x58B1, 0x58B1, big5_chars_ban613}, 
    {0x58B3, 0x58B3, big5_chars_ban614}, 
    {0x58BA, 0x58BF, big5_chars_ban615}, 
    {0x58C1, 0x58C2, big5_chars_ban616}, 
    {0x58C5, 0x58C9, big5_chars_ban617}, 
    {0x58CE, 0x58CF, big5_chars_ban618}, 
    {0x58D1, 0x58D6, big5_chars_ban619}, 
    {0x58D8, 0x58DB, big5_chars_ban620}, 
    {0x58DD, 0x58DF, big5_chars_ban621}, 
    {0x58E2, 0x58E4, big5_chars_ban622}, 
    {0x58E7, 0x58E9, big5_chars_ban623}, 
    {0x58EB, 0x58EC, big5_chars_ban624}, 
    {0x58EF, 0x58EF, big5_chars_ban625}, 
    {0x58F4, 0x58F4, big5_chars_ban626}, 
    {0x58F9, 0x58FA, big5_chars_ban627}, 
    {0x58FC, 0x58FF, big5_chars_ban628}, 
    {0x5903, 0x5903, big5_chars_ban629}, 
    {0x5906, 0x5906, big5_chars_ban630}, 
    {0x590C, 0x590F, big5_chars_ban631}, 
    {0x5912, 0x5912, big5_chars_ban632}, 
    {0x5914, 0x5917, big5_chars_ban633}, 
    {0x5919, 0x591A, big5_chars_ban634}, 
    {0x591C, 0x591C, big5_chars_ban635}, 
    {0x5920, 0x5920, big5_chars_ban636}, 
    {0x5922, 0x5922, big5_chars_ban637}, 
    {0x5924, 0x5925, big5_chars_ban638}, 
    {0x5927, 0x5927, big5_chars_ban639}, 
    {0x5929, 0x592F, big5_chars_ban640}, 
    {0x5931, 0x5931, big5_chars_ban641}, 
    {0x5937, 0x5938, big5_chars_ban642}, 
    {0x593C, 0x593C, big5_chars_ban643}, 
    {0x593E, 0x593E, big5_chars_ban644}, 
    {0x5940, 0x5940, big5_chars_ban645}, 
    {0x5944, 0x5945, big5_chars_ban646}, 
    {0x5947, 0x594A, big5_chars_ban647}, 
    {0x594E, 0x5951, big5_chars_ban648}, 
    {0x5953, 0x5955, big5_chars_ban649}, 
    {0x5957, 0x5958, big5_chars_ban650}, 
    {0x595A, 0x595A, big5_chars_ban651}, 
    {0x595C, 0x595C, big5_chars_ban652}, 
    {0x5960, 0x5962, big5_chars_ban653}, 
    {0x5967, 0x5967, big5_chars_ban654}, 
    {0x5969, 0x596B, big5_chars_ban655}, 
    {0x596D, 0x596E, big5_chars_ban656}, 
    {0x5970, 0x5974, big5_chars_ban657}, 
    {0x5976, 0x5979, big5_chars_ban658}, 
    {0x597B, 0x5985, big5_chars_ban659}, 
    {0x598A, 0x598A, big5_chars_ban660}, 
    {0x598D, 0x5990, big5_chars_ban661}, 
    {0x5992, 0x5993, big5_chars_ban662}, 
    {0x5996, 0x5999, big5_chars_ban663}, 
    {0x599D, 0x599E, big5_chars_ban664}, 
    {0x59A0, 0x59A8, big5_chars_ban665}, 
    {0x59AE, 0x59AF, big5_chars_ban666}, 
    {0x59B1, 0x59B6, big5_chars_ban667}, 
    {0x59B9, 0x59BE, big5_chars_ban668}, 
    {0x59C0, 0x59C1, big5_chars_ban669}, 
    {0x59C3, 0x59C3, big5_chars_ban670}, 
    {0x59C5, 0x59C8, big5_chars_ban671}, 
    {0x59CA, 0x59D4, big5_chars_ban672}, 
    {0x59D6, 0x59D6, big5_chars_ban673}, 
    {0x59D8, 0x59D8, big5_chars_ban674}, 
    {0x59DA, 0x59DE, big5_chars_ban675}, 
    {0x59E0, 0x59E1, big5_chars_ban676}, 
    {0x59E3, 0x59E6, big5_chars_ban677}, 
    {0x59E8, 0x59EA, big5_chars_ban678}, 
    {0x59EC, 0x59EE, big5_chars_ban679}, 
    {0x59F1, 0x59F7, big5_chars_ban680}, 
    {0x59FA, 0x5A01, big5_chars_ban681}, 
    {0x5A03, 0x5A03, big5_chars_ban682}, 
    {0x5A09, 0x5A0A, big5_chars_ban683}, 
    {0x5A0C, 0x5A0C, big5_chars_ban684}, 
    {0x5A0F, 0x5A0F, big5_chars_ban685}, 
    {0x5A11, 0x5A11, big5_chars_ban686}, 
    {0x5A13, 0x5A13, big5_chars_ban687}, 
    {0x5A15, 0x5A19, big5_chars_ban688}, 
    {0x5A1B, 0x5A1C, big5_chars_ban689}, 
    {0x5A1E, 0x5A20, big5_chars_ban690}, 
    {0x5A23, 0x5A23, big5_chars_ban691}, 
    {0x5A25, 0x5A25, big5_chars_ban692}, 
    {0x5A29, 0x5A29, big5_chars_ban693}, 
    {0x5A2D, 0x5A2E, big5_chars_ban694}, 
    {0x5A33, 0x5A33, big5_chars_ban695}, 
    {0x5A35, 0x5A39, big5_chars_ban696}, 
    {0x5A3C, 0x5A3C, big5_chars_ban697}, 
    {0x5A3E, 0x5A3E, big5_chars_ban698}, 
    {0x5A40, 0x5A44, big5_chars_ban699}, 
    {0x5A46, 0x5A4A, big5_chars_ban700}, 
    {0x5A4C, 0x5A4D, big5_chars_ban701}, 
    {0x5A50, 0x5A53, big5_chars_ban702}, 
    {0x5A55, 0x5A58, big5_chars_ban703}, 
    {0x5A5A, 0x5A60, big5_chars_ban704}, 
    {0x5A62, 0x5A62, big5_chars_ban705}, 
    {0x5A64, 0x5A67, big5_chars_ban706}, 
    {0x5A69, 0x5A6A, big5_chars_ban707}, 
    {0x5A6C, 0x5A6D, big5_chars_ban708}, 
    {0x5A70, 0x5A70, big5_chars_ban709}, 
    {0x5A77, 0x5A78, big5_chars_ban710}, 
    {0x5A7A, 0x5A7D, big5_chars_ban711}, 
    {0x5A7F, 0x5A7F, big5_chars_ban712}, 
    {0x5A83, 0x5A84, big5_chars_ban713}, 
    {0x5A8A, 0x5A8C, big5_chars_ban714}, 
    {0x5A8E, 0x5A90, big5_chars_ban715}, 
    {0x5A92, 0x5A95, big5_chars_ban716}, 
    {0x5A97, 0x5A97, big5_chars_ban717}, 
    {0x5A9A, 0x5A9F, big5_chars_ban718}, 
    {0x5AA2, 0x5AA2, big5_chars_ban719}, 
    {0x5AA5, 0x5AA7, big5_chars_ban720}, 
    {0x5AA9, 0x5AA9, big5_chars_ban721}, 
    {0x5AAC, 0x5AAC, big5_chars_ban722}, 
    {0x5AAE, 0x5AC2, big5_chars_ban723}, 
    {0x5AC4, 0x5AC4, big5_chars_ban724}, 
    {0x5AC6, 0x5ACD, big5_chars_ban725}, 
    {0x5AD5, 0x5AE3, big5_chars_ban726}, 
    {0x5AE5, 0x5AE6, big5_chars_ban727}, 
    {0x5AE8, 0x5AEE, big5_chars_ban728}, 
    {0x5AF3, 0x5AFB, big5_chars_ban729}, 
    {0x5AFD, 0x5AFD, big5_chars_ban730}, 
    {0x5AFF, 0x5AFF, big5_chars_ban731}, 
    {0x5B01, 0x5B03, big5_chars_ban732}, 
    {0x5B05, 0x5B05, big5_chars_ban733}, 
    {0x5B07, 0x5B09, big5_chars_ban734}, 
    {0x5B0B, 0x5B0C, big5_chars_ban735}, 
    {0x5B0F, 0x5B10, big5_chars_ban736}, 
    {0x5B13, 0x5B14, big5_chars_ban737}, 
    {0x5B16, 0x5B17, big5_chars_ban738}, 
    {0x5B19, 0x5B1B, big5_chars_ban739}, 
    {0x5B1D, 0x5B1E, big5_chars_ban740}, 
    {0x5B20, 0x5B21, big5_chars_ban741}, 
    {0x5B23, 0x5B28, big5_chars_ban742}, 
    {0x5B2A, 0x5B2A, big5_chars_ban743}, 
    {0x5B2C, 0x5B30, big5_chars_ban744}, 
    {0x5B32, 0x5B32, big5_chars_ban745}, 
    {0x5B34, 0x5B34, big5_chars_ban746}, 
    {0x5B38, 0x5B38, big5_chars_ban747}, 
    {0x5B3C, 0x5B40, big5_chars_ban748}, 
    {0x5B43, 0x5B43, big5_chars_ban749}, 
    {0x5B45, 0x5B45, big5_chars_ban750}, 
    {0x5B47, 0x5B48, big5_chars_ban751}, 
    {0x5B4B, 0x5B4E, big5_chars_ban752}, 
    {0x5B50, 0x5B51, big5_chars_ban753}, 
    {0x5B53, 0x5B58, big5_chars_ban754}, 
    {0x5B5A, 0x5B5D, big5_chars_ban755}, 
    {0x5B5F, 0x5B5F, big5_chars_ban756}, 
    {0x5B62, 0x5B65, big5_chars_ban757}, 
    {0x5B69, 0x5B69, big5_chars_ban758}, 
    {0x5B6B, 0x5B6C, big5_chars_ban759}, 
    {0x5B6E, 0x5B6E, big5_chars_ban760}, 
    {0x5B70, 0x5B73, big5_chars_ban761}, 
    {0x5B75, 0x5B75, big5_chars_ban762}, 
    {0x5B77, 0x5B78, big5_chars_ban763}, 
    {0x5B7A, 0x5B7B, big5_chars_ban764}, 
    {0x5B7D, 0x5B7D, big5_chars_ban765}, 
    {0x5B7F, 0x5B7F, big5_chars_ban766}, 
    {0x5B81, 0x5B81, big5_chars_ban767}, 
    {0x5B83, 0x5B85, big5_chars_ban768}, 
    {0x5B87, 0x5B89, big5_chars_ban769}, 
    {0x5B8B, 0x5B8C, big5_chars_ban770}, 
    {0x5B8E, 0x5B8F, big5_chars_ban771}, 
    {0x5B92, 0x5B93, big5_chars_ban772}, 
    {0x5B95, 0x5B95, big5_chars_ban773}, 
    {0x5B97, 0x5B9C, big5_chars_ban774}, 
    {0x5BA2, 0x5BA8, big5_chars_ban775}, 
    {0x5BAC, 0x5BAE, big5_chars_ban776}, 
    {0x5BB0, 0x5BB0, big5_chars_ban777}, 
    {0x5BB3, 0x5BB6, big5_chars_ban778}, 
    {0x5BB8, 0x5BB9, big5_chars_ban779}, 
    {0x5BBF, 0x5BC2, big5_chars_ban780}, 
    {0x5BC4, 0x5BC7, big5_chars_ban781}, 
    {0x5BCA, 0x5BCE, big5_chars_ban782}, 
    {0x5BD0, 0x5BD4, big5_chars_ban783}, 
    {0x5BD6, 0x5BD6, big5_chars_ban784}, 
    {0x5BD8, 0x5BD9, big5_chars_ban785}, 
    {0x5BDE, 0x5BEC, big5_chars_ban786}, 
    {0x5BEE, 0x5BF2, big5_chars_ban787}, 
    {0x5BF5, 0x5BF6, big5_chars_ban788}, 
    {0x5BF8, 0x5BF8, big5_chars_ban789}, 
    {0x5BFA, 0x5BFA, big5_chars_ban790}, 
    {0x5C01, 0x5C01, big5_chars_ban791}, 
    {0x5C03, 0x5C04, big5_chars_ban792}, 
    {0x5C07, 0x5C12, big5_chars_ban793}, 
    {0x5C15, 0x5C16, big5_chars_ban794}, 
    {0x5C1A, 0x5C1A, big5_chars_ban795}, 
    {0x5C1F, 0x5C1F, big5_chars_ban796}, 
    {0x5C22, 0x5C22, big5_chars_ban797}, 
    {0x5C24, 0x5C25, big5_chars_ban798}, 
    {0x5C28, 0x5C28, big5_chars_ban799}, 
    {0x5C2A, 0x5C2A, big5_chars_ban800}, 
    {0x5C2C, 0x5C2C, big5_chars_ban801}, 
    {0x5C30, 0x5C31, big5_chars_ban802}, 
    {0x5C33, 0x5C33, big5_chars_ban803}, 
    {0x5C37, 0x5C3C, big5_chars_ban804}, 
    {0x5C3E, 0x5C41, big5_chars_ban805}, 
    {0x5C44, 0x5C48, big5_chars_ban806}, 
    {0x5C4B, 0x5C51, big5_chars_ban807}, 
    {0x5C54, 0x5C56, big5_chars_ban808}, 
    {0x5C58, 0x5C59, big5_chars_ban809}, 
    {0x5C5C, 0x5C5D, big5_chars_ban810}, 
    {0x5C60, 0x5C60, big5_chars_ban811}, 
    {0x5C62, 0x5C65, big5_chars_ban812}, 
    {0x5C67, 0x5C6A, big5_chars_ban813}, 
    {0x5C6C, 0x5C6F, big5_chars_ban814}, 
    {0x5C71, 0x5C71, big5_chars_ban815}, 
    {0x5C73, 0x5C74, big5_chars_ban816}, 
    {0x5C79, 0x5C7C, big5_chars_ban817}, 
    {0x5C7E, 0x5C7E, big5_chars_ban818}, 
    {0x5C86, 0x5C86, big5_chars_ban819}, 
    {0x5C88, 0x5C8D, big5_chars_ban820}, 
    {0x5C8F, 0x5C95, big5_chars_ban821}, 
    {0x5C9D, 0x5C9D, big5_chars_ban822}, 
    {0x5C9F, 0x5CB1, big5_chars_ban823}, 
    {0x5CB3, 0x5CB3, big5_chars_ban824}, 
    {0x5CB5, 0x5CB8, big5_chars_ban825}, 
    {0x5CC6, 0x5CCC, big5_chars_ban826}, 
    {0x5CCE, 0x5CD0, big5_chars_ban827}, 
    {0x5CD2, 0x5CD4, big5_chars_ban828}, 
    {0x5CD6, 0x5CDB, big5_chars_ban829}, 
    {0x5CDE, 0x5CDF, big5_chars_ban830}, 
    {0x5CE8, 0x5CE8, big5_chars_ban831}, 
    {0x5CEA, 0x5CEA, big5_chars_ban832}, 
    {0x5CEC, 0x5CEE, big5_chars_ban833}, 
    {0x5CF0, 0x5CF1, big5_chars_ban834}, 
    {0x5CF4, 0x5CF4, big5_chars_ban835}, 
    {0x5CF6, 0x5CF9, big5_chars_ban836}, 
    {0x5CFB, 0x5CFB, big5_chars_ban837}, 
    {0x5CFD, 0x5CFD, big5_chars_ban838}, 
    {0x5CFF, 0x5D01, big5_chars_ban839}, 
    {0x5D06, 0x5D07, big5_chars_ban840}, 
    {0x5D0B, 0x5D0F, big5_chars_ban841}, 
    {0x5D11, 0x5D12, big5_chars_ban842}, 
    {0x5D14, 0x5D14, big5_chars_ban843}, 
    {0x5D16, 0x5D17, big5_chars_ban844}, 
    {0x5D19, 0x5D1B, big5_chars_ban845}, 
    {0x5D1D, 0x5D20, big5_chars_ban846}, 
    {0x5D22, 0x5D29, big5_chars_ban847}, 
    {0x5D2E, 0x5D2E, big5_chars_ban848}, 
    {0x5D30, 0x5D3A, big5_chars_ban849}, 
    {0x5D3C, 0x5D3D, big5_chars_ban850}, 
    {0x5D3F, 0x5D43, big5_chars_ban851}, 
    {0x5D45, 0x5D45, big5_chars_ban852}, 
    {0x5D47, 0x5D47, big5_chars_ban853}, 
    {0x5D49, 0x5D4C, big5_chars_ban854}, 
    {0x5D4E, 0x5D4E, big5_chars_ban855}, 
    {0x5D50, 0x5D52, big5_chars_ban856}, 
    {0x5D55, 0x5D55, big5_chars_ban857}, 
    {0x5D59, 0x5D59, big5_chars_ban858}, 
    {0x5D5E, 0x5D5E, big5_chars_ban859}, 
    {0x5D62, 0x5D63, big5_chars_ban860}, 
    {0x5D65, 0x5D65, big5_chars_ban861}, 
    {0x5D67, 0x5D69, big5_chars_ban862}, 
    {0x5D6B, 0x5D6C, big5_chars_ban863}, 
    {0x5D6F, 0x5D6F, big5_chars_ban864}, 
    {0x5D71, 0x5D72, big5_chars_ban865}, 
    {0x5D77, 0x5D77, big5_chars_ban866}, 
    {0x5D79, 0x5D7A, big5_chars_ban867}, 
    {0x5D7C, 0x5D82, big5_chars_ban868}, 
    {0x5D84, 0x5D84, big5_chars_ban869}, 
    {0x5D86, 0x5D8A, big5_chars_ban870}, 
    {0x5D8D, 0x5D8D, big5_chars_ban871}, 
    {0x5D92, 0x5D95, big5_chars_ban872}, 
    {0x5D97, 0x5D97, big5_chars_ban873}, 
    {0x5D99, 0x5D9A, big5_chars_ban874}, 
    {0x5D9C, 0x5DA2, big5_chars_ban875}, 
    {0x5DA7, 0x5DAA, big5_chars_ban876}, 
    {0x5DAC, 0x5DB2, big5_chars_ban877}, 
    {0x5DB4, 0x5DB5, big5_chars_ban878}, 
    {0x5DB7, 0x5DB8, big5_chars_ban879}, 
    {0x5DBA, 0x5DBA, big5_chars_ban880}, 
    {0x5DBC, 0x5DBD, big5_chars_ban881}, 
    {0x5DC0, 0x5DC0, big5_chars_ban882}, 
    {0x5DC2, 0x5DC3, big5_chars_ban883}, 
    {0x5DC6, 0x5DC7, big5_chars_ban884}, 
    {0x5DC9, 0x5DC9, big5_chars_ban885}, 
    {0x5DCB, 0x5DCB, big5_chars_ban886}, 
    {0x5DCD, 0x5DCD, big5_chars_ban887}, 
    {0x5DCF, 0x5DCF, big5_chars_ban888}, 
    {0x5DD1, 0x5DD2, big5_chars_ban889}, 
    {0x5DD4, 0x5DD6, big5_chars_ban890}, 
    {0x5DD8, 0x5DD8, big5_chars_ban891}, 
    {0x5DDD, 0x5DE2, big5_chars_ban892}, 
    {0x5DE5, 0x5DE8, big5_chars_ban893}, 
    {0x5DEB, 0x5DEB, big5_chars_ban894}, 
    {0x5DEE, 0x5DEE, big5_chars_ban895}, 
    {0x5DF0, 0x5DF4, big5_chars_ban896}, 
    {0x5DF7, 0x5DF7, big5_chars_ban897}, 
    {0x5DF9, 0x5DF9, big5_chars_ban898}, 
    {0x5DFD, 0x5DFF, big5_chars_ban899}, 
    {0x5E02, 0x5E04, big5_chars_ban900}, 
    {0x5E06, 0x5E06, big5_chars_ban901}, 
    {0x5E0A, 0x5E0A, big5_chars_ban902}, 
    {0x5E0C, 0x5E0C, big5_chars_ban903}, 
    {0x5E0E, 0x5E0E, big5_chars_ban904}, 
    {0x5E11, 0x5E11, big5_chars_ban905}, 
    {0x5E14, 0x5E1B, big5_chars_ban906}, 
    {0x5E1D, 0x5E1D, big5_chars_ban907}, 
    {0x5E1F, 0x5E25, big5_chars_ban908}, 
    {0x5E28, 0x5E29, big5_chars_ban909}, 
    {0x5E2B, 0x5E2B, big5_chars_ban910}, 
    {0x5E2D, 0x5E2D, big5_chars_ban911}, 
    {0x5E33, 0x5E34, big5_chars_ban912}, 
    {0x5E36, 0x5E38, big5_chars_ban913}, 
    {0x5E3D, 0x5E3E, big5_chars_ban914}, 
    {0x5E40, 0x5E41, big5_chars_ban915}, 
    {0x5E43, 0x5E45, big5_chars_ban916}, 
    {0x5E4A, 0x5E4F, big5_chars_ban917}, 
    {0x5E53, 0x5E55, big5_chars_ban918}, 
    {0x5E57, 0x5E59, big5_chars_ban919}, 
    {0x5E5B, 0x5E5D, big5_chars_ban920}, 
    {0x5E5F, 0x5E63, big5_chars_ban921}, 
    {0x5E66, 0x5E70, big5_chars_ban922}, 
    {0x5E72, 0x5E76, big5_chars_ban923}, 
    {0x5E78, 0x5E79, big5_chars_ban924}, 
    {0x5E7B, 0x5E7E, big5_chars_ban925}, 
    {0x5E80, 0x5E80, big5_chars_ban926}, 
    {0x5E82, 0x5E82, big5_chars_ban927}, 
    {0x5E84, 0x5E84, big5_chars_ban928}, 
    {0x5E87, 0x5E8D, big5_chars_ban929}, 
    {0x5E8F, 0x5E8F, big5_chars_ban930}, 
    {0x5E95, 0x5E97, big5_chars_ban931}, 
    {0x5E9A, 0x5E9C, big5_chars_ban932}, 
    {0x5EA0, 0x5EA0, big5_chars_ban933}, 
    {0x5EA2, 0x5EA8, big5_chars_ban934}, 
    {0x5EAA, 0x5EAE, big5_chars_ban935}, 
    {0x5EB0, 0x5EB9, big5_chars_ban936}, 
    {0x5EBE, 0x5EBE, big5_chars_ban937}, 
    {0x5EC1, 0x5EC2, big5_chars_ban938}, 
    {0x5EC4, 0x5ECC, big5_chars_ban939}, 
    {0x5ECE, 0x5ECE, big5_chars_ban940}, 
    {0x5ED1, 0x5EE3, big5_chars_ban941}, 
    {0x5EE5, 0x5EE9, big5_chars_ban942}, 
    {0x5EEC, 0x5EEC, big5_chars_ban943}, 
    {0x5EEE, 0x5EEF, big5_chars_ban944}, 
    {0x5EF1, 0x5EF3, big5_chars_ban945}, 
    {0x5EF6, 0x5EF7, big5_chars_ban946}, 
    {0x5EFA, 0x5EFA, big5_chars_ban947}, 
    {0x5EFE, 0x5EFF, big5_chars_ban948}, 
    {0x5F01, 0x5F02, big5_chars_ban949}, 
    {0x5F04, 0x5F05, big5_chars_ban950}, 
    {0x5F07, 0x5F08, big5_chars_ban951}, 
    {0x5F0A, 0x5F0B, big5_chars_ban952}, 
    {0x5F0F, 0x5F0F, big5_chars_ban953}, 
    {0x5F12, 0x5F15, big5_chars_ban954}, 
    {0x5F17, 0x5F18, big5_chars_ban955}, 
    {0x5F1A, 0x5F1B, big5_chars_ban956}, 
    {0x5F1D, 0x5F1D, big5_chars_ban957}, 
    {0x5F1F, 0x5F1F, big5_chars_ban958}, 
    {0x5F22, 0x5F24, big5_chars_ban959}, 
    {0x5F26, 0x5F29, big5_chars_ban960}, 
    {0x5F2D, 0x5F2E, big5_chars_ban961}, 
    {0x5F30, 0x5F31, big5_chars_ban962}, 
    {0x5F33, 0x5F33, big5_chars_ban963}, 
    {0x5F35, 0x5F38, big5_chars_ban964}, 
    {0x5F3C, 0x5F3C, big5_chars_ban965}, 
    {0x5F40, 0x5F40, big5_chars_ban966}, 
    {0x5F43, 0x5F44, big5_chars_ban967}, 
    {0x5F46, 0x5F46, big5_chars_ban968}, 
    {0x5F48, 0x5F4C, big5_chars_ban969}, 
    {0x5F4E, 0x5F4F, big5_chars_ban970}, 
    {0x5F54, 0x5F54, big5_chars_ban971}, 
    {0x5F56, 0x5F59, big5_chars_ban972}, 
    {0x5F5D, 0x5F5D, big5_chars_ban973}, 
    {0x5F62, 0x5F62, big5_chars_ban974}, 
    {0x5F64, 0x5F65, big5_chars_ban975}, 
    {0x5F67, 0x5F67, big5_chars_ban976}, 
    {0x5F69, 0x5F6D, big5_chars_ban977}, 
    {0x5F6F, 0x5F71, big5_chars_ban978}, 
    {0x5F73, 0x5F74, big5_chars_ban979}, 
    {0x5F76, 0x5F79, big5_chars_ban980}, 
    {0x5F7C, 0x5F82, big5_chars_ban981}, 
    {0x5F85, 0x5F8C, big5_chars_ban982}, 
    {0x5F90, 0x5F92, big5_chars_ban983}, 
    {0x5F96, 0x5F99, big5_chars_ban984}, 
    {0x5F9B, 0x5F9C, big5_chars_ban985}, 
    {0x5F9E, 0x5FA1, big5_chars_ban986}, 
    {0x5FA5, 0x5FA6, big5_chars_ban987}, 
    {0x5FA8, 0x5FAF, big5_chars_ban988}, 
    {0x5FB2, 0x5FB2, big5_chars_ban989}, 
    {0x5FB5, 0x5FB7, big5_chars_ban990}, 
    {0x5FB9, 0x5FB9, big5_chars_ban991}, 
    {0x5FBB, 0x5FC1, big5_chars_ban992}, 
    {0x5FC3, 0x5FC3, big5_chars_ban993}, 
    {0x5FC5, 0x5FC5, big5_chars_ban994}, 
    {0x5FC9, 0x5FC9, big5_chars_ban995}, 
    {0x5FCC, 0x5FCD, big5_chars_ban996}, 
    {0x5FCF, 0x5FD2, big5_chars_ban997}, 
    {0x5FD4, 0x5FD9, big5_chars_ban998}, 
    {0x5FDD, 0x5FDE, big5_chars_ban999}, 
    {0x5FE0, 0x5FE1, big5_chars_ban1000}, 
    {0x5FE3, 0x5FE5, big5_chars_ban1001}, 
    {0x5FE8, 0x5FE8, big5_chars_ban1002}, 
    {0x5FEA, 0x5FEB, big5_chars_ban1003}, 
    {0x5FED, 0x5FEF, big5_chars_ban1004}, 
    {0x5FF1, 0x5FF1, big5_chars_ban1005}, 
    {0x5FF3, 0x5FF5, big5_chars_ban1006}, 
    {0x5FF7, 0x5FF8, big5_chars_ban1007}, 
    {0x5FFA, 0x5FFB, big5_chars_ban1008}, 
    {0x5FFD, 0x5FFD, big5_chars_ban1009}, 
    {0x5FFF, 0x6000, big5_chars_ban1010}, 
    {0x6009, 0x6017, big5_chars_ban1011}, 
    {0x6019, 0x601E, big5_chars_ban1012}, 
    {0x6020, 0x6022, big5_chars_ban1013}, 
    {0x6024, 0x602F, big5_chars_ban1014}, 
    {0x6032, 0x6035, big5_chars_ban1015}, 
    {0x6037, 0x6037, big5_chars_ban1016}, 
    {0x6039, 0x6039, big5_chars_ban1017}, 
    {0x6040, 0x6047, big5_chars_ban1018}, 
    {0x6049, 0x6049, big5_chars_ban1019}, 
    {0x604C, 0x604D, big5_chars_ban1020}, 
    {0x6050, 0x6050, big5_chars_ban1021}, 
    {0x6052, 0x6055, big5_chars_ban1022}, 
    {0x6058, 0x605B, big5_chars_ban1023}, 
    {0x605D, 0x605F, big5_chars_ban1024}, 
    {0x6062, 0x6070, big5_chars_ban1025}, 
    {0x6072, 0x6072, big5_chars_ban1026}, 
    {0x607F, 0x6081, big5_chars_ban1027}, 
    {0x6083, 0x608A, big5_chars_ban1028}, 
    {0x608C, 0x608E, big5_chars_ban1029}, 
    {0x6090, 0x6090, big5_chars_ban1030}, 
    {0x6092, 0x6092, big5_chars_ban1031}, 
    {0x6094, 0x6097, big5_chars_ban1032}, 
    {0x609A, 0x609D, big5_chars_ban1033}, 
    {0x609F, 0x60A0, big5_chars_ban1034}, 
    {0x60A2, 0x60A3, big5_chars_ban1035}, 
    {0x60A8, 0x60A8, big5_chars_ban1036}, 
    {0x60B0, 0x60B2, big5_chars_ban1037}, 
    {0x60B4, 0x60C1, big5_chars_ban1038}, 
    {0x60C3, 0x60CF, big5_chars_ban1039}, 
    {0x60D1, 0x60D1, big5_chars_ban1040}, 
    {0x60D3, 0x60D5, big5_chars_ban1041}, 
    {0x60D8, 0x60DD, big5_chars_ban1042}, 
    {0x60DF, 0x60E2, big5_chars_ban1043}, 
    {0x60E4, 0x60E4, big5_chars_ban1044}, 
    {0x60E6, 0x60E6, big5_chars_ban1045}, 
    {0x60F0, 0x60FC, big5_chars_ban1046}, 
    {0x60FE, 0x6101, big5_chars_ban1047}, 
    {0x6103, 0x6106, big5_chars_ban1048}, 
    {0x6108, 0x610B, big5_chars_ban1049}, 
    {0x610D, 0x6110, big5_chars_ban1050}, 
    {0x6112, 0x6116, big5_chars_ban1051}, 
    {0x6118, 0x6118, big5_chars_ban1052}, 
    {0x611A, 0x611D, big5_chars_ban1053}, 
    {0x611F, 0x611F, big5_chars_ban1054}, 
    {0x6123, 0x6123, big5_chars_ban1055}, 
    {0x6127, 0x6129, big5_chars_ban1056}, 
    {0x612B, 0x612C, big5_chars_ban1057}, 
    {0x612E, 0x612F, big5_chars_ban1058}, 
    {0x6132, 0x6132, big5_chars_ban1059}, 
    {0x6134, 0x6134, big5_chars_ban1060}, 
    {0x6136, 0x6137, big5_chars_ban1061}, 
    {0x613B, 0x613B, big5_chars_ban1062}, 
    {0x613E, 0x6141, big5_chars_ban1063}, 
    {0x6144, 0x614F, big5_chars_ban1064}, 
    {0x6152, 0x6156, big5_chars_ban1065}, 
    {0x6158, 0x6158, big5_chars_ban1066}, 
    {0x615A, 0x615B, big5_chars_ban1067}, 
    {0x615D, 0x615F, big5_chars_ban1068}, 
    {0x6161, 0x6163, big5_chars_ban1069}, 
    {0x6165, 0x6168, big5_chars_ban1070}, 
    {0x616A, 0x616C, big5_chars_ban1071}, 
    {0x616E, 0x616E, big5_chars_ban1072}, 
    {0x6170, 0x6177, big5_chars_ban1073}, 
    {0x6179, 0x617A, big5_chars_ban1074}, 
    {0x617C, 0x617C, big5_chars_ban1075}, 
    {0x617E, 0x617E, big5_chars_ban1076}, 
    {0x6180, 0x6180, big5_chars_ban1077}, 
    {0x6182, 0x6183, big5_chars_ban1078}, 
    {0x6189, 0x618E, big5_chars_ban1079}, 
    {0x6190, 0x6194, big5_chars_ban1080}, 
    {0x6196, 0x6196, big5_chars_ban1081}, 
    {0x619A, 0x619B, big5_chars_ban1082}, 
    {0x619D, 0x619D, big5_chars_ban1083}, 
    {0x619F, 0x619F, big5_chars_ban1084}, 
    {0x61A1, 0x61A2, big5_chars_ban1085}, 
    {0x61A4, 0x61A4, big5_chars_ban1086}, 
    {0x61A7, 0x61B6, big5_chars_ban1087}, 
    {0x61B8, 0x61B8, big5_chars_ban1088}, 
    {0x61BA, 0x61BA, big5_chars_ban1089}, 
    {0x61BC, 0x61BC, big5_chars_ban1090}, 
    {0x61BE, 0x61BF, big5_chars_ban1091}, 
    {0x61C1, 0x61C3, big5_chars_ban1092}, 
    {0x61C5, 0x61CD, big5_chars_ban1093}, 
    {0x61D6, 0x61D6, big5_chars_ban1094}, 
    {0x61D8, 0x61D8, big5_chars_ban1095}, 
    {0x61DE, 0x61E0, big5_chars_ban1096}, 
    {0x61E3, 0x61EB, big5_chars_ban1097}, 
    {0x61ED, 0x61EE, big5_chars_ban1098}, 
    {0x61F0, 0x61F2, big5_chars_ban1099}, 
    {0x61F5, 0x6201, big5_chars_ban1100}, 
    {0x6203, 0x6204, big5_chars_ban1101}, 
    {0x6207, 0x620A, big5_chars_ban1102}, 
    {0x620C, 0x620E, big5_chars_ban1103}, 
    {0x6210, 0x6212, big5_chars_ban1104}, 
    {0x6214, 0x6216, big5_chars_ban1105}, 
    {0x6219, 0x621B, big5_chars_ban1106}, 
    {0x621F, 0x6225, big5_chars_ban1107}, 
    {0x6227, 0x6227, big5_chars_ban1108}, 
    {0x6229, 0x622B, big5_chars_ban1109}, 
    {0x622D, 0x622E, big5_chars_ban1110}, 
    {0x6230, 0x6230, big5_chars_ban1111}, 
    {0x6232, 0x6234, big5_chars_ban1112}, 
    {0x6236, 0x6236, big5_chars_ban1113}, 
    {0x623A, 0x623A, big5_chars_ban1114}, 
    {0x623D, 0x6243, big5_chars_ban1115}, 
    {0x6246, 0x624B, big5_chars_ban1116}, 
    {0x624D, 0x624E, big5_chars_ban1117}, 
    {0x6250, 0x6254, big5_chars_ban1118}, 
    {0x6258, 0x625C, big5_chars_ban1119}, 
    {0x625E, 0x625E, big5_chars_ban1120}, 
    {0x6260, 0x6266, big5_chars_ban1121}, 
    {0x626D, 0x6274, big5_chars_ban1122}, 
    {0x6276, 0x6277, big5_chars_ban1123}, 
    {0x6279, 0x6281, big5_chars_ban1124}, 
    {0x6283, 0x6284, big5_chars_ban1125}, 
    {0x6286, 0x628A, big5_chars_ban1126}, 
    {0x628C, 0x628C, big5_chars_ban1127}, 
    {0x628E, 0x628F, big5_chars_ban1128}, 
    {0x6291, 0x6298, big5_chars_ban1129}, 
    {0x62A8, 0x62B1, big5_chars_ban1130}, 
    {0x62B3, 0x62B6, big5_chars_ban1131}, 
    {0x62B8, 0x62B9, big5_chars_ban1132}, 
    {0x62BB, 0x62BF, big5_chars_ban1133}, 
    {0x62C2, 0x62C2, big5_chars_ban1134}, 
    {0x62C4, 0x62C4, big5_chars_ban1135}, 
    {0x62C6, 0x62D4, big5_chars_ban1136}, 
    {0x62D6, 0x62DC, big5_chars_ban1137}, 
    {0x62EB, 0x6303, big5_chars_ban1138}, 
    {0x6307, 0x6309, big5_chars_ban1139}, 
    {0x630B, 0x6311, big5_chars_ban1140}, 
    {0x6313, 0x6316, big5_chars_ban1141}, 
    {0x6328, 0x632D, big5_chars_ban1142}, 
    {0x632F, 0x632F, big5_chars_ban1143}, 
    {0x6332, 0x6334, big5_chars_ban1144}, 
    {0x6336, 0x6336, big5_chars_ban1145}, 
    {0x6338, 0x633E, big5_chars_ban1146}, 
    {0x6340, 0x6351, big5_chars_ban1147}, 
    {0x6354, 0x635A, big5_chars_ban1148}, 
    {0x6365, 0x6365, big5_chars_ban1149}, 
    {0x6367, 0x6369, big5_chars_ban1150}, 
    {0x636B, 0x636B, big5_chars_ban1151}, 
    {0x636D, 0x6372, big5_chars_ban1152}, 
    {0x6375, 0x6378, big5_chars_ban1153}, 
    {0x637A, 0x637D, big5_chars_ban1154}, 
    {0x6380, 0x6385, big5_chars_ban1155}, 
    {0x6387, 0x638A, big5_chars_ban1156}, 
    {0x638C, 0x6392, big5_chars_ban1157}, 
    {0x6394, 0x6394, big5_chars_ban1158}, 
    {0x6396, 0x6399, big5_chars_ban1159}, 
    {0x639B, 0x63A5, big5_chars_ban1160}, 
    {0x63A7, 0x63B1, big5_chars_ban1161}, 
    {0x63BD, 0x63BE, big5_chars_ban1162}, 
    {0x63C0, 0x63C0, big5_chars_ban1163}, 
    {0x63C2, 0x63D0, big5_chars_ban1164}, 
    {0x63D2, 0x63D3, big5_chars_ban1165}, 
    {0x63D5, 0x63DD, big5_chars_ban1166}, 
    {0x63DF, 0x63E1, big5_chars_ban1167}, 
    {0x63E3, 0x63E5, big5_chars_ban1168}, 
    {0x63E7, 0x63EB, big5_chars_ban1169}, 
    {0x63ED, 0x63F6, big5_chars_ban1170}, 
    {0x63F9, 0x63F9, big5_chars_ban1171}, 
    {0x6406, 0x6406, big5_chars_ban1172}, 
    {0x6409, 0x6410, big5_chars_ban1173}, 
    {0x6412, 0x6418, big5_chars_ban1174}, 
    {0x641A, 0x641C, big5_chars_ban1175}, 
    {0x641E, 0x6428, big5_chars_ban1176}, 
    {0x642A, 0x6430, big5_chars_ban1177}, 
    {0x6433, 0x6437, big5_chars_ban1178}, 
    {0x6439, 0x6439, big5_chars_ban1179}, 
    {0x643D, 0x6441, big5_chars_ban1180}, 
    {0x6443, 0x6443, big5_chars_ban1181}, 
    {0x644B, 0x644B, big5_chars_ban1182}, 
    {0x644D, 0x644E, big5_chars_ban1183}, 
    {0x6450, 0x6454, big5_chars_ban1184}, 
    {0x6458, 0x6459, big5_chars_ban1185}, 
    {0x645B, 0x6461, big5_chars_ban1186}, 
    {0x6465, 0x6469, big5_chars_ban1187}, 
    {0x646B, 0x6470, big5_chars_ban1188}, 
    {0x6472, 0x647B, big5_chars_ban1189}, 
    {0x647D, 0x647D, big5_chars_ban1190}, 
    {0x647F, 0x647F, big5_chars_ban1191}, 
    {0x6482, 0x6482, big5_chars_ban1192}, 
    {0x6485, 0x6485, big5_chars_ban1193}, 
    {0x6487, 0x648C, big5_chars_ban1194}, 
    {0x648F, 0x6490, big5_chars_ban1195}, 
    {0x6492, 0x6493, big5_chars_ban1196}, 
    {0x6495, 0x649A, big5_chars_ban1197}, 
    {0x649C, 0x64A0, big5_chars_ban1198}, 
    {0x64A2, 0x64A6, big5_chars_ban1199}, 
    {0x64A9, 0x64A9, big5_chars_ban1200}, 
    {0x64AB, 0x64AE, big5_chars_ban1201}, 
    {0x64B0, 0x64B3, big5_chars_ban1202}, 
    {0x64BB, 0x64BF, big5_chars_ban1203}, 
    {0x64C1, 0x64C5, big5_chars_ban1204}, 
    {0x64C7, 0x64C7, big5_chars_ban1205}, 
    {0x64C9, 0x64CB, big5_chars_ban1206}, 
    {0x64CD, 0x64D0, big5_chars_ban1207}, 
    {0x64D2, 0x64D2, big5_chars_ban1208}, 
    {0x64D4, 0x64D4, big5_chars_ban1209}, 
    {0x64D6, 0x64DB, big5_chars_ban1210}, 
    {0x64E0, 0x64E0, big5_chars_ban1211}, 
    {0x64E2, 0x64E4, big5_chars_ban1212}, 
    {0x64E6, 0x64E6, big5_chars_ban1213}, 
    {0x64E8, 0x64E9, big5_chars_ban1214}, 
    {0x64EB, 0x64ED, big5_chars_ban1215}, 
    {0x64EF, 0x64F4, big5_chars_ban1216}, 
    {0x64F7, 0x64F8, big5_chars_ban1217}, 
    {0x64FA, 0x6501, big5_chars_ban1218}, 
    {0x6503, 0x6504, big5_chars_ban1219}, 
    {0x6506, 0x6507, big5_chars_ban1220}, 
    {0x6509, 0x6509, big5_chars_ban1221}, 
    {0x650C, 0x6510, big5_chars_ban1222}, 
    {0x6513, 0x6519, big5_chars_ban1223}, 
    {0x651B, 0x651D, big5_chars_ban1224}, 
    {0x6520, 0x6526, big5_chars_ban1225}, 
    {0x6529, 0x652F, big5_chars_ban1226}, 
    {0x6532, 0x6533, big5_chars_ban1227}, 
    {0x6536, 0x6539, big5_chars_ban1228}, 
    {0x653B, 0x653B, big5_chars_ban1229}, 
    {0x653D, 0x653F, big5_chars_ban1230}, 
    {0x6541, 0x6541, big5_chars_ban1231}, 
    {0x6543, 0x6543, big5_chars_ban1232}, 
    {0x6545, 0x6546, big5_chars_ban1233}, 
    {0x6548, 0x654A, big5_chars_ban1234}, 
    {0x654F, 0x654F, big5_chars_ban1235}, 
    {0x6551, 0x6551, big5_chars_ban1236}, 
    {0x6553, 0x6559, big5_chars_ban1237}, 
    {0x655C, 0x655E, big5_chars_ban1238}, 
    {0x6562, 0x6568, big5_chars_ban1239}, 
    {0x656A, 0x656A, big5_chars_ban1240}, 
    {0x656C, 0x656C, big5_chars_ban1241}, 
    {0x656F, 0x656F, big5_chars_ban1242}, 
    {0x6572, 0x657C, big5_chars_ban1243}, 
    {0x657F, 0x6584, big5_chars_ban1244}, 
    {0x6587, 0x6587, big5_chars_ban1245}, 
    {0x658C, 0x658C, big5_chars_ban1246}, 
    {0x6590, 0x6592, big5_chars_ban1247}, 
    {0x6594, 0x6597, big5_chars_ban1248}, 
    {0x6599, 0x6599, big5_chars_ban1249}, 
    {0x659B, 0x65A2, big5_chars_ban1250}, 
    {0x65A4, 0x65A5, big5_chars_ban1251}, 
    {0x65A7, 0x65A8, big5_chars_ban1252}, 
    {0x65AA, 0x65AC, big5_chars_ban1253}, 
    {0x65AE, 0x65B0, big5_chars_ban1254}, 
    {0x65B2, 0x65B3, big5_chars_ban1255}, 
    {0x65B6, 0x65B9, big5_chars_ban1256}, 
    {0x65BB, 0x65BD, big5_chars_ban1257}, 
    {0x65BF, 0x65BF, big5_chars_ban1258}, 
    {0x65C1, 0x65C6, big5_chars_ban1259}, 
    {0x65CB, 0x65D0, big5_chars_ban1260}, 
    {0x65D2, 0x65D3, big5_chars_ban1261}, 
    {0x65D6, 0x65D7, big5_chars_ban1262}, 
    {0x65DA, 0x65DB, big5_chars_ban1263}, 
    {0x65DD, 0x65DF, big5_chars_ban1264}, 
    {0x65E1, 0x65E2, big5_chars_ban1265}, 
    {0x65E5, 0x65E6, big5_chars_ban1266}, 
    {0x65E8, 0x65E9, big5_chars_ban1267}, 
    {0x65EC, 0x65F5, big5_chars_ban1268}, 
    {0x65FA, 0x65FD, big5_chars_ban1269}, 
    {0x6600, 0x6600, big5_chars_ban1270}, 
    {0x6602, 0x6615, big5_chars_ban1271}, 
    {0x661C, 0x661D, big5_chars_ban1272}, 
    {0x661F, 0x6622, big5_chars_ban1273}, 
    {0x6624, 0x6628, big5_chars_ban1274}, 
    {0x662B, 0x662B, big5_chars_ban1275}, 
    {0x662D, 0x662F, big5_chars_ban1276}, 
    {0x6631, 0x6636, big5_chars_ban1277}, 
    {0x6639, 0x663A, big5_chars_ban1278}, 
    {0x6641, 0x6643, big5_chars_ban1279}, 
    {0x6645, 0x6645, big5_chars_ban1280}, 
    {0x6647, 0x6647, big5_chars_ban1281}, 
    {0x6649, 0x664A, big5_chars_ban1282}, 
    {0x664C, 0x664C, big5_chars_ban1283}, 
    {0x664F, 0x664F, big5_chars_ban1284}, 
    {0x6651, 0x6652, big5_chars_ban1285}, 
    {0x6659, 0x665F, big5_chars_ban1286}, 
    {0x6661, 0x6662, big5_chars_ban1287}, 
    {0x6664, 0x6666, big5_chars_ban1288}, 
    {0x6668, 0x6668, big5_chars_ban1289}, 
    {0x666A, 0x666A, big5_chars_ban1290}, 
    {0x666C, 0x666C, big5_chars_ban1291}, 
    {0x666E, 0x6672, big5_chars_ban1292}, 
    {0x6674, 0x6674, big5_chars_ban1293}, 
    {0x6676, 0x667C, big5_chars_ban1294}, 
    {0x667E, 0x667E, big5_chars_ban1295}, 
    {0x6680, 0x6680, big5_chars_ban1296}, 
    {0x6684, 0x6684, big5_chars_ban1297}, 
    {0x6686, 0x668D, big5_chars_ban1298}, 
    {0x6690, 0x6691, big5_chars_ban1299}, 
    {0x6694, 0x6699, big5_chars_ban1300}, 
    {0x669D, 0x669D, big5_chars_ban1301}, 
    {0x669F, 0x66A2, big5_chars_ban1302}, 
    {0x66A8, 0x66AB, big5_chars_ban1303}, 
    {0x66AE, 0x66B2, big5_chars_ban1304}, 
    {0x66B4, 0x66B5, big5_chars_ban1305}, 
    {0x66B7, 0x66BB, big5_chars_ban1306}, 
    {0x66BD, 0x66BE, big5_chars_ban1307}, 
    {0x66C0, 0x66C0, big5_chars_ban1308}, 
    {0x66C4, 0x66C4, big5_chars_ban1309}, 
    {0x66C6, 0x66CC, big5_chars_ban1310}, 
    {0x66CF, 0x66CF, big5_chars_ban1311}, 
    {0x66D2, 0x66D2, big5_chars_ban1312}, 
    {0x66D6, 0x66D6, big5_chars_ban1313}, 
    {0x66D8, 0x66DE, big5_chars_ban1314}, 
    {0x66E0, 0x66E0, big5_chars_ban1315}, 
    {0x66E3, 0x66E4, big5_chars_ban1316}, 
    {0x66E6, 0x66E6, big5_chars_ban1317}, 
    {0x66E8, 0x66E9, big5_chars_ban1318}, 
    {0x66EB, 0x66EE, big5_chars_ban1319}, 
    {0x66F0, 0x66F0, big5_chars_ban1320}, 
    {0x66F2, 0x66F4, big5_chars_ban1321}, 
    {0x66F6, 0x66F9, big5_chars_ban1322}, 
    {0x66FC, 0x66FC, big5_chars_ban1323}, 
    {0x66FE, 0x6701, big5_chars_ban1324}, 
    {0x6703, 0x6705, big5_chars_ban1325}, 
    {0x6708, 0x670B, big5_chars_ban1326}, 
    {0x670D, 0x670D, big5_chars_ban1327}, 
    {0x670F, 0x6710, big5_chars_ban1328}, 
    {0x6712, 0x6715, big5_chars_ban1329}, 
    {0x6717, 0x6718, big5_chars_ban1330}, 
    {0x671B, 0x671B, big5_chars_ban1331}, 
    {0x671D, 0x671D, big5_chars_ban1332}, 
    {0x671F, 0x6723, big5_chars_ban1333}, 
    {0x6726, 0x6728, big5_chars_ban1334}, 
    {0x672A, 0x672E, big5_chars_ban1335}, 
    {0x6731, 0x6731, big5_chars_ban1336}, 
    {0x6733, 0x6735, big5_chars_ban1337}, 
    {0x6738, 0x673F, big5_chars_ban1338}, 
    {0x6745, 0x6749, big5_chars_ban1339}, 
    {0x674B, 0x6751, big5_chars_ban1340}, 
    {0x6753, 0x6753, big5_chars_ban1341}, 
    {0x6755, 0x6757, big5_chars_ban1342}, 
    {0x6759, 0x675A, big5_chars_ban1343}, 
    {0x675C, 0x6760, big5_chars_ban1344}, 
    {0x676A, 0x676A, big5_chars_ban1345}, 
    {0x676C, 0x676D, big5_chars_ban1346}, 
    {0x676F, 0x677F, big5_chars_ban1347}, 
    {0x6781, 0x6781, big5_chars_ban1348}, 
    {0x6783, 0x6787, big5_chars_ban1349}, 
    {0x6789, 0x6789, big5_chars_ban1350}, 
    {0x678B, 0x678E, big5_chars_ban1351}, 
    {0x6790, 0x6795, big5_chars_ban1352}, 
    {0x6797, 0x679A, big5_chars_ban1353}, 
    {0x679C, 0x679D, big5_chars_ban1354}, 
    {0x679F, 0x679F, big5_chars_ban1355}, 
    {0x67AE, 0x67B0, big5_chars_ban1356}, 
    {0x67B2, 0x67BB, big5_chars_ban1357}, 
    {0x67C0, 0x67C6, big5_chars_ban1358}, 
    {0x67C8, 0x67D4, big5_chars_ban1359}, 
    {0x67D8, 0x67DF, big5_chars_ban1360}, 
    {0x67E2, 0x67E7, big5_chars_ban1361}, 
    {0x67E9, 0x67F8, big5_chars_ban1362}, 
    {0x67FA, 0x67FA, big5_chars_ban1363}, 
    {0x67FC, 0x67FC, big5_chars_ban1364}, 
    {0x67FF, 0x67FF, big5_chars_ban1365}, 
    {0x6812, 0x6814, big5_chars_ban1366}, 
    {0x6816, 0x6818, big5_chars_ban1367}, 
    {0x681A, 0x681A, big5_chars_ban1368}, 
    {0x681C, 0x681D, big5_chars_ban1369}, 
    {0x681F, 0x6821, big5_chars_ban1370}, 
    {0x6825, 0x6826, big5_chars_ban1371}, 
    {0x6828, 0x682B, big5_chars_ban1372}, 
    {0x682D, 0x682F, big5_chars_ban1373}, 
    {0x6831, 0x6835, big5_chars_ban1374}, 
    {0x6838, 0x683D, big5_chars_ban1375}, 
    {0x6840, 0x6846, big5_chars_ban1376}, 
    {0x6848, 0x6849, big5_chars_ban1377}, 
    {0x684B, 0x6851, big5_chars_ban1378}, 
    {0x6853, 0x6854, big5_chars_ban1379}, 
    {0x686B, 0x686B, big5_chars_ban1380}, 
    {0x686D, 0x686F, big5_chars_ban1381}, 
    {0x6871, 0x6872, big5_chars_ban1382}, 
    {0x6874, 0x6879, big5_chars_ban1383}, 
    {0x687B, 0x6883, big5_chars_ban1384}, 
    {0x6885, 0x6887, big5_chars_ban1385}, 
    {0x6889, 0x688C, big5_chars_ban1386}, 
    {0x688F, 0x6894, big5_chars_ban1387}, 
    {0x6896, 0x6897, big5_chars_ban1388}, 
    {0x689B, 0x689D, big5_chars_ban1389}, 
    {0x689F, 0x68A4, big5_chars_ban1390}, 
    {0x68A7, 0x68B5, big5_chars_ban1391}, 
    {0x68C4, 0x68C4, big5_chars_ban1392}, 
    {0x68C6, 0x68C9, big5_chars_ban1393}, 
    {0x68CB, 0x68CE, big5_chars_ban1394}, 
    {0x68D0, 0x68D8, big5_chars_ban1395}, 
    {0x68DA, 0x68DA, big5_chars_ban1396}, 
    {0x68DC, 0x68E1, big5_chars_ban1397}, 
    {0x68E3, 0x68E4, big5_chars_ban1398}, 
    {0x68E6, 0x68EC, big5_chars_ban1399}, 
    {0x68EE, 0x68FD, big5_chars_ban1400}, 
    {0x6904, 0x6908, big5_chars_ban1401}, 
    {0x690A, 0x6915, big5_chars_ban1402}, 
    {0x6917, 0x6917, big5_chars_ban1403}, 
    {0x6925, 0x6925, big5_chars_ban1404}, 
    {0x692A, 0x692A, big5_chars_ban1405}, 
    {0x692F, 0x6930, big5_chars_ban1406}, 
    {0x6932, 0x6935, big5_chars_ban1407}, 
    {0x6937, 0x6939, big5_chars_ban1408}, 
    {0x693B, 0x693D, big5_chars_ban1409}, 
    {0x693F, 0x6942, big5_chars_ban1410}, 
    {0x6944, 0x6945, big5_chars_ban1411}, 
    {0x6948, 0x694C, big5_chars_ban1412}, 
    {0x694E, 0x694F, big5_chars_ban1413}, 
    {0x6951, 0x6954, big5_chars_ban1414}, 
    {0x6956, 0x6960, big5_chars_ban1415}, 
    {0x6962, 0x6963, big5_chars_ban1416}, 
    {0x6965, 0x6966, big5_chars_ban1417}, 
    {0x6968, 0x6971, big5_chars_ban1418}, 
    {0x6974, 0x697B, big5_chars_ban1419}, 
    {0x6982, 0x6983, big5_chars_ban1420}, 
    {0x6986, 0x6986, big5_chars_ban1421}, 
    {0x698D, 0x698E, big5_chars_ban1422}, 
    {0x6990, 0x6991, big5_chars_ban1423}, 
    {0x6993, 0x6997, big5_chars_ban1424}, 
    {0x6999, 0x699C, big5_chars_ban1425}, 
    {0x699E, 0x699E, big5_chars_ban1426}, 
    {0x69A0, 0x69A1, big5_chars_ban1427}, 
    {0x69A3, 0x69B1, big5_chars_ban1428}, 
    {0x69B3, 0x69B7, big5_chars_ban1429}, 
    {0x69B9, 0x69B9, big5_chars_ban1430}, 
    {0x69BB, 0x69BF, big5_chars_ban1431}, 
    {0x69C1, 0x69C4, big5_chars_ban1432}, 
    {0x69C6, 0x69C6, big5_chars_ban1433}, 
    {0x69C9, 0x69D0, big5_chars_ban1434}, 
    {0x69D3, 0x69D4, big5_chars_ban1435}, 
    {0x69D9, 0x69D9, big5_chars_ban1436}, 
    {0x69E2, 0x69E2, big5_chars_ban1437}, 
    {0x69E4, 0x69E8, big5_chars_ban1438}, 
    {0x69EB, 0x69EE, big5_chars_ban1439}, 
    {0x69F1, 0x69F4, big5_chars_ban1440}, 
    {0x69F6, 0x69F8, big5_chars_ban1441}, 
    {0x69FB, 0x6A02, big5_chars_ban1442}, 
    {0x6A04, 0x6A0A, big5_chars_ban1443}, 
    {0x6A0D, 0x6A0D, big5_chars_ban1444}, 
    {0x6A0F, 0x6A0F, big5_chars_ban1445}, 
    {0x6A11, 0x6A11, big5_chars_ban1446}, 
    {0x6A13, 0x6A19, big5_chars_ban1447}, 
    {0x6A1B, 0x6A1B, big5_chars_ban1448}, 
    {0x6A1D, 0x6A21, big5_chars_ban1449}, 
    {0x6A23, 0x6A23, big5_chars_ban1450}, 
    {0x6A25, 0x6A28, big5_chars_ban1451}, 
    {0x6A32, 0x6A32, big5_chars_ban1452}, 
    {0x6A34, 0x6A35, big5_chars_ban1453}, 
    {0x6A38, 0x6A41, big5_chars_ban1454}, 
    {0x6A44, 0x6A44, big5_chars_ban1455}, 
    {0x6A46, 0x6A49, big5_chars_ban1456}, 
    {0x6A4B, 0x6A4B, big5_chars_ban1457}, 
    {0x6A4D, 0x6A51, big5_chars_ban1458}, 
    {0x6A54, 0x6A56, big5_chars_ban1459}, 
    {0x6A58, 0x6A5B, big5_chars_ban1460}, 
    {0x6A5D, 0x6A62, big5_chars_ban1461}, 
    {0x6A64, 0x6A64, big5_chars_ban1462}, 
    {0x6A66, 0x6A6B, big5_chars_ban1463}, 
    {0x6A6D, 0x6A6D, big5_chars_ban1464}, 
    {0x6A6F, 0x6A6F, big5_chars_ban1465}, 
    {0x6A76, 0x6A76, big5_chars_ban1466}, 
    {0x6A7E, 0x6A81, big5_chars_ban1467}, 
    {0x6A83, 0x6A85, big5_chars_ban1468}, 
    {0x6A87, 0x6A87, big5_chars_ban1469}, 
    {0x6A89, 0x6A89, big5_chars_ban1470}, 
    {0x6A8C, 0x6A8E, big5_chars_ban1471}, 
    {0x6A90, 0x6A97, big5_chars_ban1472}, 
    {0x6A9A, 0x6A9C, big5_chars_ban1473}, 
    {0x6A9E, 0x6AA6, big5_chars_ban1474}, 
    {0x6AA8, 0x6AA8, big5_chars_ban1475}, 
    {0x6AAC, 0x6AAF, big5_chars_ban1476}, 
    {0x6AB3, 0x6AB4, big5_chars_ban1477}, 
    {0x6AB6, 0x6ABB, big5_chars_ban1478}, 
    {0x6ABD, 0x6ABD, big5_chars_ban1479}, 
    {0x6AC2, 0x6AC3, big5_chars_ban1480}, 
    {0x6AC5, 0x6AC7, big5_chars_ban1481}, 
    {0x6ACB, 0x6ACD, big5_chars_ban1482}, 
    {0x6ACF, 0x6AD1, big5_chars_ban1483}, 
    {0x6AD3, 0x6AD3, big5_chars_ban1484}, 
    {0x6AD9, 0x6AE1, big5_chars_ban1485}, 
    {0x6AE5, 0x6AE5, big5_chars_ban1486}, 
    {0x6AE7, 0x6AE8, big5_chars_ban1487}, 
    {0x6AEA, 0x6AEC, big5_chars_ban1488}, 
    {0x6AEE, 0x6AF1, big5_chars_ban1489}, 
    {0x6AF3, 0x6AF3, big5_chars_ban1490}, 
    {0x6AF8, 0x6AFC, big5_chars_ban1491}, 
    {0x6B00, 0x6B00, big5_chars_ban1492}, 
    {0x6B02, 0x6B04, big5_chars_ban1493}, 
    {0x6B08, 0x6B0B, big5_chars_ban1494}, 
    {0x6B0F, 0x6B13, big5_chars_ban1495}, 
    {0x6B16, 0x6B1A, big5_chars_ban1496}, 
    {0x6B1E, 0x6B1E, big5_chars_ban1497}, 
    {0x6B20, 0x6B21, big5_chars_ban1498}, 
    {0x6B23, 0x6B23, big5_chars_ban1499}, 
    {0x6B25, 0x6B25, big5_chars_ban1500}, 
    {0x6B28, 0x6B28, big5_chars_ban1501}, 
    {0x6B2C, 0x6B2D, big5_chars_ban1502}, 
    {0x6B2F, 0x6B2F, big5_chars_ban1503}, 
    {0x6B31, 0x6B34, big5_chars_ban1504}, 
    {0x6B36, 0x6B3F, big5_chars_ban1505}, 
    {0x6B41, 0x6B43, big5_chars_ban1506}, 
    {0x6B45, 0x6B4E, big5_chars_ban1507}, 
    {0x6B50, 0x6B51, big5_chars_ban1508}, 
    {0x6B54, 0x6B56, big5_chars_ban1509}, 
    {0x6B59, 0x6B59, big5_chars_ban1510}, 
    {0x6B5B, 0x6B5C, big5_chars_ban1511}, 
    {0x6B5E, 0x6B67, big5_chars_ban1512}, 
    {0x6B6A, 0x6B6A, big5_chars_ban1513}, 
    {0x6B6D, 0x6B6D, big5_chars_ban1514}, 
    {0x6B72, 0x6B72, big5_chars_ban1515}, 
    {0x6B76, 0x6B79, big5_chars_ban1516}, 
    {0x6B7B, 0x6B7B, big5_chars_ban1517}, 
    {0x6B7E, 0x6B80, big5_chars_ban1518}, 
    {0x6B82, 0x6B84, big5_chars_ban1519}, 
    {0x6B86, 0x6B86, big5_chars_ban1520}, 
    {0x6B88, 0x6B8A, big5_chars_ban1521}, 
    {0x6B8C, 0x6B8F, big5_chars_ban1522}, 
    {0x6B91, 0x6B91, big5_chars_ban1523}, 
    {0x6B94, 0x6B99, big5_chars_ban1524}, 
    {0x6B9B, 0x6B9B, big5_chars_ban1525}, 
    {0x6B9E, 0x6BA0, big5_chars_ban1526}, 
    {0x6BA2, 0x6BA7, big5_chars_ban1527}, 
    {0x6BAA, 0x6BAB, big5_chars_ban1528}, 
    {0x6BAD, 0x6BB0, big5_chars_ban1529}, 
    {0x6BB2, 0x6BB3, big5_chars_ban1530}, 
    {0x6BB5, 0x6BB7, big5_chars_ban1531}, 
    {0x6BBA, 0x6BBA, big5_chars_ban1532}, 
    {0x6BBC, 0x6BBD, big5_chars_ban1533}, 
    {0x6BBF, 0x6BC0, big5_chars_ban1534}, 
    {0x6BC3, 0x6BCD, big5_chars_ban1535}, 
    {0x6BCF, 0x6BD0, big5_chars_ban1536}, 
    {0x6BD2, 0x6BD4, big5_chars_ban1537}, 
    {0x6BD6, 0x6BD8, big5_chars_ban1538}, 
    {0x6BDA, 0x6BDB, big5_chars_ban1539}, 
    {0x6BDE, 0x6BDE, big5_chars_ban1540}, 
    {0x6BE0, 0x6BE0, big5_chars_ban1541}, 
    {0x6BE2, 0x6BE4, big5_chars_ban1542}, 
    {0x6BE6, 0x6BE8, big5_chars_ban1543}, 
    {0x6BEB, 0x6BEC, big5_chars_ban1544}, 
    {0x6BEF, 0x6BF0, big5_chars_ban1545}, 
    {0x6BF2, 0x6BF3, big5_chars_ban1546}, 
    {0x6BF7, 0x6BF9, big5_chars_ban1547}, 
    {0x6BFB, 0x6C06, big5_chars_ban1548}, 
    {0x6C08, 0x6C09, big5_chars_ban1549}, 
    {0x6C0B, 0x6C0D, big5_chars_ban1550}, 
    {0x6C0F, 0x6C11, big5_chars_ban1551}, 
    {0x6C13, 0x6C16, big5_chars_ban1552}, 
    {0x6C18, 0x6C1B, big5_chars_ban1553}, 
    {0x6C1D, 0x6C1D, big5_chars_ban1554}, 
    {0x6C1F, 0x6C21, big5_chars_ban1555}, 
    {0x6C23, 0x6C28, big5_chars_ban1556}, 
    {0x6C2A, 0x6C2C, big5_chars_ban1557}, 
    {0x6C2E, 0x6C30, big5_chars_ban1558}, 
    {0x6C33, 0x6C34, big5_chars_ban1559}, 
    {0x6C36, 0x6C36, big5_chars_ban1560}, 
    {0x6C38, 0x6C38, big5_chars_ban1561}, 
    {0x6C3B, 0x6C3B, big5_chars_ban1562}, 
    {0x6C3E, 0x6C43, big5_chars_ban1563}, 
    {0x6C46, 0x6C46, big5_chars_ban1564}, 
    {0x6C4A, 0x6C50, big5_chars_ban1565}, 
    {0x6C52, 0x6C52, big5_chars_ban1566}, 
    {0x6C54, 0x6C55, big5_chars_ban1567}, 
    {0x6C57, 0x6C57, big5_chars_ban1568}, 
    {0x6C59, 0x6C59, big5_chars_ban1569}, 
    {0x6C5B, 0x6C61, big5_chars_ban1570}, 
    {0x6C65, 0x6C6B, big5_chars_ban1571}, 
    {0x6C6D, 0x6C6D, big5_chars_ban1572}, 
    {0x6C6F, 0x6C74, big5_chars_ban1573}, 
    {0x6C76, 0x6C76, big5_chars_ban1574}, 
    {0x6C78, 0x6C78, big5_chars_ban1575}, 
    {0x6C7A, 0x6C7B, big5_chars_ban1576}, 
    {0x6C7D, 0x6C7E, big5_chars_ban1577}, 
    {0x6C80, 0x6C90, big5_chars_ban1578}, 
    {0x6C92, 0x6C96, big5_chars_ban1579}, 
    {0x6C98, 0x6C9D, big5_chars_ban1580}, 
    {0x6CAB, 0x6CAE, big5_chars_ban1581}, 
    {0x6CB0, 0x6CB1, big5_chars_ban1582}, 
    {0x6CB3, 0x6CB4, big5_chars_ban1583}, 
    {0x6CB6, 0x6CC7, big5_chars_ban1584}, 
    {0x6CC9, 0x6CCA, big5_chars_ban1585}, 
    {0x6CCC, 0x6CCD, big5_chars_ban1586}, 
    {0x6CCF, 0x6CD7, big5_chars_ban1587}, 
    {0x6CD9, 0x6CDE, big5_chars_ban1588}, 
    {0x6CE0, 0x6CE3, big5_chars_ban1589}, 
    {0x6CE5, 0x6CE5, big5_chars_ban1590}, 
    {0x6CE7, 0x6CE9, big5_chars_ban1591}, 
    {0x6CEB, 0x6CF3, big5_chars_ban1592}, 
    {0x6CF5, 0x6CF5, big5_chars_ban1593}, 
    {0x6CF9, 0x6CF9, big5_chars_ban1594}, 
    {0x6D00, 0x6D01, big5_chars_ban1595}, 
    {0x6D03, 0x6D04, big5_chars_ban1596}, 
    {0x6D07, 0x6D12, big5_chars_ban1597}, 
    {0x6D16, 0x6D1B, big5_chars_ban1598}, 
    {0x6D1D, 0x6D20, big5_chars_ban1599}, 
    {0x6D22, 0x6D22, big5_chars_ban1600}, 
    {0x6D25, 0x6D25, big5_chars_ban1601}, 
    {0x6D27, 0x6D42, big5_chars_ban1602}, 
    {0x6D58, 0x6D5A, big5_chars_ban1603}, 
    {0x6D5E, 0x6D6A, big5_chars_ban1604}, 
    {0x6D6C, 0x6D70, big5_chars_ban1605}, 
    {0x6D74, 0x6D80, big5_chars_ban1606}, 
    {0x6D82, 0x6D8E, big5_chars_ban1607}, 
    {0x6D90, 0x6D95, big5_chars_ban1608}, 
    {0x6D97, 0x6D98, big5_chars_ban1609}, 
    {0x6DAA, 0x6DAC, big5_chars_ban1610}, 
    {0x6DAE, 0x6DAF, big5_chars_ban1611}, 
    {0x6DB2, 0x6DB5, big5_chars_ban1612}, 
    {0x6DB7, 0x6DB8, big5_chars_ban1613}, 
    {0x6DBA, 0x6DC0, big5_chars_ban1614}, 
    {0x6DC2, 0x6DC2, big5_chars_ban1615}, 
    {0x6DC4, 0x6DCD, big5_chars_ban1616}, 
    {0x6DCF, 0x6DE6, big5_chars_ban1617}, 
    {0x6DE8, 0x6DF7, big5_chars_ban1618}, 
    {0x6DF9, 0x6DFD, big5_chars_ban1619}, 
    {0x6E00, 0x6E00, big5_chars_ban1620}, 
    {0x6E03, 0x6E03, big5_chars_ban1621}, 
    {0x6E05, 0x6E05, big5_chars_ban1622}, 
    {0x6E19, 0x6E1D, big5_chars_ban1623}, 
    {0x6E1F, 0x6E28, big5_chars_ban1624}, 
    {0x6E2B, 0x6E36, big5_chars_ban1625}, 
    {0x6E38, 0x6E41, big5_chars_ban1626}, 
    {0x6E43, 0x6E47, big5_chars_ban1627}, 
    {0x6E49, 0x6E4B, big5_chars_ban1628}, 
    {0x6E4D, 0x6E4E, big5_chars_ban1629}, 
    {0x6E51, 0x6E56, big5_chars_ban1630}, 
    {0x6E58, 0x6E58, big5_chars_ban1631}, 
    {0x6E5A, 0x6E69, big5_chars_ban1632}, 
    {0x6E6B, 0x6E6B, big5_chars_ban1633}, 
    {0x6E6E, 0x6E6F, big5_chars_ban1634}, 
    {0x6E71, 0x6E74, big5_chars_ban1635}, 
    {0x6E77, 0x6E79, big5_chars_ban1636}, 
    {0x6E88, 0x6E89, big5_chars_ban1637}, 
    {0x6E8D, 0x6E90, big5_chars_ban1638}, 
    {0x6E92, 0x6E94, big5_chars_ban1639}, 
    {0x6E96, 0x6E99, big5_chars_ban1640}, 
    {0x6E9B, 0x6EA7, big5_chars_ban1641}, 
    {0x6EAA, 0x6EAB, big5_chars_ban1642}, 
    {0x6EAE, 0x6EB4, big5_chars_ban1643}, 
    {0x6EB6, 0x6EB7, big5_chars_ban1644}, 
    {0x6EB9, 0x6EBA, big5_chars_ban1645}, 
    {0x6EBC, 0x6ED6, big5_chars_ban1646}, 
    {0x6ED8, 0x6ED8, big5_chars_ban1647}, 
    {0x6EDC, 0x6EDC, big5_chars_ban1648}, 
    {0x6EEB, 0x6EEF, big5_chars_ban1649}, 
    {0x6EF1, 0x6EF2, big5_chars_ban1650}, 
    {0x6EF4, 0x6EF9, big5_chars_ban1651}, 
    {0x6EFB, 0x6F03, big5_chars_ban1652}, 
    {0x6F05, 0x6F0A, big5_chars_ban1653}, 
    {0x6F0D, 0x6F0F, big5_chars_ban1654}, 
    {0x6F12, 0x6F15, big5_chars_ban1655}, 
    {0x6F18, 0x6F1A, big5_chars_ban1656}, 
    {0x6F1C, 0x6F1C, big5_chars_ban1657}, 
    {0x6F1E, 0x6F23, big5_chars_ban1658}, 
    {0x6F25, 0x6F27, big5_chars_ban1659}, 
    {0x6F29, 0x6F33, big5_chars_ban1660}, 
    {0x6F35, 0x6F3C, big5_chars_ban1661}, 
    {0x6F3E, 0x6F41, big5_chars_ban1662}, 
    {0x6F43, 0x6F43, big5_chars_ban1663}, 
    {0x6F4E, 0x6F55, big5_chars_ban1664}, 
    {0x6F57, 0x6F58, big5_chars_ban1665}, 
    {0x6F5A, 0x6F5B, big5_chars_ban1666}, 
    {0x6F5D, 0x6F64, big5_chars_ban1667}, 
    {0x6F66, 0x6F67, big5_chars_ban1668}, 
    {0x6F69, 0x6F70, big5_chars_ban1669}, 
    {0x6F72, 0x6F73, big5_chars_ban1670}, 
    {0x6F76, 0x6F78, big5_chars_ban1671}, 
    {0x6F7A, 0x6F80, big5_chars_ban1672}, 
    {0x6F82, 0x6F82, big5_chars_ban1673}, 
    {0x6F84, 0x6F89, big5_chars_ban1674}, 
    {0x6F8B, 0x6F8E, big5_chars_ban1675}, 
    {0x6F90, 0x6F90, big5_chars_ban1676}, 
    {0x6F92, 0x6F97, big5_chars_ban1677}, 
    {0x6F9E, 0x6F9E, big5_chars_ban1678}, 
    {0x6FA0, 0x6FB4, big5_chars_ban1679}, 
    {0x6FB6, 0x6FB6, big5_chars_ban1680}, 
    {0x6FB8, 0x6FBA, big5_chars_ban1681}, 
    {0x6FBC, 0x6FBD, big5_chars_ban1682}, 
    {0x6FBF, 0x6FC4, big5_chars_ban1683}, 
    {0x6FC6, 0x6FCF, big5_chars_ban1684}, 
    {0x6FD4, 0x6FD5, big5_chars_ban1685}, 
    {0x6FD8, 0x6FD8, big5_chars_ban1686}, 
    {0x6FDB, 0x6FE4, big5_chars_ban1687}, 
    {0x6FE6, 0x6FE9, big5_chars_ban1688}, 
    {0x6FEB, 0x6FF2, big5_chars_ban1689}, 
    {0x6FF4, 0x6FF4, big5_chars_ban1690}, 
    {0x6FF7, 0x6FF7, big5_chars_ban1691}, 
    {0x6FFA, 0x6FFC, big5_chars_ban1692}, 
    {0x6FFE, 0x7001, big5_chars_ban1693}, 
    {0x7004, 0x7007, big5_chars_ban1694}, 
    {0x7009, 0x700F, big5_chars_ban1695}, 
    {0x7011, 0x7011, big5_chars_ban1696}, 
    {0x7014, 0x701D, big5_chars_ban1697}, 
    {0x701F, 0x7024, big5_chars_ban1698}, 
    {0x7026, 0x702B, big5_chars_ban1699}, 
    {0x702F, 0x7035, big5_chars_ban1700}, 
    {0x7037, 0x703C, big5_chars_ban1701}, 
    {0x703E, 0x7046, big5_chars_ban1702}, 
    {0x7048, 0x704A, big5_chars_ban1703}, 
    {0x704C, 0x704C, big5_chars_ban1704}, 
    {0x7051, 0x7052, big5_chars_ban1705}, 
    {0x7055, 0x7058, big5_chars_ban1706}, 
    {0x705A, 0x705B, big5_chars_ban1707}, 
    {0x705D, 0x7066, big5_chars_ban1708}, 
    {0x7068, 0x706B, big5_chars_ban1709}, 
    {0x7070, 0x7071, big5_chars_ban1710}, 
    {0x7074, 0x7074, big5_chars_ban1711}, 
    {0x7076, 0x7076, big5_chars_ban1712}, 
    {0x7078, 0x7078, big5_chars_ban1713}, 
    {0x707A, 0x707A, big5_chars_ban1714}, 
    {0x707C, 0x707D, big5_chars_ban1715}, 
    {0x7082, 0x7086, big5_chars_ban1716}, 
    {0x708A, 0x708A, big5_chars_ban1717}, 
    {0x708E, 0x708E, big5_chars_ban1718}, 
    {0x7091, 0x7096, big5_chars_ban1719}, 
    {0x7098, 0x709A, big5_chars_ban1720}, 
    {0x709F, 0x709F, big5_chars_ban1721}, 
    {0x70A1, 0x70A1, big5_chars_ban1722}, 
    {0x70A4, 0x70A4, big5_chars_ban1723}, 
    {0x70A9, 0x70A9, big5_chars_ban1724}, 
    {0x70AB, 0x70B1, big5_chars_ban1725}, 
    {0x70B3, 0x70B5, big5_chars_ban1726}, 
    {0x70B7, 0x70B8, big5_chars_ban1727}, 
    {0x70BA, 0x70BA, big5_chars_ban1728}, 
    {0x70BE, 0x70BE, big5_chars_ban1729}, 
    {0x70C5, 0x70C8, big5_chars_ban1730}, 
    {0x70CA, 0x70CB, big5_chars_ban1731}, 
    {0x70CD, 0x70CF, big5_chars_ban1732}, 
    {0x70D1, 0x70D4, big5_chars_ban1733}, 
    {0x70D7, 0x70DA, big5_chars_ban1734}, 
    {0x70DC, 0x70DE, big5_chars_ban1735}, 
    {0x70E0, 0x70E2, big5_chars_ban1736}, 
    {0x70E4, 0x70E4, big5_chars_ban1737}, 
    {0x70EF, 0x70F0, big5_chars_ban1738}, 
    {0x70F3, 0x70F4, big5_chars_ban1739}, 
    {0x70F6, 0x70FD, big5_chars_ban1740}, 
    {0x70FF, 0x7100, big5_chars_ban1741}, 
    {0x7102, 0x7102, big5_chars_ban1742}, 
    {0x7104, 0x7104, big5_chars_ban1743}, 
    {0x7106, 0x7106, big5_chars_ban1744}, 
    {0x7109, 0x710E, big5_chars_ban1745}, 
    {0x7110, 0x7110, big5_chars_ban1746}, 
    {0x7113, 0x7113, big5_chars_ban1747}, 
    {0x7117, 0x7117, big5_chars_ban1748}, 
    {0x7119, 0x711C, big5_chars_ban1749}, 
    {0x711E, 0x7123, big5_chars_ban1750}, 
    {0x7125, 0x7126, big5_chars_ban1751}, 
    {0x7128, 0x7128, big5_chars_ban1752}, 
    {0x712E, 0x7132, big5_chars_ban1753}, 
    {0x7136, 0x7136, big5_chars_ban1754}, 
    {0x713A, 0x713A, big5_chars_ban1755}, 
    {0x7141, 0x7144, big5_chars_ban1756}, 
    {0x7146, 0x7147, big5_chars_ban1757}, 
    {0x7149, 0x7149, big5_chars_ban1758}, 
    {0x714B, 0x714E, big5_chars_ban1759}, 
    {0x7150, 0x7150, big5_chars_ban1760}, 
    {0x7152, 0x7154, big5_chars_ban1761}, 
    {0x7156, 0x7156, big5_chars_ban1762}, 
    {0x7158, 0x715A, big5_chars_ban1763}, 
    {0x715C, 0x716A, big5_chars_ban1764}, 
    {0x716C, 0x716C, big5_chars_ban1765}, 
    {0x716E, 0x716E, big5_chars_ban1766}, 
    {0x7170, 0x7170, big5_chars_ban1767}, 
    {0x7172, 0x7172, big5_chars_ban1768}, 
    {0x7178, 0x7178, big5_chars_ban1769}, 
    {0x717B, 0x717B, big5_chars_ban1770}, 
    {0x717D, 0x717D, big5_chars_ban1771}, 
    {0x7180, 0x7182, big5_chars_ban1772}, 
    {0x7184, 0x7187, big5_chars_ban1773}, 
    {0x7189, 0x718A, big5_chars_ban1774}, 
    {0x718F, 0x7190, big5_chars_ban1775}, 
    {0x7192, 0x7192, big5_chars_ban1776}, 
    {0x7194, 0x7194, big5_chars_ban1777}, 
    {0x7197, 0x7197, big5_chars_ban1778}, 
    {0x7199, 0x71A1, big5_chars_ban1779}, 
    {0x71A4, 0x71A5, big5_chars_ban1780}, 
    {0x71A7, 0x71AA, big5_chars_ban1781}, 
    {0x71AC, 0x71AC, big5_chars_ban1782}, 
    {0x71AF, 0x71B3, big5_chars_ban1783}, 
    {0x71B5, 0x71B5, big5_chars_ban1784}, 
    {0x71B8, 0x71B9, big5_chars_ban1785}, 
    {0x71BC, 0x71CB, big5_chars_ban1786}, 
    {0x71CE, 0x71D0, big5_chars_ban1787}, 
    {0x71D2, 0x71D2, big5_chars_ban1788}, 
    {0x71D4, 0x71D6, big5_chars_ban1789}, 
    {0x71D8, 0x71DC, big5_chars_ban1790}, 
    {0x71DF, 0x71E2, big5_chars_ban1791}, 
    {0x71E4, 0x71E8, big5_chars_ban1792}, 
    {0x71EC, 0x71EE, big5_chars_ban1793}, 
    {0x71F0, 0x71F2, big5_chars_ban1794}, 
    {0x71F4, 0x71F4, big5_chars_ban1795}, 
    {0x71F8, 0x71F9, big5_chars_ban1796}, 
    {0x71FB, 0x71FF, big5_chars_ban1797}, 
    {0x7201, 0x7203, big5_chars_ban1798}, 
    {0x7205, 0x7207, big5_chars_ban1799}, 
    {0x720A, 0x720A, big5_chars_ban1800}, 
    {0x720C, 0x720D, big5_chars_ban1801}, 
    {0x7210, 0x7210, big5_chars_ban1802}, 
    {0x7213, 0x7214, big5_chars_ban1803}, 
    {0x7219, 0x721B, big5_chars_ban1804}, 
    {0x721D, 0x721F, big5_chars_ban1805}, 
    {0x7222, 0x7223, big5_chars_ban1806}, 
    {0x7226, 0x722A, big5_chars_ban1807}, 
    {0x722C, 0x722D, big5_chars_ban1808}, 
    {0x7230, 0x7230, big5_chars_ban1809}, 
    {0x7235, 0x7236, big5_chars_ban1810}, 
    {0x7238, 0x723B, big5_chars_ban1811}, 
    {0x723D, 0x723F, big5_chars_ban1812}, 
    {0x7241, 0x7242, big5_chars_ban1813}, 
    {0x7244, 0x7244, big5_chars_ban1814}, 
    {0x7246, 0x724C, big5_chars_ban1815}, 
    {0x724F, 0x724F, big5_chars_ban1816}, 
    {0x7252, 0x7253, big5_chars_ban1817}, 
    {0x7256, 0x7256, big5_chars_ban1818}, 
    {0x7258, 0x725B, big5_chars_ban1819}, 
    {0x725D, 0x7263, big5_chars_ban1820}, 
    {0x7267, 0x7267, big5_chars_ban1821}, 
    {0x7269, 0x726A, big5_chars_ban1822}, 
    {0x726C, 0x726C, big5_chars_ban1823}, 
    {0x726E, 0x7270, big5_chars_ban1824}, 
    {0x7272, 0x7274, big5_chars_ban1825}, 
    {0x7276, 0x7279, big5_chars_ban1826}, 
    {0x727B, 0x7281, big5_chars_ban1827}, 
    {0x7284, 0x7286, big5_chars_ban1828}, 
    {0x7288, 0x7289, big5_chars_ban1829}, 
    {0x728B, 0x728E, big5_chars_ban1830}, 
    {0x7290, 0x7293, big5_chars_ban1831}, 
    {0x7295, 0x7298, big5_chars_ban1832}, 
    {0x729A, 0x729B, big5_chars_ban1833}, 
    {0x729D, 0x729E, big5_chars_ban1834}, 
    {0x72A1, 0x72AA, big5_chars_ban1835}, 
    {0x72AC, 0x72AC, big5_chars_ban1836}, 
    {0x72AE, 0x72B0, big5_chars_ban1837}, 
    {0x72B4, 0x72B5, big5_chars_ban1838}, 
    {0x72BA, 0x72BA, big5_chars_ban1839}, 
    {0x72BD, 0x72BD, big5_chars_ban1840}, 
    {0x72BF, 0x72C6, big5_chars_ban1841}, 
    {0x72C9, 0x72CC, big5_chars_ban1842}, 
    {0x72CE, 0x72CE, big5_chars_ban1843}, 
    {0x72D0, 0x72D2, big5_chars_ban1844}, 
    {0x72D4, 0x72D4, big5_chars_ban1845}, 
    {0x72D6, 0x72DA, big5_chars_ban1846}, 
    {0x72DC, 0x72DC, big5_chars_ban1847}, 
    {0x72DF, 0x72E1, big5_chars_ban1848}, 
    {0x72E3, 0x72E4, big5_chars_ban1849}, 
    {0x72E6, 0x72E6, big5_chars_ban1850}, 
    {0x72E8, 0x72EB, big5_chars_ban1851}, 
    {0x72F3, 0x72F4, big5_chars_ban1852}, 
    {0x72F6, 0x7301, big5_chars_ban1853}, 
    {0x7307, 0x7308, big5_chars_ban1854}, 
    {0x730A, 0x730C, big5_chars_ban1855}, 
    {0x730F, 0x730F, big5_chars_ban1856}, 
    {0x7311, 0x7313, big5_chars_ban1857}, 
    {0x7316, 0x7319, big5_chars_ban1858}, 
    {0x731B, 0x731E, big5_chars_ban1859}, 
    {0x7322, 0x7323, big5_chars_ban1860}, 
    {0x7325, 0x7327, big5_chars_ban1861}, 
    {0x7329, 0x7329, big5_chars_ban1862}, 
    {0x732D, 0x732D, big5_chars_ban1863}, 
    {0x7330, 0x7337, big5_chars_ban1864}, 
    {0x733A, 0x733C, big5_chars_ban1865}, 
    {0x733E, 0x7340, big5_chars_ban1866}, 
    {0x7342, 0x7345, big5_chars_ban1867}, 
    {0x7349, 0x734A, big5_chars_ban1868}, 
    {0x734C, 0x734E, big5_chars_ban1869}, 
    {0x7350, 0x7352, big5_chars_ban1870}, 
    {0x7357, 0x735B, big5_chars_ban1871}, 
    {0x735D, 0x7362, big5_chars_ban1872}, 
    {0x7365, 0x736C, big5_chars_ban1873}, 
    {0x736E, 0x7370, big5_chars_ban1874}, 
    {0x7372, 0x7373, big5_chars_ban1875}, 
    {0x7375, 0x7378, big5_chars_ban1876}, 
    {0x737A, 0x738B, big5_chars_ban1877}, 
    {0x738E, 0x738E, big5_chars_ban1878}, 
    {0x7392, 0x7397, big5_chars_ban1879}, 
    {0x739D, 0x739D, big5_chars_ban1880}, 
    {0x739F, 0x73A2, big5_chars_ban1881}, 
    {0x73A4, 0x73A6, big5_chars_ban1882}, 
    {0x73A8, 0x73A9, big5_chars_ban1883}, 
    {0x73AB, 0x73AD, big5_chars_ban1884}, 
    {0x73B2, 0x73B9, big5_chars_ban1885}, 
    {0x73BB, 0x73BC, big5_chars_ban1886}, 
    {0x73BE, 0x73C0, big5_chars_ban1887}, 
    {0x73C2, 0x73C3, big5_chars_ban1888}, 
    {0x73C5, 0x73C8, big5_chars_ban1889}, 
    {0x73CA, 0x73CD, big5_chars_ban1890}, 
    {0x73D2, 0x73D4, big5_chars_ban1891}, 
    {0x73D6, 0x73DE, big5_chars_ban1892}, 
    {0x73E0, 0x73E0, big5_chars_ban1893}, 
    {0x73E3, 0x73E3, big5_chars_ban1894}, 
    {0x73E5, 0x73E5, big5_chars_ban1895}, 
    {0x73E7, 0x73EB, big5_chars_ban1896}, 
    {0x73ED, 0x73EE, big5_chars_ban1897}, 
    {0x73F4, 0x73F6, big5_chars_ban1898}, 
    {0x73F8, 0x73F8, big5_chars_ban1899}, 
    {0x73FA, 0x73FA, big5_chars_ban1900}, 
    {0x73FC, 0x7401, big5_chars_ban1901}, 
    {0x7403, 0x740D, big5_chars_ban1902}, 
    {0x7416, 0x7416, big5_chars_ban1903}, 
    {0x741A, 0x741B, big5_chars_ban1904}, 
    {0x741D, 0x741D, big5_chars_ban1905}, 
    {0x7420, 0x7426, big5_chars_ban1906}, 
    {0x7428, 0x7436, big5_chars_ban1907}, 
    {0x743A, 0x743A, big5_chars_ban1908}, 
    {0x743F, 0x7442, big5_chars_ban1909}, 
    {0x7444, 0x7444, big5_chars_ban1910}, 
    {0x7446, 0x7446, big5_chars_ban1911}, 
    {0x744A, 0x744B, big5_chars_ban1912}, 
    {0x744D, 0x7452, big5_chars_ban1913}, 
    {0x7454, 0x7455, big5_chars_ban1914}, 
    {0x7457, 0x7457, big5_chars_ban1915}, 
    {0x7459, 0x745C, big5_chars_ban1916}, 
    {0x745E, 0x745F, big5_chars_ban1917}, 
    {0x7462, 0x7464, big5_chars_ban1918}, 
    {0x7467, 0x7467, big5_chars_ban1919}, 
    {0x7469, 0x746A, big5_chars_ban1920}, 
    {0x746D, 0x7473, big5_chars_ban1921}, 
    {0x7475, 0x7475, big5_chars_ban1922}, 
    {0x7479, 0x7479, big5_chars_ban1923}, 
    {0x747C, 0x7481, big5_chars_ban1924}, 
    {0x7483, 0x7483, big5_chars_ban1925}, 
    {0x7485, 0x748B, big5_chars_ban1926}, 
    {0x7490, 0x7490, big5_chars_ban1927}, 
    {0x7492, 0x7492, big5_chars_ban1928}, 
    {0x7494, 0x7495, big5_chars_ban1929}, 
    {0x7497, 0x7498, big5_chars_ban1930}, 
    {0x749A, 0x749A, big5_chars_ban1931}, 
    {0x749C, 0x749C, big5_chars_ban1932}, 
    {0x749E, 0x74A1, big5_chars_ban1933}, 
    {0x74A3, 0x74A3, big5_chars_ban1934}, 
    {0x74A5, 0x74AB, big5_chars_ban1935}, 
    {0x74AD, 0x74AD, big5_chars_ban1936}, 
    {0x74AF, 0x74B2, big5_chars_ban1937}, 
    {0x74B5, 0x74B8, big5_chars_ban1938}, 
    {0x74BA, 0x74BB, big5_chars_ban1939}, 
    {0x74BD, 0x74C3, big5_chars_ban1940}, 
    {0x74C5, 0x74C5, big5_chars_ban1941}, 
    {0x74CA, 0x74CB, big5_chars_ban1942}, 
    {0x74CF, 0x74CF, big5_chars_ban1943}, 
    {0x74D4, 0x74E6, big5_chars_ban1944}, 
    {0x74E8, 0x74E9, big5_chars_ban1945}, 
    {0x74EC, 0x74EC, big5_chars_ban1946}, 
    {0x74EE, 0x74EE, big5_chars_ban1947}, 
    {0x74F4, 0x74F7, big5_chars_ban1948}, 
    {0x74FB, 0x74FB, big5_chars_ban1949}, 
    {0x74FD, 0x7500, big5_chars_ban1950}, 
    {0x7502, 0x7504, big5_chars_ban1951}, 
    {0x7507, 0x7508, big5_chars_ban1952}, 
    {0x750B, 0x750D, big5_chars_ban1953}, 
    {0x750F, 0x7518, big5_chars_ban1954}, 
    {0x751A, 0x751A, big5_chars_ban1955}, 
    {0x751C, 0x751D, big5_chars_ban1956}, 
    {0x751F, 0x751F, big5_chars_ban1957}, 
    {0x7521, 0x7522, big5_chars_ban1958}, 
    {0x7525, 0x7526, big5_chars_ban1959}, 
    {0x7528, 0x7533, big5_chars_ban1960}, 
    {0x7537, 0x753A, big5_chars_ban1961}, 
    {0x753D, 0x7540, big5_chars_ban1962}, 
    {0x7547, 0x7548, big5_chars_ban1963}, 
    {0x754B, 0x754C, big5_chars_ban1964}, 
    {0x754E, 0x754F, big5_chars_ban1965}, 
    {0x7554, 0x7554, big5_chars_ban1966}, 
    {0x7559, 0x755D, big5_chars_ban1967}, 
    {0x755F, 0x755F, big5_chars_ban1968}, 
    {0x7562, 0x7566, big5_chars_ban1969}, 
    {0x756A, 0x756C, big5_chars_ban1970}, 
    {0x756F, 0x7570, big5_chars_ban1971}, 
    {0x7576, 0x7579, big5_chars_ban1972}, 
    {0x757D, 0x7580, big5_chars_ban1973}, 
    {0x7584, 0x7584, big5_chars_ban1974}, 
    {0x7586, 0x7587, big5_chars_ban1975}, 
    {0x758A, 0x758C, big5_chars_ban1976}, 
    {0x758F, 0x7591, big5_chars_ban1977}, 
    {0x7594, 0x7595, big5_chars_ban1978}, 
    {0x7598, 0x759A, big5_chars_ban1979}, 
    {0x759D, 0x759D, big5_chars_ban1980}, 
    {0x75A2, 0x75A5, big5_chars_ban1981}, 
    {0x75A7, 0x75A7, big5_chars_ban1982}, 
    {0x75AA, 0x75AB, big5_chars_ban1983}, 
    {0x75B0, 0x75B0, big5_chars_ban1984}, 
    {0x75B2, 0x75B3, big5_chars_ban1985}, 
    {0x75B5, 0x75B6, big5_chars_ban1986}, 
    {0x75B8, 0x75C2, big5_chars_ban1987}, 
    {0x75C4, 0x75C5, big5_chars_ban1988}, 
    {0x75C7, 0x75C7, big5_chars_ban1989}, 
    {0x75CA, 0x75D2, big5_chars_ban1990}, 
    {0x75D4, 0x75D5, big5_chars_ban1991}, 
    {0x75D7, 0x75DB, big5_chars_ban1992}, 
    {0x75DD, 0x75E4, big5_chars_ban1993}, 
    {0x75E6, 0x75E7, big5_chars_ban1994}, 
    {0x75ED, 0x75ED, big5_chars_ban1995}, 
    {0x75EF, 0x7601, big5_chars_ban1996}, 
    {0x7603, 0x7603, big5_chars_ban1997}, 
    {0x7608, 0x760D, big5_chars_ban1998}, 
    {0x760F, 0x7611, big5_chars_ban1999}, 
    {0x7613, 0x7616, big5_chars_ban2000}, 
    {0x7619, 0x7629, big5_chars_ban2001}, 
    {0x762D, 0x762D, big5_chars_ban2002}, 
    {0x762F, 0x7635, big5_chars_ban2003}, 
    {0x7638, 0x7638, big5_chars_ban2004}, 
    {0x763A, 0x763A, big5_chars_ban2005}, 
    {0x763C, 0x763D, big5_chars_ban2006}, 
    {0x7642, 0x7643, big5_chars_ban2007}, 
    {0x7646, 0x7649, big5_chars_ban2008}, 
    {0x764C, 0x764C, big5_chars_ban2009}, 
    {0x7650, 0x7650, big5_chars_ban2010}, 
    {0x7652, 0x7653, big5_chars_ban2011}, 
    {0x7656, 0x765A, big5_chars_ban2012}, 
    {0x765C, 0x765C, big5_chars_ban2013}, 
    {0x765F, 0x7662, big5_chars_ban2014}, 
    {0x7664, 0x7665, big5_chars_ban2015}, 
    {0x7669, 0x766A, big5_chars_ban2016}, 
    {0x766C, 0x766E, big5_chars_ban2017}, 
    {0x7670, 0x7672, big5_chars_ban2018}, 
    {0x7675, 0x7675, big5_chars_ban2019}, 
    {0x7678, 0x7679, big5_chars_ban2020}, 
    {0x767B, 0x767F, big5_chars_ban2021}, 
    {0x7681, 0x7682, big5_chars_ban2022}, 
    {0x7684, 0x7684, big5_chars_ban2023}, 
    {0x7686, 0x768B, big5_chars_ban2024}, 
    {0x768E, 0x768F, big5_chars_ban2025}, 
    {0x7692, 0x7693, big5_chars_ban2026}, 
    {0x7695, 0x7696, big5_chars_ban2027}, 
    {0x7699, 0x769E, big5_chars_ban2028}, 
    {0x76A4, 0x76A4, big5_chars_ban2029}, 
    {0x76A6, 0x76A6, big5_chars_ban2030}, 
    {0x76AA, 0x76AB, big5_chars_ban2031}, 
    {0x76AD, 0x76B0, big5_chars_ban2032}, 
    {0x76B4, 0x76B5, big5_chars_ban2033}, 
    {0x76B8, 0x76B8, big5_chars_ban2034}, 
    {0x76BA, 0x76BB, big5_chars_ban2035}, 
    {0x76BD, 0x76BF, big5_chars_ban2036}, 
    {0x76C2, 0x76C6, big5_chars_ban2037}, 
    {0x76C8, 0x76CA, big5_chars_ban2038}, 
    {0x76CD, 0x76CE, big5_chars_ban2039}, 
    {0x76D2, 0x76D4, big5_chars_ban2040}, 
    {0x76DA, 0x76DF, big5_chars_ban2041}, 
    {0x76E1, 0x76E1, big5_chars_ban2042}, 
    {0x76E3, 0x76E7, big5_chars_ban2043}, 
    {0x76E9, 0x76EA, big5_chars_ban2044}, 
    {0x76EC, 0x76F5, big5_chars_ban2045}, 
    {0x76F7, 0x76FC, big5_chars_ban2046}, 
    {0x76FE, 0x76FE, big5_chars_ban2047}, 
    {0x7701, 0x7701, big5_chars_ban2048}, 
    {0x7703, 0x7705, big5_chars_ban2049}, 
    {0x7707, 0x770B, big5_chars_ban2050}, 
    {0x7710, 0x7713, big5_chars_ban2051}, 
    {0x7715, 0x7715, big5_chars_ban2052}, 
    {0x7719, 0x771B, big5_chars_ban2053}, 
    {0x771D, 0x771D, big5_chars_ban2054}, 
    {0x771F, 0x7720, big5_chars_ban2055}, 
    {0x7722, 0x7723, big5_chars_ban2056}, 
    {0x7725, 0x7725, big5_chars_ban2057}, 
    {0x7727, 0x7729, big5_chars_ban2058}, 
    {0x772D, 0x772D, big5_chars_ban2059}, 
    {0x772F, 0x772F, big5_chars_ban2060}, 
    {0x7731, 0x773E, big5_chars_ban2061}, 
    {0x7744, 0x7747, big5_chars_ban2062}, 
    {0x774A, 0x774F, big5_chars_ban2063}, 
    {0x7752, 0x7752, big5_chars_ban2064}, 
    {0x7754, 0x7756, big5_chars_ban2065}, 
    {0x7759, 0x775C, big5_chars_ban2066}, 
    {0x775E, 0x7763, big5_chars_ban2067}, 
    {0x7765, 0x776F, big5_chars_ban2068}, 
    {0x7779, 0x7779, big5_chars_ban2069}, 
    {0x777C, 0x7785, big5_chars_ban2070}, 
    {0x7787, 0x7789, big5_chars_ban2071}, 
    {0x778B, 0x778F, big5_chars_ban2072}, 
    {0x7791, 0x7791, big5_chars_ban2073}, 
    {0x7795, 0x7795, big5_chars_ban2074}, 
    {0x7797, 0x7797, big5_chars_ban2075}, 
    {0x7799, 0x77A3, big5_chars_ban2076}, 
    {0x77A5, 0x77A5, big5_chars_ban2077}, 
    {0x77A7, 0x77A8, big5_chars_ban2078}, 
    {0x77AA, 0x77AD, big5_chars_ban2079}, 
    {0x77B0, 0x77B7, big5_chars_ban2080}, 
    {0x77BA, 0x77BD, big5_chars_ban2081}, 
    {0x77BF, 0x77BF, big5_chars_ban2082}, 
    {0x77C2, 0x77C2, big5_chars_ban2083}, 
    {0x77C4, 0x77C4, big5_chars_ban2084}, 
    {0x77C7, 0x77C7, big5_chars_ban2085}, 
    {0x77C9, 0x77CA, big5_chars_ban2086}, 
    {0x77CC, 0x77D0, big5_chars_ban2087}, 
    {0x77D3, 0x77D5, big5_chars_ban2088}, 
    {0x77D7, 0x77DC, big5_chars_ban2089}, 
    {0x77DE, 0x77DE, big5_chars_ban2090}, 
    {0x77E0, 0x77E0, big5_chars_ban2091}, 
    {0x77E2, 0x77E3, big5_chars_ban2092}, 
    {0x77E5, 0x77E5, big5_chars_ban2093}, 
    {0x77E7, 0x77E9, big5_chars_ban2094}, 
    {0x77EC, 0x77F3, big5_chars_ban2095}, 
    {0x77F7, 0x77FD, big5_chars_ban2096}, 
    {0x7802, 0x7803, big5_chars_ban2097}, 
    {0x7805, 0x7806, big5_chars_ban2098}, 
    {0x7809, 0x7809, big5_chars_ban2099}, 
    {0x780C, 0x7814, big5_chars_ban2100}, 
    {0x781D, 0x781D, big5_chars_ban2101}, 
    {0x781F, 0x7823, big5_chars_ban2102}, 
    {0x7825, 0x7835, big5_chars_ban2103}, 
    {0x7837, 0x7838, big5_chars_ban2104}, 
    {0x7843, 0x7843, big5_chars_ban2105}, 
    {0x7845, 0x7845, big5_chars_ban2106}, 
    {0x7848, 0x784A, big5_chars_ban2107}, 
    {0x784C, 0x784E, big5_chars_ban2108}, 
    {0x7850, 0x7850, big5_chars_ban2109}, 
    {0x7852, 0x7852, big5_chars_ban2110}, 
    {0x785C, 0x785E, big5_chars_ban2111}, 
    {0x7860, 0x7860, big5_chars_ban2112}, 
    {0x7862, 0x7862, big5_chars_ban2113}, 
    {0x7864, 0x7865, big5_chars_ban2114}, 
    {0x7868, 0x7871, big5_chars_ban2115}, 
    {0x7879, 0x7879, big5_chars_ban2116}, 
    {0x787B, 0x787C, big5_chars_ban2117}, 
    {0x787E, 0x7881, big5_chars_ban2118}, 
    {0x7883, 0x7887, big5_chars_ban2119}, 
    {0x7889, 0x7889, big5_chars_ban2120}, 
    {0x788C, 0x788C, big5_chars_ban2121}, 
    {0x788E, 0x788F, big5_chars_ban2122}, 
    {0x7891, 0x7891, big5_chars_ban2123}, 
    {0x7893, 0x789A, big5_chars_ban2124}, 
    {0x789E, 0x78A5, big5_chars_ban2125}, 
    {0x78A7, 0x78AD, big5_chars_ban2126}, 
    {0x78B0, 0x78B0, big5_chars_ban2127}, 
    {0x78B2, 0x78B4, big5_chars_ban2128}, 
    {0x78BA, 0x78BC, big5_chars_ban2129}, 
    {0x78BE, 0x78BE, big5_chars_ban2130}, 
    {0x78C1, 0x78C1, big5_chars_ban2131}, 
    {0x78C3, 0x78C5, big5_chars_ban2132}, 
    {0x78C8, 0x78D1, big5_chars_ban2133}, 
    {0x78D4, 0x78D5, big5_chars_ban2134}, 
    {0x78DA, 0x78DB, big5_chars_ban2135}, 
    {0x78DD, 0x78E3, big5_chars_ban2136}, 
    {0x78E5, 0x78E5, big5_chars_ban2137}, 
    {0x78E7, 0x78EA, big5_chars_ban2138}, 
    {0x78EC, 0x78ED, big5_chars_ban2139}, 
    {0x78EF, 0x78EF, big5_chars_ban2140}, 
    {0x78F2, 0x78F4, big5_chars_ban2141}, 
    {0x78F7, 0x78F7, big5_chars_ban2142}, 
    {0x78F9, 0x78FF, big5_chars_ban2143}, 
    {0x7901, 0x7902, big5_chars_ban2144}, 
    {0x7904, 0x7905, big5_chars_ban2145}, 
    {0x7909, 0x7909, big5_chars_ban2146}, 
    {0x790C, 0x790C, big5_chars_ban2147}, 
    {0x790E, 0x790E, big5_chars_ban2148}, 
    {0x7910, 0x7914, big5_chars_ban2149}, 
    {0x7917, 0x7917, big5_chars_ban2150}, 
    {0x7919, 0x7919, big5_chars_ban2151}, 
    {0x791B, 0x791E, big5_chars_ban2152}, 
    {0x7921, 0x7921, big5_chars_ban2153}, 
    {0x7923, 0x792D, big5_chars_ban2154}, 
    {0x792F, 0x792F, big5_chars_ban2155}, 
    {0x7931, 0x7931, big5_chars_ban2156}, 
    {0x7935, 0x7935, big5_chars_ban2157}, 
    {0x7938, 0x793A, big5_chars_ban2158}, 
    {0x793D, 0x7942, big5_chars_ban2159}, 
    {0x7944, 0x794C, big5_chars_ban2160}, 
    {0x794F, 0x7957, big5_chars_ban2161}, 
    {0x795A, 0x7961, big5_chars_ban2162}, 
    {0x7963, 0x7965, big5_chars_ban2163}, 
    {0x7967, 0x796B, big5_chars_ban2164}, 
    {0x796D, 0x796D, big5_chars_ban2165}, 
    {0x7970, 0x7970, big5_chars_ban2166}, 
    {0x7972, 0x7974, big5_chars_ban2167}, 
    {0x7979, 0x797A, big5_chars_ban2168}, 
    {0x797C, 0x797D, big5_chars_ban2169}, 
    {0x797F, 0x797F, big5_chars_ban2170}, 
    {0x7981, 0x7982, big5_chars_ban2171}, 
    {0x7988, 0x7988, big5_chars_ban2172}, 
    {0x798A, 0x798B, big5_chars_ban2173}, 
    {0x798D, 0x7990, big5_chars_ban2174}, 
    {0x7992, 0x7998, big5_chars_ban2175}, 
    {0x799A, 0x799C, big5_chars_ban2176}, 
    {0x79A0, 0x79A2, big5_chars_ban2177}, 
    {0x79A4, 0x79A4, big5_chars_ban2178}, 
    {0x79A6, 0x79A8, big5_chars_ban2179}, 
    {0x79AA, 0x79AE, big5_chars_ban2180}, 
    {0x79B0, 0x79B4, big5_chars_ban2181}, 
    {0x79B6, 0x79BB, big5_chars_ban2182}, 
    {0x79BD, 0x79C1, big5_chars_ban2183}, 
    {0x79C5, 0x79C5, big5_chars_ban2184}, 
    {0x79C8, 0x79C9, big5_chars_ban2185}, 
    {0x79CB, 0x79CB, big5_chars_ban2186}, 
    {0x79CD, 0x79CF, big5_chars_ban2187}, 
    {0x79D1, 0x79D2, big5_chars_ban2188}, 
    {0x79D5, 0x79D6, big5_chars_ban2189}, 
    {0x79D8, 0x79D8, big5_chars_ban2190}, 
    {0x79DC, 0x79E0, big5_chars_ban2191}, 
    {0x79E3, 0x79E4, big5_chars_ban2192}, 
    {0x79E6, 0x79E7, big5_chars_ban2193}, 
    {0x79E9, 0x79EE, big5_chars_ban2194}, 
    {0x79F6, 0x79F8, big5_chars_ban2195}, 
    {0x79FA, 0x79FB, big5_chars_ban2196}, 
    {0x7A00, 0x7A00, big5_chars_ban2197}, 
    {0x7A02, 0x7A05, big5_chars_ban2198}, 
    {0x7A08, 0x7A08, big5_chars_ban2199}, 
    {0x7A0A, 0x7A0D, big5_chars_ban2200}, 
    {0x7A10, 0x7A15, big5_chars_ban2201}, 
    {0x7A17, 0x7A1C, big5_chars_ban2202}, 
    {0x7A1E, 0x7A20, big5_chars_ban2203}, 
    {0x7A22, 0x7A22, big5_chars_ban2204}, 
    {0x7A26, 0x7A26, big5_chars_ban2205}, 
    {0x7A28, 0x7A28, big5_chars_ban2206}, 
    {0x7A2B, 0x7A2B, big5_chars_ban2207}, 
    {0x7A2E, 0x7A31, big5_chars_ban2208}, 
    {0x7A37, 0x7A37, big5_chars_ban2209}, 
    {0x7A39, 0x7A39, big5_chars_ban2210}, 
    {0x7A3B, 0x7A3D, big5_chars_ban2211}, 
    {0x7A3F, 0x7A40, big5_chars_ban2212}, 
    {0x7A44, 0x7A44, big5_chars_ban2213}, 
    {0x7A46, 0x7A48, big5_chars_ban2214}, 
    {0x7A4A, 0x7A4E, big5_chars_ban2215}, 
    {0x7A54, 0x7A54, big5_chars_ban2216}, 
    {0x7A56, 0x7A58, big5_chars_ban2217}, 
    {0x7A5A, 0x7A5C, big5_chars_ban2218}, 
    {0x7A5F, 0x7A62, big5_chars_ban2219}, 
    {0x7A67, 0x7A69, big5_chars_ban2220}, 
    {0x7A6B, 0x7A6E, big5_chars_ban2221}, 
    {0x7A70, 0x7A71, big5_chars_ban2222}, 
    {0x7A74, 0x7A76, big5_chars_ban2223}, 
    {0x7A78, 0x7A7B, big5_chars_ban2224}, 
    {0x7A7E, 0x7A81, big5_chars_ban2225}, 
    {0x7A84, 0x7A8C, big5_chars_ban2226}, 
    {0x7A8F, 0x7A90, big5_chars_ban2227}, 
    {0x7A92, 0x7A92, big5_chars_ban2228}, 
    {0x7A94, 0x7A99, big5_chars_ban2229}, 
    {0x7A9E, 0x7AA0, big5_chars_ban2230}, 
    {0x7AA2, 0x7AA3, big5_chars_ban2231}, 
    {0x7AA8, 0x7AAC, big5_chars_ban2232}, 
    {0x7AAE, 0x7AAF, big5_chars_ban2233}, 
    {0x7AB1, 0x7AB8, big5_chars_ban2234}, 
    {0x7ABA, 0x7ABA, big5_chars_ban2235}, 
    {0x7ABE, 0x7AC1, big5_chars_ban2236}, 
    {0x7AC4, 0x7AC5, big5_chars_ban2237}, 
    {0x7AC7, 0x7AC7, big5_chars_ban2238}, 
    {0x7ACA, 0x7ACB, big5_chars_ban2239}, 
    {0x7AD1, 0x7AD1, big5_chars_ban2240}, 
    {0x7AD8, 0x7AD9, big5_chars_ban2241}, 
    {0x7ADF, 0x7AE0, big5_chars_ban2242}, 
    {0x7AE3, 0x7AE6, big5_chars_ban2243}, 
    {0x7AEB, 0x7AEB, big5_chars_ban2244}, 
    {0x7AED, 0x7AEF, big5_chars_ban2245}, 
    {0x7AF6, 0x7AF7, big5_chars_ban2246}, 
    {0x7AF9, 0x7AFB, big5_chars_ban2247}, 
    {0x7AFD, 0x7AFD, big5_chars_ban2248}, 
    {0x7AFF, 0x7B01, big5_chars_ban2249}, 
    {0x7B04, 0x7B06, big5_chars_ban2250}, 
    {0x7B08, 0x7B0A, big5_chars_ban2251}, 
    {0x7B0E, 0x7B13, big5_chars_ban2252}, 
    {0x7B18, 0x7B1B, big5_chars_ban2253}, 
    {0x7B1D, 0x7B1E, big5_chars_ban2254}, 
    {0x7B20, 0x7B20, big5_chars_ban2255}, 
    {0x7B22, 0x7B26, big5_chars_ban2256}, 
    {0x7B28, 0x7B28, big5_chars_ban2257}, 
    {0x7B2A, 0x7B35, big5_chars_ban2258}, 
    {0x7B38, 0x7B38, big5_chars_ban2259}, 
    {0x7B3B, 0x7B3B, big5_chars_ban2260}, 
    {0x7B40, 0x7B40, big5_chars_ban2261}, 
    {0x7B44, 0x7B52, big5_chars_ban2262}, 
    {0x7B54, 0x7B54, big5_chars_ban2263}, 
    {0x7B56, 0x7B56, big5_chars_ban2264}, 
    {0x7B58, 0x7B58, big5_chars_ban2265}, 
    {0x7B60, 0x7B61, big5_chars_ban2266}, 
    {0x7B63, 0x7B67, big5_chars_ban2267}, 
    {0x7B69, 0x7B69, big5_chars_ban2268}, 
    {0x7B6D, 0x7B6E, big5_chars_ban2269}, 
    {0x7B70, 0x7B78, big5_chars_ban2270}, 
    {0x7B82, 0x7B82, big5_chars_ban2271}, 
    {0x7B84, 0x7B85, big5_chars_ban2272}, 
    {0x7B87, 0x7B88, big5_chars_ban2273}, 
    {0x7B8A, 0x7B91, big5_chars_ban2274}, 
    {0x7B94, 0x7B99, big5_chars_ban2275}, 
    {0x7B9B, 0x7B9D, big5_chars_ban2276}, 
    {0x7BA0, 0x7BA1, big5_chars_ban2277}, 
    {0x7BA4, 0x7BA4, big5_chars_ban2278}, 
    {0x7BAC, 0x7BAD, big5_chars_ban2279}, 
    {0x7BAF, 0x7BAF, big5_chars_ban2280}, 
    {0x7BB1, 0x7BB1, big5_chars_ban2281}, 
    {0x7BB4, 0x7BB5, big5_chars_ban2282}, 
    {0x7BB7, 0x7BB9, big5_chars_ban2283}, 
    {0x7BBE, 0x7BBE, big5_chars_ban2284}, 
    {0x7BC0, 0x7BC1, big5_chars_ban2285}, 
    {0x7BC4, 0x7BC4, big5_chars_ban2286}, 
    {0x7BC6, 0x7BC7, big5_chars_ban2287}, 
    {0x7BC9, 0x7BCC, big5_chars_ban2288}, 
    {0x7BCE, 0x7BCE, big5_chars_ban2289}, 
    {0x7BD4, 0x7BD5, big5_chars_ban2290}, 
    {0x7BD8, 0x7BEB, big5_chars_ban2291}, 
    {0x7BF0, 0x7BF4, big5_chars_ban2292}, 
    {0x7BF7, 0x7BF9, big5_chars_ban2293}, 
    {0x7BFB, 0x7BFB, big5_chars_ban2294}, 
    {0x7BFD, 0x7C03, big5_chars_ban2295}, 
    {0x7C05, 0x7C07, big5_chars_ban2296}, 
    {0x7C09, 0x7C11, big5_chars_ban2297}, 
    {0x7C19, 0x7C19, big5_chars_ban2298}, 
    {0x7C1C, 0x7C23, big5_chars_ban2299}, 
    {0x7C25, 0x7C2D, big5_chars_ban2300}, 
    {0x7C30, 0x7C30, big5_chars_ban2301}, 
    {0x7C33, 0x7C33, big5_chars_ban2302}, 
    {0x7C37, 0x7C39, big5_chars_ban2303}, 
    {0x7C3B, 0x7C40, big5_chars_ban2304}, 
    {0x7C43, 0x7C43, big5_chars_ban2305}, 
    {0x7C45, 0x7C45, big5_chars_ban2306}, 
    {0x7C47, 0x7C4A, big5_chars_ban2307}, 
    {0x7C4C, 0x7C4D, big5_chars_ban2308}, 
    {0x7C50, 0x7C50, big5_chars_ban2309}, 
    {0x7C53, 0x7C54, big5_chars_ban2310}, 
    {0x7C57, 0x7C57, big5_chars_ban2311}, 
    {0x7C59, 0x7C5C, big5_chars_ban2312}, 
    {0x7C5F, 0x7C60, big5_chars_ban2313}, 
    {0x7C63, 0x7C67, big5_chars_ban2314}, 
    {0x7C69, 0x7C6C, big5_chars_ban2315}, 
    {0x7C6E, 0x7C6F, big5_chars_ban2316}, 
    {0x7C72, 0x7C73, big5_chars_ban2317}, 
    {0x7C75, 0x7C75, big5_chars_ban2318}, 
    {0x7C78, 0x7C7A, big5_chars_ban2319}, 
    {0x7C7D, 0x7C7D, big5_chars_ban2320}, 
    {0x7C7F, 0x7C81, big5_chars_ban2321}, 
    {0x7C84, 0x7C85, big5_chars_ban2322}, 
    {0x7C88, 0x7C8A, big5_chars_ban2323}, 
    {0x7C8C, 0x7C8D, big5_chars_ban2324}, 
    {0x7C91, 0x7C92, big5_chars_ban2325}, 
    {0x7C94, 0x7C98, big5_chars_ban2326}, 
    {0x7C9E, 0x7C9F, big5_chars_ban2327}, 
    {0x7CA1, 0x7CA3, big5_chars_ban2328}, 
    {0x7CA5, 0x7CA5, big5_chars_ban2329}, 
    {0x7CA7, 0x7CA8, big5_chars_ban2330}, 
    {0x7CAF, 0x7CAF, big5_chars_ban2331}, 
    {0x7CB1, 0x7CB5, big5_chars_ban2332}, 
    {0x7CB9, 0x7CBF, big5_chars_ban2333}, 
    {0x7CC5, 0x7CC5, big5_chars_ban2334}, 
    {0x7CC8, 0x7CC8, big5_chars_ban2335}, 
    {0x7CCA, 0x7CCC, big5_chars_ban2336}, 
    {0x7CCE, 0x7CCE, big5_chars_ban2337}, 
    {0x7CD0, 0x7CD2, big5_chars_ban2338}, 
    {0x7CD4, 0x7CD7, big5_chars_ban2339}, 
    {0x7CD9, 0x7CD9, big5_chars_ban2340}, 
    {0x7CDC, 0x7CE0, big5_chars_ban2341}, 
    {0x7CE2, 0x7CE2, big5_chars_ban2342}, 
    {0x7CE7, 0x7CE8, big5_chars_ban2343}, 
    {0x7CEA, 0x7CEA, big5_chars_ban2344}, 
    {0x7CEC, 0x7CEC, big5_chars_ban2345}, 
    {0x7CEE, 0x7CF2, big5_chars_ban2346}, 
    {0x7CF4, 0x7CF4, big5_chars_ban2347}, 
    {0x7CF6, 0x7CF8, big5_chars_ban2348}, 
    {0x7CFB, 0x7CFB, big5_chars_ban2349}, 
    {0x7CFD, 0x7CFE, big5_chars_ban2350}, 
    {0x7D00, 0x7D22, big5_chars_ban2351}, 
    {0x7D28, 0x7D29, big5_chars_ban2352}, 
    {0x7D2B, 0x7D2C, big5_chars_ban2353}, 
    {0x7D2E, 0x7D33, big5_chars_ban2354}, 
    {0x7D35, 0x7D36, big5_chars_ban2355}, 
    {0x7D38, 0x7D47, big5_chars_ban2356}, 
    {0x7D4A, 0x7D4A, big5_chars_ban2357}, 
    {0x7D4E, 0x7D56, big5_chars_ban2358}, 
    {0x7D58, 0x7D58, big5_chars_ban2359}, 
    {0x7D5B, 0x7D5C, big5_chars_ban2360}, 
    {0x7D5E, 0x7D5F, big5_chars_ban2361}, 
    {0x7D61, 0x7D63, big5_chars_ban2362}, 
    {0x7D66, 0x7D6B, big5_chars_ban2363}, 
    {0x7D6D, 0x7D73, big5_chars_ban2364}, 
    {0x7D79, 0x7D7D, big5_chars_ban2365}, 
    {0x7D7F, 0x7D81, big5_chars_ban2366}, 
    {0x7D83, 0x7D86, big5_chars_ban2367}, 
    {0x7D88, 0x7D88, big5_chars_ban2368}, 
    {0x7D8C, 0x7D8F, big5_chars_ban2369}, 
    {0x7D91, 0x7D94, big5_chars_ban2370}, 
    {0x7D96, 0x7D96, big5_chars_ban2371}, 
    {0x7D9C, 0x7DA3, big5_chars_ban2372}, 
    {0x7DA6, 0x7DA7, big5_chars_ban2373}, 
    {0x7DA9, 0x7DAA, big5_chars_ban2374}, 
    {0x7DAC, 0x7DB2, big5_chars_ban2375}, 
    {0x7DB4, 0x7DB5, big5_chars_ban2376}, 
    {0x7DB7, 0x7DC2, big5_chars_ban2377}, 
    {0x7DC4, 0x7DC7, big5_chars_ban2378}, 
    {0x7DC9, 0x7DCC, big5_chars_ban2379}, 
    {0x7DCE, 0x7DCE, big5_chars_ban2380}, 
    {0x7DD2, 0x7DD2, big5_chars_ban2381}, 
    {0x7DD7, 0x7DDB, big5_chars_ban2382}, 
    {0x7DDD, 0x7DE1, big5_chars_ban2383}, 
    {0x7DE3, 0x7DE3, big5_chars_ban2384}, 
    {0x7DE6, 0x7DEA, big5_chars_ban2385}, 
    {0x7DEC, 0x7DEC, big5_chars_ban2386}, 
    {0x7DEE, 0x7DF4, big5_chars_ban2387}, 
    {0x7DF6, 0x7DF7, big5_chars_ban2388}, 
    {0x7DF9, 0x7DFB, big5_chars_ban2389}, 
    {0x7E03, 0x7E03, big5_chars_ban2390}, 
    {0x7E08, 0x7E17, big5_chars_ban2391}, 
    {0x7E1A, 0x7E25, big5_chars_ban2392}, 
    {0x7E29, 0x7E2B, big5_chars_ban2393}, 
    {0x7E2D, 0x7E49, big5_chars_ban2394}, 
    {0x7E4C, 0x7E4C, big5_chars_ban2395}, 
    {0x7E50, 0x7E5A, big5_chars_ban2396}, 
    {0x7E5C, 0x7E5C, big5_chars_ban2397}, 
    {0x7E5E, 0x7E63, big5_chars_ban2398}, 
    {0x7E68, 0x7E6B, big5_chars_ban2399}, 
    {0x7E6D, 0x7E6D, big5_chars_ban2400}, 
    {0x7E6F, 0x7E70, big5_chars_ban2401}, 
    {0x7E72, 0x7E7E, big5_chars_ban2402}, 
    {0x7E80, 0x7E82, big5_chars_ban2403}, 
    {0x7E86, 0x7E88, big5_chars_ban2404}, 
    {0x7E8A, 0x7E8D, big5_chars_ban2405}, 
    {0x7E8F, 0x7E8F, big5_chars_ban2406}, 
    {0x7E91, 0x7E91, big5_chars_ban2407}, 
    {0x7E93, 0x7E9C, big5_chars_ban2408}, 
    {0x7F36, 0x7F36, big5_chars_ban2409}, 
    {0x7F38, 0x7F3A, big5_chars_ban2410}, 
    {0x7F3D, 0x7F3F, big5_chars_ban2411}, 
    {0x7F43, 0x7F45, big5_chars_ban2412}, 
    {0x7F48, 0x7F48, big5_chars_ban2413}, 
    {0x7F4A, 0x7F4D, big5_chars_ban2414}, 
    {0x7F4F, 0x7F51, big5_chars_ban2415}, 
    {0x7F54, 0x7F55, big5_chars_ban2416}, 
    {0x7F58, 0x7F58, big5_chars_ban2417}, 
    {0x7F5B, 0x7F61, big5_chars_ban2418}, 
    {0x7F63, 0x7F63, big5_chars_ban2419}, 
    {0x7F65, 0x7F6E, big5_chars_ban2420}, 
    {0x7F70, 0x7F70, big5_chars_ban2421}, 
    {0x7F72, 0x7F73, big5_chars_ban2422}, 
    {0x7F75, 0x7F77, big5_chars_ban2423}, 
    {0x7F79, 0x7F7F, big5_chars_ban2424}, 
    {0x7F83, 0x7F83, big5_chars_ban2425}, 
    {0x7F85, 0x7F8E, big5_chars_ban2426}, 
    {0x7F91, 0x7F92, big5_chars_ban2427}, 
    {0x7F94, 0x7F96, big5_chars_ban2428}, 
    {0x7F9A, 0x7F9E, big5_chars_ban2429}, 
    {0x7FA0, 0x7FA2, big5_chars_ban2430}, 
    {0x7FA4, 0x7FA9, big5_chars_ban2431}, 
    {0x7FAC, 0x7FAD, big5_chars_ban2432}, 
    {0x7FAF, 0x7FB3, big5_chars_ban2433}, 
    {0x7FB5, 0x7FC3, big5_chars_ban2434}, 
    {0x7FC5, 0x7FC5, big5_chars_ban2435}, 
    {0x7FC7, 0x7FC7, big5_chars_ban2436}, 
    {0x7FC9, 0x7FD2, big5_chars_ban2437}, 
    {0x7FD4, 0x7FD5, big5_chars_ban2438}, 
    {0x7FD7, 0x7FD7, big5_chars_ban2439}, 
    {0x7FDB, 0x7FDC, big5_chars_ban2440}, 
    {0x7FDE, 0x7FE3, big5_chars_ban2441}, 
    {0x7FE5, 0x7FE6, big5_chars_ban2442}, 
    {0x7FE8, 0x7FF5, big5_chars_ban2443}, 
    {0x7FF7, 0x7FF9, big5_chars_ban2444}, 
    {0x7FFB, 0x8001, big5_chars_ban2445}, 
    {0x8003, 0x8007, big5_chars_ban2446}, 
    {0x800B, 0x8012, big5_chars_ban2447}, 
    {0x8014, 0x8019, big5_chars_ban2448}, 
    {0x801B, 0x801C, big5_chars_ban2449}, 
    {0x801E, 0x801F, big5_chars_ban2450}, 
    {0x8021, 0x8021, big5_chars_ban2451}, 
    {0x8024, 0x8024, big5_chars_ban2452}, 
    {0x8026, 0x8026, big5_chars_ban2453}, 
    {0x8028, 0x802A, big5_chars_ban2454}, 
    {0x802C, 0x802C, big5_chars_ban2455}, 
    {0x8030, 0x8030, big5_chars_ban2456}, 
    {0x8033, 0x8037, big5_chars_ban2457}, 
    {0x8039, 0x8039, big5_chars_ban2458}, 
    {0x803D, 0x803F, big5_chars_ban2459}, 
    {0x8043, 0x8043, big5_chars_ban2460}, 
    {0x8046, 0x8048, big5_chars_ban2461}, 
    {0x804A, 0x804A, big5_chars_ban2462}, 
    {0x804F, 0x8052, big5_chars_ban2463}, 
    {0x8056, 0x8056, big5_chars_ban2464}, 
    {0x8058, 0x8058, big5_chars_ban2465}, 
    {0x805A, 0x805A, big5_chars_ban2466}, 
    {0x805C, 0x805E, big5_chars_ban2467}, 
    {0x8064, 0x8064, big5_chars_ban2468}, 
    {0x8067, 0x8067, big5_chars_ban2469}, 
    {0x806C, 0x806C, big5_chars_ban2470}, 
    {0x806F, 0x8073, big5_chars_ban2471}, 
    {0x8075, 0x8079, big5_chars_ban2472}, 
    {0x807D, 0x807F, big5_chars_ban2473}, 
    {0x8082, 0x8082, big5_chars_ban2474}, 
    {0x8084, 0x8087, big5_chars_ban2475}, 
    {0x8089, 0x808C, big5_chars_ban2476}, 
    {0x808F, 0x8090, big5_chars_ban2477}, 
    {0x8092, 0x8093, big5_chars_ban2478}, 
    {0x8095, 0x8096, big5_chars_ban2479}, 
    {0x8098, 0x809D, big5_chars_ban2480}, 
    {0x80A1, 0x80A3, big5_chars_ban2481}, 
    {0x80A5, 0x80A5, big5_chars_ban2482}, 
    {0x80A9, 0x80AB, big5_chars_ban2483}, 
    {0x80AD, 0x80AF, big5_chars_ban2484}, 
    {0x80B1, 0x80B2, big5_chars_ban2485}, 
    {0x80B4, 0x80B5, big5_chars_ban2486}, 
    {0x80B8, 0x80B8, big5_chars_ban2487}, 
    {0x80BA, 0x80BA, big5_chars_ban2488}, 
    {0x80C2, 0x80C5, big5_chars_ban2489}, 
    {0x80C7, 0x80CA, big5_chars_ban2490}, 
    {0x80CC, 0x80D1, big5_chars_ban2491}, 
    {0x80D4, 0x80DE, big5_chars_ban2492}, 
    {0x80E0, 0x80E1, big5_chars_ban2493}, 
    {0x80E3, 0x80E6, big5_chars_ban2494}, 
    {0x80ED, 0x80ED, big5_chars_ban2495}, 
    {0x80EF, 0x80F5, big5_chars_ban2496}, 
    {0x80F8, 0x80FE, big5_chars_ban2497}, 
    {0x8100, 0x8102, big5_chars_ban2498}, 
    {0x8105, 0x8106, big5_chars_ban2499}, 
    {0x8108, 0x8108, big5_chars_ban2500}, 
    {0x810A, 0x810A, big5_chars_ban2501}, 
    {0x8115, 0x8116, big5_chars_ban2502}, 
    {0x8118, 0x8119, big5_chars_ban2503}, 
    {0x811B, 0x811B, big5_chars_ban2504}, 
    {0x811D, 0x811F, big5_chars_ban2505}, 
    {0x8121, 0x8125, big5_chars_ban2506}, 
    {0x8127, 0x8127, big5_chars_ban2507}, 
    {0x8129, 0x8129, big5_chars_ban2508}, 
    {0x812B, 0x812D, big5_chars_ban2509}, 
    {0x812F, 0x8130, big5_chars_ban2510}, 
    {0x8139, 0x813A, big5_chars_ban2511}, 
    {0x813D, 0x813E, big5_chars_ban2512}, 
    {0x8143, 0x8144, big5_chars_ban2513}, 
    {0x8146, 0x8147, big5_chars_ban2514}, 
    {0x814A, 0x8155, big5_chars_ban2515}, 
    {0x815B, 0x815C, big5_chars_ban2516}, 
    {0x815E, 0x815E, big5_chars_ban2517}, 
    {0x8160, 0x8162, big5_chars_ban2518}, 
    {0x8164, 0x8167, big5_chars_ban2519}, 
    {0x8169, 0x8169, big5_chars_ban2520}, 
    {0x816B, 0x816B, big5_chars_ban2521}, 
    {0x816E, 0x8174, big5_chars_ban2522}, 
    {0x8176, 0x817A, big5_chars_ban2523}, 
    {0x817F, 0x8180, big5_chars_ban2524}, 
    {0x8182, 0x8183, big5_chars_ban2525}, 
    {0x8186, 0x818D, big5_chars_ban2526}, 
    {0x818F, 0x818F, big5_chars_ban2527}, 
    {0x8195, 0x8195, big5_chars_ban2528}, 
    {0x8197, 0x81A0, big5_chars_ban2529}, 
    {0x81A2, 0x81A3, big5_chars_ban2530}, 
    {0x81A6, 0x81A9, big5_chars_ban2531}, 
    {0x81AB, 0x81AC, big5_chars_ban2532}, 
    {0x81AE, 0x81AE, big5_chars_ban2533}, 
    {0x81B0, 0x81B5, big5_chars_ban2534}, 
    {0x81B7, 0x81B7, big5_chars_ban2535}, 
    {0x81B9, 0x81C0, big5_chars_ban2536}, 
    {0x81C2, 0x81C7, big5_chars_ban2537}, 
    {0x81C9, 0x81CA, big5_chars_ban2538}, 
    {0x81CC, 0x81CD, big5_chars_ban2539}, 
    {0x81CF, 0x81D2, big5_chars_ban2540}, 
    {0x81D5, 0x81D5, big5_chars_ban2541}, 
    {0x81D7, 0x81DB, big5_chars_ban2542}, 
    {0x81DD, 0x81E3, big5_chars_ban2543}, 
    {0x81E5, 0x81EA, big5_chars_ban2544}, 
    {0x81EC, 0x81EE, big5_chars_ban2545}, 
    {0x81F2, 0x81F4, big5_chars_ban2546}, 
    {0x81F7, 0x81FC, big5_chars_ban2547}, 
    {0x81FE, 0x8202, big5_chars_ban2548}, 
    {0x8204, 0x8205, big5_chars_ban2549}, 
    {0x8207, 0x820D, big5_chars_ban2550}, 
    {0x8210, 0x8212, big5_chars_ban2551}, 
    {0x8214, 0x8216, big5_chars_ban2552}, 
    {0x821B, 0x8222, big5_chars_ban2553}, 
    {0x8225, 0x8225, big5_chars_ban2554}, 
    {0x8228, 0x8228, big5_chars_ban2555}, 
    {0x822A, 0x822C, big5_chars_ban2556}, 
    {0x822F, 0x822F, big5_chars_ban2557}, 
    {0x8232, 0x823A, big5_chars_ban2558}, 
    {0x823C, 0x823D, big5_chars_ban2559}, 
    {0x823F, 0x8240, big5_chars_ban2560}, 
    {0x8242, 0x8242, big5_chars_ban2561}, 
    {0x8244, 0x8245, big5_chars_ban2562}, 
    {0x8247, 0x8247, big5_chars_ban2563}, 
    {0x8249, 0x8249, big5_chars_ban2564}, 
    {0x824B, 0x824B, big5_chars_ban2565}, 
    {0x824E, 0x8253, big5_chars_ban2566}, 
    {0x8255, 0x825C, big5_chars_ban2567}, 
    {0x825E, 0x825F, big5_chars_ban2568}, 
    {0x8261, 0x8261, big5_chars_ban2569}, 
    {0x8263, 0x8264, big5_chars_ban2570}, 
    {0x8266, 0x8266, big5_chars_ban2571}, 
    {0x8268, 0x8269, big5_chars_ban2572}, 
    {0x826B, 0x826F, big5_chars_ban2573}, 
    {0x8271, 0x8272, big5_chars_ban2574}, 
    {0x8274, 0x8275, big5_chars_ban2575}, 
    {0x8277, 0x8278, big5_chars_ban2576}, 
    {0x827C, 0x8280, big5_chars_ban2577}, 
    {0x8283, 0x8285, big5_chars_ban2578}, 
    {0x828A, 0x828B, big5_chars_ban2579}, 
    {0x828D, 0x8294, big5_chars_ban2580}, 
    {0x8298, 0x829B, big5_chars_ban2581}, 
    {0x829D, 0x82A5, big5_chars_ban2582}, 
    {0x82A7, 0x82A9, big5_chars_ban2583}, 
    {0x82AB, 0x82B1, big5_chars_ban2584}, 
    {0x82B3, 0x82BE, big5_chars_ban2585}, 
    {0x82C0, 0x82C0, big5_chars_ban2586}, 
    {0x82C2, 0x82C3, big5_chars_ban2587}, 
    {0x82D1, 0x82D7, big5_chars_ban2588}, 
    {0x82D9, 0x82D9, big5_chars_ban2589}, 
    {0x82DB, 0x82DC, big5_chars_ban2590}, 
    {0x82DE, 0x82E1, big5_chars_ban2591}, 
    {0x82E3, 0x82E8, big5_chars_ban2592}, 
    {0x82EA, 0x82ED, big5_chars_ban2593}, 
    {0x82EF, 0x82F6, big5_chars_ban2594}, 
    {0x82F9, 0x82FB, big5_chars_ban2595}, 
    {0x82FE, 0x82FE, big5_chars_ban2596}, 
    {0x8300, 0x8309, big5_chars_ban2597}, 
    {0x830C, 0x830D, big5_chars_ban2598}, 
    {0x8316, 0x8317, big5_chars_ban2599}, 
    {0x8319, 0x8319, big5_chars_ban2600}, 
    {0x831B, 0x831C, big5_chars_ban2601}, 
    {0x831E, 0x831E, big5_chars_ban2602}, 
    {0x8320, 0x8320, big5_chars_ban2603}, 
    {0x8322, 0x8322, big5_chars_ban2604}, 
    {0x8324, 0x832D, big5_chars_ban2605}, 
    {0x832F, 0x832F, big5_chars_ban2606}, 
    {0x8331, 0x833C, big5_chars_ban2607}, 
    {0x833F, 0x8345, big5_chars_ban2608}, 
    {0x8347, 0x8354, big5_chars_ban2609}, 
    {0x8356, 0x8356, big5_chars_ban2610}, 
    {0x8373, 0x8378, big5_chars_ban2611}, 
    {0x837A, 0x837F, big5_chars_ban2612}, 
    {0x8381, 0x8381, big5_chars_ban2613}, 
    {0x8383, 0x8383, big5_chars_ban2614}, 
    {0x8386, 0x8390, big5_chars_ban2615}, 
    {0x8392, 0x839B, big5_chars_ban2616}, 
    {0x839D, 0x839E, big5_chars_ban2617}, 
    {0x83A0, 0x83A0, big5_chars_ban2618}, 
    {0x83A2, 0x83AB, big5_chars_ban2619}, 
    {0x83AE, 0x83B0, big5_chars_ban2620}, 
    {0x83BD, 0x83BD, big5_chars_ban2621}, 
    {0x83BF, 0x83CC, big5_chars_ban2622}, 
    {0x83CE, 0x83CF, big5_chars_ban2623}, 
    {0x83D1, 0x83D1, big5_chars_ban2624}, 
    {0x83D4, 0x83D9, big5_chars_ban2625}, 
    {0x83DB, 0x83E5, big5_chars_ban2626}, 
    {0x83E7, 0x83EC, big5_chars_ban2627}, 
    {0x83EE, 0x83F6, big5_chars_ban2628}, 
    {0x83F8, 0x83FF, big5_chars_ban2629}, 
    {0x8401, 0x8401, big5_chars_ban2630}, 
    {0x8403, 0x8404, big5_chars_ban2631}, 
    {0x8406, 0x8407, big5_chars_ban2632}, 
    {0x8409, 0x8413, big5_chars_ban2633}, 
    {0x841B, 0x841B, big5_chars_ban2634}, 
    {0x8423, 0x8423, big5_chars_ban2635}, 
    {0x8429, 0x8429, big5_chars_ban2636}, 
    {0x842B, 0x842D, big5_chars_ban2637}, 
    {0x842F, 0x843D, big5_chars_ban2638}, 
    {0x843F, 0x8440, big5_chars_ban2639}, 
    {0x8442, 0x8447, big5_chars_ban2640}, 
    {0x8449, 0x8449, big5_chars_ban2641}, 
    {0x844B, 0x844E, big5_chars_ban2642}, 
    {0x8450, 0x8452, big5_chars_ban2643}, 
    {0x8454, 0x8454, big5_chars_ban2644}, 
    {0x8456, 0x8457, big5_chars_ban2645}, 
    {0x8459, 0x845B, big5_chars_ban2646}, 
    {0x845D, 0x8461, big5_chars_ban2647}, 
    {0x8463, 0x8463, big5_chars_ban2648}, 
    {0x8465, 0x8469, big5_chars_ban2649}, 
    {0x846B, 0x8470, big5_chars_ban2650}, 
    {0x8473, 0x847A, big5_chars_ban2651}, 
    {0x847D, 0x847E, big5_chars_ban2652}, 
    {0x8482, 0x8482, big5_chars_ban2653}, 
    {0x8486, 0x8486, big5_chars_ban2654}, 
    {0x848D, 0x8491, big5_chars_ban2655}, 
    {0x8494, 0x8494, big5_chars_ban2656}, 
    {0x8497, 0x84A2, big5_chars_ban2657}, 
    {0x84A4, 0x84A4, big5_chars_ban2658}, 
    {0x84A7, 0x84AC, big5_chars_ban2659}, 
    {0x84AE, 0x84B2, big5_chars_ban2660}, 
    {0x84B4, 0x84B4, big5_chars_ban2661}, 
    {0x84B6, 0x84B6, big5_chars_ban2662}, 
    {0x84B8, 0x84BC, big5_chars_ban2663}, 
    {0x84BF, 0x84C2, big5_chars_ban2664}, 
    {0x84C4, 0x84C7, big5_chars_ban2665}, 
    {0x84C9, 0x84D4, big5_chars_ban2666}, 
    {0x84D6, 0x84D7, big5_chars_ban2667}, 
    {0x84DB, 0x84DB, big5_chars_ban2668}, 
    {0x84E7, 0x84EC, big5_chars_ban2669}, 
    {0x84EE, 0x84F4, big5_chars_ban2670}, 
    {0x84F6, 0x84F7, big5_chars_ban2671}, 
    {0x84F9, 0x8500, big5_chars_ban2672}, 
    {0x8502, 0x8502, big5_chars_ban2673}, 
    {0x8506, 0x850F, big5_chars_ban2674}, 
    {0x8511, 0x851A, big5_chars_ban2675}, 
    {0x851C, 0x8521, big5_chars_ban2676}, 
    {0x8523, 0x8531, big5_chars_ban2677}, 
    {0x853B, 0x853B, big5_chars_ban2678}, 
    {0x853D, 0x853E, big5_chars_ban2679}, 
    {0x8540, 0x8541, big5_chars_ban2680}, 
    {0x8543, 0x854A, big5_chars_ban2681}, 
    {0x854D, 0x854E, big5_chars_ban2682}, 
    {0x8551, 0x8551, big5_chars_ban2683}, 
    {0x8553, 0x8559, big5_chars_ban2684}, 
    {0x855B, 0x855B, big5_chars_ban2685}, 
    {0x855D, 0x855E, big5_chars_ban2686}, 
    {0x8560, 0x856E, big5_chars_ban2687}, 
    {0x8571, 0x8571, big5_chars_ban2688}, 
    {0x8575, 0x857C, big5_chars_ban2689}, 
    {0x857E, 0x857E, big5_chars_ban2690}, 
    {0x8580, 0x8591, big5_chars_ban2691}, 
    {0x8594, 0x8596, big5_chars_ban2692}, 
    {0x8598, 0x85A4, big5_chars_ban2693}, 
    {0x85A6, 0x85AA, big5_chars_ban2694}, 
    {0x85AF, 0x85B1, big5_chars_ban2695}, 
    {0x85B3, 0x85BA, big5_chars_ban2696}, 
    {0x85BD, 0x85C0, big5_chars_ban2697}, 
    {0x85C2, 0x85C9, big5_chars_ban2698}, 
    {0x85CB, 0x85CB, big5_chars_ban2699}, 
    {0x85CD, 0x85D2, big5_chars_ban2700}, 
    {0x85D5, 0x85D5, big5_chars_ban2701}, 
    {0x85D7, 0x85DA, big5_chars_ban2702}, 
    {0x85DC, 0x85DF, big5_chars_ban2703}, 
    {0x85E1, 0x85E6, big5_chars_ban2704}, 
    {0x85E8, 0x85ED, big5_chars_ban2705}, 
    {0x85EF, 0x85F2, big5_chars_ban2706}, 
    {0x85F6, 0x85FB, big5_chars_ban2707}, 
    {0x85FD, 0x8601, big5_chars_ban2708}, 
    {0x8604, 0x8607, big5_chars_ban2709}, 
    {0x8609, 0x860C, big5_chars_ban2710}, 
    {0x8611, 0x8611, big5_chars_ban2711}, 
    {0x8617, 0x861C, big5_chars_ban2712}, 
    {0x861E, 0x8627, big5_chars_ban2713}, 
    {0x8629, 0x862A, big5_chars_ban2714}, 
    {0x862C, 0x862E, big5_chars_ban2715}, 
    {0x8631, 0x8636, big5_chars_ban2716}, 
    {0x8638, 0x863C, big5_chars_ban2717}, 
    {0x863E, 0x8640, big5_chars_ban2718}, 
    {0x8643, 0x8643, big5_chars_ban2719}, 
    {0x8646, 0x8648, big5_chars_ban2720}, 
    {0x864B, 0x864E, big5_chars_ban2721}, 
    {0x8650, 0x8650, big5_chars_ban2722}, 
    {0x8652, 0x8656, big5_chars_ban2723}, 
    {0x8659, 0x8659, big5_chars_ban2724}, 
    {0x865B, 0x865C, big5_chars_ban2725}, 
    {0x865E, 0x865F, big5_chars_ban2726}, 
    {0x8661, 0x8665, big5_chars_ban2727}, 
    {0x8667, 0x866B, big5_chars_ban2728}, 
    {0x866D, 0x8671, big5_chars_ban2729}, 
    {0x8673, 0x8674, big5_chars_ban2730}, 
    {0x8677, 0x8677, big5_chars_ban2731}, 
    {0x8679, 0x867C, big5_chars_ban2732}, 
    {0x8685, 0x8687, big5_chars_ban2733}, 
    {0x868A, 0x868E, big5_chars_ban2734}, 
    {0x8690, 0x8691, big5_chars_ban2735}, 
    {0x8693, 0x869A, big5_chars_ban2736}, 
    {0x869C, 0x869E, big5_chars_ban2737}, 
    {0x86A1, 0x86A5, big5_chars_ban2738}, 
    {0x86A7, 0x86AA, big5_chars_ban2739}, 
    {0x86AF, 0x86B1, big5_chars_ban2740}, 
    {0x86B3, 0x86C9, big5_chars_ban2741}, 
    {0x86CB, 0x86CC, big5_chars_ban2742}, 
    {0x86D0, 0x86D1, big5_chars_ban2743}, 
    {0x86D3, 0x86D4, big5_chars_ban2744}, 
    {0x86D6, 0x86DF, big5_chars_ban2745}, 
    {0x86E2, 0x86E4, big5_chars_ban2746}, 
    {0x86E6, 0x86E6, big5_chars_ban2747}, 
    {0x86E8, 0x86ED, big5_chars_ban2748}, 
    {0x86F5, 0x86FB, big5_chars_ban2749}, 
    {0x86FE, 0x86FE, big5_chars_ban2750}, 
    {0x8700, 0x870E, big5_chars_ban2751}, 
    {0x8711, 0x8713, big5_chars_ban2752}, 
    {0x8718, 0x871C, big5_chars_ban2753}, 
    {0x871E, 0x871E, big5_chars_ban2754}, 
    {0x8720, 0x872A, big5_chars_ban2755}, 
    {0x872C, 0x872E, big5_chars_ban2756}, 
    {0x8730, 0x8735, big5_chars_ban2757}, 
    {0x8737, 0x8738, big5_chars_ban2758}, 
    {0x873A, 0x873C, big5_chars_ban2759}, 
    {0x873E, 0x8743, big5_chars_ban2760}, 
    {0x8746, 0x8746, big5_chars_ban2761}, 
    {0x874C, 0x876F, big5_chars_ban2762}, 
    {0x8773, 0x877B, big5_chars_ban2763}, 
    {0x8781, 0x8785, big5_chars_ban2764}, 
    {0x8787, 0x8789, big5_chars_ban2765}, 
    {0x878D, 0x878D, big5_chars_ban2766}, 
    {0x878F, 0x8794, big5_chars_ban2767}, 
    {0x8796, 0x8798, big5_chars_ban2768}, 
    {0x879A, 0x879F, big5_chars_ban2769}, 
    {0x87A2, 0x87A4, big5_chars_ban2770}, 
    {0x87AA, 0x87B0, big5_chars_ban2771}, 
    {0x87B2, 0x87C0, big5_chars_ban2772}, 
    {0x87C2, 0x87C6, big5_chars_ban2773}, 
    {0x87C8, 0x87CC, big5_chars_ban2774}, 
    {0x87D1, 0x87D4, big5_chars_ban2775}, 
    {0x87D7, 0x87D9, big5_chars_ban2776}, 
    {0x87DB, 0x87E8, big5_chars_ban2777}, 
    {0x87EA, 0x87ED, big5_chars_ban2778}, 
    {0x87EF, 0x87EF, big5_chars_ban2779}, 
    {0x87F2, 0x87F4, big5_chars_ban2780}, 
    {0x87F6, 0x87F7, big5_chars_ban2781}, 
    {0x87F9, 0x87FC, big5_chars_ban2782}, 
    {0x87FE, 0x8803, big5_chars_ban2783}, 
    {0x8805, 0x8806, big5_chars_ban2784}, 
    {0x8808, 0x880D, big5_chars_ban2785}, 
    {0x8810, 0x8811, big5_chars_ban2786}, 
    {0x8813, 0x8817, big5_chars_ban2787}, 
    {0x8819, 0x8819, big5_chars_ban2788}, 
    {0x881B, 0x881D, big5_chars_ban2789}, 
    {0x881F, 0x8826, big5_chars_ban2790}, 
    {0x8828, 0x882C, big5_chars_ban2791}, 
    {0x882E, 0x8833, big5_chars_ban2792}, 
    {0x8835, 0x8839, big5_chars_ban2793}, 
    {0x883B, 0x8841, big5_chars_ban2794}, 
    {0x8843, 0x8844, big5_chars_ban2795}, 
    {0x8848, 0x8848, big5_chars_ban2796}, 
    {0x884A, 0x884E, big5_chars_ban2797}, 
    {0x8852, 0x8853, big5_chars_ban2798}, 
    {0x8855, 0x8857, big5_chars_ban2799}, 
    {0x8859, 0x885B, big5_chars_ban2800}, 
    {0x885D, 0x885D, big5_chars_ban2801}, 
    {0x8861, 0x8863, big5_chars_ban2802}, 
    {0x8867, 0x886B, big5_chars_ban2803}, 
    {0x886D, 0x886D, big5_chars_ban2804}, 
    {0x886F, 0x8872, big5_chars_ban2805}, 
    {0x8874, 0x8877, big5_chars_ban2806}, 
    {0x8879, 0x8879, big5_chars_ban2807}, 
    {0x887C, 0x8883, big5_chars_ban2808}, 
    {0x8888, 0x8889, big5_chars_ban2809}, 
    {0x888B, 0x888E, big5_chars_ban2810}, 
    {0x8891, 0x8893, big5_chars_ban2811}, 
    {0x8895, 0x889B, big5_chars_ban2812}, 
    {0x889E, 0x889F, big5_chars_ban2813}, 
    {0x88A1, 0x88A2, big5_chars_ban2814}, 
    {0x88A4, 0x88A4, big5_chars_ban2815}, 
    {0x88A7, 0x88A8, big5_chars_ban2816}, 
    {0x88AA, 0x88AC, big5_chars_ban2817}, 
    {0x88B1, 0x88B2, big5_chars_ban2818}, 
    {0x88B6, 0x88BA, big5_chars_ban2819}, 
    {0x88BC, 0x88BE, big5_chars_ban2820}, 
    {0x88C0, 0x88C2, big5_chars_ban2821}, 
    {0x88C9, 0x88D0, big5_chars_ban2822}, 
    {0x88D2, 0x88D2, big5_chars_ban2823}, 
    {0x88D4, 0x88DF, big5_chars_ban2824}, 
    {0x88E1, 0x88E1, big5_chars_ban2825}, 
    {0x88E7, 0x88E8, big5_chars_ban2826}, 
    {0x88EB, 0x88EC, big5_chars_ban2827}, 
    {0x88EE, 0x88F4, big5_chars_ban2828}, 
    {0x88F6, 0x88FE, big5_chars_ban2829}, 
    {0x8901, 0x8902, big5_chars_ban2830}, 
    {0x8905, 0x8907, big5_chars_ban2831}, 
    {0x8909, 0x890C, big5_chars_ban2832}, 
    {0x890E, 0x890E, big5_chars_ban2833}, 
    {0x8910, 0x891A, big5_chars_ban2834}, 
    {0x891E, 0x891F, big5_chars_ban2835}, 
    {0x8921, 0x8923, big5_chars_ban2836}, 
    {0x8925, 0x8927, big5_chars_ban2837}, 
    {0x8929, 0x8933, big5_chars_ban2838}, 
    {0x8935, 0x8938, big5_chars_ban2839}, 
    {0x893B, 0x893E, big5_chars_ban2840}, 
    {0x8941, 0x8942, big5_chars_ban2841}, 
    {0x8944, 0x8944, big5_chars_ban2842}, 
    {0x8946, 0x8946, big5_chars_ban2843}, 
    {0x8949, 0x8949, big5_chars_ban2844}, 
    {0x894B, 0x894C, big5_chars_ban2845}, 
    {0x894F, 0x8953, big5_chars_ban2846}, 
    {0x8956, 0x8964, big5_chars_ban2847}, 
    {0x8966, 0x8966, big5_chars_ban2848}, 
    {0x8969, 0x896F, big5_chars_ban2849}, 
    {0x8971, 0x8974, big5_chars_ban2850}, 
    {0x8976, 0x8976, big5_chars_ban2851}, 
    {0x8979, 0x897C, big5_chars_ban2852}, 
    {0x897E, 0x897F, big5_chars_ban2853}, 
    {0x8981, 0x8983, big5_chars_ban2854}, 
    {0x8985, 0x8986, big5_chars_ban2855}, 
    {0x8988, 0x8988, big5_chars_ban2856}, 
    {0x898B, 0x898B, big5_chars_ban2857}, 
    {0x898F, 0x898F, big5_chars_ban2858}, 
    {0x8993, 0x8993, big5_chars_ban2859}, 
    {0x8995, 0x8998, big5_chars_ban2860}, 
    {0x899B, 0x899F, big5_chars_ban2861}, 
    {0x89A1, 0x89A4, big5_chars_ban2862}, 
    {0x89A6, 0x89A6, big5_chars_ban2863}, 
    {0x89AA, 0x89AA, big5_chars_ban2864}, 
    {0x89AC, 0x89AF, big5_chars_ban2865}, 
    {0x89B2, 0x89B2, big5_chars_ban2866}, 
    {0x89B6, 0x89B7, big5_chars_ban2867}, 
    {0x89B9, 0x89BA, big5_chars_ban2868}, 
    {0x89BD, 0x89C0, big5_chars_ban2869}, 
    {0x89D2, 0x89D6, big5_chars_ban2870}, 
    {0x89D9, 0x89DD, big5_chars_ban2871}, 
    {0x89DF, 0x89E6, big5_chars_ban2872}, 
    {0x89E8, 0x89E9, big5_chars_ban2873}, 
    {0x89EB, 0x89ED, big5_chars_ban2874}, 
    {0x89F0, 0x89F4, big5_chars_ban2875}, 
    {0x89F6, 0x89F8, big5_chars_ban2876}, 
    {0x89FA, 0x89FC, big5_chars_ban2877}, 
    {0x89FE, 0x8A00, big5_chars_ban2878}, 
    {0x8A02, 0x8A04, big5_chars_ban2879}, 
    {0x8A07, 0x8A08, big5_chars_ban2880}, 
    {0x8A0A, 0x8A0A, big5_chars_ban2881}, 
    {0x8A0C, 0x8A0C, big5_chars_ban2882}, 
    {0x8A0E, 0x8A13, big5_chars_ban2883}, 
    {0x8A15, 0x8A18, big5_chars_ban2884}, 
    {0x8A1B, 0x8A1B, big5_chars_ban2885}, 
    {0x8A1D, 0x8A1F, big5_chars_ban2886}, 
    {0x8A22, 0x8A23, big5_chars_ban2887}, 
    {0x8A25, 0x8A25, big5_chars_ban2888}, 
    {0x8A27, 0x8A27, big5_chars_ban2889}, 
    {0x8A2A, 0x8A2A, big5_chars_ban2890}, 
    {0x8A2C, 0x8A2D, big5_chars_ban2891}, 
    {0x8A30, 0x8A31, big5_chars_ban2892}, 
    {0x8A34, 0x8A34, big5_chars_ban2893}, 
    {0x8A36, 0x8A36, big5_chars_ban2894}, 
    {0x8A39, 0x8A3C, big5_chars_ban2895}, 
    {0x8A3E, 0x8A41, big5_chars_ban2896}, 
    {0x8A44, 0x8A46, big5_chars_ban2897}, 
    {0x8A48, 0x8A48, big5_chars_ban2898}, 
    {0x8A4A, 0x8A4A, big5_chars_ban2899}, 
    {0x8A4C, 0x8A52, big5_chars_ban2900}, 
    {0x8A54, 0x8A59, big5_chars_ban2901}, 
    {0x8A5B, 0x8A5B, big5_chars_ban2902}, 
    {0x8A5E, 0x8A5E, big5_chars_ban2903}, 
    {0x8A60, 0x8A63, big5_chars_ban2904}, 
    {0x8A66, 0x8A66, big5_chars_ban2905}, 
    {0x8A68, 0x8A69, big5_chars_ban2906}, 
    {0x8A6B, 0x8A6E, big5_chars_ban2907}, 
    {0x8A70, 0x8A77, big5_chars_ban2908}, 
    {0x8A79, 0x8A7C, big5_chars_ban2909}, 
    {0x8A7F, 0x8A7F, big5_chars_ban2910}, 
    {0x8A81, 0x8A87, big5_chars_ban2911}, 
    {0x8A8B, 0x8A8D, big5_chars_ban2912}, 
    {0x8A8F, 0x8A8F, big5_chars_ban2913}, 
    {0x8A91, 0x8A93, big5_chars_ban2914}, 
    {0x8A95, 0x8A96, big5_chars_ban2915}, 
    {0x8A98, 0x8A9A, big5_chars_ban2916}, 
    {0x8A9E, 0x8A9E, big5_chars_ban2917}, 
    {0x8AA0, 0x8AA1, big5_chars_ban2918}, 
    {0x8AA3, 0x8AA8, big5_chars_ban2919}, 
    {0x8AAA, 0x8AAB, big5_chars_ban2920}, 
    {0x8AB0, 0x8AB0, big5_chars_ban2921}, 
    {0x8AB2, 0x8AB2, big5_chars_ban2922}, 
    {0x8AB6, 0x8AB6, big5_chars_ban2923}, 
    {0x8AB8, 0x8AC0, big5_chars_ban2924}, 
    {0x8AC2, 0x8AC9, big5_chars_ban2925}, 
    {0x8ACB, 0x8ACB, big5_chars_ban2926}, 
    {0x8ACD, 0x8ACD, big5_chars_ban2927}, 
    {0x8ACF, 0x8ACF, big5_chars_ban2928}, 
    {0x8AD1, 0x8AD9, big5_chars_ban2929}, 
    {0x8ADB, 0x8AE2, big5_chars_ban2930}, 
    {0x8AE4, 0x8AE4, big5_chars_ban2931}, 
    {0x8AE6, 0x8AE8, big5_chars_ban2932}, 
    {0x8AEB, 0x8AEB, big5_chars_ban2933}, 
    {0x8AED, 0x8AF8, big5_chars_ban2934}, 
    {0x8AFA, 0x8AFC, big5_chars_ban2935}, 
    {0x8AFE, 0x8B02, big5_chars_ban2936}, 
    {0x8B04, 0x8B08, big5_chars_ban2937}, 
    {0x8B0A, 0x8B0B, big5_chars_ban2938}, 
    {0x8B0D, 0x8B1E, big5_chars_ban2939}, 
    {0x8B20, 0x8B20, big5_chars_ban2940}, 
    {0x8B22, 0x8B28, big5_chars_ban2941}, 
    {0x8B2A, 0x8B2C, big5_chars_ban2942}, 
    {0x8B2E, 0x8B31, big5_chars_ban2943}, 
    {0x8B33, 0x8B33, big5_chars_ban2944}, 
    {0x8B35, 0x8B37, big5_chars_ban2945}, 
    {0x8B39, 0x8B3E, big5_chars_ban2946}, 
    {0x8B40, 0x8B42, big5_chars_ban2947}, 
    {0x8B45, 0x8B4B, big5_chars_ban2948}, 
    {0x8B4E, 0x8B5A, big5_chars_ban2949}, 
    {0x8B5C, 0x8B5D, big5_chars_ban2950}, 
    {0x8B5F, 0x8B60, big5_chars_ban2951}, 
    {0x8B63, 0x8B63, big5_chars_ban2952}, 
    {0x8B65, 0x8B68, big5_chars_ban2953}, 
    {0x8B6A, 0x8B6D, big5_chars_ban2954}, 
    {0x8B6F, 0x8B70, big5_chars_ban2955}, 
    {0x8B74, 0x8B74, big5_chars_ban2956}, 
    {0x8B77, 0x8B7B, big5_chars_ban2957}, 
    {0x8B7D, 0x8B80, big5_chars_ban2958}, 
    {0x8B82, 0x8B82, big5_chars_ban2959}, 
    {0x8B84, 0x8B86, big5_chars_ban2960}, 
    {0x8B88, 0x8B88, big5_chars_ban2961}, 
    {0x8B8A, 0x8B8C, big5_chars_ban2962}, 
    {0x8B8E, 0x8B8E, big5_chars_ban2963}, 
    {0x8B92, 0x8B96, big5_chars_ban2964}, 
    {0x8B98, 0x8B9A, big5_chars_ban2965}, 
    {0x8B9C, 0x8B9C, big5_chars_ban2966}, 
    {0x8B9E, 0x8B9F, big5_chars_ban2967}, 
    {0x8C37, 0x8C37, big5_chars_ban2968}, 
    {0x8C39, 0x8C39, big5_chars_ban2969}, 
    {0x8C3B, 0x8C3F, big5_chars_ban2970}, 
    {0x8C41, 0x8C43, big5_chars_ban2971}, 
    {0x8C45, 0x8C50, big5_chars_ban2972}, 
    {0x8C54, 0x8C57, big5_chars_ban2973}, 
    {0x8C5A, 0x8C5A, big5_chars_ban2974}, 
    {0x8C5C, 0x8C5D, big5_chars_ban2975}, 
    {0x8C5F, 0x8C5F, big5_chars_ban2976}, 
    {0x8C61, 0x8C62, big5_chars_ban2977}, 
    {0x8C64, 0x8C66, big5_chars_ban2978}, 
    {0x8C68, 0x8C6D, big5_chars_ban2979}, 
    {0x8C6F, 0x8C73, big5_chars_ban2980}, 
    {0x8C75, 0x8C7B, big5_chars_ban2981}, 
    {0x8C7D, 0x8C7D, big5_chars_ban2982}, 
    {0x8C80, 0x8C82, big5_chars_ban2983}, 
    {0x8C84, 0x8C86, big5_chars_ban2984}, 
    {0x8C89, 0x8C8A, big5_chars_ban2985}, 
    {0x8C8C, 0x8C8D, big5_chars_ban2986}, 
    {0x8C8F, 0x8C95, big5_chars_ban2987}, 
    {0x8C97, 0x8C9A, big5_chars_ban2988}, 
    {0x8C9C, 0x8C9E, big5_chars_ban2989}, 
    {0x8CA0, 0x8CA5, big5_chars_ban2990}, 
    {0x8CA7, 0x8CAC, big5_chars_ban2991}, 
    {0x8CAF, 0x8CB0, big5_chars_ban2992}, 
    {0x8CB2, 0x8CC5, big5_chars_ban2993}, 
    {0x8CC7, 0x8CC8, big5_chars_ban2994}, 
    {0x8CCA, 0x8CCA, big5_chars_ban2995}, 
    {0x8CCC, 0x8CCC, big5_chars_ban2996}, 
    {0x8CCF, 0x8CCF, big5_chars_ban2997}, 
    {0x8CD1, 0x8CD3, big5_chars_ban2998}, 
    {0x8CD5, 0x8CD5, big5_chars_ban2999}, 
    {0x8CD7, 0x8CD7, big5_chars_ban3000}, 
    {0x8CD9, 0x8CDA, big5_chars_ban3001}, 
    {0x8CDC, 0x8CE8, big5_chars_ban3002}, 
    {0x8CEA, 0x8CEA, big5_chars_ban3003}, 
    {0x8CEC, 0x8CEE, big5_chars_ban3004}, 
    {0x8CF0, 0x8CF1, big5_chars_ban3005}, 
    {0x8CF3, 0x8CF5, big5_chars_ban3006}, 
    {0x8CF8, 0x8CFE, big5_chars_ban3007}, 
    {0x8D00, 0x8D00, big5_chars_ban3008}, 
    {0x8D02, 0x8D02, big5_chars_ban3009}, 
    {0x8D04, 0x8D0A, big5_chars_ban3010}, 
    {0x8D0D, 0x8D0D, big5_chars_ban3011}, 
    {0x8D0F, 0x8D10, big5_chars_ban3012}, 
    {0x8D13, 0x8D17, big5_chars_ban3013}, 
    {0x8D19, 0x8D19, big5_chars_ban3014}, 
    {0x8D1B, 0x8D1B, big5_chars_ban3015}, 
    {0x8D64, 0x8D64, big5_chars_ban3016}, 
    {0x8D66, 0x8D69, big5_chars_ban3017}, 
    {0x8D6B, 0x8D70, big5_chars_ban3018}, 
    {0x8D72, 0x8D74, big5_chars_ban3019}, 
    {0x8D76, 0x8D79, big5_chars_ban3020}, 
    {0x8D7B, 0x8D7B, big5_chars_ban3021}, 
    {0x8D7D, 0x8D7D, big5_chars_ban3022}, 
    {0x8D80, 0x8D81, big5_chars_ban3023}, 
    {0x8D84, 0x8D85, big5_chars_ban3024}, 
    {0x8D89, 0x8D8A, big5_chars_ban3025}, 
    {0x8D8C, 0x8D96, big5_chars_ban3026}, 
    {0x8D99, 0x8D99, big5_chars_ban3027}, 
    {0x8D9B, 0x8D9C, big5_chars_ban3028}, 
    {0x8D9F, 0x8DA1, big5_chars_ban3029}, 
    {0x8DA3, 0x8DA3, big5_chars_ban3030}, 
    {0x8DA5, 0x8DA5, big5_chars_ban3031}, 
    {0x8DA7, 0x8DA8, big5_chars_ban3032}, 
    {0x8DAA, 0x8DAF, big5_chars_ban3033}, 
    {0x8DB2, 0x8DB7, big5_chars_ban3034}, 
    {0x8DB9, 0x8DBA, big5_chars_ban3035}, 
    {0x8DBC, 0x8DBC, big5_chars_ban3036}, 
    {0x8DBE, 0x8DBF, big5_chars_ban3037}, 
    {0x8DC1, 0x8DC2, big5_chars_ban3038}, 
    {0x8DC5, 0x8DC8, big5_chars_ban3039}, 
    {0x8DCB, 0x8DD1, big5_chars_ban3040}, 
    {0x8DD3, 0x8DD3, big5_chars_ban3041}, 
    {0x8DD5, 0x8DDD, big5_chars_ban3042}, 
    {0x8DDF, 0x8DE4, big5_chars_ban3043}, 
    {0x8DE6, 0x8DEC, big5_chars_ban3044}, 
    {0x8DEE, 0x8DF4, big5_chars_ban3045}, 
    {0x8DFA, 0x8DFA, big5_chars_ban3046}, 
    {0x8DFC, 0x8E00, big5_chars_ban3047}, 
    {0x8E02, 0x8E07, big5_chars_ban3048}, 
    {0x8E09, 0x8E0A, big5_chars_ban3049}, 
    {0x8E0D, 0x8E0D, big5_chars_ban3050}, 
    {0x8E0F, 0x8E27, big5_chars_ban3051}, 
    {0x8E29, 0x8E29, big5_chars_ban3052}, 
    {0x8E2B, 0x8E2B, big5_chars_ban3053}, 
    {0x8E2E, 0x8E2E, big5_chars_ban3054}, 
    {0x8E30, 0x8E31, big5_chars_ban3055}, 
    {0x8E33, 0x8E36, big5_chars_ban3056}, 
    {0x8E38, 0x8E39, big5_chars_ban3057}, 
    {0x8E3C, 0x8E42, big5_chars_ban3058}, 
    {0x8E44, 0x8E45, big5_chars_ban3059}, 
    {0x8E47, 0x8E4E, big5_chars_ban3060}, 
    {0x8E50, 0x8E50, big5_chars_ban3061}, 
    {0x8E53, 0x8E57, big5_chars_ban3062}, 
    {0x8E59, 0x8E67, big5_chars_ban3063}, 
    {0x8E69, 0x8E6A, big5_chars_ban3064}, 
    {0x8E6C, 0x8E6D, big5_chars_ban3065}, 
    {0x8E6F, 0x8E6F, big5_chars_ban3066}, 
    {0x8E72, 0x8E74, big5_chars_ban3067}, 
    {0x8E76, 0x8E76, big5_chars_ban3068}, 
    {0x8E78, 0x8E78, big5_chars_ban3069}, 
    {0x8E7A, 0x8E7C, big5_chars_ban3070}, 
    {0x8E81, 0x8E82, big5_chars_ban3071}, 
    {0x8E84, 0x8E8E, big5_chars_ban3072}, 
    {0x8E90, 0x8E98, big5_chars_ban3073}, 
    {0x8E9A, 0x8E9A, big5_chars_ban3074}, 
    {0x8E9D, 0x8EA1, big5_chars_ban3075}, 
    {0x8EA3, 0x8EA6, big5_chars_ban3076}, 
    {0x8EA8, 0x8EAC, big5_chars_ban3077}, 
    {0x8EB2, 0x8EB2, big5_chars_ban3078}, 
    {0x8EBA, 0x8EBA, big5_chars_ban3079}, 
    {0x8EBD, 0x8EBD, big5_chars_ban3080}, 
    {0x8EC0, 0x8EC0, big5_chars_ban3081}, 
    {0x8EC2, 0x8EC2, big5_chars_ban3082}, 
    {0x8EC9, 0x8ECD, big5_chars_ban3083}, 
    {0x8ECF, 0x8ECF, big5_chars_ban3084}, 
    {0x8ED1, 0x8ED4, big5_chars_ban3085}, 
    {0x8ED7, 0x8ED8, big5_chars_ban3086}, 
    {0x8EDB, 0x8EE1, big5_chars_ban3087}, 
    {0x8EE5, 0x8EE9, big5_chars_ban3088}, 
    {0x8EEB, 0x8EEC, big5_chars_ban3089}, 
    {0x8EEE, 0x8EEF, big5_chars_ban3090}, 
    {0x8EF1, 0x8EF1, big5_chars_ban3091}, 
    {0x8EF4, 0x8EFC, big5_chars_ban3092}, 
    {0x8EFE, 0x8F03, big5_chars_ban3093}, 
    {0x8F05, 0x8F0B, big5_chars_ban3094}, 
    {0x8F0D, 0x8F0E, big5_chars_ban3095}, 
    {0x8F10, 0x8F18, big5_chars_ban3096}, 
    {0x8F1A, 0x8F20, big5_chars_ban3097}, 
    {0x8F23, 0x8F26, big5_chars_ban3098}, 
    {0x8F29, 0x8F2A, big5_chars_ban3099}, 
    {0x8F2C, 0x8F2C, big5_chars_ban3100}, 
    {0x8F2E, 0x8F2F, big5_chars_ban3101}, 
    {0x8F32, 0x8F39, big5_chars_ban3102}, 
    {0x8F3B, 0x8F3B, big5_chars_ban3103}, 
    {0x8F3E, 0x8F40, big5_chars_ban3104}, 
    {0x8F42, 0x8F49, big5_chars_ban3105}, 
    {0x8F4B, 0x8F4B, big5_chars_ban3106}, 
    {0x8F4D, 0x8F5B, big5_chars_ban3107}, 
    {0x8F5D, 0x8F64, big5_chars_ban3108}, 
    {0x8F9B, 0x8F9C, big5_chars_ban3109}, 
    {0x8F9F, 0x8F9F, big5_chars_ban3110}, 
    {0x8FA3, 0x8FA3, big5_chars_ban3111}, 
    {0x8FA6, 0x8FA6, big5_chars_ban3112}, 
    {0x8FA8, 0x8FA8, big5_chars_ban3113}, 
    {0x8FAD, 0x8FB2, big5_chars_ban3114}, 
    {0x8FB4, 0x8FB4, big5_chars_ban3115}, 
    {0x8FBF, 0x8FBF, big5_chars_ban3116}, 
    {0x8FC2, 0x8FC2, big5_chars_ban3117}, 
    {0x8FC4, 0x8FC6, big5_chars_ban3118}, 
    {0x8FC9, 0x8FC9, big5_chars_ban3119}, 
    {0x8FCB, 0x8FCB, big5_chars_ban3120}, 
    {0x8FCD, 0x8FCE, big5_chars_ban3121}, 
    {0x8FD1, 0x8FD7, big5_chars_ban3122}, 
    {0x8FE0, 0x8FE6, big5_chars_ban3123}, 
    {0x8FE8, 0x8FE8, big5_chars_ban3124}, 
    {0x8FEA, 0x8FEB, big5_chars_ban3125}, 
    {0x8FED, 0x8FEE, big5_chars_ban3126}, 
    {0x8FF0, 0x8FF0, big5_chars_ban3127}, 
    {0x8FF4, 0x8FF8, big5_chars_ban3128}, 
    {0x8FFA, 0x9006, big5_chars_ban3129}, 
    {0x900B, 0x900D, big5_chars_ban3130}, 
    {0x900F, 0x9011, big5_chars_ban3131}, 
    {0x9014, 0x9017, big5_chars_ban3132}, 
    {0x9019, 0x9024, big5_chars_ban3133}, 
    {0x902D, 0x902F, big5_chars_ban3134}, 
    {0x9031, 0x9032, big5_chars_ban3135}, 
    {0x9034, 0x9036, big5_chars_ban3136}, 
    {0x9038, 0x9038, big5_chars_ban3137}, 
    {0x903C, 0x903F, big5_chars_ban3138}, 
    {0x9041, 0x9042, big5_chars_ban3139}, 
    {0x9044, 0x9044, big5_chars_ban3140}, 
    {0x9047, 0x9047, big5_chars_ban3141}, 
    {0x9049, 0x904B, big5_chars_ban3142}, 
    {0x904D, 0x9055, big5_chars_ban3143}, 
    {0x9058, 0x9059, big5_chars_ban3144}, 
    {0x905B, 0x905E, big5_chars_ban3145}, 
    {0x9060, 0x9060, big5_chars_ban3146}, 
    {0x9062, 0x9063, big5_chars_ban3147}, 
    {0x9067, 0x9069, big5_chars_ban3148}, 
    {0x906B, 0x906B, big5_chars_ban3149}, 
    {0x906D, 0x9070, big5_chars_ban3150}, 
    {0x9072, 0x9088, big5_chars_ban3151}, 
    {0x908A, 0x908B, big5_chars_ban3152}, 
    {0x908D, 0x908D, big5_chars_ban3153}, 
    {0x908F, 0x9091, big5_chars_ban3154}, 
    {0x9094, 0x9095, big5_chars_ban3155}, 
    {0x9097, 0x9099, big5_chars_ban3156}, 
    {0x909B, 0x909B, big5_chars_ban3157}, 
    {0x909E, 0x90A3, big5_chars_ban3158}, 
    {0x90A5, 0x90A7, big5_chars_ban3159}, 
    {0x90AA, 0x90AA, big5_chars_ban3160}, 
    {0x90AF, 0x90B6, big5_chars_ban3161}, 
    {0x90B8, 0x90B8, big5_chars_ban3162}, 
    {0x90BD, 0x90BF, big5_chars_ban3163}, 
    {0x90C1, 0x90C1, big5_chars_ban3164}, 
    {0x90C3, 0x90C3, big5_chars_ban3165}, 
    {0x90C5, 0x90C5, big5_chars_ban3166}, 
    {0x90C7, 0x90C8, big5_chars_ban3167}, 
    {0x90CA, 0x90CB, big5_chars_ban3168}, 
    {0x90CE, 0x90CE, big5_chars_ban3169}, 
    {0x90D4, 0x90DD, big5_chars_ban3170}, 
    {0x90DF, 0x90E5, big5_chars_ban3171}, 
    {0x90E8, 0x90ED, big5_chars_ban3172}, 
    {0x90EF, 0x90F5, big5_chars_ban3173}, 
    {0x90F9, 0x9109, big5_chars_ban3174}, 
    {0x910B, 0x910B, big5_chars_ban3175}, 
    {0x910D, 0x9112, big5_chars_ban3176}, 
    {0x9114, 0x9114, big5_chars_ban3177}, 
    {0x9116, 0x9124, big5_chars_ban3178}, 
    {0x9126, 0x9136, big5_chars_ban3179}, 
    {0x9138, 0x913B, big5_chars_ban3180}, 
    {0x913E, 0x9141, big5_chars_ban3181}, 
    {0x9143, 0x9150, big5_chars_ban3182}, 
    {0x9152, 0x9153, big5_chars_ban3183}, 
    {0x9155, 0x9158, big5_chars_ban3184}, 
    {0x915A, 0x915A, big5_chars_ban3185}, 
    {0x915F, 0x9165, big5_chars_ban3186}, 
    {0x9168, 0x916A, big5_chars_ban3187}, 
    {0x916C, 0x916C, big5_chars_ban3188}, 
    {0x916E, 0x916F, big5_chars_ban3189}, 
    {0x9172, 0x9175, big5_chars_ban3190}, 
    {0x9177, 0x917A, big5_chars_ban3191}, 
    {0x9180, 0x9187, big5_chars_ban3192}, 
    {0x9189, 0x918B, big5_chars_ban3193}, 
    {0x918D, 0x918D, big5_chars_ban3194}, 
    {0x918F, 0x9193, big5_chars_ban3195}, 
    {0x9199, 0x91A3, big5_chars_ban3196}, 
    {0x91A5, 0x91A5, big5_chars_ban3197}, 
    {0x91A7, 0x91A8, big5_chars_ban3198}, 
    {0x91AA, 0x91B5, big5_chars_ban3199}, 
    {0x91B7, 0x91B7, big5_chars_ban3200}, 
    {0x91B9, 0x91BA, big5_chars_ban3201}, 
    {0x91BC, 0x91BE, big5_chars_ban3202}, 
    {0x91C0, 0x91C3, big5_chars_ban3203}, 
    {0x91C5, 0x91C7, big5_chars_ban3204}, 
    {0x91C9, 0x91C9, big5_chars_ban3205}, 
    {0x91CB, 0x91D1, big5_chars_ban3206}, 
    {0x91D3, 0x91D5, big5_chars_ban3207}, 
    {0x91D7, 0x91DA, big5_chars_ban3208}, 
    {0x91DC, 0x91DD, big5_chars_ban3209}, 
    {0x91E2, 0x91E4, big5_chars_ban3210}, 
    {0x91E6, 0x91EE, big5_chars_ban3211}, 
    {0x91F1, 0x91F1, big5_chars_ban3212}, 
    {0x91F3, 0x91F5, big5_chars_ban3213}, 
    {0x91F7, 0x91F9, big5_chars_ban3214}, 
    {0x91FD, 0x91FD, big5_chars_ban3215}, 
    {0x91FF, 0x9207, big5_chars_ban3216}, 
    {0x9209, 0x920A, big5_chars_ban3217}, 
    {0x920C, 0x920D, big5_chars_ban3218}, 
    {0x920F, 0x9212, big5_chars_ban3219}, 
    {0x9214, 0x9217, big5_chars_ban3220}, 
    {0x9219, 0x921A, big5_chars_ban3221}, 
    {0x921C, 0x921C, big5_chars_ban3222}, 
    {0x921E, 0x921E, big5_chars_ban3223}, 
    {0x9223, 0x9227, big5_chars_ban3224}, 
    {0x922D, 0x922E, big5_chars_ban3225}, 
    {0x9230, 0x9234, big5_chars_ban3226}, 
    {0x9236, 0x923A, big5_chars_ban3227}, 
    {0x923D, 0x9240, big5_chars_ban3228}, 
    {0x9245, 0x9246, big5_chars_ban3229}, 
    {0x9248, 0x9254, big5_chars_ban3230}, 
    {0x9256, 0x9257, big5_chars_ban3231}, 
    {0x925A, 0x925B, big5_chars_ban3232}, 
    {0x925E, 0x925E, big5_chars_ban3233}, 
    {0x9260, 0x9261, big5_chars_ban3234}, 
    {0x9263, 0x9267, big5_chars_ban3235}, 
    {0x926C, 0x926D, big5_chars_ban3236}, 
    {0x926F, 0x9270, big5_chars_ban3237}, 
    {0x9272, 0x9272, big5_chars_ban3238}, 
    {0x9276, 0x9276, big5_chars_ban3239}, 
    {0x9278, 0x9280, big5_chars_ban3240}, 
    {0x9282, 0x9283, big5_chars_ban3241}, 
    {0x9285, 0x9288, big5_chars_ban3242}, 
    {0x928A, 0x928E, big5_chars_ban3243}, 
    {0x9291, 0x9291, big5_chars_ban3244}, 
    {0x9293, 0x929D, big5_chars_ban3245}, 
    {0x92A0, 0x92AC, big5_chars_ban3246}, 
    {0x92B2, 0x92B7, big5_chars_ban3247}, 
    {0x92B9, 0x92B9, big5_chars_ban3248}, 
    {0x92BB, 0x92BC, big5_chars_ban3249}, 
    {0x92C0, 0x92D3, big5_chars_ban3250}, 
    {0x92D5, 0x92D5, big5_chars_ban3251}, 
    {0x92D7, 0x92D9, big5_chars_ban3252}, 
    {0x92DD, 0x92E1, big5_chars_ban3253}, 
    {0x92E4, 0x92E4, big5_chars_ban3254}, 
    {0x92E6, 0x92EA, big5_chars_ban3255}, 
    {0x92EE, 0x92F1, big5_chars_ban3256}, 
    {0x92F7, 0x92FC, big5_chars_ban3257}, 
    {0x92FE, 0x9302, big5_chars_ban3258}, 
    {0x9304, 0x9304, big5_chars_ban3259}, 
    {0x9306, 0x9306, big5_chars_ban3260}, 
    {0x9308, 0x9309, big5_chars_ban3261}, 
    {0x930B, 0x9310, big5_chars_ban3262}, 
    {0x9312, 0x9316, big5_chars_ban3263}, 
    {0x9318, 0x931B, big5_chars_ban3264}, 
    {0x931D, 0x932B, big5_chars_ban3265}, 
    {0x932D, 0x932F, big5_chars_ban3266}, 
    {0x9333, 0x9336, big5_chars_ban3267}, 
    {0x9338, 0x9339, big5_chars_ban3268}, 
    {0x933C, 0x933C, big5_chars_ban3269}, 
    {0x9346, 0x9347, big5_chars_ban3270}, 
    {0x9349, 0x9352, big5_chars_ban3271}, 
    {0x9354, 0x935C, big5_chars_ban3272}, 
    {0x935E, 0x935E, big5_chars_ban3273}, 
    {0x9360, 0x9361, big5_chars_ban3274}, 
    {0x9363, 0x9365, big5_chars_ban3275}, 
    {0x9367, 0x9367, big5_chars_ban3276}, 
    {0x936A, 0x936A, big5_chars_ban3277}, 
    {0x936C, 0x936D, big5_chars_ban3278}, 
    {0x9370, 0x9371, big5_chars_ban3279}, 
    {0x9375, 0x9377, big5_chars_ban3280}, 
    {0x9379, 0x937C, big5_chars_ban3281}, 
    {0x937E, 0x937E, big5_chars_ban3282}, 
    {0x9380, 0x9380, big5_chars_ban3283}, 
    {0x9382, 0x9383, big5_chars_ban3284}, 
    {0x9388, 0x938A, big5_chars_ban3285}, 
    {0x938C, 0x938F, big5_chars_ban3286}, 
    {0x9391, 0x9392, big5_chars_ban3287}, 
    {0x9394, 0x939B, big5_chars_ban3288}, 
    {0x939D, 0x939F, big5_chars_ban3289}, 
    {0x93A1, 0x93AA, big5_chars_ban3290}, 
    {0x93AC, 0x93AC, big5_chars_ban3291}, 
    {0x93AE, 0x93B5, big5_chars_ban3292}, 
    {0x93B7, 0x93B7, big5_chars_ban3293}, 
    {0x93C0, 0x93C0, big5_chars_ban3294}, 
    {0x93C2, 0x93C4, big5_chars_ban3295}, 
    {0x93C7, 0x93C8, big5_chars_ban3296}, 
    {0x93CA, 0x93CA, big5_chars_ban3297}, 
    {0x93CC, 0x93D2, big5_chars_ban3298}, 
    {0x93D4, 0x93DA, big5_chars_ban3299}, 
    {0x93DC, 0x93DF, big5_chars_ban3300}, 
    {0x93E1, 0x93E4, big5_chars_ban3301}, 
    {0x93E6, 0x93E8, big5_chars_ban3302}, 
    {0x93EC, 0x93EC, big5_chars_ban3303}, 
    {0x93EE, 0x93EE, big5_chars_ban3304}, 
    {0x93F5, 0x9400, big5_chars_ban3305}, 
    {0x9403, 0x9403, big5_chars_ban3306}, 
    {0x9406, 0x9407, big5_chars_ban3307}, 
    {0x9409, 0x9416, big5_chars_ban3308}, 
    {0x9418, 0x9419, big5_chars_ban3309}, 
    {0x9420, 0x9420, big5_chars_ban3310}, 
    {0x9428, 0x942C, big5_chars_ban3311}, 
    {0x942E, 0x942E, big5_chars_ban3312}, 
    {0x9430, 0x9433, big5_chars_ban3313}, 
    {0x9435, 0x943D, big5_chars_ban3314}, 
    {0x943F, 0x9440, big5_chars_ban3315}, 
    {0x9444, 0x944C, big5_chars_ban3316}, 
    {0x944F, 0x9452, big5_chars_ban3317}, 
    {0x9455, 0x9455, big5_chars_ban3318}, 
    {0x9457, 0x9457, big5_chars_ban3319}, 
    {0x945D, 0x945E, big5_chars_ban3320}, 
    {0x9460, 0x9460, big5_chars_ban3321}, 
    {0x9462, 0x9464, big5_chars_ban3322}, 
    {0x9468, 0x946B, big5_chars_ban3323}, 
    {0x946D, 0x9478, big5_chars_ban3324}, 
    {0x947C, 0x9483, big5_chars_ban3325}, 
    {0x9577, 0x9577, big5_chars_ban3326}, 
    {0x957A, 0x957D, big5_chars_ban3327}, 
    {0x9580, 0x9580, big5_chars_ban3328}, 
    {0x9582, 0x9583, big5_chars_ban3329}, 
    {0x9586, 0x9586, big5_chars_ban3330}, 
    {0x9588, 0x9589, big5_chars_ban3331}, 
    {0x958B, 0x9594, big5_chars_ban3332}, 
    {0x9598, 0x9598, big5_chars_ban3333}, 
    {0x959B, 0x959C, big5_chars_ban3334}, 
    {0x959E, 0x959F, big5_chars_ban3335}, 
    {0x95A1, 0x95A1, big5_chars_ban3336}, 
    {0x95A3, 0x95A5, big5_chars_ban3337}, 
    {0x95A8, 0x95A9, big5_chars_ban3338}, 
    {0x95AB, 0x95AE, big5_chars_ban3339}, 
    {0x95B0, 0x95B1, big5_chars_ban3340}, 
    {0x95B5, 0x95B7, big5_chars_ban3341}, 
    {0x95B9, 0x95C0, big5_chars_ban3342}, 
    {0x95C3, 0x95C3, big5_chars_ban3343}, 
    {0x95C5, 0x95CD, big5_chars_ban3344}, 
    {0x95D0, 0x95D6, big5_chars_ban3345}, 
    {0x95DA, 0x95DC, big5_chars_ban3346}, 
    {0x95DE, 0x95E5, big5_chars_ban3347}, 
    {0x961C, 0x961C, big5_chars_ban3348}, 
    {0x961E, 0x961E, big5_chars_ban3349}, 
    {0x9620, 0x9624, big5_chars_ban3350}, 
    {0x9628, 0x9628, big5_chars_ban3351}, 
    {0x962A, 0x962A, big5_chars_ban3352}, 
    {0x962C, 0x9632, big5_chars_ban3353}, 
    {0x9639, 0x963D, big5_chars_ban3354}, 
    {0x963F, 0x9640, big5_chars_ban3355}, 
    {0x9642, 0x9644, big5_chars_ban3356}, 
    {0x964A, 0x9651, big5_chars_ban3357}, 
    {0x9653, 0x9654, big5_chars_ban3358}, 
    {0x9658, 0x9658, big5_chars_ban3359}, 
    {0x965B, 0x965F, big5_chars_ban3360}, 
    {0x9661, 0x9664, big5_chars_ban3361}, 
    {0x966A, 0x966D, big5_chars_ban3362}, 
    {0x966F, 0x9678, big5_chars_ban3363}, 
    {0x967C, 0x967E, big5_chars_ban3364}, 
    {0x9680, 0x9680, big5_chars_ban3365}, 
    {0x9683, 0x968B, big5_chars_ban3366}, 
    {0x968D, 0x968E, big5_chars_ban3367}, 
    {0x9691, 0x9695, big5_chars_ban3368}, 
    {0x9697, 0x9699, big5_chars_ban3369}, 
    {0x969B, 0x969C, big5_chars_ban3370}, 
    {0x969E, 0x969E, big5_chars_ban3371}, 
    {0x96A1, 0x96A2, big5_chars_ban3372}, 
    {0x96A4, 0x96A4, big5_chars_ban3373}, 
    {0x96A7, 0x96AA, big5_chars_ban3374}, 
    {0x96AC, 0x96AC, big5_chars_ban3375}, 
    {0x96AE, 0x96AE, big5_chars_ban3376}, 
    {0x96B0, 0x96B1, big5_chars_ban3377}, 
    {0x96B3, 0x96B4, big5_chars_ban3378}, 
    {0x96B8, 0x96B9, big5_chars_ban3379}, 
    {0x96BB, 0x96BC, big5_chars_ban3380}, 
    {0x96BF, 0x96CE, big5_chars_ban3381}, 
    {0x96D2, 0x96DF, big5_chars_ban3382}, 
    {0x96E1, 0x96E3, big5_chars_ban3383}, 
    {0x96E5, 0x96E5, big5_chars_ban3384}, 
    {0x96E8, 0x96EA, big5_chars_ban3385}, 
    {0x96EF, 0x96F2, big5_chars_ban3386}, 
    {0x96F5, 0x96FB, big5_chars_ban3387}, 
    {0x96FD, 0x96FD, big5_chars_ban3388}, 
    {0x96FF, 0x9700, big5_chars_ban3389}, 
    {0x9702, 0x9702, big5_chars_ban3390}, 
    {0x9704, 0x9709, big5_chars_ban3391}, 
    {0x970B, 0x970B, big5_chars_ban3392}, 
    {0x970D, 0x9713, big5_chars_ban3393}, 
    {0x9716, 0x9716, big5_chars_ban3394}, 
    {0x9718, 0x9719, big5_chars_ban3395}, 
    {0x971C, 0x9720, big5_chars_ban3396}, 
    {0x9722, 0x972C, big5_chars_ban3397}, 
    {0x972E, 0x9730, big5_chars_ban3398}, 
    {0x9732, 0x9732, big5_chars_ban3399}, 
    {0x9735, 0x9735, big5_chars_ban3400}, 
    {0x9738, 0x973A, big5_chars_ban3401}, 
    {0x973D, 0x973F, big5_chars_ban3402}, 
    {0x9742, 0x9744, big5_chars_ban3403}, 
    {0x9746, 0x9749, big5_chars_ban3404}, 
    {0x974B, 0x974B, big5_chars_ban3405}, 
    {0x9752, 0x9752, big5_chars_ban3406}, 
    {0x9756, 0x9756, big5_chars_ban3407}, 
    {0x9758, 0x9758, big5_chars_ban3408}, 
    {0x975A, 0x975C, big5_chars_ban3409}, 
    {0x975E, 0x975E, big5_chars_ban3410}, 
    {0x9760, 0x9762, big5_chars_ban3411}, 
    {0x9766, 0x9766, big5_chars_ban3412}, 
    {0x9768, 0x976A, big5_chars_ban3413}, 
    {0x976C, 0x976C, big5_chars_ban3414}, 
    {0x976E, 0x976E, big5_chars_ban3415}, 
    {0x9770, 0x9770, big5_chars_ban3416}, 
    {0x9772, 0x9774, big5_chars_ban3417}, 
    {0x9776, 0x9778, big5_chars_ban3418}, 
    {0x977A, 0x9785, big5_chars_ban3419}, 
    {0x9788, 0x9788, big5_chars_ban3420}, 
    {0x978A, 0x978B, big5_chars_ban3421}, 
    {0x978D, 0x978F, big5_chars_ban3422}, 
    {0x9794, 0x9794, big5_chars_ban3423}, 
    {0x9797, 0x979A, big5_chars_ban3424}, 
    {0x979C, 0x979E, big5_chars_ban3425}, 
    {0x97A0, 0x97A6, big5_chars_ban3426}, 
    {0x97A8, 0x97A8, big5_chars_ban3427}, 
    {0x97AA, 0x97AE, big5_chars_ban3428}, 
    {0x97B3, 0x97B3, big5_chars_ban3429}, 
    {0x97B6, 0x97B7, big5_chars_ban3430}, 
    {0x97B9, 0x97B9, big5_chars_ban3431}, 
    {0x97BB, 0x97BB, big5_chars_ban3432}, 
    {0x97BF, 0x97BF, big5_chars_ban3433}, 
    {0x97C1, 0x97C1, big5_chars_ban3434}, 
    {0x97C3, 0x97C7, big5_chars_ban3435}, 
    {0x97C9, 0x97C9, big5_chars_ban3436}, 
    {0x97CB, 0x97D0, big5_chars_ban3437}, 
    {0x97D3, 0x97D9, big5_chars_ban3438}, 
    {0x97DC, 0x97DF, big5_chars_ban3439}, 
    {0x97E1, 0x97E1, big5_chars_ban3440}, 
    {0x97E3, 0x97E3, big5_chars_ban3441}, 
    {0x97E5, 0x97E5, big5_chars_ban3442}, 
    {0x97ED, 0x97ED, big5_chars_ban3443}, 
    {0x97F0, 0x97F1, big5_chars_ban3444}, 
    {0x97F3, 0x97F3, big5_chars_ban3445}, 
    {0x97F6, 0x97F6, big5_chars_ban3446}, 
    {0x97F8, 0x97FB, big5_chars_ban3447}, 
    {0x97FD, 0x9808, big5_chars_ban3448}, 
    {0x980A, 0x980A, big5_chars_ban3449}, 
    {0x980C, 0x9813, big5_chars_ban3450}, 
    {0x9816, 0x9818, big5_chars_ban3451}, 
    {0x981B, 0x981E, big5_chars_ban3452}, 
    {0x9820, 0x9821, big5_chars_ban3453}, 
    {0x9824, 0x9824, big5_chars_ban3454}, 
    {0x9826, 0x9829, big5_chars_ban3455}, 
    {0x982B, 0x982B, big5_chars_ban3456}, 
    {0x982D, 0x982D, big5_chars_ban3457}, 
    {0x982F, 0x9830, big5_chars_ban3458}, 
    {0x9832, 0x9832, big5_chars_ban3459}, 
    {0x9835, 0x9835, big5_chars_ban3460}, 
    {0x9837, 0x9839, big5_chars_ban3461}, 
    {0x983B, 0x983B, big5_chars_ban3462}, 
    {0x9841, 0x9841, big5_chars_ban3463}, 
    {0x9843, 0x9846, big5_chars_ban3464}, 
    {0x9848, 0x984A, big5_chars_ban3465}, 
    {0x984C, 0x9853, big5_chars_ban3466}, 
    {0x9857, 0x9859, big5_chars_ban3467}, 
    {0x985B, 0x9860, big5_chars_ban3468}, 
    {0x9862, 0x9865, big5_chars_ban3469}, 
    {0x9867, 0x9867, big5_chars_ban3470}, 
    {0x9869, 0x986B, big5_chars_ban3471}, 
    {0x986F, 0x9874, big5_chars_ban3472}, 
    {0x98A8, 0x98A9, big5_chars_ban3473}, 
    {0x98AC, 0x98AF, big5_chars_ban3474}, 
    {0x98B1, 0x98B3, big5_chars_ban3475}, 
    {0x98B6, 0x98B6, big5_chars_ban3476}, 
    {0x98B8, 0x98B8, big5_chars_ban3477}, 
    {0x98BA, 0x98C2, big5_chars_ban3478}, 
    {0x98C4, 0x98C4, big5_chars_ban3479}, 
    {0x98C6, 0x98C6, big5_chars_ban3480}, 
    {0x98C9, 0x98C9, big5_chars_ban3481}, 
    {0x98CB, 0x98CC, big5_chars_ban3482}, 
    {0x98DB, 0x98DB, big5_chars_ban3483}, 
    {0x98DF, 0x98DF, big5_chars_ban3484}, 
    {0x98E2, 0x98E3, big5_chars_ban3485}, 
    {0x98E5, 0x98E5, big5_chars_ban3486}, 
    {0x98E7, 0x98E7, big5_chars_ban3487}, 
    {0x98E9, 0x98EB, big5_chars_ban3488}, 
    {0x98ED, 0x98ED, big5_chars_ban3489}, 
    {0x98EF, 0x98EF, big5_chars_ban3490}, 
    {0x98F2, 0x98F2, big5_chars_ban3491}, 
    {0x98F4, 0x98F4, big5_chars_ban3492}, 
    {0x98F6, 0x98F6, big5_chars_ban3493}, 
    {0x98F9, 0x98FA, big5_chars_ban3494}, 
    {0x98FC, 0x98FE, big5_chars_ban3495}, 
    {0x9900, 0x9900, big5_chars_ban3496}, 
    {0x9902, 0x9903, big5_chars_ban3497}, 
    {0x9905, 0x9905, big5_chars_ban3498}, 
    {0x9907, 0x990A, big5_chars_ban3499}, 
    {0x990C, 0x990C, big5_chars_ban3500}, 
    {0x9910, 0x9918, big5_chars_ban3501}, 
    {0x991A, 0x991B, big5_chars_ban3502}, 
    {0x991E, 0x991F, big5_chars_ban3503}, 
    {0x9921, 0x9921, big5_chars_ban3504}, 
    {0x9924, 0x9925, big5_chars_ban3505}, 
    {0x9927, 0x9933, big5_chars_ban3506}, 
    {0x9935, 0x9935, big5_chars_ban3507}, 
    {0x993A, 0x993A, big5_chars_ban3508}, 
    {0x993C, 0x993F, big5_chars_ban3509}, 
    {0x9941, 0x9941, big5_chars_ban3510}, 
    {0x9943, 0x9943, big5_chars_ban3511}, 
    {0x9945, 0x9945, big5_chars_ban3512}, 
    {0x9947, 0x9949, big5_chars_ban3513}, 
    {0x994B, 0x994C, big5_chars_ban3514}, 
    {0x994E, 0x994E, big5_chars_ban3515}, 
    {0x9950, 0x9959, big5_chars_ban3516}, 
    {0x995B, 0x995C, big5_chars_ban3517}, 
    {0x995E, 0x995F, big5_chars_ban3518}, 
    {0x9961, 0x9961, big5_chars_ban3519}, 
    {0x9996, 0x9999, big5_chars_ban3520}, 
    {0x999C, 0x999E, big5_chars_ban3521}, 
    {0x99A1, 0x99A1, big5_chars_ban3522}, 
    {0x99A3, 0x99A3, big5_chars_ban3523}, 
    {0x99A5, 0x99A8, big5_chars_ban3524}, 
    {0x99AB, 0x99B5, big5_chars_ban3525}, 
    {0x99B9, 0x99BB, big5_chars_ban3526}, 
    {0x99BD, 0x99BD, big5_chars_ban3527}, 
    {0x99C1, 0x99C3, big5_chars_ban3528}, 
    {0x99C7, 0x99C7, big5_chars_ban3529}, 
    {0x99C9, 0x99C9, big5_chars_ban3530}, 
    {0x99CB, 0x99D9, big5_chars_ban3531}, 
    {0x99DB, 0x99DD, big5_chars_ban3532}, 
    {0x99DF, 0x99DF, big5_chars_ban3533}, 
    {0x99E2, 0x99E5, big5_chars_ban3534}, 
    {0x99E7, 0x99E7, big5_chars_ban3535}, 
    {0x99E9, 0x99EA, big5_chars_ban3536}, 
    {0x99EC, 0x99EE, big5_chars_ban3537}, 
    {0x99F0, 0x99F1, big5_chars_ban3538}, 
    {0x99F4, 0x99F4, big5_chars_ban3539}, 
    {0x99F6, 0x99FF, big5_chars_ban3540}, 
    {0x9A01, 0x9A07, big5_chars_ban3541}, 
    {0x9A09, 0x9A0B, big5_chars_ban3542}, 
    {0x9A0D, 0x9A0F, big5_chars_ban3543}, 
    {0x9A11, 0x9A11, big5_chars_ban3544}, 
    {0x9A14, 0x9A16, big5_chars_ban3545}, 
    {0x9A19, 0x9A1E, big5_chars_ban3546}, 
    {0x9A20, 0x9A20, big5_chars_ban3547}, 
    {0x9A22, 0x9A25, big5_chars_ban3548}, 
    {0x9A27, 0x9A27, big5_chars_ban3549}, 
    {0x9A29, 0x9A2E, big5_chars_ban3550}, 
    {0x9A30, 0x9A32, big5_chars_ban3551}, 
    {0x9A34, 0x9A3A, big5_chars_ban3552}, 
    {0x9A3D, 0x9A46, big5_chars_ban3553}, 
    {0x9A48, 0x9A4A, big5_chars_ban3554}, 
    {0x9A4C, 0x9A50, big5_chars_ban3555}, 
    {0x9A52, 0x9A57, big5_chars_ban3556}, 
    {0x9A59, 0x9A5B, big5_chars_ban3557}, 
    {0x9A5E, 0x9A60, big5_chars_ban3558}, 
    {0x9A62, 0x9A62, big5_chars_ban3559}, 
    {0x9A64, 0x9A6B, big5_chars_ban3560}, 
    {0x9AA8, 0x9AA8, big5_chars_ban3561}, 
    {0x9AAB, 0x9AAB, big5_chars_ban3562}, 
    {0x9AAD, 0x9AAD, big5_chars_ban3563}, 
    {0x9AAF, 0x9AB1, big5_chars_ban3564}, 
    {0x9AB3, 0x9AB4, big5_chars_ban3565}, 
    {0x9AB7, 0x9AB9, big5_chars_ban3566}, 
    {0x9ABB, 0x9ABC, big5_chars_ban3567}, 
    {0x9ABE, 0x9AC2, big5_chars_ban3568}, 
    {0x9AC6, 0x9AC7, big5_chars_ban3569}, 
    {0x9ACA, 0x9ACA, big5_chars_ban3570}, 
    {0x9ACD, 0x9ACD, big5_chars_ban3571}, 
    {0x9ACF, 0x9AD6, big5_chars_ban3572}, 
    {0x9AD8, 0x9AD8, big5_chars_ban3573}, 
    {0x9ADC, 0x9ADC, big5_chars_ban3574}, 
    {0x9ADF, 0x9ADF, big5_chars_ban3575}, 
    {0x9AE1, 0x9AE1, big5_chars_ban3576}, 
    {0x9AE3, 0x9AE3, big5_chars_ban3577}, 
    {0x9AE6, 0x9AE7, big5_chars_ban3578}, 
    {0x9AEB, 0x9AEF, big5_chars_ban3579}, 
    {0x9AF1, 0x9AF3, big5_chars_ban3580}, 
    {0x9AF6, 0x9AF7, big5_chars_ban3581}, 
    {0x9AF9, 0x9AFE, big5_chars_ban3582}, 
    {0x9B01, 0x9B01, big5_chars_ban3583}, 
    {0x9B03, 0x9B06, big5_chars_ban3584}, 
    {0x9B08, 0x9B08, big5_chars_ban3585}, 
    {0x9B0A, 0x9B0E, big5_chars_ban3586}, 
    {0x9B10, 0x9B12, big5_chars_ban3587}, 
    {0x9B15, 0x9B1A, big5_chars_ban3588}, 
    {0x9B1E, 0x9B20, big5_chars_ban3589}, 
    {0x9B22, 0x9B25, big5_chars_ban3590}, 
    {0x9B27, 0x9B29, big5_chars_ban3591}, 
    {0x9B2B, 0x9B2B, big5_chars_ban3592}, 
    {0x9B2E, 0x9B2F, big5_chars_ban3593}, 
    {0x9B31, 0x9B33, big5_chars_ban3594}, 
    {0x9B35, 0x9B35, big5_chars_ban3595}, 
    {0x9B37, 0x9B37, big5_chars_ban3596}, 
    {0x9B3A, 0x9B3C, big5_chars_ban3597}, 
    {0x9B3E, 0x9B3F, big5_chars_ban3598}, 
    {0x9B41, 0x9B46, big5_chars_ban3599}, 
    {0x9B48, 0x9B48, big5_chars_ban3600}, 
    {0x9B4A, 0x9B4F, big5_chars_ban3601}, 
    {0x9B51, 0x9B52, big5_chars_ban3602}, 
    {0x9B54, 0x9B56, big5_chars_ban3603}, 
    {0x9B58, 0x9B5B, big5_chars_ban3604}, 
    {0x9B5F, 0x9B61, big5_chars_ban3605}, 
    {0x9B64, 0x9B64, big5_chars_ban3606}, 
    {0x9B66, 0x9B68, big5_chars_ban3607}, 
    {0x9B6C, 0x9B6C, big5_chars_ban3608}, 
    {0x9B6F, 0x9B71, big5_chars_ban3609}, 
    {0x9B74, 0x9B77, big5_chars_ban3610}, 
    {0x9B7A, 0x9B7E, big5_chars_ban3611}, 
    {0x9B80, 0x9B80, big5_chars_ban3612}, 
    {0x9B82, 0x9B82, big5_chars_ban3613}, 
    {0x9B85, 0x9B88, big5_chars_ban3614}, 
    {0x9B90, 0x9B93, big5_chars_ban3615}, 
    {0x9B95, 0x9B95, big5_chars_ban3616}, 
    {0x9B9A, 0x9B9B, big5_chars_ban3617}, 
    {0x9B9E, 0x9B9E, big5_chars_ban3618}, 
    {0x9BA0, 0x9BA2, big5_chars_ban3619}, 
    {0x9BA4, 0x9BA6, big5_chars_ban3620}, 
    {0x9BA8, 0x9BA8, big5_chars_ban3621}, 
    {0x9BAA, 0x9BAB, big5_chars_ban3622}, 
    {0x9BAD, 0x9BAF, big5_chars_ban3623}, 
    {0x9BB5, 0x9BB6, big5_chars_ban3624}, 
    {0x9BB8, 0x9BB9, big5_chars_ban3625}, 
    {0x9BBD, 0x9BBD, big5_chars_ban3626}, 
    {0x9BBF, 0x9BC1, big5_chars_ban3627}, 
    {0x9BC3, 0x9BC4, big5_chars_ban3628}, 
    {0x9BC6, 0x9BCA, big5_chars_ban3629}, 
    {0x9BD3, 0x9BD7, big5_chars_ban3630}, 
    {0x9BD9, 0x9BDC, big5_chars_ban3631}, 
    {0x9BDE, 0x9BDE, big5_chars_ban3632}, 
    {0x9BE0, 0x9BE2, big5_chars_ban3633}, 
    {0x9BE4, 0x9BE8, big5_chars_ban3634}, 
    {0x9BEA, 0x9BEC, big5_chars_ban3635}, 
    {0x9BF0, 0x9BF0, big5_chars_ban3636}, 
    {0x9BF7, 0x9BF8, big5_chars_ban3637}, 
    {0x9BFD, 0x9BFD, big5_chars_ban3638}, 
    {0x9C05, 0x9C09, big5_chars_ban3639}, 
    {0x9C0B, 0x9C0B, big5_chars_ban3640}, 
    {0x9C0D, 0x9C0E, big5_chars_ban3641}, 
    {0x9C12, 0x9C14, big5_chars_ban3642}, 
    {0x9C17, 0x9C17, big5_chars_ban3643}, 
    {0x9C1C, 0x9C1D, big5_chars_ban3644}, 
    {0x9C21, 0x9C21, big5_chars_ban3645}, 
    {0x9C23, 0x9C25, big5_chars_ban3646}, 
    {0x9C28, 0x9C29, big5_chars_ban3647}, 
    {0x9C2B, 0x9C2D, big5_chars_ban3648}, 
    {0x9C31, 0x9C34, big5_chars_ban3649}, 
    {0x9C36, 0x9C37, big5_chars_ban3650}, 
    {0x9C39, 0x9C39, big5_chars_ban3651}, 
    {0x9C3B, 0x9C41, big5_chars_ban3652}, 
    {0x9C44, 0x9C44, big5_chars_ban3653}, 
    {0x9C46, 0x9C46, big5_chars_ban3654}, 
    {0x9C48, 0x9C4E, big5_chars_ban3655}, 
    {0x9C50, 0x9C50, big5_chars_ban3656}, 
    {0x9C52, 0x9C52, big5_chars_ban3657}, 
    {0x9C54, 0x9C59, big5_chars_ban3658}, 
    {0x9C5E, 0x9C60, big5_chars_ban3659}, 
    {0x9C62, 0x9C63, big5_chars_ban3660}, 
    {0x9C66, 0x9C68, big5_chars_ban3661}, 
    {0x9C6D, 0x9C6E, big5_chars_ban3662}, 
    {0x9C71, 0x9C71, big5_chars_ban3663}, 
    {0x9C73, 0x9C75, big5_chars_ban3664}, 
    {0x9C77, 0x9C7A, big5_chars_ban3665}, 
    {0x9CE5, 0x9CE7, big5_chars_ban3666}, 
    {0x9CE9, 0x9CEA, big5_chars_ban3667}, 
    {0x9CED, 0x9CED, big5_chars_ban3668}, 
    {0x9CF1, 0x9CF7, big5_chars_ban3669}, 
    {0x9CF9, 0x9CFD, big5_chars_ban3670}, 
    {0x9CFF, 0x9D00, big5_chars_ban3671}, 
    {0x9D03, 0x9D09, big5_chars_ban3672}, 
    {0x9D10, 0x9D10, big5_chars_ban3673}, 
    {0x9D12, 0x9D12, big5_chars_ban3674}, 
    {0x9D14, 0x9D15, big5_chars_ban3675}, 
    {0x9D17, 0x9D19, big5_chars_ban3676}, 
    {0x9D1B, 0x9D1B, big5_chars_ban3677}, 
    {0x9D1D, 0x9D20, big5_chars_ban3678}, 
    {0x9D22, 0x9D23, big5_chars_ban3679}, 
    {0x9D25, 0x9D26, big5_chars_ban3680}, 
    {0x9D28, 0x9D29, big5_chars_ban3681}, 
    {0x9D2D, 0x9D31, big5_chars_ban3682}, 
    {0x9D33, 0x9D33, big5_chars_ban3683}, 
    {0x9D36, 0x9D38, big5_chars_ban3684}, 
    {0x9D3B, 0x9D3B, big5_chars_ban3685}, 
    {0x9D3D, 0x9D43, big5_chars_ban3686}, 
    {0x9D45, 0x9D45, big5_chars_ban3687}, 
    {0x9D4A, 0x9D4C, big5_chars_ban3688}, 
    {0x9D4F, 0x9D4F, big5_chars_ban3689}, 
    {0x9D51, 0x9D54, big5_chars_ban3690}, 
    {0x9D56, 0x9D5D, big5_chars_ban3691}, 
    {0x9D5F, 0x9D61, big5_chars_ban3692}, 
    {0x9D67, 0x9D6C, big5_chars_ban3693}, 
    {0x9D6F, 0x9D75, big5_chars_ban3694}, 
    {0x9D77, 0x9D79, big5_chars_ban3695}, 
    {0x9D7B, 0x9D7B, big5_chars_ban3696}, 
    {0x9D7D, 0x9D7D, big5_chars_ban3697}, 
    {0x9D7F, 0x9D82, big5_chars_ban3698}, 
    {0x9D84, 0x9D8C, big5_chars_ban3699}, 
    {0x9D90, 0x9D90, big5_chars_ban3700}, 
    {0x9D92, 0x9D92, big5_chars_ban3701}, 
    {0x9D94, 0x9D94, big5_chars_ban3702}, 
    {0x9D96, 0x9DA4, big5_chars_ban3703}, 
    {0x9DA6, 0x9DAA, big5_chars_ban3704}, 
    {0x9DAC, 0x9DAD, big5_chars_ban3705}, 
    {0x9DAF, 0x9DAF, big5_chars_ban3706}, 
    {0x9DB1, 0x9DBC, big5_chars_ban3707}, 
    {0x9DBE, 0x9DBF, big5_chars_ban3708}, 
    {0x9DC1, 0x9DC3, big5_chars_ban3709}, 
    {0x9DC5, 0x9DC5, big5_chars_ban3710}, 
    {0x9DC7, 0x9DC8, big5_chars_ban3711}, 
    {0x9DCA, 0x9DD3, big5_chars_ban3712}, 
    {0x9DD5, 0x9DDF, big5_chars_ban3713}, 
    {0x9DE1, 0x9DE6, big5_chars_ban3714}, 
    {0x9DE8, 0x9DE9, big5_chars_ban3715}, 
    {0x9DEB, 0x9DF0, big5_chars_ban3716}, 
    {0x9DF2, 0x9DFB, big5_chars_ban3717}, 
    {0x9DFD, 0x9E07, big5_chars_ban3718}, 
    {0x9E09, 0x9E09, big5_chars_ban3719}, 
    {0x9E0B, 0x9E0B, big5_chars_ban3720}, 
    {0x9E0D, 0x9E0D, big5_chars_ban3721}, 
    {0x9E0F, 0x9E15, big5_chars_ban3722}, 
    {0x9E17, 0x9E17, big5_chars_ban3723}, 
    {0x9E19, 0x9E1B, big5_chars_ban3724}, 
    {0x9E1D, 0x9E1E, big5_chars_ban3725}, 
    {0x9E75, 0x9E75, big5_chars_ban3726}, 
    {0x9E79, 0x9E7A, big5_chars_ban3727}, 
    {0x9E7C, 0x9E7D, big5_chars_ban3728}, 
    {0x9E7F, 0x9E80, big5_chars_ban3729}, 
    {0x9E82, 0x9E83, big5_chars_ban3730}, 
    {0x9E86, 0x9E8E, big5_chars_ban3731}, 
    {0x9E91, 0x9E94, big5_chars_ban3732}, 
    {0x9E97, 0x9E97, big5_chars_ban3733}, 
    {0x9E99, 0x9E9D, big5_chars_ban3734}, 
    {0x9E9F, 0x9EA1, big5_chars_ban3735}, 
    {0x9EA4, 0x9EA5, big5_chars_ban3736}, 
    {0x9EA7, 0x9EA7, big5_chars_ban3737}, 
    {0x9EA9, 0x9EA9, big5_chars_ban3738}, 
    {0x9EAD, 0x9EAE, big5_chars_ban3739}, 
    {0x9EB0, 0x9EB0, big5_chars_ban3740}, 
    {0x9EB4, 0x9EB7, big5_chars_ban3741}, 
    {0x9EBB, 0x9EBC, big5_chars_ban3742}, 
    {0x9EBE, 0x9EBE, big5_chars_ban3743}, 
    {0x9EC0, 0x9EC0, big5_chars_ban3744}, 
    {0x9EC2, 0x9EC3, big5_chars_ban3745}, 
    {0x9EC8, 0x9EC8, big5_chars_ban3746}, 
    {0x9ECC, 0x9ED1, big5_chars_ban3747}, 
    {0x9ED3, 0x9ED6, big5_chars_ban3748}, 
    {0x9ED8, 0x9ED8, big5_chars_ban3749}, 
    {0x9EDA, 0x9EE0, big5_chars_ban3750}, 
    {0x9EE4, 0x9EE8, big5_chars_ban3751}, 
    {0x9EEB, 0x9EEB, big5_chars_ban3752}, 
    {0x9EED, 0x9EF0, big5_chars_ban3753}, 
    {0x9EF2, 0x9EF7, big5_chars_ban3754}, 
    {0x9EF9, 0x9EFD, big5_chars_ban3755}, 
    {0x9EFF, 0x9F01, big5_chars_ban3756}, 
    {0x9F06, 0x9F07, big5_chars_ban3757}, 
    {0x9F09, 0x9F0A, big5_chars_ban3758}, 
    {0x9F0E, 0x9F10, big5_chars_ban3759}, 
    {0x9F12, 0x9F13, big5_chars_ban3760}, 
    {0x9F15, 0x9F16, big5_chars_ban3761}, 
    {0x9F18, 0x9F1C, big5_chars_ban3762}, 
    {0x9F1E, 0x9F1E, big5_chars_ban3763}, 
    {0x9F20, 0x9F20, big5_chars_ban3764}, 
    {0x9F22, 0x9F25, big5_chars_ban3765}, 
    {0x9F28, 0x9F38, big5_chars_ban3766}, 
    {0x9F3B, 0x9F3B, big5_chars_ban3767}, 
    {0x9F3D, 0x9F3E, big5_chars_ban3768}, 
    {0x9F40, 0x9F43, big5_chars_ban3769}, 
    {0x9F46, 0x9F4F, big5_chars_ban3770}, 
    {0x9F52, 0x9F52, big5_chars_ban3771}, 
    {0x9F54, 0x9F59, big5_chars_ban3772}, 
    {0x9F5B, 0x9F61, big5_chars_ban3773}, 
    {0x9F63, 0x9F67, big5_chars_ban3774}, 
    {0x9F6A, 0x9F6C, big5_chars_ban3775}, 
    {0x9F6E, 0x9F72, big5_chars_ban3776}, 
    {0x9F74, 0x9F7B, big5_chars_ban3777}, 
    {0x9F7E, 0x9F7E, big5_chars_ban3778}, 
    {0x9F8D, 0x9F8D, big5_chars_ban3779}, 
    {0x9F90, 0x9F92, big5_chars_ban3780}, 
    {0x9F94, 0x9F95, big5_chars_ban3781}, 
    {0x9F98, 0x9F98, big5_chars_ban3782}, 
    {0x9F9C, 0x9F9C, big5_chars_ban3783}, 
    {0x9FA0, 0x9FA0, big5_chars_ban3784}, 
    {0x9FA2, 0x9FA2, big5_chars_ban3785}, 
    {0x9FA4, 0x9FA4, big5_chars_ban3786}, 
    {0xFA0C, 0xFA0D, big5_chars_ban3787}, 
    {0xFE30, 0xFE31, big5_chars_ban3788}, 
    {0xFE33, 0xFE44, big5_chars_ban3789}, 
    {0xFE49, 0xFE52, big5_chars_ban3790}, 
    {0xFE54, 0xFE57, big5_chars_ban3791}, 
    {0xFE59, 0xFE66, big5_chars_ban3792}, 
    {0xFE68, 0xFE6B, big5_chars_ban3793}, 
    {0xFF01, 0xFF01, big5_chars_ban3794}, 
    {0xFF03, 0xFF06, big5_chars_ban3795}, 
    {0xFF08, 0xFF3A, big5_chars_ban3796}, 
    {0xFF3C, 0xFF3C, big5_chars_ban3797}, 
    {0xFF3F, 0xFF3F, big5_chars_ban3798}, 
    {0xFF41, 0xFF5E, big5_chars_ban3799}, 
    {0xFFE0, 0xFFE1, big5_chars_ban3800}, 
    {0xFFE3, 0xFFE3, big5_chars_ban3801}, 
    {0xFFE5, 0xFFE5, big5_chars_ban3802}, 
};
#define NR_BYTES_PER_CHAR 2

/* using binary search */
const unsigned char* __mg_map_uc16_to_big5 (unsigned short uc16)
{
    int low, high, mid;

    if (uc16 < uc16_min || uc16 > uc16_max)
        return NULL;

    low = 0;
    high = sizeof(uc16_bans)/sizeof(uc16_bans[0]) - 1;

    while (low <= high) {
        unsigned short start, end;

        mid = (low + high) / 2;

        start = uc16_bans [mid].start;
        end = uc16_bans [mid].end;

        if (uc16 >= start && uc16 <= end) {
                return uc16_bans [mid].big5_chars + ((uc16 - start) * NR_BYTES_PER_CHAR);
        }
        else if (uc16 < start) {
            high = mid - 1;
        }
        else {
            low = mid + 1;
        }
    }

    return NULL;
}

#endif /* _MGCHARSET_UNICODE */

#endif /* _MGCHARSET_BIG5 */

